@@ -1,35 +1,23 @@
 
 /*
- * config.c - master MH configuration file
+ * config.c -- master nmh configuration file
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../config.h"
 #include "../h/mh.h"
 
 #ifdef MHRC
 # include <pwd.h>
 #endif
 
-#include <stdio.h>
-
 #define nmhbindir(file) NMHBINDIR#file
 #define nmhetcdir(file) NMHETCDIR#file
 #define nmhlibdir(file) NMHLIBDIR#file
 
-#ifndef	__STDC__
-# ifdef	MHRC
-#  ifdef SYS5
-struct passwd *getpwnam();
-#  endif /* SYS5 */
-# endif /* MHRC */
-#endif
-
 static char lpath[BUFSIZ];
 
+
 char *
 libpath (char *file)
 {
@@ -49,20 +37,20 @@ libpath (char *file)
 
 #ifdef MHRC
 	case '~': 
-	    if (cp = strchr(pp = file + 1, '/'))
+	    if ((cp = strchr(pp = file + 1, '/')))
 		*cp++ = '\0';
 	    if (*pp == '\0')
 		pp = mypath;
 	    else
-		if (pw = getpwnam (pp))
-		    pp = pw -> pw_dir;
+		if ((pw = getpwnam (pp)))
+		    pp = pw->pw_dir;
 		else {
 		    if (cp)
 			*--cp = '/';
 		    goto try_it;
 		}
 
-	    (void) sprintf (lpath, "%s/%s", pp, cp ? cp : "");
+	    sprintf (lpath, "%s/%s", pp, cp ? cp : "");
 	    if (cp)
 		*--cp = '/';
 
@@ -84,13 +72,13 @@ libpath (char *file)
  */
 
 struct swit anoyes[] = {
-    "no", 0,
-    "yes", 0,
-    NULL, 0
+    { "no", 0 },
+    { "yes", 0 },
+    { NULL, 0 }
 };
 
 /* 
- * MH constants
+ * nmh constants
  */
 
 char   *components = "components";
@@ -114,32 +102,30 @@ char   *usequence = "Unseen-Sequence";
 char   *mhlibdir = NMHLIBDIR;
 
 /* 
- * MH not-so constants
+ * nmh not-so constants
  */
 
-char   *context = "context";
+char *context = "context";
 
 #ifndef	NOMHSEQ
-char   *mh_seq = ".mh_sequences";
+char *mh_seq = ".mh_sequences";
 #else
-char   *mh_seq = NULL;
+char *mh_seq = NULL;
 #endif
 
 /* 
- * MH globals
+ * nmh globals
  */
 
-char    ctxflags;		/* status of user's context */
-
-char   *invo_name;		/* pgm invocation name */
-char   *mypath;			/* user's $HOME */
-char   *defpath;		/* pathname of user's profile */
-char   *ctxpath;		/* pathname of user's context */
-
-struct node *m_defs;		/* profile/context structure */
+char ctxflags;		/* status of user's context   */
+char *invo_name;	/* command invocation name    */
+char *mypath;		/* user's $HOME               */
+char *defpath;		/* pathname of user's profile */
+char *ctxpath;		/* pathname of user's context */
+struct node *m_defs;	/* profile/context structure  */
 
 /* 
- * MH processes
+ * nmh processes
  */
 
 /*
@@ -162,8 +148,8 @@ char *fileproc = nmhbindir (/refile);
 char *incproc = nmhbindir (/inc);
 
 /*
- * When a user runs an MH program for the first time, this program
- * is called to create his MH profile, and mail directory.
+ * When a user runs an nmh program for the first time, this program
+ * is called to create his nmh profile, and mail directory.
  */
 
 char *installproc = nmhlibdir (/install-mh);
@@ -194,8 +180,8 @@ char *moreproc = DEFAULT_PAGER;
 char *mhlproc = nmhlibdir (/mhl);
 
 /* 
- * This is the super handy BBoard reading program, which is really just the MH
- * shell program
+ * This is the super handy BBoard reading program, which is
+ * really just the nmh shell program.
  */
 
 char *mshproc = nmhbindir (/msh);
@@ -246,7 +232,7 @@ char *sendproc = nmhbindir (/send);
 char *showproc = DEFAULT_PAGER;
 
 /* 
- * This program is called under stand-alone MH to deliver a message to
+ * This program is called under stand-alone nmh to deliver a message to
  * a local user.  Under other MTS's it can be used to emulate a
  * MMDF-II .maildelivery mechanism.
  */
@@ -281,7 +267,7 @@ char *whomproc = nmhbindir (/whom);
 char *sysed = DEFAULT_EDITOR;
 
 /* 
- * This is the Global MH alias file.  It is somewhat obsolete, since
+ * This is the global nmh alias file.  It is somewhat obsolete, since
  * global aliases should be handled by the Mail Transport Agent (MTA).
  */
 
