@@ -1,8 +1,8 @@
 
 /*
- * $Id$
- *
  * nmh.h -- system configuration header file
+ *
+ * $Id$
  */
 
 #include "../config.h"
@@ -37,6 +37,8 @@
 # include <stdlib.h>
 #endif
 
+#include <stdarg.h>
+
 #if STDC_HEADERS || HAVE_STRING_H
 # include <string.h>
 /* An ANSI string.h and pre-ANSI memory.h might conflict.  */
@@ -52,6 +54,10 @@
 # include <sys/param.h>
 #endif
 
+#ifdef LOCALE
+# include <locale.h>
+#endif
+
 #include <signal.h>
  
 #define bcmp(b1,b2,length)      memcmp(b1, b2, length)
@@ -59,5 +65,3 @@
 #define bcpy(b1,b2,length)      memcmp (b1, b2, length)
 #define bzero(b,length)         memset (b, 0, length)
 
-#include "prototypes.h"
-
