@@ -1,10 +1,10 @@
 
 /*
  * scansbr.h -- definitions for scan()
+ *
+ * $Id$
  */
 
-/* $Id$ */
-
 extern char *scanl;
 
 #define	SCNENC	2		/* message just fine, but encrypted(!!) */
@@ -14,21 +14,25 @@ extern char *scanl;
 #define	SCNNUM	(-2)		/* number out of range */
 #define	SCNFAT	(-3)		/* fatal error */
 
+/*
+ * default format for scan
+ */
+
 #ifndef	UK
 #define	FORMAT	\
 "%4(msg)%<(cur)+%| %>%<{replied}-%?{encrypted}E%| %>\
 %02(mon{date})/%02(mday{date})%<{date} %|*%>\
 %<(mymbox{from})%<{to}To:%14(friendly{to})%>%>%<(zero)%17(friendly{from})%>  \
 %{subject}%<{body}<<%{body}>>%>\n"
-#else /* UK */
+#else
 #define	FORMAT	\
 "%4(msg)%<(cur)+%| %>%<{replied}-%?{encrypted}E%| %>\
 %02(mday{date})/%02(mon{date})%<{date} %|*%>\
 %<(mymbox{from})%<{to}To:%14(friendly{to})%>%>%<(zero)%17(friendly{from})%>  \
 %{subject}%<{body}<<%{body}>>%>\n"
-#endif /* UK */
+#endif
 
-#define	WIDTH	78
+#define	WIDTH  78
 
 /*
  * prototypes
