@@ -1,14 +1,21 @@
 
 /*
  * signals.h -- header file for nmh signal interface
+ *
+ * $Id$
  */
 
 #include "../config.h"
 
+/*
+ * The type for a signal handler
+ */
+typedef RETSIGTYPE (*SIGNAL_HANDLER)(int);
+
 /*
  * If not a POSIX machine, then we create our
  * own POSIX style signal sets functions. This
- * currently assumes you have 32 signals, which
+ * currently assumes you have 31 signals, which
  * should be true on most pure BSD machines.
  */
 #ifndef POSIX_SIGNALS
@@ -18,3 +25,8 @@
 # define sigdelset(s,n)    (*(s) &= ~(1 << ((n) - 1)), 0)
 # define sigismember(s,n)  ((*(s) & (1 << ((n) - 1))) != 0)
 #endif
+
+/*
+ * prototypes
+ */
+int SIGPROCMASK (int, const sigset_t *, sigset_t *);
