@@ -1,11 +1,9 @@
 
-/* hosts.c - find out the official name of a host */
-
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-/* LINTLIBRARY */
+/*
+ * hosts.c -- find out the official name of a host
+ *
+ * $Id$
+ */
 
 #undef	NETWORK
 
