@@ -1,12 +1,10 @@
 
 /*
  * hosts.c -- find out the official name of a host
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 /*
  * In the SendMail world, we really don't know what the valid
  * hosts are.  We could poke around in the sendmail.cf file, but
@@ -14,37 +12,32 @@ static char ident[] = "$Id$";
  * everything is a valid host, and let SendMail worry about it.
  */
 
-#include "../../h/nmh.h"
-#include <stdio.h>
+#include "../../h/mh.h"
 #include "../../zotnet/mts/mts.h"
-#include <ctype.h>
 
-#if defined(BSD42) || defined(SOCKETS)
+#ifdef SOCKETS
 # include <netdb.h>
 #endif
 
-#define	NOTOK (-1)
-
 static struct host {
-    char   *h_name;
-    char  **h_aliases;
-    struct host   *h_next;
+    char *h_name;
+    char **h_aliases;
+    struct host *h_next;
 } hosts;
 
 
 /*
- * prototypes
+ * static prototypes
  */
 static int init_hs(void);
-char *getcpy();
 
 
 char *
 OfficialName (char *name)
 {
-    char  *p, *q, site[BUFSIZ];
+    char *p, *q, site[BUFSIZ];
 
-#if defined(BSD42) || defined(SOCKETS)
+#ifdef SOCKETS
     struct hostent *hp;
 #endif
 
@@ -73,19 +66,19 @@ OfficialName (char *name)
     sethostent (1);
 #endif
     if (hp = gethostbyname (q)) {
-	strcpy (buffer, hp -> h_name);
+	strcpy (buffer, hp->h_name);
 	return buffer;
     }
 #endif	/* BSD42 or SOCKETS */
 
     if (hosts.h_name || init_hs ())
-	for (h = hosts.h_next; h; h = h -> h_next)
-	    if (uleq (h -> h_name, q))
-		return h -> h_name;
+	for (h = hosts.h_next; h; h = h->h_next)
+	    if (uleq (h->h_name, q))
+		return h->h_name;
 	    else
-		for (r = h -> h_aliases; *r; r++)
+		for (r = h->h_aliases; *r; r++)
 		    if (uleq (*r, q))
-			return h -> h_name;
+			return h->h_name;
 
     strcpy (buffer, site);
     return buffer;
@@ -143,10 +136,10 @@ init_hs (void)
 
 	*q = 0;
 
-	h -> h_next = (struct host *) calloc (1, sizeof *h);
-	h = h -> h_next;
-	h -> h_name = getcpy (dp);
-	r = h -> h_aliases =
+	h->h_next = (struct host *) calloc (1, sizeof *h);
+	h = h->h_next;
+	h->h_name = getcpy (dp);
+	r = h->h_aliases =
 		(char **) calloc ((unsigned) (q - aliases + 1), sizeof *q);
 	for (q = aliases; *q; q++)
 	    *r++ = getcpy (*q);
