@@ -1,11 +1,14 @@
 
 /*
- * smail.c -- MH interface to SendMail/SMTP
+ * smail.c -- nmh interface to SendMail/SMTP
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif
+#include "../../h/mh.h"
+#include "smail.h"
+#include "../../zotnet/mts/mts.h"
+#include <signal.h>
 
 /*
  * This module implements an interface to SendMail very similar
@@ -38,33 +41,15 @@ static char ident[] = "$Id$";
 # endif
 #endif
 
-/* HP-UX has this capability. It also handles (some) signals. */
-#ifdef hpux	
-# define BSD42 
-#endif /* hpux */
-
 #ifdef SMTP
 # undef	SENDMAIL
 #endif	/* SMTP */
 
-#include "../../h/nmh.h"
-#include <stdio.h>
-#include "smail.h"
-#include "../../zotnet/mts/mts.h"
-#include <ctype.h>
-#include <signal.h>
-
-#define	NOTOK	(-1)
-#define	OK	0
-#define	DONE	1
-
 #define	TRUE	1
 #define	FALSE	0
 
 #define	NBITS ((sizeof (int)) * 8)
 
-#define	min(a,b) ((a) < (b) ? (a) : (b))
-
 /*
  * these codes must all be different!
  */
@@ -79,25 +64,23 @@ static char ident[] = "$Id$";
 #define	SM_QUIT	 30
 #define	SM_CLOS	 10
 
-static RETSIGTYPE alrmser();
-
-static int  sm_addrs = 0;
-static int  sm_alarmed = 0;
+static int sm_addrs = 0;
+static int sm_alarmed = 0;
 
 #ifndef	SMTP
-static int  sm_child = NOTOK;
+static int sm_child = NOTOK;
 #endif	/* not SMTP */
 
-static int  sm_debug = 0;
-static int  sm_nl = TRUE;
-static int  sm_verbose = 0;
+static int sm_debug = 0;
+static int sm_nl = TRUE;
+static int sm_verbose = 0;
 
-static  FILE * sm_rfp = NULL;
-static  FILE * sm_wfp = NULL;
+static FILE *sm_rfp = NULL;
+static FILE *sm_wfp = NULL;
 
-#ifdef	MPOP
-static	int  sm_ispool = 0;
-static	char sm_tmpfil[BUFSIZ];
+#ifdef MPOP
+static int sm_ispool = 0;
+static char sm_tmpfil[BUFSIZ];
 #endif /* MPOP */
 
 static char *sm_noreply = "No reply text given";
@@ -105,33 +88,42 @@ static char *sm_moreply = "; ";
 
 struct smtp sm_reply;		/* global... */
 
-
-void	discard ();
-char   *r1bindex ();
-
-static int	rclient(), sm_ierror(), smtalk(), sm_wrecord(), sm_wstream();
-static int	sm_werror(), smhear(), sm_rrecord(), sm_rerror();
-
-#ifdef	MPOP
-extern	int	errno;
-#ifndef	BSD44
-extern	int	sys_nerr;
-extern	char   *sys_errlist[];
+#ifdef MPOP
+extern int errno;
 #endif
-extern	char  **brkstring (), **copyip (), *getcpy ();
-#endif
-
 
 static int doingEHLO;
 
 #define	MAXEHLO	10
-char   *EHLOkeys[MAXEHLO + 1];
+char *EHLOkeys[MAXEHLO + 1];
+
+/*
+ * static prototypes
+ */
+static int rclient (char *, char *, char *);
+static int sm_ierror (char *fmt, ...);
+static int smtalk (int time, char *fmt, ...);
+static int sm_wrecord (char *, int);
+static int sm_wstream (char *, int);
+static int sm_werror (void);
+static int smhear (void);
+static int sm_rrecord (char *, int *);
+static int sm_rerror (void);
+static RETSIGTYPE alrmser (int);
+static char *EHLOset (char *);
+
+#ifdef MPOP
+/*
+ * smail.c's own static copy of several nmh library subroutines
+ */
+static char **smail_brkstring (char *, char *, char *);
+static int smail_brkany (char, char *);
+char **smail_copyip (char **, char **);
+#endif
 
-char   *EHLOset ();
 
 #ifndef	SMTP
 
-
 int
 sm_init (char *client, char *server, int watch, int verbose,
          int debug, int onex, int queued)
@@ -141,11 +133,11 @@ sm_init (char *client, char *server, int watch, int verbose,
     char *vec[15];
 
     if (watch)
-#ifndef	SUN40
+# ifndef SUN40
 	verbose = TRUE;
-#else	/* to show the transaction, -watch must imply -snoop */
+# else	/* to show the transaction, -watch must imply -snoop */
 	debug = verbose = TRUE;
-#endif
+# endif
     sm_verbose = verbose;
     sm_debug = debug;
     if (sm_rfp != NULL && sm_wfp != NULL)
@@ -153,10 +145,10 @@ sm_init (char *client, char *server, int watch, int verbose,
 
     if (client == NULL || *client == '\0')
 	client = clientname;
-#ifdef ZMAILER
+# ifdef ZMAILER
     if (client == NULL || *client == '\0')
 	client = "localhost";
-#endif
+# endif
 
     if (pipe (pdi) == NOTOK)
 	return sm_ierror ("no pipes");
@@ -189,15 +181,15 @@ sm_init (char *client, char *server, int watch, int verbose,
 	    vecp = 0;
 	    vec[vecp++] = r1bindex (sendmail, '/');
 	    vec[vecp++] = "-bs";
-#ifndef ZMAILER
+# ifndef ZMAILER
 	    vec[vecp++] = watch ? "-odi" : queued ? "-odq" : "-odb";
 	    vec[vecp++] = "-oem";
 	    vec[vecp++] = "-om";
-#ifndef	RAND
+#  ifndef RAND
 	    if (verbose)
 		vec[vecp++] = "-ov";
-#endif	/* not RAND */
-#endif	/* not ZMAILER */
+#  endif /* not RAND */
+# endif /* not ZMAILER */
 	    vec[vecp++] = NULL;
 
 	    setgid (getegid ());
@@ -251,17 +243,17 @@ sm_init (char *client, char *server, int watch, int verbose,
 		}
 	    }
 
-#ifndef	ZMAILER
+# ifndef ZMAILER
 	    if (onex)
 		smtalk (SM_HELO, "ONEX");
-#endif
+# endif
 	    if (watch)
 		smtalk (SM_HELO, "VERB on");
 
 	    return RP_OK;
     }
 }
-#else	/* SMTP */
+#else /* SMTP */
 
 
 int
@@ -271,35 +263,35 @@ sm_init (char *client, char *server, int watch, int verbose,
     register int result, sd1, sd2;
 
     if (watch)
-#if !defined(SUN40) || defined(MMDFII)
+# if !defined(SUN40) || defined(MMDFII)
 	verbose = TRUE;
-#else	/* to show the transaction, -watch must imply -snoop */
+# else	/* to show the transaction, -watch must imply -snoop */
 	debug = verbose = TRUE;
-#endif
+# endif
     sm_verbose = verbose;
     sm_debug = debug;
-#ifdef	MPOP
+# ifdef	MPOP
     if (sm_ispool)
 	goto all_done;
-#endif
+# endif
     if (sm_rfp != NULL && sm_wfp != NULL)
 	goto send_options;
 
     if (client == NULL || *client == '\0')
 	client = clientname;
-#ifdef ZMAILER
+# ifdef ZMAILER
     if (client == NULL || *client == '\0')
 	client = "localhost";
-#else
-#if	!defined(SENDMTS) || defined(MMDFII) || defined(SVR4)
+# else
+#  if !defined(SENDMTS) || defined(MMDFII) || defined(SVR4)
     if (client == NULL || *client == 0)
 	client = LocalName ();
-#endif
-#endif	/* not ZMAILER */
+#  endif
+# endif	/* not ZMAILER */
 
     if ((sd1 = rclient (server, "tcp", "smtp")) == NOTOK)
 	return RP_BHST;
-#ifdef	MPOP
+# ifdef MPOP
     if (sm_ispool) {
 	if (sm_rfp) {
 	    alarm (SM_CLOS);
@@ -316,7 +308,7 @@ all_done: ;
 	sm_reply.text[sm_reply.length = 0] = NULL;
 	return (sm_reply.code = RP_OK);
     }
-#endif /* MPOP */
+# endif /* MPOP */
     if ((sd2 = dup (sd1)) == NOTOK) {
 	close (sd1);
 	return sm_ierror ("unable to dup");
@@ -375,28 +367,28 @@ send_options: ;
 }
 
 
-#ifdef	MPOP
-#define	MAXARGS	1000
-#endif /* MPOP */
+# ifdef MPOP
+#  define MAXARGS	1000
+# endif /* MPOP */
 
 static int
 rclient (char *server, char *protocol, char *service)
 {
     int sd;
     char response[BUFSIZ];
-#ifdef	MPOP
+# ifdef MPOP
     char *cp;
-#endif /* MPOP */
+# endif /* MPOP */
 
     if ((sd = client (server, protocol, service, FALSE, response)) != NOTOK)
 	return sd;
 
-#ifdef	MPOP
+# ifdef MPOP
     if (!server && servers && (cp = strchr(servers, '/'))) {
 	register char  **ap;
 	char   *arguments[MAXARGS];
 
-	copyip (brkstring (cp = getcpy (servers), " ", "\n"), arguments);
+	smail_copyip (smail_brkstring (cp = getcpy (servers), " ", "\n"), arguments);
 
 	for (ap = arguments; *ap; ap++)
 	    if (**ap == '/') {
@@ -417,7 +409,7 @@ rclient (char *server, char *protocol, char *service)
 	if (sd != NOTOK)
 	    return sd;
     }
-#endif /* MPOP */
+# endif /* MPOP */
 
     sm_ierror ("%s", response);
     return NOTOK;
@@ -648,20 +640,19 @@ sm_end (int type)
 }
 
 
-#ifdef	MPOP
-#ifdef	SMTP
+#ifdef MPOP
+#ifdef SMTP
 #include <sys/types.h>
 #include <sys/stat.h>
 
-
 int
 sm_bulk (char *file)
 {
     int	cc, i, j, k, result;
     long pos;
     register char *dp;
-    char *bp, *cp,
-	 buffer[BUFSIZ], sender[BUFSIZ];
+    char *bp, *cp, s;
+    char buffer[BUFSIZ], sender[BUFSIZ];
     FILE *fp, *gp;
 
     gp = NULL;
@@ -669,8 +660,8 @@ sm_bulk (char *file)
     if ((fp = fopen (file, "r")) == NULL) {
 	sprintf (bp = sm_reply.text, "unable to read %s: ", file);
 	bp += strlen (bp);
-	if (errno > 0 && errno < sys_nerr)
-	    sprintf (bp, "%s", sys_errlist[errno]);
+	if ((s = strerror (errno)))
+	    strcpy (bp, s);
 	else
 	    sprintf (bp, "Error %d", errno);
 	sm_reply.length = strlen (sm_reply.text);
@@ -737,10 +728,10 @@ losing2: ;
 losing3: ;
 	    strcpy (bp = sm_reply.text, "error writing to server: ");
 	    bp += strlen (bp);
-	    if (errno > 0 && errno < sys_nerr)
-		sprintf (bp, "%s", sys_errlist[errno]);
+	    if ((s = strerror (errno)))
+		strcpy (bp, s);
 	    else
-		sprintf (bp, "Error %d", errno);
+		sprintf (bp, "unknown error %d", errno);
 	    sm_reply.length = strlen (sm_reply.text);
 	    goto losing2;
 	}
@@ -888,10 +879,10 @@ bad_data: ;
 		if (ferror (fp)) {
 		    sprintf (bp = sm_reply.text, "error reading %s: ", file);
 		    bp += strlen (bp);
-		    if (errno > 0 && errno < sys_nerr)
-			sprintf (bp, "%s", sys_errlist[errno]);
+		    if ((s = strerror (errno)))
+			strcpy (bp, s);
 		    else
-			sprintf (bp, "Error %d", errno);
+			sprintf (bp, "unknown error %d", errno);
 		    sm_reply.length = strlen (sm_reply.text);
 		    goto losing2;
 		}
@@ -989,17 +980,15 @@ no_dice: ;
 #endif /* MPOP */
 
 
-/* VARARGS */
-
 static int
-sm_ierror (fmt, a, b, c, d)
-char   *fmt,
-       *a,
-       *b,
-       *c,
-       *d;
+sm_ierror (char *fmt, ...)
 {
-    sprintf (sm_reply.text, fmt, a, b, c, d);
+    va_list ap;
+
+    va_start(ap, fmt);
+    vsprintf (sm_reply.text, fmt, ap);
+    va_end(ap);
+
     sm_reply.length = strlen (sm_reply.text);
     sm_reply.code = NOTOK;
 
@@ -1007,17 +996,18 @@ char   *fmt,
 }
 
 
-/* VARARGS2 */
-
 static int
-smtalk (time, fmt, a, b, c, d)
-register int     time;
-register char   *fmt;
+smtalk (int time, char *fmt, ...)
 {
-    register int    result;
-    char    buffer[BUFSIZ];
+    va_list ap;
+
+    register int result;
+    char buffer[BUFSIZ];
+
+    va_start(ap, fmt);
+    vsprintf (buffer, fmt, ap);
+    va_end(ap);
 
-    sprintf (buffer, fmt, a, b, c, d);
     if (sm_debug) {
 	printf ("=> %s\n", buffer);
 	fflush (stdout);
@@ -1043,10 +1033,10 @@ register char   *fmt;
 				    "error renaming %s to %s: ",
 				    sm_tmpfil, file);
 		    bp += strlen (bp);
-		    if (errno > 0 && errno < sys_nerr)
-			sprintf (bp, "%s", sys_errlist[errno]);
+		    if ((s = strerror (errno)))
+			strcpy (bp, s);
 		    else
-			sprintf (bp, "Error %d", errno);
+			sprintf (bp, "unknown error %d", errno);
 		    sm_reply.length = strlen (sm_reply.text);
 		    sm_reply.code = NOTOK;
 		    return RP_BHST;
@@ -1164,26 +1154,26 @@ sm_wstream (char *buffer, int len)
  * with the #ifdef MPOP in the middle.  Should the #ifdef MPOP be removed,
  * remove these #undefs.
  */
-#undef strlen
-#undef strcpy
+# undef strlen
+# undef strcpy
 #endif /* _AIX */
 
 static int
 sm_werror (void)
 {
     sm_reply.length =
-#ifdef	SMTP
+#ifdef SMTP
 	strlen (strcpy (sm_reply.text, sm_wfp == NULL ? "no socket opened"
 	    : sm_alarmed ? "write to socket timed out"
-#ifdef	MPOP
+# ifdef MPOP
 	    : sm_ispool ? "error writing to spool file"
-#endif
+# endif
 	    : "error writing to socket"));
-#else	/* !SMTP */
+#else /* !SMTP */
 	strlen (strcpy (sm_reply.text, sm_wfp == NULL ? "no pipe opened"
 	    : sm_alarmed ? "write to pipe timed out"
 	    : "error writing to pipe"));
-#endif	/* !SMTP */
+#endif /* !SMTP */
 
     return (sm_reply.code = NOTOK);
 }
@@ -1326,25 +1316,23 @@ static int
 sm_rerror (void)
 {
     sm_reply.length =
-#ifdef	SMTP
+#ifdef SMTP
 	strlen (strcpy (sm_reply.text, sm_rfp == NULL ? "no socket opened"
 	    : sm_alarmed ? "read from socket timed out"
 	    : feof (sm_rfp) ? "premature end-of-file on socket"
 	    : "error reading from socket"));
-#else	/* not SMTP */
+#else /* not SMTP */
 	strlen (strcpy (sm_reply.text, sm_rfp == NULL ? "no pipe opened"
 	    : sm_alarmed ? "read from pipe timed out"
 	    : feof (sm_rfp) ? "premature end-of-file on pipe"
 	    : "error reading from pipe"));
-#endif	/* not SMTP */
+#endif /* not SMTP */
 
     return (sm_reply.code = NOTOK);
 }
 
 
-/* ARGSUSED */
-
-static	RETSIGTYPE
+static RETSIGTYPE
 alrmser (int i)
 {
 #ifndef	BSD42
@@ -1410,13 +1398,12 @@ rp_string (int code)
 }
 
 
-#ifdef	MPOP
-#ifdef	SMTP
+#if defined(MPOP) && defined(SMTP)
+
 static char *broken[MAXARGS + 1];
 
-
 static char **
-brkstring (char *strg, char *brksep, char *brkterm)
+smail_brkstring (char *strg, char *brksep, char *brkterm)
 {
     register int bi;
     register char c, *sp;
@@ -1424,16 +1411,16 @@ brkstring (char *strg, char *brksep, char *brkterm)
     sp = strg;
 
     for (bi = 0; bi < MAXARGS; bi++) {
-	while (brkany (c = *sp, brksep))
+	while (smail_brkany (c = *sp, brksep))
 	    *sp++ = 0;
-	if (!c || brkany (c, brkterm)) {
+	if (!c || smail_brkany (c, brkterm)) {
 	    *sp = 0;
 	    broken[bi] = 0;
 	    return broken;
 	}
 
 	broken[bi] = sp;
-	while ((c = *++sp) && !brkany (c, brksep) && !brkany (c, brkterm))
+	while ((c = *++sp) && !smail_brkany (c, brksep) && !smail_brkany (c, brkterm))
 	    continue;
     }
     broken[MAXARGS] = 0;
@@ -1442,11 +1429,14 @@ brkstring (char *strg, char *brksep, char *brkterm)
 }
 
 
+/*
+ * returns 1 if chr in strg, 0 otherwise
+ */
 static int
-brkany (char chr, char *strg)
+smail_brkany (char chr, char *strg)
 {
     register char *sp;
-
+ 
     if (strg)
 	for (sp = strg; *sp; sp++)
 	    if (chr == *sp)
@@ -1454,21 +1444,23 @@ brkany (char chr, char *strg)
     return 0;
 }
 
-
-static char **
-copyip (char **p, char **q)
+/*
+ * copy a string array and return pointer to end
+ */
+char **
+smail_copyip (char **p, char **q)
 {
     while (*p)
 	*q++ = *p++;
     *q = 0;
-
+ 
     return q;
 }
-#endif
-#endif /* MPOP */
+
+#endif /* MPOP && SMTP */
 
 
-char *
+static char *
 EHLOset (char *s)
 {
     size_t len;
