@@ -1,10 +1,11 @@
 
 /*
  * add.c -- concatenate two strings in managed memory
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
 
 char *
 add (char *this, char *that)
