@@ -1,17 +1,15 @@
 
 /*
- * addrsbr.c - parse addresses 822-style
+ * addrsbr.c -- parse addresses 822-style
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif /* lint */
-
 #include "../h/mh.h"
 #include "../h/addrsbr.h"
 #include "../zotnet/mf/mf.h"
-#include <stdio.h>
-#ifdef	BERK
+
+#ifdef BERK
 #include <ctype.h>
 #endif /* BERK */
 
@@ -106,8 +104,7 @@ static char err[BUFSIZ];
 #endif /* not BERK */
 static char adr[BUFSIZ];
 
-
-char   *getusr ();
+char *getusr ();
 
 
 char   *getname (addrs)
@@ -297,41 +294,35 @@ register char   *addrs;
     if ((ap = getadrx (addrs ? addrs : "")) == NULL)
 	return NULL;
 
-    (void) strcpy (adr, ap -> text);
-    pers = ap -> pers;
-    mbox = ap -> mbox;
-    host = ap -> host;
-    route = ap -> path;
-    grp = ap -> grp;
-    ingrp = ap -> ingrp;
-    note = ap -> note;
-    if (ap -> err && *ap -> err)
-	(void) strcpy (err, ap -> err);
+    (void) strcpy (adr, ap->text);
+    pers = ap->pers;
+    mbox = ap->mbox;
+    host = ap->host;
+    route = ap->path;
+    grp = ap->grp;
+    ingrp = ap->ingrp;
+    note = ap->note;
+    if (ap->err && *ap->err)
+	(void) strcpy (err, ap->err);
 
     return adr;
 #endif /* not BERK */
 }
 
-/*  */
-
 #ifdef	BERK
 /* ARGSUSED */
 #endif /* BERK */
 
-struct mailname *getm (str, dfhost, dftype, wanthost, eresult)
-register char   *str,
-		*eresult;
-char   *dfhost;
-int     dftype,
-	wanthost;
+struct mailname *
+getm (char *str, char *dfhost, int dftype, int wanthost, char *eresult)
 {
 #ifndef	BERK
-    register char   *pp;
+    register char *pp;
 #ifndef	DUMB
-    register char   *dp;
+    register char *dp;
 #endif /* not DUMB */
 #ifdef	MF
-    char   *up = UucpChan ();
+    char *up = UucpChan ();
 #endif /* MF */
 #endif /* not BERK */
     register struct mailname *mp;
@@ -341,7 +332,7 @@ int     dftype,
 	    (void) strcpy (eresult, err);
 	else
 	    if (wanthost == AD_HOST)
-		admonish (NULLCP, "bad address '%s' - %s", str, err);
+		admonish (NULL, "bad address '%s' - %s", str, err);
 	return NULL;
     }
 #ifdef	BERK
@@ -355,7 +346,7 @@ int     dftype,
 	    (void) strcpy (eresult, "null address");
 	else
 	    if (wanthost == AD_HOST)
-		admonish (NULLCP, "null address '%s'", str);
+		admonish (NULL, "null address '%s'", str);
 	return NULL;
     }
 #ifndef	BERK
@@ -364,7 +355,7 @@ int     dftype,
 	    (void) strcpy (eresult, "no mailbox in address");
 	else
 	    if (wanthost == AD_HOST)
-		admonish (NULLCP, "no mailbox in address '%s'", str);
+		admonish (NULL, "no mailbox in address '%s'", str);
 	return NULL;
     }
 
@@ -380,33 +371,31 @@ int     dftype,
 	   (void) strcpy (eresult, "insufficient memory to represent address");
 	else
 	    if (wanthost == AD_HOST)
-		adios (NULLCP, "insufficient memory to represent address");
+		adios (NULL, "insufficient memory to represent address");
 	return NULL;
     }
 
-    mp -> m_next = NULL;
-    mp -> m_text = getcpy (str);
+    mp->m_next = NULL;
+    mp->m_text = getcpy (str);
 #ifdef	BERK
-    mp -> m_type = LOCALHOST;
-    mp -> m_mbox = getcpy (adr);
+    mp->m_type = LOCALHOST;
+    mp->m_mbox = getcpy (adr);
     if (!strchr(adr, '@') && !strchr(adr, '!'))
-	mp -> m_nohost = 1;
+	mp->m_nohost = 1;
 #else /* not BERK */
     if (pers)
-	mp -> m_pers = getcpy (pers);
+	mp->m_pers = getcpy (pers);
 
     if (mbox == NULL) {
-	mp -> m_type = BADHOST;
-	mp -> m_nohost = 1;
-	mp -> m_ingrp = ingrp;
-	mp -> m_gname = getcpy (grp);
+	mp->m_type = BADHOST;
+	mp->m_nohost = 1;
+	mp->m_ingrp = ingrp;
+	mp->m_gname = getcpy (grp);
 	if (note)
-	    mp -> m_note = getcpy (note);
+	    mp->m_note = getcpy (note);
 	return mp;
     }
 
-/*  */
-
     if (host) {
 #ifdef MF
 #ifdef	MMDFMTS
@@ -420,9 +409,9 @@ int     dftype,
 	if (up && (pp = strchr(host, '.')) 
 		&& uleq (up, pp + 1)) {/* uucpaddr@host.<uucp> */
 	    *pp = NULL;
-	    mp -> m_host = getcpy (host);
-	    mp -> m_mbox = getcpy (mbox);
-	    mp -> m_type = UUCPHOST;
+	    mp->m_host = getcpy (host);
+	    mp->m_mbox = getcpy (mbox);
+	    mp->m_type = UUCPHOST;
 	    goto got_host;
 	}
 #endif /* not MMDFMTS */
@@ -430,126 +419,121 @@ int     dftype,
 		&& uleq (up, host)) {/* uucpaddr@<uucp> [local] */
 	    if (pp = strchr(mbox, '!')) {
 		*pp++ = NULL;
-		mp -> m_host = getcpy (mbox);
-		mp -> m_mbox = getcpy (pp);
+		mp->m_host = getcpy (mbox);
+		mp->m_mbox = getcpy (pp);
 	    }
 	    else {
-		mp -> m_host = getcpy (SystemName ());
-		mp -> m_mbox = getcpy (mbox);
+		mp->m_host = getcpy (SystemName ());
+		mp->m_mbox = getcpy (mbox);
 	    }
-	    mp -> m_type = UUCPHOST;
+	    mp->m_type = UUCPHOST;
 	    goto got_host;
 	}
 #endif /* MF */
-	mp -> m_mbox = getcpy (mbox);
-	mp -> m_host = getcpy (host);
+	mp->m_mbox = getcpy (mbox);
+	mp->m_host = getcpy (host);
     }
     else {
-	if (pp = strchr(mbox, '!')) {
+	if ((pp = strchr(mbox, '!'))) {
 	    *pp++ = '\0';
-	    mp -> m_mbox = getcpy (pp);
-	    mp -> m_host = getcpy (mbox);
-	    mp -> m_type = UUCPHOST;
+	    mp->m_mbox = getcpy (pp);
+	    mp->m_host = getcpy (mbox);
+	    mp->m_type = UUCPHOST;
 	}
 	else {
-	    mp -> m_nohost = 1;
-	    mp -> m_mbox = getcpy (mbox);
+	    mp->m_nohost = 1;
+	    mp->m_mbox = getcpy (mbox);
 #ifdef	DUMB
 	    if (route == NULL && dftype == LOCALHOST) {
-		mp -> m_host = NULLCP;
-		mp -> m_type = dftype;
+		mp->m_host = NULL;
+		mp->m_type = dftype;
 	    }
 	    else
 #endif /* DUMB */
 	    {
-		mp -> m_host = route ? NULLCP : getcpy (dfhost);
-		mp -> m_type = route ? NETHOST : dftype;
+		mp->m_host = route ? NULL : getcpy (dfhost);
+		mp->m_type = route ? NETHOST : dftype;
 	    }
 	}
 	goto got_host;
     }
 
-/*  */
-
     if (wanthost == AD_NHST)
-	mp -> m_type = uleq (LocalName (), mp -> m_host)
+	mp->m_type = uleq (LocalName (), mp->m_host)
 	    ? LOCALHOST : NETHOST;
 #ifdef	DUMB
     else
-	mp -> m_type = uleq (LocalName (), mp -> m_host) ? LOCALHOST
+	mp->m_type = uleq (LocalName (), mp->m_host) ? LOCALHOST
 		: NETHOST;
 #else /* not DUMB */
     else
-	if (pp = OfficialName (mp -> m_host)) {
+	if (pp = OfficialName (mp->m_host)) {
     got_real_host: ;
-	    free (mp -> m_host);
-	    mp -> m_host = getcpy (pp);
-	    mp -> m_type = uleq (LocalName (), mp -> m_host) ? LOCALHOST
+	    free (mp->m_host);
+	    mp->m_host = getcpy (pp);
+	    mp->m_type = uleq (LocalName (), mp->m_host) ? LOCALHOST
 		    : NETHOST;
 	}
 	else {
-	    if (dp = strchr(mp -> m_host, '.')) {
+	    if (dp = strchr(mp->m_host, '.')) {
 		*dp = NULL;
-		if (pp = OfficialName (mp -> m_host))
+		if (pp = OfficialName (mp->m_host))
 		    goto got_real_host;
 		*dp = '.';
 	    }
-	    mp -> m_type = BADHOST;
+	    mp->m_type = BADHOST;
 	}
 #endif /* not DUMB */
 
 got_host: ;
     if (route)
-	mp -> m_path = getcpy (route);
-    mp -> m_ingrp = ingrp;
+	mp->m_path = getcpy (route);
+    mp->m_ingrp = ingrp;
     if (grp)
-	mp -> m_gname = getcpy (grp);
+	mp->m_gname = getcpy (grp);
     if (note)
-	mp -> m_note = getcpy (note);
+	mp->m_note = getcpy (note);
 #endif /* not BERK */
 
     return mp;
 }
 
-/*  */
 
-void	mnfree (mp)
-register struct mailname *mp;
+void
+mnfree (struct mailname *mp)
 {
     if (!mp)
 	return;
 
-    if (mp -> m_text)
-	free (mp -> m_text);
-    if (mp -> m_pers)
-	free (mp -> m_pers);
-    if (mp -> m_mbox)
-	free (mp -> m_mbox);
-    if (mp -> m_host)
-	free (mp -> m_host);
-    if (mp -> m_path)
-	free (mp -> m_path);
-    if (mp -> m_gname)
-	free (mp -> m_gname);
-    if (mp -> m_note)
-	free (mp -> m_note);
+    if (mp->m_text)
+	free (mp->m_text);
+    if (mp->m_pers)
+	free (mp->m_pers);
+    if (mp->m_mbox)
+	free (mp->m_mbox);
+    if (mp->m_host)
+	free (mp->m_host);
+    if (mp->m_path)
+	free (mp->m_path);
+    if (mp->m_gname)
+	free (mp->m_gname);
+    if (mp->m_note)
+	free (mp->m_note);
 #ifdef	MHMTS
-    if (mp -> m_aka)
-	free (mp -> m_aka);
+    if (mp->m_aka)
+	free (mp->m_aka);
 #endif /* MHMTS */
 
     free ((char *) mp);
 }
 
-/*  */
 
-char   *auxformat (mp, extras)
-register struct mailname   *mp;
-int	extras;
+char *
+auxformat (struct mailname *mp, int extras)
 {
 #ifndef	BERK
 #ifdef	MF
-    char   *up = UucpChan ();
+    char *up = UucpChan ();
 #endif /* MF */
     static char addr[BUFSIZ];
 #endif /* not BERK */
@@ -560,49 +544,49 @@ int	extras;
     if (mp->m_pers && !extras)
 	(void) sprintf (buffer, "%s <%s>", mp->m_pers, mp->m_mbox);
     else
-	(void) strcpy (buffer, mp -> m_text);
+	(void) strcpy (buffer, mp->m_text);
 #else /* not BERK */
 
 #ifdef	MF
-    if (up && mp -> m_type == UUCPHOST)
+    if (up && mp->m_type == UUCPHOST)
 #ifdef	MMDFMTS
-	(void) sprintf (addr, "%s!%s%%%s@%s", mp -> m_host, mp -> m_mbox,
+	(void) sprintf (addr, "%s!%s%%%s@%s", mp->m_host, mp->m_mbox,
 		up, LocalName ());
 #else /* not MMDFMTS */
-	(void) sprintf (addr, "%s@%s.%s", mp -> m_mbox, mp -> m_host, up);
+	(void) sprintf (addr, "%s@%s.%s", mp->m_mbox, mp->m_host, up);
 #endif /* not MMDFMTS */
     else 
 #endif /* MF */
 
 #ifdef	DUMB
-	if (mp -> m_nohost)
-	    (void) strcpy (addr, mp -> m_mbox ? mp -> m_mbox : "");
+	if (mp->m_nohost)
+	    (void) strcpy (addr, mp->m_mbox ? mp->m_mbox : "");
 	else
 #endif /* DUMB */
 
 #ifndef	BANG
-	if (mp -> m_type != UUCPHOST)
-	    (void) sprintf (addr, mp -> m_host ? "%s%s@%s" : "%s%s",
-		mp -> m_path ? mp -> m_path : "", mp -> m_mbox, mp -> m_host);
+	if (mp->m_type != UUCPHOST)
+	    (void) sprintf (addr, mp->m_host ? "%s%s@%s" : "%s%s",
+		mp->m_path ? mp->m_path : "", mp->m_mbox, mp->m_host);
 	else
 #endif /* not BANG */
-	    (void) sprintf (addr, "%s!%s", mp -> m_host, mp -> m_mbox);
+	    (void) sprintf (addr, "%s!%s", mp->m_host, mp->m_mbox);
 
     if (!extras)
 	return addr;
 
-    if (mp -> m_pers || mp -> m_path)
-	if (mp -> m_note)
+    if (mp->m_pers || mp->m_path)
+	if (mp->m_note)
 	    (void) sprintf (buffer, "%s %s <%s>",
-		    legal_person (mp -> m_pers ? mp -> m_pers : mp -> m_mbox),
-		    mp -> m_note, addr);
+		    legal_person (mp->m_pers ? mp->m_pers : mp->m_mbox),
+		    mp->m_note, addr);
 	else
 	    (void) sprintf (buffer, "%s <%s>",
-		    legal_person (mp -> m_pers ? mp -> m_pers : mp -> m_mbox),
+		    legal_person (mp->m_pers ? mp->m_pers : mp->m_mbox),
 		    addr);
     else
-	if (mp -> m_note)
-	    (void) sprintf (buffer, "%s %s", addr, mp -> m_note);
+	if (mp->m_note)
+	    (void) sprintf (buffer, "%s %s", addr, mp->m_note);
 	else
 	    (void) strcpy (buffer, addr);
 #endif /* not BERK */
@@ -610,17 +594,15 @@ int	extras;
     return buffer;
 }
 
-/*  */
 
-#if	defined(BERK) || (defined(DUMB) && !defined(MMDFMTS) && !defined(SMTP))
-#define	REALLYDUMB
+#if defined(BERK) || (defined(DUMB) && !defined(MMDFMTS) && !defined(SMTP))
+# define REALLYDUMB
 #else
-#undef	REALLYDUMB
+# undef REALLYDUMB
 #endif
 
-char   *adrsprintf (local, domain)
-char   *local,
-       *domain;
+char *
+adrsprintf (char *local, char *domain)
 {
     static char addr[BUFSIZ];
 
@@ -647,7 +629,6 @@ char   *local,
     return addr;
 }
 
-/*  */
 
 #define	W_NIL	0x0000
 #define	W_MBEG	0x0001
@@ -659,18 +640,17 @@ char   *local,
 #define	WBITS	"\020\01MBEG\02MEND\03HBEG\04HEND"
 
 
-int	ismymbox (np)
-register struct mailname *np;
+int
+ismymbox (struct mailname *np)
 {
-    int     oops;
-    register int    len,
-                    i;
-    register char  *cp;
+    int oops;
+    register int len, i;
+    register char *cp;
 #ifndef	BERK
-    register char  *pp;
-    char    buffer[BUFSIZ];
+    register char *pp;
+    char buffer[BUFSIZ];
 #endif /* not BERK */
-    register struct mailname   *mp;
+    register struct mailname *mp;
     static char *am = NULL;
     static struct mailname  mq={NULL};
 
@@ -683,51 +663,51 @@ register struct mailname *np;
 	else {
 	    mp = &mq;
 	    oops = 0;
-	    while (cp = getname (am))
-		if ((mp -> m_next = getm (cp, NULLCP, 0, AD_NAME, NULLCP))
+	    while ((cp = getname (am)))
+		if ((mp->m_next = getm (cp, NULL, 0, AD_NAME, NULL))
 			== NULL)
-		    admonish (NULLCP, "illegal address: %s", cp), oops++;
+		    admonish (NULL, "illegal address: %s", cp), oops++;
 		else {
-		    mp = mp -> m_next;
-		    mp -> m_type = W_NIL;
+		    mp = mp->m_next;
+		    mp->m_type = W_NIL;
 #ifdef	BERK
 		    /* check for wildcards on the mailbox name and
 		       set m_type accordingly. */
-		    mp -> m_ingrp = strlen (mp -> m_mbox);
-		    if (*(mp -> m_mbox) == '*') {
-			mp -> m_type |= W_MBEG;
-			mp -> m_mbox++;
-			--mp -> m_ingrp;
+		    mp->m_ingrp = strlen (mp->m_mbox);
+		    if (*(mp->m_mbox) == '*') {
+			mp->m_type |= W_MBEG;
+			mp->m_mbox++;
+			--mp->m_ingrp;
 		    }
-		    if (mp -> m_mbox[mp -> m_ingrp - 1] == '*') {
-			mp -> m_type |= W_MEND;
-			mp -> m_ingrp--;
-			mp -> m_mbox[mp -> m_ingrp] = 0;
+		    if (mp->m_mbox[mp->m_ingrp - 1] == '*') {
+			mp->m_type |= W_MEND;
+			mp->m_ingrp--;
+			mp->m_mbox[mp->m_ingrp] = 0;
 		    }
 #else /* not BERK */
 		    /* owing to screwy munging, wildcarding is a great idea
 		       even under #ifndef BERK, so... */
-		    mp -> m_type = W_NIL;
-		    if (*mp -> m_mbox == '*')
-			mp -> m_type |= W_MBEG, mp -> m_mbox++;
-		    if (*(cp = mp -> m_mbox + strlen (mp -> m_mbox) - 1)
+		    mp->m_type = W_NIL;
+		    if (*mp->m_mbox == '*')
+			mp->m_type |= W_MBEG, mp->m_mbox++;
+		    if (*(cp = mp->m_mbox + strlen (mp->m_mbox) - 1)
 			    == '*')
-			mp -> m_type |= W_MEND, *cp = '\0';
-		    if (mp -> m_host) {
-			if (*mp -> m_host == '*')
-			    mp -> m_type |= W_HBEG, mp -> m_host++;
-			if (*(cp = mp -> m_host + strlen (mp -> m_host) - 1)
+			mp->m_type |= W_MEND, *cp = '\0';
+		    if (mp->m_host) {
+			if (*mp->m_host == '*')
+			    mp->m_type |= W_HBEG, mp->m_host++;
+			if (*(cp = mp->m_host + strlen (mp->m_host) - 1)
 				== '*')
-			    mp -> m_type |= W_HEND, *cp = '\0';
+			    mp->m_type |= W_HEND, *cp = '\0';
 		    }
 		    if ((cp = getenv ("MHWDEBUG")) && *cp)
 			fprintf (stderr, "mbox=\"%s\" host=\"%s\" %s\n",
-			    mp -> m_mbox, mp -> m_host,
-			    sprintb (buffer, (unsigned) mp -> m_type, WBITS));
+			    mp->m_mbox, mp->m_host,
+			    sprintb (buffer, (unsigned) mp->m_type, WBITS));
 #endif /* not BERK */
 		}
 	    if (oops)
-		advise (NULLCP, "please fix the %s: entry in your %s file",
+		advise (NULL, "please fix the %s: entry in your %s file",
 			"alternate-mailboxes", mh_profile);
 	}
     }
@@ -735,23 +715,23 @@ register struct mailname *np;
 	return 0;
     
 #ifdef	BERK
-    cp = np -> m_mbox;
+    cp = np->m_mbox;
     if (strcmp (cp, mq.m_mbox) == 0)
 	return 1;
 #else /* not BERK */
-    switch (np -> m_type) {
+    switch (np->m_type) {
 	case NETHOST:
 	    len = strlen (cp = LocalName ());
-	    if (!uprf (np -> m_host, cp) || np -> m_host[len] != '.')
+	    if (!uprf (np->m_host, cp) || np->m_host[len] != '.')
 		break;
 	    goto local_test;
 
 	case UUCPHOST:
-	    if (!uleq (np -> m_host, SystemName ()))
+	    if (!uleq (np->m_host, SystemName ()))
 		break;		/* fall */
 	case LOCALHOST:
 local_test: ;
-	    if (uleq (np -> m_mbox, mq.m_mbox))
+	    if (uleq (np->m_mbox, mq.m_mbox))
 		return 1;
 	    break;
 
@@ -762,37 +742,37 @@ local_test: ;
 
 #ifdef	BERK
     len = strlen (cp);
-    for (mp = &mq; mp = mp -> m_next;)
-	if (len >= mp -> m_ingrp)
-	    switch (mp -> m_type) {
+    for (mp = &mq; mp = mp->m_next;)
+	if (len >= mp->m_ingrp)
+	    switch (mp->m_type) {
 		case W_NIL: 	/* no wildcards */
-		    if (strcmp (cp, mp -> m_mbox) == 0)
+		    if (strcmp (cp, mp->m_mbox) == 0)
 			return 1;
 		    break;
 
 		case W_MBEG: 	/* wildcard at beginning */
-		    if (strcmp (&cp[len - mp -> m_ingrp], mp -> m_mbox) == 0)
+		    if (strcmp (&cp[len - mp->m_ingrp], mp->m_mbox) == 0)
 			return 1;
 		    break;
 
 		case W_MEND: 	/* wildcard at end */
-		    if (strncmp (cp, mp -> m_mbox, mp -> m_ingrp) == 0)
+		    if (strncmp (cp, mp->m_mbox, mp->m_ingrp) == 0)
 			return 1;
 		    break;
 
 		case W_MBEG | W_MEND: /* wildcard at beginning & end */
-		    for (i = 0; i <= len - mp -> m_ingrp; i++)
-			if (strncmp (&cp[i], mp -> m_mbox, mp -> m_ingrp) == 0)
+		    for (i = 0; i <= len - mp->m_ingrp; i++)
+			if (strncmp (&cp[i], mp->m_mbox, mp->m_ingrp) == 0)
 			    return 1;
 	    }
 #else /* not BERK */
-    for (mp = &mq; mp = mp -> m_next;) {
-	if (np -> m_mbox == NULL)
+    for (mp = &mq; mp = mp->m_next;) {
+	if (np->m_mbox == NULL)
 	    continue;
-	if ((len = strlen (cp = np -> m_mbox))
-		< (i = strlen (pp = mp -> m_mbox)))
+	if ((len = strlen (cp = np->m_mbox))
+		< (i = strlen (pp = mp->m_mbox)))
 	    continue;
-	switch (mp -> m_type & W_MBOX) {
+	switch (mp->m_type & W_MBOX) {
 	    case W_NIL: 
 		if (!uleq (cp, pp))
 		    continue;
@@ -811,14 +791,14 @@ local_test: ;
 		break;
 	}
 
-	if (mp -> m_nohost)
+	if (mp->m_nohost)
 	    return 1;
-	if (np -> m_host == NULL)
+	if (np->m_host == NULL)
 	    continue;
-	if ((len = strlen (cp = np -> m_host))
-		< (i = strlen (pp = mp -> m_host)))
+	if ((len = strlen (cp = np->m_host))
+		< (i = strlen (pp = mp->m_host)))
 	    continue;
-	switch (mp -> m_type & W_HOST) {
+	switch (mp->m_type & W_HOST) {
 	    case W_NIL: 
 		if (!uleq (cp, pp))
 		    continue;
