@@ -1,10 +1,11 @@
 
 /*
  * ambigsw.c -- report an ambiguous switch
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
 
 
 void
