@@ -1,9 +1,12 @@
 
 /*
- * atooi.c - octal version of atoi()
+ * atooi.c -- octal version of atoi()
+ *
+ * $Id$
  */
 
-int atooi(char *cp)
+int
+atooi(char *cp)
 {
     register int i, base;
 
