@@ -1,17 +1,22 @@
 
 /*
- * brkstring.c - break string into an array of strings
+ * brkstring.c -- break string into an array of strings
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
 
-static char *broken[MAXARGS+1];	/* array of substring start addresses */
+/*
+ * array of substring start addresses
+ */
+static char *broken[MAXARGS+1];
 
 /*
- * prototypes
+ * static prototypes
  */
 static int brkany (char, char *);
-char **brkstring (char *, char *, char *);
+
 
 char **
 brkstring (char *strg, char *brksep, char *brkterm)
@@ -19,8 +24,9 @@ brkstring (char *strg, char *brksep, char *brkterm)
     register int bi;
     register char c, *sp;
 
-    sp = strg;			/* scan string, replacing separators with
-				   zeroes */
+    /* scan string, replacing *
+     * separators with zeroes */
+    sp = strg;
 
     for (bi = 0; bi < MAXARGS; bi++) {
 				/* and entering start addrs in "broken" */
@@ -42,8 +48,11 @@ brkstring (char *strg, char *brksep, char *brkterm)
 }
 
 
+/*
+ * returns 1 if chr in strg, 0 otherwise
+ */
 static int
-brkany (char chr, char *strg)	/* returns 1 if chr in strg, 0 otherwise  */
+brkany (char chr, char *strg)
 {
     register char *sp;
 
