@@ -1,21 +1,19 @@
 
 /*
  * closefds.c - close-up fd's
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../config.h"
 #include "../h/mh.h"
 
 #ifdef HAVE_LIMITS_H
-# include <stdio.h>
 # include <limits.h>
 #endif
 
-/* get maximum number of open file descriptors */
+/*
+ * get maximum number of open file descriptors
+ */
 #ifndef OPEN_MAX
 # ifdef NOFILE
 #  define OPEN_MAX NOFILE
