@@ -2,11 +2,11 @@
 /*
  * concat.c - concatenate a variable number (minimum of 1)
  *            of strings in managed memory
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
-#include <stdarg.h>
 
 
 char *
@@ -18,7 +18,7 @@ concat (char *s1, ...)
 
     len = strlen (s1) + 1;
     va_start(list, s1); 
-    while (cp = va_arg(list, char *))
+    while ((cp = va_arg(list, char *)))
 	len += strlen (cp);
     va_end(list);
 
@@ -28,7 +28,7 @@ concat (char *s1, ...)
     sp = copy(s1, sp);
 
     va_start(list, s1); 
-    while (cp = va_arg (list, char *))
+    while ((cp = va_arg (list, char *)))
 	sp = copy(cp, sp);
     va_end(list);
 
