@@ -1,10 +1,11 @@
 
 /*
  * cpydata.c -- copy from one fd to another
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
 
 void
 cpydata (int in, int out, char *ifile, char *ofile)
