@@ -1,14 +1,11 @@
 
 /*
  * cpydgst.c -- copy from one fd to another in encapsulating mode
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
 
 /*
  * We want to perform the substitution
@@ -22,8 +19,8 @@ static char ident[] = "$Id$";
  *  but the routine below is faster than the pipe, fork, and exec.
  */
 
-#define	S1  0
-#define	S2  1
+#define	S1 0
+#define	S2 1
 
 #define	output(c)   if (bp >= dp) {flush(); *bp++ = c;} else *bp++ = c
 #define	flush()	    if ((j = bp - outbuf) && write (out, outbuf, j) != j) \
