@@ -1,20 +1,11 @@
 
 /*
  * discard.c -- discard output on a file pointer
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
-#include <stdio.h>
-
-#ifdef SYS5
-# include <sys/types.h>
-# include <sys/ioctl.h>
-#endif
 
 #ifdef HAVE_TERMIOS_H
 # include <termios.h>
@@ -26,6 +17,7 @@ static char ident[] = "$Id$";
 # endif
 #endif
 
+
 void
 discard (FILE *io)
 {
@@ -57,7 +49,7 @@ discard (FILE *io)
 #ifdef _FSTDIO
     fpurge (io);
 #else
-    if (io->_ptr = io->_base)
+    if ((io->_ptr = io->_base))
 	io->_cnt = 0;
 #endif
 }
