@@ -1,15 +1,11 @@
 
 /*
  * fdcompare.c -- are two files identical?
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char Id[] = "$Id$";
-#endif
-
 #include "../h/mh.h"
-#include <stdio.h>
-#include <sys/types.h>	/* for off_t */
 
 
 int
@@ -36,7 +32,7 @@ fdcompare (int fd1, int fd2)
     resp = 0;
 
 leave: ;
-    lseek (fd1, (off_t)0, 0);
-    lseek (fd2, (off_t)0, 0);
+    lseek (fd1, (off_t) 0, 0);
+    lseek (fd2, (off_t) 0, 0);
     return resp;
 }
