@@ -1,21 +1,15 @@
 
 /*
  * formatsbr.c -- format string interpretation
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 #include "../h/addrsbr.h"
 #include "../h/formatsbr.h"
 #include "../zotnet/tws/tws.h"
 #include "../h/fmtcompile.h"
-#include <ctype.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 
 #define	NFMTS	MAXARGS
 #define QUOTE '\\'
@@ -27,13 +21,17 @@ extern char *formataddr ();	/* hook for custom address formatting */
 struct msgs *fmt_current_folder; /* current folder (set by main program) */
 #endif
 
-static void normalize(char *);
-static int get_x400_comp();
-
 extern int fmt_norm;		/* defined in sbr/formatdef.c = AD_NAME */
 struct mailname fmt_mnull;
 
-long time();
+/*
+ * static prototypes
+ */
+static void normalize (char *);
+static int match (char *, char *);
+static char *get_x400_friendly (char *, char *);
+static int get_x400_comp (char *, char *, char *);
+
 
 /* MAJOR HACK:	See MHCHANGES for discussion */
 
@@ -278,19 +276,18 @@ static char *lmonth[] = { "January",  "February","March",   "April",
 			  "May",      "June",    "July",    "August",
 			  "September","October", "November","December" };
 
-static char *get_x400_friendly (mbox, buffer)
-char   *mbox,
-       *buffer;
+static char *
+get_x400_friendly (char *mbox, char *buffer)
 {
     char    given[BUFSIZ],
 	    surname[BUFSIZ];
 
-    if (mbox == NULLCP)
-	return NULLCP;
+    if (mbox == NULL)
+	return NULL;
     if (*mbox == '"')
 	mbox++;
     if (*mbox != '/')
-	return NULLCP;
+	return NULL;
 
     if (get_x400_comp (mbox, "/PN=", buffer)) {
 	for (mbox = buffer; mbox = strchr(mbox, '.'); )
@@ -300,7 +297,7 @@ char   *mbox,
     }
 
     if (!get_x400_comp (mbox, "/S=", surname))
-	return NULLCP;
+	return NULL;
 
     if (get_x400_comp (mbox, "/G=", given))
 	(void) sprintf (buffer, "%s %s", given, surname);
@@ -310,13 +307,11 @@ char   *mbox,
     return buffer;
 }
 
-static int get_x400_comp (mbox, key, buffer)
-char   *mbox,
-       *key,
-       *buffer;
+static int
+get_x400_comp (char *mbox, char *key, char *buffer)
 {
-    int	    idx;
-    char   *cp;
+    int	idx;
+    char *cp;
 
     if ((idx = stringdex (key, mbox)) < 0
 	    || !(cp = strchr(mbox += idx + strlen (key), '/')))
@@ -327,16 +322,12 @@ char   *mbox,
 }
 
 struct format *
-fmtscan (format, scanl, width, dat)
-	struct format *format;
-	char	*scanl;
-	int	width;
-	int	dat[];
+fmtscan (struct format *format, char *scanl, int width, int *dat)
 {
     register char	*cp = scanl;
     register char	*ep = scanl + width - 1;
     register struct format *fmt = format;
-    register char	*str = NULLCP;
+    register char	*str = NULL;
     register int	value = 0;
     register char	*sp;
     register int	i;
@@ -385,7 +376,7 @@ fmtscan (format, scanl, width, dat)
 	    PUTSF (cp, str, fmt->f_width, fmt->f_fill);
 	    break;
 	case FT_STRFW:
-	    adios (NULLCP, "internal error (FT_STRFW)");
+	    adios (NULL, "internal error (FT_STRFW)");
 
 	case FT_NUM:
 	    PUTD (cp, value);
@@ -409,7 +400,7 @@ fmtscan (format, scanl, width, dat)
 	    break;
 
 	case FT_IF_S_NULL:
-	    if (!(value = (str == NULLCP || *str == 0))) {
+	    if (!(value = (str == NULL || *str == 0))) {
 		fmt += fmt->f_skip;
 		continue;
 	    }
@@ -462,11 +453,11 @@ fmtscan (format, scanl, width, dat)
 	    break;
 
 	case FT_S_NONNULL:
-	    value = (str != NULLCP && *str != 0);
+	    value = (str != NULL && *str != 0);
 	    break;
 
 	case FT_S_NULL:
-	    value = (str == NULLCP || *str == 0);
+	    value = (str == NULL || *str == 0);
 	    break;
 
 	case FT_V_EQ:
@@ -690,14 +681,14 @@ fmtscan (format, scanl, width, dat)
 #ifdef BERK
 	    str = fmt->f_comp->c_mn->m_mbox;
 #else	/* not BERK */
-	    if ((mn = fmt -> f_comp -> c_mn) == &fmt_mnull) {
-		str = fmt -> f_comp -> c_text;
+	    if ((mn = fmt->f_comp->c_mn) == &fmt_mnull) {
+		str = fmt->f_comp->c_text;
 		break;
 	    }
-	    if (fmt -> f_type == FT_LS_ADDR)
+	    if (fmt->f_type == FT_LS_ADDR)
 		goto unfriendly;
-	    if ((str = mn -> m_pers) == NULL)
-	        if ((str = mn -> m_note)) {
+	    if ((str = mn->m_pers) == NULL)
+	        if ((str = mn->m_note)) {
 	            (void) strcpy (buffer, str);
 	            str = buffer;
 	            if (*str == '(')
@@ -711,25 +702,25 @@ fmtscan (format, scanl, width, dat)
 	            	    else
 	            		break;
 	            }
-	        } else if (!(str = get_x400_friendly (mn -> m_mbox, buffer))) {
+	        } else if (!(str = get_x400_friendly (mn->m_mbox, buffer))) {
 	unfriendly: ;
-		  switch (mn -> m_type) {
+		  switch (mn->m_type) {
 		    case LOCALHOST:
-			str = mn -> m_mbox;
+			str = mn->m_mbox;
 			break;
 		    case UUCPHOST:
 			(void) sprintf (buffer, "%s!%s",
-					mn -> m_host, mn -> m_mbox);
+					mn->m_host, mn->m_mbox);
 			str = buffer;
 			break;
 		    default:
-			if (mn -> m_mbox) {
+			if (mn->m_mbox) {
 			    (void) sprintf (buffer, "%s@%s",
-					    mn -> m_mbox, mn -> m_host);
+					    mn->m_mbox, mn->m_host);
 			    str= buffer;
 			}
 			else
-			    str = mn -> m_text;
+			    str = mn->m_text;
 			break;
 		  }
 		}
@@ -758,7 +749,7 @@ fmtscan (format, scanl, width, dat)
 		*comp->c_tws = *tws;
 		comp->c_flags = 0;
 	    } else if (comp->c_flags >= 0) {
-		memset ((char *) comp -> c_tws, 0, sizeof *comp -> c_tws);
+		memset ((char *) comp->c_tws, 0, sizeof *comp->c_tws);
 		comp->c_flags = 1;
 	    }
 	    break;
@@ -817,7 +808,7 @@ fmtscan (format, scanl, width, dat)
 	    if (comp->c_mn != &fmt_mnull)
 		mnfree (comp->c_mn);
 	    if ((sp = comp->c_text) && (sp = getname(sp)) &&
-		(mn = getm (sp, NULLCP, 0, fmt_norm, NULLCP))) {
+		(mn = getm (sp, NULL, 0, fmt_norm, NULL))) {
 		comp->c_mn = mn;
 		while (getname(""))
 		    ;
@@ -838,12 +829,12 @@ fmtscan (format, scanl, width, dat)
 	    if (comp->c_mn != &fmt_mnull)
 		mnfree (comp->c_mn);
 	    if ((sp = comp->c_text) && (sp = getname(sp)) &&
-		(mn = getm (sp, NULLCP, 0, AD_NAME, NULLCP))) {
+		(mn = getm (sp, NULL, 0, AD_NAME, NULL))) {
 		comp->c_mn = mn;
 		comp->c_flags = ismymbox(mn);
 		while (sp = getname(sp))
 		    if (comp->c_flags == 0 &&
-			(mn = getm (sp, NULLCP, 0, AD_NAME, NULLCP)))
+			(mn = getm (sp, NULL, 0, AD_NAME, NULL)))
 			comp->c_flags |= ismymbox(mn);
 	    } else {
 		while (getname(""))		/* XXX */
@@ -880,7 +871,7 @@ fmtscan (format, scanl, width, dat)
 
     finished:;    
     *cp = '\0';
-    return (fmt -> f_value ? ++fmt : (struct format *)0);
+    return (fmt->f_value ? ++fmt : (struct format *)0);
 
 #endif /* JLR */
 }
