@@ -1,14 +1,12 @@
 
 /*
- * gans.c - get an answer from the user
+ * gans.c -- get an answer from the user
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif /* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 int
 gans (char *prompt, struct swit *ansp)
@@ -38,8 +36,8 @@ gans (char *prompt, struct swit *ansp)
 	*cp = 0;
 	if (ansbuf[0] == '?' || cp == ansbuf) {
 	    printf ("Options are:\n");
-	    for (ap = ansp; ap -> sw; ap++)
-		printf ("  %s\n", ap -> sw);
+	    for (ap = ansp; ap->sw; ap++)
+		printf ("  %s\n", ap->sw);
 	    continue;
 	}
 	if ((i = smatch (ansbuf, ansp)) < 0) {
