@@ -1,17 +1,14 @@
 
 /*
  * getans.c -- get an answer from the user and return a string array
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
+#include "../h/signals.h"
 #include <setjmp.h>
 #include <signal.h>
-#include <stdio.h>
 
 static char ansbuf[BUFSIZ];
 static jmp_buf sigenv;
@@ -19,14 +16,14 @@ static jmp_buf sigenv;
 /*
  * static prototypes
  */
-static RETSIGTYPE intrser (int);;
+static RETSIGTYPE intrser (int);
 
 
 char **
 getans (char *prompt, struct swit *ansp)
 {
     int i;
-    RETSIGTYPE (*istat)();
+    SIGNAL_HANDLER istat;
     char *cp, **cpp;
 
     if (!(setjmp (sigenv))) {
@@ -52,7 +49,7 @@ getans (char *prompt, struct swit *ansp)
 	    print_sw (ALL, ansp, "");
 	    continue;
 	}
-	cpp = brkstring (ansbuf, " ", NULLCP);
+	cpp = brkstring (ansbuf, " ", NULL);
 	switch (smatch (*cpp, ansp)) {
 	    case AMBIGSW: 
 		ambigsw (*cpp, ansp);
