@@ -1,11 +1,12 @@
 
 /*
  * getcpy.c - copy a string in managed memory
+ *
+ * $Id$
  */
 
-#include "../config.h"
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 char *
 getcpy (char *str)
