@@ -1,12 +1,10 @@
 
 /*
- * m_atoi.c - parse a string representation of a message number
+ * m_atoi.c -- parse a string representation of a message number
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif /* lint */
-
 #include "../h/mh.h"
 
 
