@@ -1,11 +1,11 @@
 
 /*
- * m_backup.c - construct a backup file
+ * m_backup.c -- construct a backup file
+ *
+ * $Id$
  */
 
-#include "../config.h"
 #include "../h/mh.h"
-#include <stdio.h>
 
 
 char *
