@@ -1,15 +1,11 @@
 
 /*
- * m_convert.c - parse a message sequence and set SELECTED
+ * m_convert.c -- parse a message sequence and set SELECTED
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
-#include <ctype.h>
 
 #define	BADMSG	(-2)
 #define	BADRNG	(-3)
@@ -26,9 +22,8 @@ static int convdir;
 static char *delimp;
 
 /*
- * prototypes
+ * static prototypes
  */
-int m_convert (struct msgs *, char *);
 static int m_conv (struct msgs *, char *, int);
 static int attr (struct msgs *, char *);
 
@@ -67,7 +62,7 @@ m_convert (struct msgs *mp, char *name)
 	goto badmsg;
     if (*(cp = delimp) && *cp != '-' && *cp != ':') {
 badelim: ;
-	advise (NULLCP, "illegal argument delimiter: `%c'(0%o)",
+	advise (NULL, "illegal argument delimiter: `%c'(0%o)",
 		*delimp, *delimp);
 	return 0;
     }
@@ -77,29 +72,29 @@ badelim: ;
     badmsg: ;
 	    switch (err) {
 		case BADMSG: 
-		    advise (NULLCP, "no %s message", cp);
+		    advise (NULL, "no %s message", cp);
 		    break;
 
 		case BADNUM: 
-		    advise (NULLCP, "message %s doesn't exist", cp);
+		    advise (NULL, "message %s doesn't exist", cp);
 		    break;
 
 		case BADRNG: 
-		    advise (NULLCP, "message %s out of range 1-%d",
-			    cp, mp -> hghmsg);
+		    advise (NULL, "message %s out of range 1-%d",
+			    cp, mp->hghmsg);
 		    break;
 
 		case BADLST: 
 	    badlist: ;
-		    advise (NULLCP, "bad message list %s", name);
+		    advise (NULL, "bad message list %s", name);
 		    break;
 
 		case BADNEW:
-		    advise (NULLCP, "folder full, no %s message", name);
+		    advise (NULL, "folder full, no %s message", name);
 		    break;
 
 		default: 
-		    advise (NULLCP, "no messages match specification");
+		    advise (NULL, "no messages match specification");
 	    }
 	    return 0;
 	}
@@ -107,15 +102,15 @@ badelim: ;
 	    goto badlist;
 	if (*delimp)
 	    goto badelim;
-	if (first > mp -> hghmsg || last < mp -> lowmsg) {
+	if (first > mp->hghmsg || last < mp->lowmsg) {
     rangerr: ;
-	    advise (NULLCP, "no messages in range %s", name);
+	    advise (NULL, "no messages in range %s", name);
 	    return 0;
 	}
-	if (last > mp -> hghmsg)
-	    last = mp -> hghmsg;
-	if (first < mp -> lowmsg)
-	    first = mp -> lowmsg;
+	if (last > mp->hghmsg)
+	    last = mp->hghmsg;
+	if (first < mp->lowmsg)
+	    first = mp->lowmsg;
 	}
     else
 	if (*cp == ':') {
@@ -135,23 +130,23 @@ badelim: ;
 		bp++;
 	    if (*bp)
 		goto badelim;
-	    if ((convdir > 0 && first > mp -> hghmsg)
-		    || (convdir < 0 && first < mp -> lowmsg))
+	    if ((convdir > 0 && first > mp->hghmsg)
+		    || (convdir < 0 && first < mp->lowmsg))
 		goto rangerr;
-	    if (first < mp -> lowmsg)
-		first = mp -> lowmsg;
-	    if (first > mp -> hghmsg)
-		first = mp -> hghmsg;
+	    if (first < mp->lowmsg)
+		first = mp->lowmsg;
+	    if (first > mp->hghmsg)
+		first = mp->hghmsg;
 	    for (last = first;
-		    last >= mp -> lowmsg && last <= mp -> hghmsg;
+		    last >= mp->lowmsg && last <= mp->hghmsg;
 		    last += convdir)
-		if (mp -> msgstats[last] & EXISTS)
+		if (mp->msgstats[last] & EXISTS)
 		    if (--range <= 0)
 			break;
-	    if (last < mp -> lowmsg)
-		last = mp -> lowmsg;
-	    if (last > mp -> hghmsg)
-		last = mp -> hghmsg;
+	    if (last < mp->lowmsg)
+		last = mp->lowmsg;
+	    if (last > mp->hghmsg)
+		last = mp->hghmsg;
 	    if (last < first) {
 		range = last;
 		last = first;
@@ -159,30 +154,30 @@ badelim: ;
 	    }
 	}
 	else {
-	    if (!(mp -> msgflags & MHPATH))
-		if (first > mp -> hghmsg
-			|| first < mp -> lowmsg
-			|| !(mp -> msgstats[first] & EXISTS)) {
+	    if (!(mp->msgflags & MHPATH))
+		if (first > mp->hghmsg
+			|| first < mp->lowmsg
+			|| !(mp->msgstats[first] & EXISTS)) {
 		    if (strcmp (name, "cur") == 0 || strcmp (name, ".") == 0)
-			advise (NULLCP, "no %s message", name);
+			advise (NULL, "no %s message", name);
 		    else
-			advise (NULLCP, "message %d doesn't exist", first);
+			advise (NULL, "message %d doesn't exist", first);
 		    return 0;
 		}
     single: ;
 	    last = first;
-	    if (mp -> msgflags & MHPATH)
-		mp -> msgstats[first] |= SELECT_EMPTY;
+	    if (mp->msgflags & MHPATH)
+		mp->msgstats[first] |= SELECT_EMPTY;
 	}
     for (; first <= last; first++)
-	if (mp -> msgstats[first] & flags) {
-	    if (!(mp -> msgstats[first] & SELECTED)) {
-		mp -> numsel++;
-		mp -> msgstats[first] |= SELECTED;
-		if (mp -> lowsel == 0 || first < mp -> lowsel)
-		    mp -> lowsel = first;
-		if (first > mp -> hghsel)
-		    mp -> hghsel = first;
+	if (mp->msgstats[first] & flags) {
+	    if (!(mp->msgstats[first] & SELECTED)) {
+		mp->numsel++;
+		mp->msgstats[first] |= SELECTED;
+		if (mp->lowsel == 0 || first < mp->lowsel)
+		    mp->lowsel = first;
+		if (first > mp->hghsel)
+		    mp->hghsel = first;
 	    }
 	    found++;
 	}
@@ -206,9 +201,9 @@ m_conv (struct msgs *mp, char *str, int call)
 	while (isdigit (*bp))
 	    bp++;
 	delimp = bp;
-	return ((i = atoi (cp)) <= mp -> hghmsg ? i
-		: *delimp || call == LAST ? mp -> hghmsg + 1
-		: mp -> msgflags & MHPATH ? BADRNG : BADNUM);
+	return ((i = atoi (cp)) <= mp->hghmsg ? i
+		: *delimp || call == LAST ? mp->hghmsg + 1
+		: mp->msgflags & MHPATH ? BADRNG : BADNUM);
     }
 
     bp = buf;
@@ -222,32 +217,32 @@ m_conv (struct msgs *mp, char *str, int call)
     delimp = cp;
 
     if (strcmp (buf, "first") == 0)
-	return (mp -> hghmsg || !(mp -> msgflags & MHPATH)
-		? mp -> lowmsg : BADMSG);
+	return (mp->hghmsg || !(mp->msgflags & MHPATH)
+		? mp->lowmsg : BADMSG);
 
     if (strcmp (buf, "last") == 0) {
 	convdir = -1;
-	return (mp -> hghmsg || !(mp -> msgflags & MHPATH)
-		? mp -> hghmsg : BADMSG);
+	return (mp->hghmsg || !(mp->msgflags & MHPATH)
+		? mp->hghmsg : BADMSG);
     }
 
     if (strcmp (buf, "cur") == 0 || strcmp (buf, ".") == 0)
-	return (mp -> curmsg > 0 ? mp -> curmsg : BADMSG);
+	return (mp->curmsg > 0 ? mp->curmsg : BADMSG);
 
     if (strcmp (buf, "prev") == 0) {
 	convdir = -1;
-	for (i = (mp -> curmsg <= mp -> hghmsg) ? mp -> curmsg - 1 : mp -> hghmsg;
-		i >= mp -> lowmsg; i--) {
-	    if (mp -> msgstats[i] & EXISTS)
+	for (i = (mp->curmsg <= mp->hghmsg) ? mp->curmsg - 1 : mp->hghmsg;
+		i >= mp->lowmsg; i--) {
+	    if (mp->msgstats[i] & EXISTS)
 		return i;
 	}
 	return BADMSG;
     }
 
     if (strcmp (buf, "next") == 0) {
-	for (i = (mp -> curmsg >= mp -> lowmsg) ? mp -> curmsg + 1 : mp -> lowmsg;
-		i <= mp -> hghmsg; i++) {
-	    if (mp -> msgstats[i] & EXISTS)
+	for (i = (mp->curmsg >= mp->lowmsg) ? mp->curmsg + 1 : mp->lowmsg;
+		i <= mp->hghmsg; i++) {
+	    if (mp->msgstats[i] & EXISTS)
 		return i;
 	}
 	return BADMSG;
@@ -287,15 +282,15 @@ attr (struct msgs *mp, char *cp)
 	if (isalpha (*dp)) {	/* optimize? */
 	    if (strcmp (dp, "prev") == 0) {
 		convdir = -1;
-		first = (mp -> curmsg > 0) && (mp -> curmsg <= mp -> hghmsg)
-			? mp -> curmsg - 1
-			: mp -> hghmsg;
+		first = (mp->curmsg > 0) && (mp->curmsg <= mp->hghmsg)
+			? mp->curmsg - 1
+			: mp->hghmsg;
 	    }
 	    else if (strcmp (dp, "next") == 0) {
 		convdir = 1;
-		first = (mp -> curmsg >= mp -> lowmsg)
-			    ? mp -> curmsg + 1
-			    : mp -> lowmsg;
+		first = (mp->curmsg >= mp->lowmsg)
+			    ? mp->curmsg + 1
+			    : mp->lowmsg;
 	    }
 	    else if (strcmp (dp, "first") == 0) {
 		convdir = 1;
@@ -326,27 +321,27 @@ attr (struct msgs *mp, char *cp)
 
 
     bits = FFATTRSLOT;
-    for (i = 0; mp -> msgattrs[i]; i++)
-	if (strcmp (mp -> msgattrs[i], cp) == 0)
+    for (i = 0; mp->msgattrs[i]; i++)
+	if (strcmp (mp->msgattrs[i], cp) == 0)
 	    break;
     if (bp)
 	*bp = ':';		/* restore sequence name */
-    if (mp -> msgattrs[i] == NULL)
+    if (mp->msgattrs[i] == NULL)
 	return OK;
 
     found = 0;
-    for (j = first ? first : (convdir > 0) ? mp -> lowmsg : mp -> hghmsg;
-		j >= mp -> lowmsg && j <= mp -> hghmsg; j += convdir)
-	if ((mp -> msgstats[j] & EXISTS)
-		&& inverted ? !(mp -> msgstats[j] & (1 << (bits + i)))
-		: mp -> msgstats[j] & (1 << (bits + i))) {
-	    if (!(mp -> msgstats[j] & SELECTED)) {
-		mp -> numsel++;
-		mp -> msgstats[j] |= SELECTED;
-		if (mp -> lowsel == 0 || j < mp -> lowsel)
-		    mp -> lowsel = j;
-		if (j > mp -> hghsel)
-		    mp -> hghsel = j;
+    for (j = first ? first : (convdir > 0) ? mp->lowmsg : mp->hghmsg;
+		j >= mp->lowmsg && j <= mp->hghmsg; j += convdir)
+	if ((mp->msgstats[j] & EXISTS)
+		&& inverted ? !(mp->msgstats[j] & (1 << (bits + i)))
+		: mp->msgstats[j] & (1 << (bits + i))) {
+	    if (!(mp->msgstats[j] & SELECTED)) {
+		mp->numsel++;
+		mp->msgstats[j] |= SELECTED;
+		if (mp->lowsel == 0 || j < mp->lowsel)
+		    mp->lowsel = j;
+		if (j > mp->hghsel)
+		    mp->hghsel = j;
 	    }
 	    found++;
 	    if (range && found >= range)
@@ -357,6 +352,6 @@ attr (struct msgs *mp, char *cp)
 
     if (first)
 	return BADMSG;
-    advise (NULLCP, "sequence %s %s", cp, inverted ? "full" : "empty");
+    advise (NULL, "sequence %s %s", cp, inverted ? "full" : "empty");
     return NOTOK;
 }
