@@ -1,10 +1,11 @@
 
 /*
- * m_delete.c - delete an entry from the profile
+ * m_delete.c -- delete an entry from the profile
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
 
 int
 m_delete (char *key)
@@ -15,7 +16,7 @@ m_delete (char *key)
     for (np = m_defs, pp = NULL; np; pp = np, np = np->n_next) {
 	if (uleq (np->n_name, key)) {
 	    if (!np->n_context)
-		admonish (NULLCP, "bug: m_delete(key=\"%s\")", np->n_name);
+		admonish (NULL, "bug: m_delete(key=\"%s\")", np->n_name);
 	    if (pp)
 		pp->n_next = np->n_next;
 	    else
