@@ -1,20 +1,16 @@
 
 /*
- * m_draft.c - construct the draft name
+ * m_draft.c -- construct the draft name
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 #include <errno.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 
 extern int errno;
 
+
 char *
 m_draft (char *folder, char *msg, int use, int *isdf)
 {
@@ -39,33 +35,33 @@ m_draft (char *folder, char *msg, int use, int *isdf)
     if (stat (buffer, &st) == NOTOK) {
 	if (errno != ENOENT)
 	    adios (buffer, "error on folder");
-	cp = concat ("Create folder \"", buffer, "\"? ", NULLCP);
+	cp = concat ("Create folder \"", buffer, "\"? ", NULL);
 	if (!getanswer (cp))
 	    done (0);
 	free (cp);
 	if (!makedir (buffer))
-	    adios (NULLCP, "unable to create folder %s", buffer);
+	    adios (NULL, "unable to create folder %s", buffer);
     }
 
     if (chdir (buffer) == NOTOK)
 	adios (buffer, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
 
     if ((mp = m_remsg (mp, 0, MAXFOLDER)) == NULL)
-	adios (NULLCP, "unable to allocate folder storage");
-    mp -> msgflags |= MHPATH;
+	adios (NULL, "unable to allocate folder storage");
+    mp->msgflags |= MHPATH;
 
     if (!m_convert (mp, msg && *msg ? msg : use ? "cur" : "new"))
 	done (1);
     m_setseq (mp);
-    if (mp -> numsel > 1)
-	adios (NULLCP, "only one message draft at a time!");
+    if (mp->numsel > 1)
+	adios (NULL, "only one message draft at a time!");
 
-    sprintf (buffer, "%s/%s", mp -> foldpath, m_name (mp -> lowsel));
+    sprintf (buffer, "%s/%s", mp->foldpath, m_name (mp->lowsel));
     cp = buffer;
 
-    m_setcur (mp, mp -> lowsel);
+    m_setcur (mp, mp->lowsel);
     m_sync (mp);
     m_fmsg (mp);
 
