@@ -1,10 +1,12 @@
 
 /*
- * m_find.c - find an entry in the profile
+ * m_find.c -- find an entry in the profile
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 char *
 m_find(char *str)
