@@ -1,11 +1,15 @@
 
-/* m_foil.c - foil search of .mh_profile */
+/*
+ * m_foil.c -- foil search of .mh_profile
+ *
+ * $Id$
+ */
 
 #include "../h/mh.h"
-#include <stdio.h>
 
-void m_foil (path)
-char   *path;
+
+void
+m_foil (char *path)
 {
     register struct node *np;
 
@@ -14,12 +18,12 @@ char   *path;
     if (path) {
 	np = m_defs = (struct node *) malloc (sizeof *np);
 	if (np == NULL)
-	    adios (NULLCP, "unable to allocate profile storage");
+	    adios (NULL, "unable to allocate profile storage");
 
-	np -> n_name = getcpy ("Path");
-	np -> n_field = getcpy (path);
-	np -> n_context = 0;
-	np -> n_next = NULL;
+	np->n_name = getcpy ("Path");
+	np->n_field = getcpy (path);
+	np->n_context = 0;
+	np->n_next = NULL;
 
 	if (mypath == NULL && (mypath = getenv ("HOME")) != NULL)
 	    mypath = getcpy (mypath);		
