@@ -1,39 +1,30 @@
 
 /*
- * m_getdefs.c - read the user's MH environment
+ * m_getdefs.c -- read the user's MH environment
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
 #include <errno.h>
 #include <pwd.h>
 
 extern int errno;
 
-#ifndef __STDC__
-# ifdef	SYS5
-struct	passwd *getpwuid();
-# endif
-#endif /* !__STDC__ */
-
 #ifndef	OVERHEAD
 # define FOpen(f,m,e,c) fopen (f, m)
 # define FClose(f) fclose (f)
 #else	/* OVERHEAD */
 static FILE *FOpen ();
 static int FClose ();
-off_t lseek ();
 #endif	/* OVERHEAD */
 
+
 void
 m_getdefs(void)
 {
     pid_t pid;
-    register char  *cp, *pp;
+    register char *cp, *pp;
     char buf[BUFSIZ];
     struct stat st;
     register struct passwd *pw;
@@ -46,11 +37,11 @@ m_getdefs(void)
 	    mypath = getcpy (mypath);
 	else
 	    if ((pw = getpwuid (getuid ())) == NULL
-		    || pw -> pw_dir == NULL
-		    || *pw -> pw_dir == 0)
-		adios (NULLCP, "no HOME envariable");
+		    || pw->pw_dir == NULL
+		    || *pw->pw_dir == 0)
+		adios (NULL, "no HOME envariable");
 	    else
-		mypath = getcpy (pw -> pw_dir);
+		mypath = getcpy (pw->pw_dir);
 	if ((cp = mypath + strlen (mypath) - 1) > mypath && *cp == '/')
 	    *cp = 0;
     }
@@ -63,7 +54,7 @@ m_getdefs(void)
 	    m_putenv ("MH", defpath);
     }
     else {
-	defpath = concat (mypath, "/", mh_profile, NULLCP);
+	defpath = concat (mypath, "/", mh_profile, NULL);
 
 	if ((ib = FOpen (defpath, "r", "MHFD", 0)) == NULL)
 	    switch (pid = vfork ()) {
@@ -74,7 +65,7 @@ m_getdefs(void)
 		    setgid (getgid ());
 		    setuid (getuid ());
 
-		    execlp (installproc, "install-mh", "-auto", NULLCP);
+		    execlp (installproc, "install-mh", "-auto", NULL);
 		    fprintf (stderr, "unable to exec ");
 		    perror (installproc);
 		    _exit (-1);
@@ -82,7 +73,7 @@ m_getdefs(void)
 		default:
 		    if (pidwait (pid, OK)
 			    || (ib = fopen (defpath, "r")) == NULL)
-			adios (NULLCP, "[install-mh aborted]");
+			adios (NULL, "[install-mh aborted]");
 	    }
     }
 
@@ -98,12 +89,12 @@ m_getdefs(void)
 	    if (errno != ENOENT)
 		adios (buf, "error opening");
 	    cp = concat ("Your MH-directory \"", buf,
-		"\" doesn't exist; Create it? ", NULLCP);
+		"\" doesn't exist; Create it? ", NULL);
 	    if (!getanswer(cp))
-		adios (NULLCP, "unable to access MH-directory \"%s\"", buf);
+		adios (NULL, "unable to access MH-directory \"%s\"", buf);
 	    free (cp);
 	    if (!makedir (buf))
-		adios (NULLCP, "unable to create", buf);
+		adios (NULL, "unable to create", buf);
 	}
     }
 
@@ -120,8 +111,8 @@ m_getdefs(void)
 
 
 #ifdef	OVERHEAD
-int	fd_def = NOTOK;
-int	fd_ctx = NOTOK;
+int fd_def = NOTOK;
+int fd_ctx = NOTOK;
 
 
 static FILE *
@@ -137,7 +128,7 @@ FOpen (char *filename, char *mode, char *envariable, int ctx)
 	goto not_open;
 
     if ((fd = atoi (cp)) <= fileno (stderr)) {
-	advise (NULLCP, "bad value for $%s: %s", envariable, cp);
+	advise (NULL, "bad value for $%s: %s", envariable, cp);
 	unputenv (envariable);
 	return fopen (filename, mode);
     }
