@@ -1,13 +1,10 @@
 
 /*
- * m_getfld.c - read/parse a message
+ * m_getfld.c -- read/parse a message
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif /* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
 #include "../zotnet/mts/mts.h"
 
@@ -30,7 +27,7 @@ static char ident[] = "$Id$";
    the eom() macro returns FALSE saying we aren't at the end of the
    message.
 
-   The next thing to do is to read the mtstailor file and initialize
+   The next thing to do is to read the mts.conf file and initialize
    delimiter[] and delimlen accordingly...
 
    After mhl was made a built-in in msh, m_getfld() worked just fine
@@ -134,15 +131,14 @@ static char ident[] = "$Id$";
    there is data in "name" or "buf").
   */
 
+static unsigned char *matchc(int, char *, int, char *);
+static unsigned char *locc(int, unsigned char *, unsigned char);
 
 #define Getc(iob)	getc(iob)
 #define eom(c,iob)	(msg_style != MS_DEFAULT && \
 			 (((c) == *msg_delim && m_Eom(c,iob)) ||\
 			  (eom_action && (*eom_action)(c))))
 
-static unsigned char *matchc();
-static unsigned char *locc();
-
 static unsigned char **pat_map;
 
 extern int msg_count;	/* defined in sbr/m_msgdef.c = 0
@@ -171,7 +167,7 @@ static int  fdelimlen;
 static unsigned char *edelim;
 static int  edelimlen;
 
-static int  (*eom_action) () = NULL;
+static int (*eom_action)() = NULL;
 
 #ifdef _FSTDIO
 #define	_ptr	_p		/* Gag */
@@ -180,21 +176,12 @@ static int  (*eom_action) () = NULL;
 #endif
 
 
-m_getfld (state, name, buf, bufsz, iob)
-int		state;
-int		bufsz;
-unsigned char	*name,
-		*buf;
-register FILE	*iob;
+int
+m_getfld (int state, unsigned char *name, unsigned char *buf,
+          int bufsz, FILE *iob)
 {
-    register unsigned char  *cp;
-    register unsigned char  *bp;
-    register unsigned char  *ep;
-    register unsigned char  *sp;
-    register int    cnt;
-    register int    c;
-    register int    i;
-    register int    j;
+    register unsigned char  *bp, *cp, *ep, *sp;
+    register int cnt, c, i, j;
 
     if ((c = Getc(iob)) < 0) {
 	msg_count = 0;
@@ -254,7 +241,7 @@ register FILE	*iob;
 		if ((cnt -= j) <= 0) {
 		    if (_filbuf(iob) == EOF) {
 			*cp = *buf = 0;
-			advise (NULLCP, "eof encountered in field \"%s\"",
+			advise (NULL, "eof encountered in field \"%s\"",
 				name);
 			return FMTERR;
 		    }
@@ -273,13 +260,13 @@ register FILE	*iob;
 		 */
 		if (c == '\n') {
 		    *cp = *buf = 0;
-		    advise (NULLCP, "eol encountered in field \"%s\"", name);
+		    advise (NULL, "eol encountered in field \"%s\"", name);
 		    state = FMTERR;
 		    goto finish;
 		}
 		if ((i -= j) <= 0) {
 		    *cp = *buf = 0;
-		    advise (NULLCP, "field name \"%s\" exceeds %d bytes",
+		    advise (NULL, "field name \"%s\" exceeds %d bytes",
 			    name, NAMESZ - 1);
 		    state = LENERR;
 		    goto finish;
@@ -421,7 +408,7 @@ register FILE	*iob;
 	    break;
 
 	default: 
-	    adios (NULLCP, "m_getfld() called with bogus state of %d", state);
+	    adios (NULL, "m_getfld() called with bogus state of %d", state);
     }
 finish:;
     *cp = 0;
@@ -435,14 +422,13 @@ static char  unixbuf[BUFSIZ] = "";
 #endif /* RPATHS */
 
 void
-m_unknown(iob)
-	register FILE *iob;
+m_unknown(FILE *iob)
 {
-    register	int c;
-    register	long pos;
-    char	text[10];
-    register    char *cp;
-    register	char *delimstr;
+    register int c;
+    register long pos;
+    char text[10];
+    register char *cp;
+    register char *delimstr;
 
     msg_style = MS_UNKNOWN;
 
@@ -455,7 +441,7 @@ m_unknown(iob)
      * If the first line of the maildrop is a Unix "from" line, we say the
      * style is UUCP and eat the rest of the line.  Otherwise we say the style
      * is MMDF & look for the delimiter string specified when MH was built
-     * (or from the mtstailor file).
+     * (or from the mts.conf file).
      */
     pos = ftell (iob);
     if (fread (text, sizeof *text, 5, iob) == 5
@@ -474,7 +460,7 @@ m_unknown(iob)
     } else {
 	/* not a Unix style maildrop */
 	fseek (iob, pos, 0);
-	if (mmdlm2 == NULLCP || *mmdlm2 == 0)
+	if (mmdlm2 == NULL || *mmdlm2 == 0)
 	    mmdlm2 = "\001\001\001\001\n";
 	delimstr = mmdlm2;
 	msg_style = MS_MMDF;
@@ -490,7 +476,7 @@ m_unknown(iob)
     strcpy(msg_delim, delimstr);
     delimend = (unsigned char *)msg_delim + edelimlen;
     if (edelimlen <= 1)
-	adios (NULLCP, "maildrop delimiter must be at least 2 bytes");
+	adios (NULL, "maildrop delimiter must be at least 2 bytes");
     /*
      * build a Boyer-Moore end-position map for the matcher in m_getfld.
      * N.B. - we don't match just the first char (since it's the newline
@@ -512,8 +498,8 @@ m_unknown(iob)
 }
 
 
-void m_eomsbr (action)
-int     (*action) ();
+void
+m_eomsbr (int (*action)())
 {
     if (eom_action = action) {
 	msg_style = MS_MSH;
@@ -529,17 +515,18 @@ int     (*action) ();
 }
 
 
-/* test for msg delimiter string */
+/*
+ * test for msg delimiter string
+ */
 
-int  m_Eom (c, iob)
-register int     c;
-register FILE   *iob;
+int
+m_Eom (int c, FILE *iob)
 {
     register long pos = 0L;
     register int i;
-    char    text[10];
+    char text[10];
 #ifdef	RPATHS
-    register    char *cp;
+    register char *cp;
 #endif /* RPATHS */
 
     pos = ftell (iob);
@@ -577,11 +564,11 @@ register FILE   *iob;
 }
 
 
-#ifdef	RPATHS
-char   *unixline () {
-    register char  *cp,
-                   *dp,
-                   *pp;
+#ifdef RPATHS
+char *
+unixline (void)
+{
+    register char *cp, *dp, *pp;
     static char unixfrom[BUFSIZ];
 
     pp = unixfrom;
@@ -617,12 +604,9 @@ char   *unixline () {
 	asm("1:	subl3  4(ap),r3,r0");
 	asm("	ret");
 #else
+
 static unsigned char *
-matchc( patln, pat, strln, str )
-	int patln;
-	char *pat;
-	int strln;
-	register char *str;
+matchc(int patln, char *pat, int strln, char *str)
 {
 	register char *es = str + strln - patln;
 	register char *sp;
@@ -658,11 +642,9 @@ matchc( patln, pat, strln, str )
 	asm("	movl  r1,r0");
 	asm("1:	ret");
 #else
+
 static unsigned char *
-locc( cnt, src, term )
-	register int  cnt;
-	register unsigned char *src;
-	register unsigned char term;
+locc(int cnt, unsigned char *src, unsigned char term)
 {
     while (*src++ != term && --cnt > 0);
 
