@@ -1,10 +1,12 @@
 
 /*
- * m_getfolder.c - get the current folder
+ * m_getfolder.c -- get the current folder
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 char *
 m_getfolder(void)
