@@ -1,12 +1,10 @@
 
 /*
- * m_msgdef.c - some defines for sbr/m_getfld.c
+ * m_msgdef.c -- some defines for sbr/m_getfld.c
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 
 int msg_count = 0;	/* disgusting hack for "inc" so it can
