@@ -1,13 +1,15 @@
 
 /*
- * m_name.c - return a message number as a string
+ * m_name.c -- return a message number as a string
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
 
 static char name[BUFSIZ];
 
+
 char *
 m_name (int num)
 {
