@@ -1,10 +1,12 @@
 
 /*
  * m_scratch.c -- construct a scratch file
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 char *
 m_scratch (char *file, char *template)
