@@ -1,16 +1,12 @@
 
 /*
- * m_seq.c - print out a message sequence
+ * m_seq.c -- print out a message sequence
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
 
-/* new version from VJ 2/90 - faster? */
 
 char *
 m_seq(struct msgs *mp, char *cp)
