@@ -1,10 +1,11 @@
 
 /*
- * m_setseq.c - set the previous-sequence
+ * m_setseq.c -- set the previous-sequence
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
 
 
 void
@@ -24,8 +25,8 @@ m_setseq (struct msgs *mp)
 
     for (; *ap; ap++)
 	if (m_seqnew (mp, *ap, -1))
-	    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-		if (mp -> msgstats[msgnum] & SELECTED)
+	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+		if (mp->msgstats[msgnum] & SELECTED)
 		    m_seqadd (mp, *ap, msgnum, -1);
 
     if (dp)
