@@ -1,10 +1,12 @@
 
 /*
- * m_setvis.c - set the unseen-sequence
+ * m_setvis.c -- set the unseen-sequence
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 void
 m_setvis (struct msgs *mp, int seen)
@@ -24,13 +26,13 @@ m_setvis (struct msgs *mp, int seen)
     for (; *ap; ap++)
 	if (seen) {
 	    if (m_seqflag (mp, *ap))
-		for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-		    if (mp -> msgstats[msgnum] & UNSEEN)
+		for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+		    if (mp->msgstats[msgnum] & UNSEEN)
 			m_seqdel (mp, *ap, msgnum);
 	}
 	else
-	    for (msgnum = mp -> lowmsg; msgnum <= mp -> hghmsg; msgnum++)
-		if (mp -> msgstats[msgnum] & UNSEEN)
+	    for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
+		if (mp->msgstats[msgnum] & UNSEEN)
 		    m_seqadd (mp, *ap, msgnum, -1);
 
     if (dp)
