@@ -1,10 +1,12 @@
 
 /*
- * m_tmpfil.c - construct a temporary file
+ * m_tmpfil.c -- construct a temporary file
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 char *
 m_tmpfil (char *template)
