@@ -1,14 +1,11 @@
 
 /*
  * path.c -- return a pathname
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
 
 #define	CWD	"./"
 #define	NCWD	(sizeof CWD - 1)
@@ -20,7 +17,7 @@ static char ident[] = "$Id$";
 static char *pwds;
 
 /*
- * prototypes
+ * static prototypes
  */
 static char *expath(char *,int);
 static void compath(char *);
