@@ -1,10 +1,12 @@
 
 /*
  * peekc.c -- peek at the next character in a stream
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 int
 peekc(FILE *ib)
