@@ -1,16 +1,13 @@
 
 /*
  * pidwait.c -- wait for child to exit
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
+#include "../h/signals.h"
 #include <signal.h>
-#include <stdio.h>
 
 #ifdef HAVE_SYS_WAIT_H
 # include <sys/wait.h>
@@ -20,7 +17,7 @@ int
 pidwait (pid_t id, int sigsok)
 {
     pid_t pid;
-    RETSIGTYPE (*istat)(), (*qstat)();
+    SIGNAL_HANDLER istat, qstat;
 
 #ifdef WAITINT
     int status;
