@@ -1,14 +1,12 @@
 
 /*
  * print_help.c -- print a help message
+ *
+ * $Id$
  */
 
-#ifndef lint
-static char ident[] = "$Id$";
-#endif
-
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 void
 print_help (char *str, struct swit *swp)
