@@ -1,10 +1,13 @@
 
 /*
  * print_sw.c -- print switches
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
 
+
 void
 print_sw (char *substr, struct swit *swp, char *prefix)
 {
@@ -39,8 +42,7 @@ print_sw (char *substr, struct swit *swp, char *prefix)
 	    }
 	    else
 		if (swp->minchars == 0)
-		    printf (optno ? "  %s[no]%s\n" : "  %s%s\n",
-			    prefix, swp -> sw);
+		    printf(optno ? "  %s[no]%s\n" : "  %s%s\n", prefix, swp->sw);
 	    if (optno)
 		swp++;	/* skip -noswitch */
 	}
