@@ -1,14 +1,13 @@
 
 /*
  * print_version.c -- print a version string
+ *
+ * $Id$
  */
 
-#ifndef lint
-static char ident[] = "$Id$";
-#endif
-
 #include "../h/mh.h"
 
+
 void
 print_version (char *invo_name)
 {
