@@ -1,16 +1,14 @@
 
 /*
  * push.c -- push a fork into the background
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
 #include <signal.h>
 
+
 void
 push(void)
 {
