@@ -1,14 +1,11 @@
 
 /*
  * putenv.c -- (un)set an envariable
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
 
 extern char **environ;
 
