@@ -1,20 +1,17 @@
 
 /*
  * pwd.c -- return the current working directory
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
-#include <stdio.h>
 
 #define	MAXPATHLEN 1024
 
 static char curwd[MAXPATHLEN];
 
+
 char *
 pwd(void)
 {
@@ -77,10 +74,10 @@ getwd(char *cwd)
 		goto out;
 	    if (st2.st_dev != st1.st_dev)
 		while (dp = readdir (dd)) {
-		    if (stat (dp -> d_name, &st1) == NOTOK)
+		    if (stat (dp->d_name, &st1) == NOTOK)
 			goto out;
 		    if (st2.st_dev == st1.st_dev) {
-			sprintf (tmp1, "%s%s", dp -> d_name, cwd);
+			sprintf (tmp1, "%s%s", dp->d_name, cwd);
 			strcpy (cwd + 1, tmp1);
 			closedir (dd);
 			return (chdir (cwd));
@@ -94,14 +91,14 @@ getwd(char *cwd)
 
 	found = 0;
 	while (dp = readdir (dd)) {
-	    sprintf (tmp2, "../%s", dp -> d_name);
+	    sprintf (tmp2, "../%s", dp->d_name);
 	    if (stat (tmp2, &st1) != NOTOK
 		    && st1.st_ino == st2.st_ino
 		    && st1.st_dev == st2.st_dev) {
 		closedir (dd);
 		found++;
 		chdir ("..");
-		sprintf (tmp1, "%s%s", dp -> d_name, cwd);
+		sprintf (tmp1, "%s%s", dp->d_name, cwd);
 		strcpy (cwd + 1, tmp1);
 		break;
 	    }
