@@ -1,14 +1,12 @@
 
 /*
  * refile.c -- refile the draft into another folder
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 int
 refile (char **arg, char *file)
