@@ -1,15 +1,12 @@
 
 /*
  * remdir.c -- remove a directory
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	lint
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 int
 remdir (char *dir)
