@@ -1,10 +1,12 @@
 
 /*
  * showfile.c -- invoke lproc
+ *
+ * $Id$
  */
 
 #include "../h/mh.h"
-#include <stdio.h>
+
 
 int
 showfile (char **arg, char *file)
