@@ -1,9 +1,12 @@
 
 /*
  * signals.c -- general signals interface for nmh
+ *
+ * $Id$
  */
 
-#include "../h/nmh.h"
+#include "../h/mh.h"
+
 
 int
 SIGPROCMASK (int how, const sigset_t *set, sigset_t *oset)
