@@ -1,17 +1,12 @@
 
 /*
- * smatch.c - match a switch
+ * smatch.c -- match a switch
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 
-#ifndef abs
-# define abs(i) (i < 0 ? -i : i)
-#endif
 
 int
 smatch(char *string, struct swit *swp)
@@ -25,8 +20,8 @@ smatch(char *string, struct swit *swp)
     if (string == 0)
 	return firstone;
 
-    for (stringlen = strlen (string), tp = swp; tcp = tp -> sw; tp++) {
-	if (stringlen < abs (tp -> minchars))
+    for (stringlen = strlen (string), tp = swp; tcp = tp->sw; tp++) {
+	if (stringlen < abs (tp->minchars))
 	    continue;		/* no match */
 	for (sp = string; *sp == *tcp++;) {
 	    if (*sp++ == 0)
