@@ -1,14 +1,11 @@
 
 /*
  * sprintb.c -- sprintf a %b string
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
 
 
 char *
