@@ -1,18 +1,19 @@
 
 /*
- * strindex.c - "unsigned" lexical index
+ * strindex.c -- "unsigned" lexical index
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
+#include "../h/mh.h"
 
 int
 stringdex (char *p1, char *p2)
 {
     char *p;
 
-    if (p1 == 0 || p2 == 0) return(-1);		/* XXX */
+    if (p1 == 0 || p2 == 0)
+	return (-1);
 
     for (p = p2; *p; p++)
 	if (uprf (p, p1))
