@@ -1,15 +1,12 @@
 
 /*
  * trimcpy.c -- strip [lt]wsp and replace newlines with spaces
+ *
+ * $Id$
  */
 
-#ifndef lint
-static char ident[] = "$Id$";
-#endif
-
 #include "../h/mh.h"
-#include <ctype.h>
-#include <stdio.h>
+
 
 char *
 trimcpy (char *cp)
