@@ -1,17 +1,16 @@
 
 /*
  * uleq.c -- "unsigned" lexical compare
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #define TO_LOWER 040
 #define NO_MASK  000
 
 #include <ctype.h>
 
+
 int
 uleq (char *c1, char *c2)
 {
