@@ -1,17 +1,15 @@
 
 /*
  * vfgets.c -- virtual fgets
+ *
+ * $Id$
  */
 
-#ifndef lint
-static char ident[] = "$Id$";
-#endif
-
 #include "../h/mh.h"
-#include <stdio.h>
 
 #define	QUOTE	'\\'
 
+
 int
 vfgets (FILE *in, char **bp)
 {
@@ -22,7 +20,7 @@ vfgets (FILE *in, char **bp)
 
     if (pp == NULL)
 	if (!(pp = malloc ((size_t) (len = BUFSIZ))))
-	    adios (NULLCP, "unable to allocate string storage");
+	    adios (NULL, "unable to allocate string storage");
 
     for (ep = (cp = pp) + len - 1;;) {
 	if (fgets (cp, ep - cp + 1, in) == NULL) {
@@ -36,7 +34,7 @@ vfgets (FILE *in, char **bp)
 	if ((dp = cp + strlen (cp) - 2) < cp || *dp != QUOTE) {
 wrong_guess: ;
 	    if (cp > ++dp)
-		adios (NULLCP, "vfgets() botch -- you lose big");
+		adios (NULL, "vfgets() botch -- you lose big");
 	    if (*dp == '\n') {
 		*bp = pp;
 		return OK;
@@ -62,7 +60,7 @@ wrong_guess: ;
 	    register int curlen = cp - pp;
 
 	    if (!(dp = realloc (pp, (size_t) (len += BUFSIZ))))
-		adios (NULLCP, "unable to allocate string storage");
+		adios (NULL, "unable to allocate string storage");
 	    else
 		cp = dp + curlen, ep = (pp = dp) + len - 1;
 	}
