@@ -1,50 +1,41 @@
 
 /*
- * ali.c - list mail aliases
+ * ali.c -- list mail aliases
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 #include "../h/addrsbr.h"
 #include "../h/aliasbr.h"
-#include <stdio.h>
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
-#define	NVEC	50		/* maximum number of names */
+/*
+ * maximum number of names
+ */
+#define	NVEC 50
 
 static struct swit switches[] = {
-#define	ALIASW	0
-    "alias aliasfile", 0,
-#define	NALIASW	1
-    "noalias", -7,
-
-#define	LISTSW	2
-    "list", 0,
-#define	NLISTSW	3
-    "nolist", 0,
-
-#define	NORMSW	4
-    "normalize", 0,
-#define	NNORMSW	5
-    "nonormalize", 0,
-
-#define	USERSW	6
-    "user", 0,
-#define	NUSERSW	7
-    "nouser", 0,
-
-#define VERSIONSW 8
-    "version", 0,
-#define	HELPSW	9
-    "help", 4,
-
-    NULL, 0
+#define	ALIASW                0
+    { "alias aliasfile", 0 },
+#define	NALIASW               1
+    { "noalias", -7 },
+#define	LISTSW                2
+    { "list", 0 },
+#define	NLISTSW               3
+    { "nolist", 0 },
+#define	NORMSW                4
+    { "normalize", 0 },
+#define	NNORMSW               5
+    { "nonormalize", 0 },
+#define	USERSW                6
+    { "user", 0 },
+#define	NUSERSW               7
+    { "nouser", 0 },
+#define VERSIONSW             8
+    { "version", 0 },
+#define	HELPSW                9
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 static int pos = 1;
@@ -87,7 +78,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] aliases ...", invo_name);
@@ -99,10 +90,9 @@ main (int argc, char **argv)
 
 		case ALIASW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if ((i = alias (cp)) != AK_OK)
-			adios (NULLCP, "aliasing error in %s - %s",
-				cp, akerror (i));
+			adios (NULL, "aliasing error in %s - %s", cp, akerror (i));
 		    continue;
 		case NALIASW: 
 		    noalias++;
@@ -138,8 +128,7 @@ main (int argc, char **argv)
 
 	    for (ap = brkstring(dp = getcpy(cp), " ", "\n"); ap && *ap; ap++)
 		if ((i = alias (*ap)) != AK_OK)
-		    adios (NULLCP,
-			    "aliasing error in %s - %s", *ap, akerror (i));
+		    adios (NULL, "aliasing error in %s - %s", *ap, akerror (i));
 	    if (dp)
 		free(dp);
 	}
@@ -155,13 +144,12 @@ main (int argc, char **argv)
 		print_aka (akvalue (vec[i]), list, 0);
     else {
 	if (inverted)
-	    adios (NULLCP,
-		    "usage: %s -user addresses ...  (you forgot the addresses)",
-		invo_name);
+	    adios (NULL, "usage: %s -user addresses ...  (you forgot the addresses)",
+		   invo_name);
 
-	for (ak = akahead; ak; ak = ak -> ak_next) {
-	    printf ("%s: ", ak -> ak_name);
-	    pos += strlen (ak -> ak_name) + 1;
+	for (ak = akahead; ak; ak = ak->ak_next) {
+	    printf ("%s: ", ak->ak_name);
+	    pos += strlen (ak->ak_name) + 1;
 	    print_aka (akresult (ak), list, pos);
 	}
     }
@@ -215,22 +203,22 @@ print_usr (char *s, int list, int norm)
     register struct mailname *mp, *np;
 
     if ((pp = getname (s)) == NULL)
-	adios (NULLCP, "no address in \"%s\"", s);
-    if ((mp = getm (pp, NULLCP, 0, norm, NULLCP)) == NULL)
-	adios (NULLCP, "bad address \"%s\"", s);
+	adios (NULL, "no address in \"%s\"", s);
+    if ((mp = getm (pp, NULL, 0, norm, NULL)) == NULL)
+	adios (NULL, "bad address \"%s\"", s);
     while (getname (""))
 	continue;
 
     vp = NULL;
-    for (ak = akahead; ak; ak = ak -> ak_next) {
+    for (ak = akahead; ak; ak = ak->ak_next) {
 	pp = akresult (ak);
 	while (cp = getname (pp)) {
-	    if ((np = getm (cp, NULLCP, 0, norm, NULLCP)) == NULL)
+	    if ((np = getm (cp, NULL, 0, norm, NULL)) == NULL)
 		continue;
-	    if (uleq (mp -> m_host, np -> m_host)
-		    && uleq (mp -> m_mbox, np -> m_mbox)) {
-		vp = vp ? add (ak -> ak_name, add (",", vp))
-		    : getcpy (ak -> ak_name);
+	    if (uleq (mp->m_host, np->m_host)
+		    && uleq (mp->m_mbox, np->m_mbox)) {
+		vp = vp ? add (ak->ak_name, add (",", vp))
+		    : getcpy (ak->ak_name);
 		mnfree (np);
 		while (getname (""))
 		    continue;
