@@ -1,25 +1,16 @@
 
 /*
  * aliasbr.c -- new aliasing mechanism
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 #include "../h/aliasbr.h"
-
-#ifdef	BSD44
-# include <sys/types.h>
-#endif
-
-#include <ctype.h>
 #include <grp.h>
 #include <pwd.h>
-#include <stdio.h>
 
-static int  akvis;
+static int akvis;
 static char *akerrst;
 
 struct aka *akahead = NULL;
@@ -28,13 +19,6 @@ struct aka *akatail = NULL;
 struct home *homehead = NULL;
 struct home *hometail = NULL;
 
-#ifndef	__STDC__
-# ifdef	SYS5
-struct passwd *getpwent();
-struct group  *getgrnam(), *getgrgid();
-# endif
-#endif
-
 /*
  * prototypes
  */
@@ -66,7 +50,7 @@ struct home *seek_home (char *);
 char *
 akvalue (char *s)
 {
-    register char  *v;
+    register char *v;
 
     if (akahead == NULL)
 	alias (AliasFile);
@@ -89,17 +73,15 @@ akvisible (void)
 char *
 akresult (struct aka *ak)
 {
-    register char *cp = NULL,
-                  *dp,
-                  *pp;
+    register char *cp = NULL, *dp, *pp;
     register struct adr *ad;
 
-    for (ad = ak -> ak_addr; ad; ad = ad -> ad_next) {
-	pp = ad -> ad_local ? akval (ak -> ak_next, ad -> ad_text)
-	    : getcpy (ad -> ad_text);
+    for (ad = ak->ak_addr; ad; ad = ad->ad_next) {
+	pp = ad->ad_local ? akval (ak->ak_next, ad->ad_text)
+	    : getcpy (ad->ad_text);
 
 	if (dp = cp) {
-	    cp = concat (cp, ",", pp, NULLCP);
+	    cp = concat (cp, ",", pp, NULL);
 	    free (dp);
 	    free (pp);
 	}
@@ -108,7 +90,7 @@ akresult (struct aka *ak)
     }
 
     if (akvis == -1)
-	akvis = ak -> ak_visible;
+	akvis = ak->ak_visible;
     return cp;
 }
 
@@ -119,8 +101,8 @@ akval (struct aka *ak, char *s)
     if (!s)
 	return s;			/* XXX */
 
-    for (; ak; ak = ak -> ak_next)
-	if (aleq (s, ak -> ak_name))
+    for (; ak; ak = ak->ak_next)
+	if (aleq (s, ak->ak_name))
 	    return akresult (ak);
 
     return getcpy (s);
@@ -194,11 +176,11 @@ alias (char *file)
 	}
 	switch (lc) {
 	    case ':': 
-		ak -> ak_visible = 0;
+		ak->ak_visible = 0;
 		break;
 
 	    case ';': 
-		ak -> ak_visible = 1;
+		ak->ak_visible = 1;
 		break;
 
 	    default: 
@@ -354,9 +336,9 @@ addfile (struct aka *ak, char *file)
 static int
 addgroup (struct aka *ak, char *grp)
 {
-    register char  *gp;
-    register struct group  *gr = getgrnam (grp);
-    register struct home   *hm = NULL;
+    register char *gp;
+    register struct group *gr = getgrnam (grp);
+    register struct home *hm = NULL;
 
     if (!gr)
 	gr = getgrgid (atoi (grp));
@@ -370,14 +352,14 @@ addgroup (struct aka *ak, char *grp)
 	init_pw ();
 #endif /* DBMPWD */
 
-    while (gp = *gr -> gr_mem++)
+    while (gp = *gr->gr_mem++)
 #ifdef DBMPWD
     {
 	struct passwd *pw;
 #endif /* DBMPWD */
-	for (hm = homehead; hm; hm = hm -> h_next)
-	    if (!strcmp (hm -> h_name, gp)) {
-		add_aka (ak, hm -> h_name);
+	for (hm = homehead; hm; hm = hm->h_next)
+	    if (!strcmp (hm->h_name, gp)) {
+		add_aka (ak, hm->h_name);
 		break;
 	    }
 #ifdef DBMPWD
@@ -396,12 +378,12 @@ addgroup (struct aka *ak, char *grp)
 static int
 addmember (struct aka *ak, char *grp)
 {
-    int gid;
-    register struct group  *gr = getgrnam (grp);
-    register struct home   *hm = NULL;
+    gid_t gid;
+    register struct group *gr = getgrnam (grp);
+    register struct home *hm = NULL;
 
     if (gr)
-	gid = gr -> gr_gid;
+	gid = gr->gr_gid;
     else {
 	gid = atoi (grp);
 	gr = getgrgid (gid);
@@ -416,9 +398,9 @@ addmember (struct aka *ak, char *grp)
 #endif /* DBMPWD */
 	init_pw ();
 
-    for (hm = homehead; hm; hm = hm -> h_next)
-	if (hm -> h_gid == gid)
-	    add_aka (ak, hm -> h_name);
+    for (hm = homehead; hm; hm = hm->h_next)
+	if (hm->h_gid == gid)
+	    add_aka (ak, hm->h_name);
 
     return 1;
 }
@@ -427,8 +409,8 @@ addmember (struct aka *ak, char *grp)
 static int
 addall (struct aka *ak)
 {
-    int noshell = NoShell == NULLCP || *NoShell == 0;
-    register struct home   *hm;
+    int noshell = NoShell == NULL || *NoShell == 0;
+    register struct home *hm;
 
 #ifndef DBMPWD
     if (homehead == NULL)
@@ -437,10 +419,10 @@ addall (struct aka *ak)
     if (Everyone < 0)
 	Everyone = EVERYONE;
 
-    for (hm = homehead; hm; hm = hm -> h_next)
-	if (hm -> h_uid > Everyone
-		&& (noshell || strcmp (hm -> h_shell, NoShell)))
-	    add_aka (ak, hm -> h_name);
+    for (hm = homehead; hm; hm = hm->h_next)
+	if (hm->h_uid > Everyone
+		&& (noshell || strcmp (hm->h_shell, NoShell)))
+	    add_aka (ak, hm->h_name);
 
     return homehead != NULL;
 }
@@ -482,20 +464,20 @@ add_aka (struct aka *ak, char *pp)
 {
     register struct adr *ad, *ld;
 
-    for (ad = ak -> ak_addr, ld = NULL; ad; ld = ad, ad = ad -> ad_next)
-	if (!strcmp (pp, ad -> ad_text))
+    for (ad = ak->ak_addr, ld = NULL; ad; ld = ad, ad = ad->ad_next)
+	if (!strcmp (pp, ad->ad_text))
 	    return;
 
     ad = (struct adr *) malloc (sizeof(*ad));
     if (ad == NULL)
 	return;
-    ad -> ad_text = getcpy (pp);
-    ad -> ad_local = index (pp, '@') == NULL && index (pp, '!') == NULL;
-    ad -> ad_next = NULL;
-    if (ak -> ak_addr)
-	ld -> ad_next = ad;
+    ad->ad_text = getcpy (pp);
+    ad->ad_local = index (pp, '@') == NULL && index (pp, '!') == NULL;
+    ad->ad_next = NULL;
+    if (ak->ak_addr)
+	ld->ad_next = ad;
     else
-	ak -> ak_addr = ad;
+	ak->ak_addr = ad;
 }
 
 
@@ -592,8 +574,8 @@ seek_home (char *name)
 	init_pw ();
 #endif /* DBMPWD */
 
-    for (hp = homehead; hp; hp = hp -> h_next)
-	if (uleq (name, hp -> h_name))
+    for (hp = homehead; hp; hp = hp->h_next)
+	if (uleq (name, hp->h_name))
 	    return hp;
 
 #ifdef DBMPWD       /* The only place where there might be problems */
