@@ -1,47 +1,34 @@
 
 /*
  * anno.c -- annotate messages
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <ctype.h>
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define	COMPSW	0
-    "component field", 0,
-
+    { "component field", 0 },
 #define	INPLSW	1
-    "inplace", 0,
+    { "inplace", 0 },
 #define	NINPLSW	2
-    "noinplace", 0,
-
+    { "noinplace", 0 },
 #define	DATESW	3
-    "date", 0,
+    { "date", 0 },
 #define	NDATESW	4
-    "nodate", 0,
-
+    { "nodate", 0 },
 #define	TEXTSW	5
-    "text body", 0,
-
+    { "text body", 0 },
 #define VERSIONSW 6
-    "version", 0,
+    { "version", 0 },
 #define	HELPSW	7
-    "help", 4,
-
-    NULL, 0
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 /*
- * prototypes
+ * static prototypes
  */
 static void make_comp (char **);
 
@@ -75,7 +62,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
@@ -87,9 +74,9 @@ main (int argc, char **argv)
 
 		case COMPSW: 
 		    if (comp)
-			adios (NULLCP, "only one component at a time!");
+			adios (NULL, "only one component at a time!");
 		    if (!(comp = *argp++) || *comp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case DATESW: 
@@ -108,14 +95,14 @@ main (int argc, char **argv)
 
 		case TEXTSW: 
 		    if (text)
-			adios (NULLCP, "only one body at a time!");
+			adios (NULL, "only one body at a time!");
 		    if (!(text = *argp++) || *text == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
@@ -138,9 +125,9 @@ main (int argc, char **argv)
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
-    if (mp -> hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
+    if (mp->hghmsg == 0)
+	adios (NULL, "no messages in %s", folder);
 
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
@@ -148,13 +135,13 @@ main (int argc, char **argv)
 
     make_comp (&comp);
 
-    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	if (mp -> msgstats[msgnum] & SELECTED)
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (mp->msgstats[msgnum] & SELECTED)
 	    annotate (m_name (msgnum), comp, text, inplace, datesw);
 
     m_replace (pfolder, folder);
-    if (mp -> lowsel != mp -> curmsg)
-	m_setcur (mp, mp -> lowsel);
+    if (mp->lowsel != mp->curmsg)
+	m_setcur (mp, mp->lowsel);
     m_sync (mp);
     m_update ();
 
@@ -180,13 +167,13 @@ make_comp (char **ap)
     if ((cp = *ap + strlen (*ap) - 1) > *ap && *cp == ':')
 	*cp = 0;
     if (strlen (*ap) == 0)
-	adios (NULLCP, "null component name");
+	adios (NULL, "null component name");
     if (**ap == '-')
-	adios (NULLCP, "invalid component name %s", *ap);
+	adios (NULL, "invalid component name %s", *ap);
     if (strlen (*ap) >= NAMESZ)
-	adios (NULLCP, "too large component name %s", *ap);
+	adios (NULL, "too large component name %s", *ap);
 
     for (cp = *ap; *cp; cp++)
 	if (!isalnum (*cp) && *cp != '-')
-	    adios (NULLCP, "invalid component name %s", *ap);
+	    adios (NULL, "invalid component name %s", *ap);
 }
