@@ -1,30 +1,26 @@
 
-/* annosbr.c - prepend annotation to messages */
-
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
+/*
+ * annosbr.c -- prepend annotation to messages
+ *
+ * $Id$
+ */
 
 #include "../h/mh.h"
 #include "../zotnet/tws/tws.h"
 #include <errno.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 
 extern int  errno;
-off_t lseek ();
-static annosbr();
 
-annotate (file, comp, text, inplace, datesw)
-register char   *file,
-		*comp,
-		*text;
-int     inplace,
-        datesw;
+/*
+ * static prototypes
+ */
+static int annosbr (int, char *, char *, char *, int, int);
+
+
+int
+annotate (char *file, char *comp, char *text, int inplace, int datesw)
 {
-    int     i,
-            fd;
+    int i, fd;
 
     if ((fd = lkopen (file, 2)) == NOTOK) {
 	switch (errno) {
@@ -39,39 +35,29 @@ int     inplace,
     }
 
     i = annosbr (fd, file, comp, text, inplace, datesw);
-
-    (void) lkclose (fd, file);
-
+    lkclose (fd, file);
     return i;
 }
 
 
-static	annosbr (src, file, comp, text, inplace, datesw)
-register char  *file,
-	       *comp,
-	       *text;
-int     src,
-	inplace,
-	datesw;
+static int
+annosbr (int src, char *file, char *comp, char *text, int inplace, int datesw)
 {
-    int     mode,
-            fd;
-    register char  *cp,
-                   *sp;
-    char    buffer[BUFSIZ],
-            tmpfil[BUFSIZ];
+    int mode, fd;
+    register char *cp, *sp;
+    char buffer[BUFSIZ], tmpfil[BUFSIZ];
     struct stat st;
-    register    FILE *tmp;
+    register FILE *tmp;
 
     mode = fstat (src, &st) != NOTOK ? (st.st_mode & 0777) : m_gmprot ();
 
-    (void) strcpy (tmpfil, m_scratch (file, "annotate"));
+    strcpy (tmpfil, m_scratch (file, "annotate"));
 
     if ((tmp = fopen (tmpfil, "w")) == NULL) {
 	admonish (tmpfil, "unable to create");
 	return 1;
     }
-    (void) chmod (tmpfil, mode);
+    chmod (tmpfil, mode);
 
     if (datesw)
 	fprintf (tmp, "%s: %s\n", comp, dtimenow ());
@@ -86,26 +72,26 @@ int     src,
 		fprintf (tmp, "%s: %*.*s", comp, cp - sp, cp - sp, sp);
 	} while (*cp);
 	if (cp[-1] != '\n' && cp != text)
-	    (void) putc ('\n', tmp);
+	    putc ('\n', tmp);
     }
-    (void) fflush (tmp);
+    fflush (tmp);
     cpydata (src, fileno (tmp), file, tmpfil);
-    (void) fclose (tmp);
+    fclose (tmp);
 
     if (inplace) {
 	if ((fd = open (tmpfil, 0)) == NOTOK)
 	    adios (tmpfil, "unable to open for re-reading");
 	lseek (src, (off_t) 0, 0);
 	cpydata (fd, src, tmpfil, file);
-	(void) close (fd);
-	(void) unlink (tmpfil);
+	close (fd);
+	unlink (tmpfil);
     }
     else {
-	(void) strcpy (buffer, m_backup (file));
+	strcpy (buffer, m_backup (file));
 	if (rename (file, buffer) == NOTOK) {
 	    switch (errno) {
 		case ENOENT:	/* unlinked early - no annotations */
-		    (void) unlink (tmpfil);
+		    unlink (tmpfil);
 		    break;
 
 		default:
