@@ -1,20 +1,13 @@
 
 /*
- * ap.c - parse addresses 822-style
+ * ap.c -- parse addresses 822-style
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 #include "../h/addrsbr.h"
 #include "../h/formatsbr.h"
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 #define	NADDRS	100
 
@@ -25,24 +18,20 @@ static char ident[] = "$Id$";
 
 static struct swit switches[] = {
 #define	FORMSW	0
-    "form formatfile", 0,
+    { "form formatfile", 0 },
 #define	FMTSW	1
-    "format string", 5,
-
+    { "format string", 5 },
 #define	NORMSW	2
-    "normalize", 0,
+    { "normalize", 0 },
 #define	NNORMSW	3
-    "nonormalize", 0,
-
+    { "nonormalize", 0 },
 #define	WIDSW	4
-    "width columns", 0,
-
+    { "width columns", 0 },
 #define VERSIONSW 5
-    "version", 0,
+    { "version", 0 },
 #define	HELPSW	6
-    "help", 4,
-
-    NULL, 0
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 static struct format *fmt;
@@ -50,7 +39,7 @@ static struct format *fmt;
 static int dat[5];
 
 /*
- * prototypes
+ * static prototypes
  */
 static int process (char *, int, int);
 
@@ -85,7 +74,7 @@ main (int argc, char **argv)
 		    done (1);
 
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] addrs ...", invo_name);
@@ -97,18 +86,18 @@ main (int argc, char **argv)
 
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    format = NULL;
 		    continue;
 		case FMTSW: 
 		    if (!(format = *argp++) || *format == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    form = NULL;
 		    continue;
 
 		case WIDSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    width = atoi (cp);
 		    continue;
 
@@ -120,14 +109,14 @@ main (int argc, char **argv)
 		    continue;
 	    }
 	if (addrp > NADDRS)
-	    adios (NULLCP, "more than %d addresses", NADDRS);
+	    adios (NULL, "more than %d addresses", NADDRS);
 	else
 	    addrs[addrp++] = cp;
     }
     addrs[addrp] = NULL;
 
     if (addrp == 0)
-	adios (NULLCP, "usage: %s [switches] addrs ...", invo_name);
+	adios (NULL, "usage: %s [switches] addrs ...", invo_name);
 
     nfs = new_fs (form, format, FORMAT);
     if (width == 0) {
@@ -149,8 +138,8 @@ main (int argc, char **argv)
 }
 
 struct pqpair {
-    char    *pq_text;
-    char    *pq_error;
+    char *pq_text;
+    char *pq_error;
     struct pqpair *pq_next;
 };
 
@@ -159,44 +148,44 @@ static int
 process (char *arg, int length, int norm)
 {
     int	status = 0;
-    register char  *cp;
+    register char *cp;
     char buffer[WBUFSIZ + 1], error[BUFSIZ];
     register struct comp *cptr;
     register struct pqpair *p, *q;
-    struct pqpair   pq;
+    struct pqpair pq;
     register struct mailname *mp;
 
-    (q = &pq) -> pq_next = NULL;
+    (q = &pq)->pq_next = NULL;
     while (cp = getname (arg)) {
 	if ((p = (struct pqpair *) calloc ((unsigned) 1, sizeof *p)) == NULL)
-	    adios (NULLCP, "unable to allocate pqpair memory");
-	if ((mp = getm (cp, NULLCP, 0, norm, error)) == NULL) {
-	    p -> pq_text = getcpy (cp);
-	    p -> pq_error = getcpy (error);
+	    adios (NULL, "unable to allocate pqpair memory");
+	if ((mp = getm (cp, NULL, 0, norm, error)) == NULL) {
+	    p->pq_text = getcpy (cp);
+	    p->pq_error = getcpy (error);
 	    status++;
 	}
 	else {
-	    p -> pq_text = getcpy (mp -> m_text);
+	    p->pq_text = getcpy (mp->m_text);
 	    mnfree (mp);
 	}
-	q = (q -> pq_next = p);
+	q = (q->pq_next = p);
     }
 
     for (p = pq.pq_next; p; p = q) {
 	FINDCOMP (cptr, "text");
 	if (cptr)
-	    cptr -> c_text = p -> pq_text;
+	    cptr->c_text = p->pq_text;
 	FINDCOMP (cptr, "error");
 	if (cptr)
-	    cptr -> c_text = p -> pq_error;
+	    cptr->c_text = p->pq_error;
 
 	fmtscan (fmt, buffer, length, dat);
 	fputs (buffer, stdout);
 
-	free (p -> pq_text);
-	if (p -> pq_error)
-	    free (p -> pq_error);
-	q = p -> pq_next;
+	free (p->pq_text);
+	if (p->pq_error)
+	    free (p->pq_error);
+	q = p->pq_next;
 	free ((char *) p);
     }
 
