@@ -1,20 +1,17 @@
 
 /*
  * bbc.c -- ZOTnet BBoard checker
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	lint
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
-#include "../zotnet/bboards.h"
-#include <stdio.h>
+#include "../h/signals.h"
+#include "../zotnet/bboards/bboards.h"
 
-#ifdef	BPOP
+#ifdef BPOP
 # include "../zotnet/mts.h"
-#endif	BPOP
+#endif /* BPOP */
 
 #include <errno.h>
 #include <signal.h>
@@ -36,89 +33,85 @@ static char ident[] = "$Id$";
 # include <sys/resource.h>
 #endif SIGTSTP
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 #define	RCFILE	".bbrc"
 
 #define	NBB	100
 
 
 static struct swit switches[] = {
-#define	TOPICSW	0
-    "topics", 6,
-#define	CHECKSW	1
-    "check", 5,
-#define	READSW	2
-    "read", 4,
+#define	TOPICSW              0
+    { "topics", 6 },
+#define	CHECKSW              1
+    { "check", 5 },
+#define	READSW               2
+    { "read", 4 },
+#define	QUIETSW              3
+    { "quiet", 4 },
+#define	VERBOSW              4
+    { "verbose", 4 },
+#define ARCHSW               5
+    { "archive", 4 },
+#define NOARCH               6
+    { "noarchive", 3 },
+#define	PROTSW               7
+    { "protocol", 4 },
+#define	NPROTSW              8
+    { "noprotocol", 3 },
+#define	PROGSW               9
+    { "mshproc program", 4 },
+#define	RCSW                10
+    { "rcfile rcfile", 4 },
+#define	NRCSW               11
+    { "norcfile", 3 },
+#define	FILESW              12
+    { "file BBoardsfile", 4 },
 
-#define	QUIETSW	3
-    "quiet", 4,
-#define	VERBOSW	4
-    "verbose", 4,
-
-#define ARCHSW	5
-    "archive", 4,
-#define NOARCH  6
-    "noarchive", 3,
-
-#define	PROTSW	7
-    "protocol", 4,
-#define	NPROTSW	8
-    "noprotocol", 3,
-
-#define	PROGSW	9
-    "mshproc program", 4,
-
-#define	RCSW	10
-    "rcfile rcfile", 4,
-#define	NRCSW	11
-    "norcfile", 3,
-
-#define	FILESW	12
-    "file BBoardsfile", 4,
-#define	USERSW	13
-    "user BBoardsuser",
+#define	USERSW              13
+    { "user BBoardsuser",
 #ifndef	NNTP
-	4,
+	                  4
 #else	NNTP
-	-4,
+	                 -4
 #endif	NNTP
+                            },
 
-#define	HOSTSW	14
-    "host host",
+#define	HOSTSW              14
+    { "host host",
 #ifndef	BPOP
-    -4,
+                   -4
 #else	BPOP
-    4,
+                    4
 #endif	BPOP
-#define	RPOPSW	15
-    "rpop",
-#ifndef	RPOP
-	-4,
-#else	RPOP
-	4,
-#endif	RPOP
-#define	NRPOPSW	16
-    "norpop",
-#ifndef	RPOP
-	-6,
-#else	RPOP
-	6,
-#endif	RPOP
+                      },
 
-#define VERSIONSW 17
-    "version", 0,
-#define	HELPSW	18
-    "help", 4,
+#define	RPOPSW              15
+    { "rpop",
+#ifndef	RPOP
+	      -4
+#else	RPOP
+	       4
+#endif	RPOP
+                 },
 
-    NULL, NULL
+#define	NRPOPSW             16
+    { "norpop",
+#ifndef	RPOP
+	        -6
+#else	RPOP
+	         6
+#endif	RPOP
+                   },
+
+#define VERSIONSW           17
+    { "version", 0 },
+#define	HELPSW              18
+    { "help", 4 },
+    { NULL, NULL }
 };
 
 struct bbcount {
-    char   *key;
-    int     count;
+    char *key;
+    int count;
     struct bbcount *left;
     struct bbcount *right;
 };
@@ -270,12 +263,12 @@ main (int argc, char **argv)
 
 		case PROGSW:
 		    if (!(mshproc = *argp++) || *mshproc == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case RCSW:
 		    if (!(rc = *argp++) || *rc == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case NRCSW:
 		    rc = NULL;
@@ -283,19 +276,19 @@ main (int argc, char **argv)
 
 		case FILESW:
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if (!setbbinfo (user, cp, 1))
-			adios (NULLCP, "setbbinfo(%s, %s, 1) failed -- %s",
+			adios (NULL, "setbbinfo(%s, %s, 1) failed -- %s",
 				user, cp, getbberr ());
 		    continue;
 		case USERSW:
 		    if (!(user = *argp++) || *user == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case HOSTSW:
 		    if (!(host = *argp++) || *host == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    didpop = NOTOK;
 		    continue;
 		case RPOPSW:
@@ -308,7 +301,7 @@ main (int argc, char **argv)
 	if (bbp < NBB)
 	    bbs[bbp++] = cp;
 	else
-	    adios (NULLCP, "too many bboards, starting with %s", cp);
+	    adios (NULL, "too many bboards, starting with %s", cp);
     }
     bbs[bbp] = NULL;
 
@@ -346,7 +339,7 @@ main (int argc, char **argv)
 
 #ifdef	BPOP
     if (didpop != OK && pop_quit () == NOTOK)
-	adios (NULLCP, "%s", response);
+	adios (NULL, "%s", response);
 #endif	BPOP
 
     done (0);
@@ -366,34 +359,34 @@ topics () {
 
     for (bb = bbl ? bbl : getbbvis ();
 	    bb;
-	    bb = bbl ? bb -> bb_link : getbbvis ()) {
+	    bb = bbl ? bb->bb_link : getbbvis ()) {
 	printf ("%16s %5d   %s\n",
-		bb -> bb_name, bb -> bb_maxima,
-		bb -> bb_date ? bb -> bb_date : "no deliveries");
+		bb->bb_name, bb->bb_maxima,
+		bb->bb_date ? bb->bb_date : "no deliveries");
 	if (verbosw) {
-	    if (*bb -> bb_aka) {
+	    if (*bb->bb_aka) {
 		cp = NULL;
-		for (ap = bb -> bb_aka; *ap; ap++)
+		for (ap = bb->bb_aka; *ap; ap++)
 		    cp = add (*ap, cp ? add (", ", cp) : cp);
 		printv ("AKA", cp);
 		free (cp);
 	    }
 
-	    printv ("Leaders", *bb -> bb_leader);
-	    for (ap = bb -> bb_leader + 1; *ap; ap++)
-		printv (NULLCP, *ap);
-	    printv ("File", bb -> bb_file);
-	    printv ("Archive", bb -> bb_archive);
-	    printv ("Info", bb -> bb_info);
-	    printv ("Map", bb -> bb_map);
-	    printv ("Password", bb -> bb_passwd);
-	    if (strcmp (bb -> bb_name, bb -> bb_addr))
-		printv ("Address", bb -> bb_addr);
-	    if (strcmp (*bb -> bb_leader, bb -> bb_request))
-		printv ("Request", bb -> bb_request);
-	    if (*bb -> bb_relay)
-		printv ("Relay", bb -> bb_relay);
-	    if (*bb -> bb_dist) {
+	    printv ("Leaders", *bb->bb_leader);
+	    for (ap = bb->bb_leader + 1; *ap; ap++)
+		printv (NULL, *ap);
+	    printv ("File", bb->bb_file);
+	    printv ("Archive", bb->bb_archive);
+	    printv ("Info", bb->bb_info);
+	    printv ("Map", bb->bb_map);
+	    printv ("Password", bb->bb_passwd);
+	    if (strcmp (bb->bb_name, bb->bb_addr))
+		printv ("Address", bb->bb_addr);
+	    if (strcmp (*bb->bb_leader, bb->bb_request))
+		printv ("Request", bb->bb_request);
+	    if (*bb->bb_relay)
+		printv ("Relay", bb->bb_relay);
+	    if (*bb->bb_dist) {
 		changed = 0;
 		getbbdist (bb, action);
 		if (!changed)
@@ -401,7 +394,7 @@ topics () {
 		if (cp = getbberr ())
 		    printv ("Error", cp);
 	    }
-	    printb (bb -> bb_flags & ~BB_SEEN);
+	    printb (bb->bb_flags & ~BB_SEEN);
 	}
     }
 }
@@ -454,29 +447,29 @@ check () {
     int     diff;
     register struct bboard  *bb;
 
-    for (bb = bbl; bb; bb = bb -> bb_link) {
-	diff = bb -> bb_maxima - bb -> bb_count;
+    for (bb = bbl; bb; bb = bb->bb_link) {
+	diff = bb->bb_maxima - bb->bb_count;
 	if (quietsw) {
 	    if (diff > 0)
 		printf ("%s -- %d item%s unseen\n",
-			bb -> bb_name, diff, plural (diff));
+			bb->bb_name, diff, plural (diff));
 	}
 	else
-	    if (bb -> bb_maxima == 0)
-		printf ("%s -- empty\n", bb -> bb_name);
+	    if (bb->bb_maxima == 0)
+		printf ("%s -- empty\n", bb->bb_name);
 	    else
-		if (bb -> bb_count == 0)
+		if (bb->bb_count == 0)
 		    printf ("%s -- %d item%sseen)\n",
-			    bb -> bb_name, bb -> bb_maxima,
-			    grammar (bb -> bb_maxima, " (un", "s (none "));
+			    bb->bb_name, bb->bb_maxima,
+			    grammar (bb->bb_maxima, " (un", "s (none "));
 		else
 		    if (diff <= 0)
 			printf ("%s -- %d item%s (all seen)\n",
-				bb -> bb_name, bb -> bb_maxima,
-				plural (bb -> bb_maxima));
+				bb->bb_name, bb->bb_maxima,
+				plural (bb->bb_maxima));
 		    else
 			printf ("%s -- %d item%s unseen\n",
-				bb -> bb_name, diff, plural (diff));
+				bb->bb_name, diff, plural (diff));
     }
 }
 
@@ -486,9 +479,9 @@ process (vecp, vec)
 int	vecp;
 char   *vec[];
 {
-    int     diff;
+    int diff;
 #ifdef	SIGTSTP
-    RETSIGTYPE	    (*tstat) ();
+    SIGNAL_HANDLER tstat;
 #endif	SIGTSTP
     register struct bboard *bb;
 
@@ -497,19 +490,19 @@ char   *vec[];
     tstat = signal (SIGTSTP, tstpser);
 #endif	SIGTSTP
 
-    for (bb = bbl; bb && !quitting; bb = bb -> bb_link) {
-	diff = bb -> bb_maxima - bb -> bb_count;
-	if (bb -> bb_maxima == 0) {
+    for (bb = bbl; bb && !quitting; bb = bb->bb_link) {
+	diff = bb->bb_maxima - bb->bb_count;
+	if (bb->bb_maxima == 0) {
 	    if (!quietsw)
-		printf ("%s -- empty\n", bb -> bb_name);
+		printf ("%s -- empty\n", bb->bb_name);
 	    continue;
 	}
 	else {
 	    if (diff < 0) {
 		printf (
 		"Oops! looks like someone reset %s -- assuming all unseen\n",
-		    bb -> bb_name);
-		diff = bb -> bb_maxima;
+		    bb->bb_name);
+		diff = bb->bb_maxima;
 		bbreset (bb, 0);
 	    }
 	    if (verbosw || archivesw || diff > 0)
@@ -517,8 +510,8 @@ char   *vec[];
 	    else
 		if (!quietsw)
 		    printf ("%s -- %d item%s (all seen)\n",
-			    bb -> bb_name, bb -> bb_maxima,
-			    plural (bb -> bb_maxima));
+			    bb->bb_name, bb->bb_maxima,
+			    plural (bb->bb_maxima));
 	}
     };
 
@@ -561,25 +554,25 @@ char   *vec[];
     struct stat st;
 
 #ifdef	BPOP
-    if (bb -> bb_flags & BB_REMOTE) {
+    if (bb->bb_flags & BB_REMOTE) {
 	if (pop_xtnd (xtnd1, "%s %s", archivesw ? "archive" : "bboards",
-			bb -> bb_name) == NOTOK) {
-	    advise (NULLCP, "%s", response);
+			bb->bb_name) == NOTOK) {
+	    advise (NULL, "%s", response);
 	    return;
 	}
 	if (pop_stat (&nmsgs, &nbytes) == NOTOK)
-	    adios (NULLCP, "%s", response);
+	    adios (NULL, "%s", response);
 	if (nmsgs == 0) {
 	    if (verbosw)
-		printf ("%s -- empty\n", bb -> bb_name);
+		printf ("%s -- empty\n", bb->bb_name);
 	    return;
 	}
 	if (pop_fd (buf4, buf5) == NOTOK)
-	    adios (NULLCP, "%s", response);
+	    adios (NULL, "%s", response);
     }
     else
 #endif	BPOP
-    if (stat (archivesw ? bb -> bb_archive : bb -> bb_file, &st) != NOTOK
+    if (stat (archivesw ? bb->bb_archive : bb->bb_file, &st) != NOTOK
 	    && st.st_size == 0)
 	return;
 
@@ -596,10 +589,10 @@ char   *vec[];
 	case OK: 
 	    if (protsw) {
 		close (pd[0]);
-		sprintf (buf1, "%d", bb -> bb_count + 1);
+		sprintf (buf1, "%d", bb->bb_count + 1);
 		sprintf (buf2, "%d", pd[1]);
 		vec[vecp++] = "-idname";
-		vec[vecp++] = bb -> bb_name;
+		vec[vecp++] = bb->bb_name;
 		vec[vecp++] = "-idstart";
 		vec[vecp++] = buf1;
 		vec[vecp++] = "-idstop";
@@ -608,14 +601,14 @@ char   *vec[];
 		vec[vecp++] = buf3;
 	    }
 #ifdef	BPOP
-	    if (bb -> bb_flags & BB_REMOTE) {
+	    if (bb->bb_flags & BB_REMOTE) {
 		vec[vecp++] = "-popread";
 		vec[vecp++] = buf4;
 		vec[vecp++] = "-popwrite";
 		vec[vecp++] = buf5;
 	    }
 #endif	BPOP
-	    vec[vecp++] = archivesw ? bb -> bb_archive : bb -> bb_file;
+	    vec[vecp++] = archivesw ? bb->bb_archive : bb->bb_file;
 	    vec[vecp] = NULL;
 	    execvp (mshproc, vec);
 	    fprintf (stderr, "unable to exec ");
@@ -642,10 +635,8 @@ int     pd,
         child_id;
 register struct bboard  *bb;
 {
-    int     i,
-            j,
-            n;
-    RETSIGTYPE (*estat) (), (*hstat) (), (*istat) (), (*qstat) (), (*tstat) ();
+    int i, j, n;
+    SIGNAL_HANDLER estat, hstat, istat, qstat, tstat;
     char    buffer[BUFSIZ];
     struct bbcount *selected;
 
@@ -671,22 +662,22 @@ register struct bboard  *bb;
     if (sscanf (buffer, "%d %d", &i, &j) != 2 || i <= 0 || j <= 0)
 	return;
 
-    if ((selected = seek_count (bbc, bb -> bb_name)) == NULL) {
-	bbc = add_count (bbc, bb -> bb_name, i);
+    if ((selected = seek_count (bbc, bb->bb_name)) == NULL) {
+	bbc = add_count (bbc, bb->bb_name, i);
 	changed++;
     }
     else
 	if (archivesw) {
-	    if (i > selected -> count) {
-		selected -> count = i;
+	    if (i > selected->count) {
+		selected->count = i;
 		changed++;
 	    }
 	}
 	else {
-	    if (bb -> bb_maxima > j && i >= j)/* bbl... */
-		i = bb -> bb_maxima;
-	    if (i != selected -> count) {
-		selected -> count = i;
+	    if (bb->bb_maxima > j && i >= j)/* bbl... */
+		i = bb->bb_maxima;
+	    if (i != selected->count) {
+		selected->count = i;
 		changed++;
 	    }
 	}
@@ -737,7 +728,7 @@ register char  *rc;
 	    m_putenv ("MHBBRC", rcfile);
     }
     else
-	rcfile = concat (mypath, "/", RCFILE, NULLCP);
+	rcfile = concat (mypath, "/", RCFILE, NULL);
 
     if ((bbrc = fopen (rcfile, "r")) == NULL)
 	if (cp && *cp)
@@ -756,7 +747,7 @@ register char  *rc;
 		continue;
 
 	    default: 
-		admonish (NULLCP, "bad format: %s", rcfile);
+		admonish (NULL, "bad format: %s", rcfile);
 	    case FILEEOF:
 		break;
 	}
@@ -772,7 +763,7 @@ register char  *rc;
 /*  */
 
 rcend () {
-    RETSIGTYPE (*hstat) (), (*istat) (), (*qstat) (), (*tstat) ();
+    SIGNAL_HANDLER hstat, istat, qstat, tstat;
     register FILE *bbrc;
 
     if (!changed)
@@ -807,9 +798,9 @@ register struct bbcount *p;
     if (p == NULL)
 	return;
 
-    fprintf (bbrc, "%s: %d\n", p -> key, p -> count);
-    rcput (bbrc, p -> left);
-    rcput (bbrc, p -> right);
+    fprintf (bbrc, "%s: %d\n", p->key, p->count);
+    rcput (bbrc, p->left);
+    rcput (bbrc, p->right);
 }
 
 
@@ -855,11 +846,11 @@ int i;
 {
     struct bbcount *selected;
 
-    bb -> bb_count = i;
-    if ((selected = seek_count (bbc, bb -> bb_name)) == NULL)
-	bbc = add_count (bbc, bb -> bb_name, i);
+    bb->bb_count = i;
+    if ((selected = seek_count (bbc, bb->bb_name)) == NULL)
+	bbc = add_count (bbc, bb->bb_name, i);
     else
-	selected -> count = i;
+	selected->count = i;
 
     changed++;
 }
@@ -874,17 +865,17 @@ int     i;
     if (p == NULL) {
 	p = (struct bbcount *) malloc (sizeof *p);
 	if (p == NULL)
-	    adios (NULLCP,"insufficient memory");
-	p -> key = getcpy (w);
-	p -> count = i;
-	p -> left = p -> right = NULL;
+	    adios (NULL,"insufficient memory");
+	p->key = getcpy (w);
+	p->count = i;
+	p->left = p->right = NULL;
     }
     else
-	if ((cond = strcmp (w, p -> key)) < 0)
-	    p -> left = add_count (p -> left, w, i);
+	if ((cond = strcmp (w, p->key)) < 0)
+	    p->left = add_count (p->left, w, i);
 	else
 	    if (cond > 0)
-		p -> right = add_count (p -> right, w, i);
+		p->right = add_count (p->right, w, i);
 
     return p;
 }
@@ -896,10 +887,10 @@ register char   *w;
 {
     int     cond;
 
-    if (p == NULL || (cond = strcmp (w, p -> key)) == 0)
+    if (p == NULL || (cond = strcmp (w, p->key)) == 0)
 	return p;
     else
-	return seek_count (cond < 0 ? p -> left : p -> right, w);
+	return seek_count (cond < 0 ? p->left : p->right, w);
 }
 
 /*  */
@@ -932,7 +923,7 @@ default_bboards () {
 	free (cp);
 #endif	not BPOP
 	if (oops)
-	    advise (NULLCP, "please fix the %s: entry in your %s file",
+	    advise (NULL, "please fix the %s: entry in your %s file",
 		"bboards", mh_profile);
     }
     else {
@@ -972,19 +963,19 @@ int     hush;
 	if (hush == OK)
 	    return;
 	else
-	    adios (NULLCP, "no such bboard as '%s'", s);
+	    adios (NULL, "no such bboard as '%s'", s);
 
-    if (bb -> bb_flags & BB_SEEN) {
+    if (bb->bb_flags & BB_SEEN) {
 	if (hush == OK) {
-	    admonish (NULLCP, "duplicate bboard '%s'", s);
+	    admonish (NULL, "duplicate bboard '%s'", s);
 	    oops++;
 	}
 	return;
     }
-    bb -> bb_flags |= BB_SEEN;
+    bb->bb_flags |= BB_SEEN;
 
     if (tail != NULL)
-	tail -> bb_link = bb;
+	tail->bb_link = bb;
     if (bbl == NULL)
 	bbl = bb;
     tail = bb;
@@ -1004,48 +995,48 @@ char   *s;
     register struct bboard *bb;
 
     if (sscanf (s, "%s %d", name, &maxima) != 2)
-	adios (NULLCP, "XTND2 botch: %s", s);
+	adios (NULL, "XTND2 botch: %s", s);
 
     if ((bb = (struct bboard   *) calloc (1, sizeof *bb)) == NULL)
-	adios (NULLCP, "insufficient memory");
-    bb -> bb_name = getcpy (name);
+	adios (NULL, "insufficient memory");
+    bb->bb_name = getcpy (name);
 #ifdef	NNTP
     if (index(name, '.')) {
 	char *cp;
-	bb -> bb_aka = getip (name);
-	for (cp = *bb -> bb_aka; *cp; cp++)
+	bb->bb_aka = getip (name);
+	for (cp = *bb->bb_aka; *cp; cp++)
 	    if (*cp == '.')
 		*cp = '-';
     } else {
 #endif
-    if ((bb -> bb_aka = (char **) calloc (1, sizeof *bb -> bb_aka)) == NULL)
-	adios (NULLCP, "insufficient memory");
-    *bb -> bb_aka = NULL;
+    if ((bb->bb_aka = (char **) calloc (1, sizeof *bb->bb_aka)) == NULL)
+	adios (NULL, "insufficient memory");
+    *bb->bb_aka = NULL;
 #ifdef	NNTP
     }
 #endif	NNTP
-    bb -> bb_file = bb -> bb_archive = bb -> bb_info = bb -> bb_map = "";
-    bb -> bb_passwd = "";
+    bb->bb_file = bb->bb_archive = bb->bb_info = bb->bb_map = "";
+    bb->bb_passwd = "";
 #ifndef	NNTP
-    if ((bb -> bb_leader = (char **) calloc (1, sizeof *bb -> bb_leader))
+    if ((bb->bb_leader = (char **) calloc (1, sizeof *bb->bb_leader))
 	    == NULL)
-	adios (NULLCP, "insufficient memory");
-    *bb -> bb_leader = NULL;
+	adios (NULL, "insufficient memory");
+    *bb->bb_leader = NULL;
 #else	NNTP
-    bb -> bb_leader = getip ("usenet");
+    bb->bb_leader = getip ("usenet");
 #endif	NNTP
-    bb -> bb_addr = bb -> bb_request = bb -> bb_relay = "";
-    if ((bb -> bb_dist = (char **) calloc (1, sizeof *bb -> bb_dist)) == NULL)
-	adios (NULLCP, "insufficient memory");
-    *bb -> bb_dist = NULL;
-    bb -> bb_flags = BB_REMOTE;
-    bb -> bb_count = 0;
-    bb -> bb_maxima = maxima;
-    bb -> bb_date = "";
-    bb -> bb_next = bb -> bb_link = bb -> bb_chain = NULL;
+    bb->bb_addr = bb->bb_request = bb->bb_relay = "";
+    if ((bb->bb_dist = (char **) calloc (1, sizeof *bb->bb_dist)) == NULL)
+	adios (NULL, "insufficient memory");
+    *bb->bb_dist = NULL;
+    bb->bb_flags = BB_REMOTE;
+    bb->bb_count = 0;
+    bb->bb_maxima = maxima;
+    bb->bb_date = "";
+    bb->bb_next = bb->bb_link = bb->bb_chain = NULL;
 
     if (Btail != NULL)
-	Btail -> bb_chain = bb;
+	Btail->bb_chain = bb;
     if (Bhead == NULL)
 	Bhead = bb;
     Btail = bb;
@@ -1063,61 +1054,61 @@ char   *s;
 
     switch (bbs_int++) {
 	case 0: 
-	    for (bb = Bhead; bb; bb = bb -> bb_chain)
-		if (strcmp (bb -> bb_name, s) == 0)
+	    for (bb = Bhead; bb; bb = bb->bb_chain)
+		if (strcmp (bb->bb_name, s) == 0)
 		    break;
 	    if (bb == NULL)
-		adios (NULLCP, "XTND3 botch");
+		adios (NULL, "XTND3 botch");
 
-	    free (bb -> bb_name);
-	    bb -> bb_name = getcpy (s);
+	    free (bb->bb_name);
+	    bb->bb_name = getcpy (s);
 	    break;
 	case 1: 
-	    if (bb -> bb_aka)
-		free ((char *) bb -> bb_aka);
-	    bb -> bb_aka = getip (s);
+	    if (bb->bb_aka)
+		free ((char *) bb->bb_aka);
+	    bb->bb_aka = getip (s);
 	    break;
 	case 2: 
-	    bb -> bb_file = getcpy (s);
+	    bb->bb_file = getcpy (s);
 	    break;
 	case 3: 
-	    bb -> bb_archive = getcpy (s);
+	    bb->bb_archive = getcpy (s);
 	    break;
 	case 4: 
-	    bb -> bb_info = getcpy (s);
+	    bb->bb_info = getcpy (s);
 	    break;
 	case 5: 
-	    bb -> bb_map = getcpy (s);
+	    bb->bb_map = getcpy (s);
 	    break;
 	case 6: 
-	    bb -> bb_passwd = getcpy (s);
+	    bb->bb_passwd = getcpy (s);
 	    break;
 	case 7: 
-	    if (bb -> bb_leader)
-		free ((char *) bb -> bb_leader);
-	    bb -> bb_leader = getip (s);
+	    if (bb->bb_leader)
+		free ((char *) bb->bb_leader);
+	    bb->bb_leader = getip (s);
 	    break;
 	case 8: 
-	    bb -> bb_addr = getcpy (s);
+	    bb->bb_addr = getcpy (s);
 	    break;
 	case 9: 
-	    bb -> bb_request = getcpy (s);
+	    bb->bb_request = getcpy (s);
 	    break;
 	case 10: 
-	    bb -> bb_relay = getcpy (s);
+	    bb->bb_relay = getcpy (s);
 	    break;
 	case 11: 
-	    if (bb -> bb_dist)
-		free ((char *) bb -> bb_dist);
-	    bb -> bb_dist = getip (s);
+	    if (bb->bb_dist)
+		free ((char *) bb->bb_dist);
+	    bb->bb_dist = getip (s);
 	    break;
 	case 12: 
-	    bb -> bb_flags = bb -> bb_maxima = 0;
-	    sscanf (s, "%o %d", &bb -> bb_flags, &bb -> bb_maxima);
-	    bb -> bb_flags |= BB_REMOTE;
+	    bb->bb_flags = bb->bb_maxima = 0;
+	    sscanf (s, "%o %d", &bb->bb_flags, &bb->bb_maxima);
+	    bb->bb_flags |= BB_REMOTE;
 	    break;
 	case 13: 
-	    bb -> bb_date = getcpy (s);
+	    bb->bb_date = getcpy (s);
 	    bbs_int = 0;
 	    break;
     }
@@ -1138,7 +1129,7 @@ char   *s;
 
     q = (char **) calloc ((unsigned) (p - ap + 1), sizeof *q);
     if (q == NULL)
-	adios (NULLCP, "insufficient memory");
+	adios (NULL, "insufficient memory");
 
     for (p = ap, ap = q; *p; *q++ = *p++)
 	continue;
@@ -1176,15 +1167,15 @@ struct bboard  *getbbpop () {
 	    didpop = DONE;
 
 	if (pop_init (host, user, pass, snoop, rpop) == NOTOK)
-	    adios (NULLCP, "%s", response);
+	    adios (NULL, "%s", response);
 	if (rpop)
 	    setuid (getuid ());
 	if (pop_xtnd (xtnd2, "bboards") == NOTOK)
-	    adios (NULLCP, "%s", response);
+	    adios (NULL, "%s", response);
 	if (topicsw && verbosw)	/* could optimize here */
-	    for (bb = Bhead; bb; bb = bb -> bb_chain)
-		if (pop_xtnd (xtnd3, "x-bboards %s", bb -> bb_name) == NOTOK)
-		    adios (NULLCP, "%s", response);
+	    for (bb = Bhead; bb; bb = bb->bb_chain)
+		if (pop_xtnd (xtnd3, "x-bboards %s", bb->bb_name) == NOTOK)
+		    adios (NULL, "%s", response);
 	rover = Bhead;
     }
 
@@ -1210,10 +1201,10 @@ register char	*s;
     static struct bboard   *head = NULL,
                            *tail = NULL;
 
-    for (bb = head; bb; bb = bb -> bb_next) {
-	if (strcmp (bb -> bb_name, s) == 0)
+    for (bb = head; bb; bb = bb->bb_next) {
+	if (strcmp (bb->bb_name, s) == 0)
 	    return bb;
-	for (ap = bb -> bb_aka; *ap; ap++)
+	for (ap = bb->bb_aka; *ap; ap++)
 	    if (strcmp (*ap, s) == 0)
 		return bb;
     }
@@ -1222,26 +1213,26 @@ register char	*s;
 one_more_time: ;
 #endif	BPOP
     while (bb = getbbent ()) {
-	if ((selected = seek_count (bbc, bb -> bb_name)) != NULL)
-	    bb -> bb_count = selected -> count;
+	if ((selected = seek_count (bbc, bb->bb_name)) != NULL)
+	    bb->bb_count = selected->count;
 
 #ifdef	BPOP
-	if (!(bb -> bb_flags & BB_REMOTE))
+	if (!(bb->bb_flags & BB_REMOTE))
 #endif	BPOP
 	if ((bb = getbbcpy (bb)) == NULL)
-	    adios (NULLCP, "insufficient memory");
+	    adios (NULL, "insufficient memory");
 	if (tail != NULL)
-	    tail -> bb_next = bb;
+	    tail->bb_next = bb;
 	if (head == NULL)
 	    head = bb;
 	tail = bb;
 
-	if (strcmp (bb -> bb_name, s) == 0) {
+	if (strcmp (bb->bb_name, s) == 0) {
 found_it: ;
-	    bb -> bb_flags &= ~BB_SEEN;
+	    bb->bb_flags &= ~BB_SEEN;
 	    return bb;
 	}
-	for (ap = bb -> bb_aka; *ap; ap++)
+	for (ap = bb->bb_aka; *ap; ap++)
 	    if (strcmp (*ap, s) == 0)
 		goto found_it;
     }
@@ -1262,8 +1253,8 @@ struct bboard *getbbvis () {
     register struct bboard *bb;
 
     while (bb = getbbent ())
-	if (!(bb -> bb_flags & BB_INVIS)
-		&& (access (bb -> bb_file, 04) != NOTOK || errno != EACCES))
+	if (!(bb->bb_flags & BB_INVIS)
+		&& (access (bb->bb_file, 04) != NOTOK || errno != EACCES))
 	    break;
 
     return bb;
