@@ -1,54 +1,38 @@
 
 /*
- * conflict.c -- the new conflict
+ * conflict.c -- check for conflicts in mail system
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
 #include "../h/aliasbr.h"
-#include <stdio.h>
 #include "../zotnet/mts/mts.h"
 #include <grp.h>
 #include <pwd.h>
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 #define	NDIRS	100
 #define	NGRPS	100
 
 static struct swit switches[] = {
 #define	MAILSW	0
-    "mail name", 0,
+    { "mail name", 0 },
 #define	SERCHSW	1
-    "search directory", 0,
+    { "search directory", 0 },
 #define VERSIONSW 2
-    "version", 0,
+    { "version", 0 },
 #define	HELPSW	3
-    "help", 4,
-
-    NULL, 0
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 static char *mail = NULL;
-
 static char *dirs[NDIRS];
-
 static FILE *out = NULL;
 
-
 extern struct aka  *akahead;
 extern struct home *homehead;
 
-#if !defined(__STDC__) && !defined(__stdc__)	/* __stdc__ for convex */
-struct	group *getgrent (), *getgrgid();
-#endif /* !__STDC__ */
-
 /*
  * prototypes
  */
@@ -73,7 +57,7 @@ main (int argc, char **argv)
 	setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    m_foil (NULLCP);
+    m_foil (NULL);
     mts_init (invo_name);
 
     while (cp = *argp++) {
@@ -83,7 +67,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] [aliasfiles ...]", invo_name);
@@ -95,18 +79,18 @@ main (int argc, char **argv)
 
 		case MAILSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if (mail)
-			adios (NULLCP, "mail to one address only");
+			adios (NULL, "mail to one address only");
 		    else
 			mail = cp;
 		    continue;
 
 		case SERCHSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if (dp >= NDIRS)
-			adios (NULLCP, "more than %d directories", NDIRS);
+			adios (NULL, "more than %d directories", NDIRS);
 		    dirs[dp++] = cp;
 		    continue;
 	    }
@@ -158,12 +142,12 @@ pwd_names (void)
     int hit = 0;
     register struct home *hm, *lm;
 
-    for (hm = homehead; hm; hm = hm -> h_next)
-	for (lm = hm -> h_next; lm; lm = lm -> h_next)
-	    if (strcmp (hm -> h_name, lm -> h_name) == 0) {
+    for (hm = homehead; hm; hm = hm->h_next)
+	for (lm = hm->h_next; lm; lm = lm->h_next)
+	    if (strcmp (hm->h_name, lm->h_name) == 0) {
 		setup ();
 		fprintf (out, "duplicate user %s(uid=%d)\n",
-			lm -> h_name, lm -> h_uid);
+			lm->h_name, lm->h_uid);
 		hit++;
 	    }
 
@@ -175,25 +159,24 @@ pwd_names (void)
 void
 grp_names (void)
 {
-    register int    gp,
-                    hit = 0;
-    char   *grps[NGRPS];
+    register int gp, hit = 0;
+    char *grps[NGRPS];
     register struct group  *gr;
 
     grps[0] = NULL;
     setgrent ();
     while (gr = getgrent ()) {
 	for (gp = 0; grps[gp]; gp++)
-	    if (strcmp (grps[gp], gr -> gr_name) == 0) {
+	    if (strcmp (grps[gp], gr->gr_name) == 0) {
 		setup ();
 		fprintf (out, "duplicate group %s(gid=%d)\n",
-			gr -> gr_name, gr -> gr_gid);
+			gr->gr_name, gr->gr_gid);
 		hit++;
 		break;
 	    }
 	if (grps[gp] == NULL)
 	    if (gp < NGRPS) {
-		grps[gp++] = getcpy (gr -> gr_name);
+		grps[gp++] = getcpy (gr->gr_name);
 		grps[gp] = NULL;
 	    }
 	    else {
@@ -216,45 +199,44 @@ grp_names (void)
 void
 grp_members (void)
 {
-    register int    hit = 0;
-    register char **cp,
-                  **dp;
-    register struct group  *gr;
-    register struct home   *hm;
+    register int hit = 0;
+    register char **cp, **dp;
+    register struct group *gr;
+    register struct home  *hm;
 
     setgrent ();
     while (gr = getgrent ())
-	for (cp = gr -> gr_mem; *cp; cp++) {
-	    for (hm = homehead; hm; hm = hm -> h_next)
-		if (!strcmp (*cp, hm -> h_name))
+	for (cp = gr->gr_mem; *cp; cp++) {
+	    for (hm = homehead; hm; hm = hm->h_next)
+		if (!strcmp (*cp, hm->h_name))
 		    break;
 	    if (hm == NULL) {
 		setup ();
 		fprintf (out, "group %s(gid=%d) has unknown member %s\n",
-			gr -> gr_name, gr -> gr_gid, *cp);
+			gr->gr_name, gr->gr_gid, *cp);
 		hit++;
 	    }
 #ifdef	BSD42
 	    else
-		hm -> h_ngrps++;
+		hm->h_ngrps++;
 #endif	/* BSD42 */
 
 	    for (dp = cp + 1; *dp; dp++)
 		if (strcmp (*cp, *dp) == 0) {
 		    setup ();
 		    fprintf (out, "group %s(gid=%d) has duplicate member %s\n",
-			    gr -> gr_name, gr -> gr_gid, *cp);
+			    gr->gr_name, gr->gr_gid, *cp);
 		    hit++;
 		}
 	}
     endgrent ();
 
 #ifdef	BSD42
-    for (hm = homehead; hm; hm = hm -> h_next)
-	if (hm -> h_ngrps > NGROUPS) {
+    for (hm = homehead; hm; hm = hm->h_next)
+	if (hm->h_ngrps > NGROUPS) {
 	    setup ();
 	    fprintf (out, "user %s is a member of %d groups (max %d)",
-		    hm -> h_name, hm -> h_ngrps, NGROUPS);
+		    hm->h_name, hm->h_ngrps, NGROUPS);
 	    hit++;
 	}
 #endif	/* BSD42 */
@@ -267,14 +249,14 @@ grp_members (void)
 void
 grp_ids (void)
 {		/* -DRAND not implemented at most places */
-    register int    hit = 0;
-    register struct home   *hm;
+    register int hit = 0;
+    register struct home *hm;
 
-    for (hm = homehead; hm; hm = hm -> h_next)
-	if (getgrgid (hm -> h_gid) == NULL) {
+    for (hm = homehead; hm; hm = hm->h_next)
+	if (getgrgid (hm->h_gid) == NULL) {
 	    setup ();
 	    fprintf (out, "user %s(uid=%d) has unknown group-id %d\n",
-		    hm -> h_name, hm -> h_uid, hm -> h_gid);
+		    hm->h_name, hm->h_uid, hm->h_gid);
 	    hit++;
 	}
 
@@ -286,7 +268,7 @@ grp_ids (void)
 void
 maildrops (void) 
 {
-    register int    i;
+    register int i;
 
     if (mmdfldir && *mmdfldir)
 	mdrop (mmdfldir);
@@ -300,7 +282,7 @@ maildrops (void)
 void
 mdrop(char *drop)
 {
-    register int    hit = 0;
+    register int hit = 0;
     register struct dirent *dp;
     register DIR *dd = opendir (drop);
 
@@ -311,11 +293,11 @@ mdrop(char *drop)
     }
 
     while (dp = readdir (dd))
-	if (dp -> d_name[0] != '.' && !check (dp ->d_name)) {
+	if (dp->d_name[0] != '.' && !check (dp->d_name)) {
 	    setup ();
 	    fprintf (out,
 		    "there is a maildrop for the unknown user %s in %s\n",
-		    dp -> d_name, drop);
+		    dp->d_name, drop);
 	    hit++;
 	}
 
@@ -330,8 +312,8 @@ check (char *s)
 {
     register struct home *hm;
 
-    for (hm = homehead; hm; hm = hm -> h_next)
-	if (!strcmp (s, hm -> h_name))
+    for (hm = homehead; hm; hm = hm->h_next)
+	if (!strcmp (s, hm->h_name))
 	    return 1;
     return 0;
 }
@@ -364,7 +346,7 @@ setup (void)
 			close (fd);
 		    }
 		execlp (mailproc, r1bindex (mailproc, '/'),
-			mail, "-subject", invo_name, NULLCP);
+			mail, "-subject", invo_name, NULL);
 		adios (mailproc, "unable to exec ");
 
 	    default: 
@@ -388,7 +370,7 @@ struct grpldr {
     char **gl_ldr;
 };
 
-int	setglent (), endglent ();
+int setglent (), endglent ();
 struct grpldr *getglent (), *getglnam ();
 
 
@@ -459,7 +441,7 @@ char   *name;
 
     setglent ();
     while (gl = getglent ())
-	if (strcmp (name, gl -> gl_name) == 0)
+	if (strcmp (name, gl->gl_name) == 0)
 	    break;
     endglent ();
 
@@ -475,23 +457,23 @@ ldr_names () {
     gldrs[0] = NULL;
     setglent ();
     while (gl = getglent ()) {
-	if (getgrnam (gl -> gl_name) == NULL) {
+	if (getgrnam (gl->gl_name) == NULL) {
 	    setup ();
 	    fprintf (out, "unknown group %s in group leaders file\n",
-		    gl -> gl_name);
+		    gl->gl_name);
 	    hit++;
 	}
 	for (gp = 0; gldrs[gp]; gp++)
-	    if (strcmp (gldrs[gp], gl -> gl_name) == 0) {
+	    if (strcmp (gldrs[gp], gl->gl_name) == 0) {
 		setup ();
 		fprintf (out, "duplicate group %s in group leaders file\n",
-			gl -> gl_name);
+			gl->gl_name);
 		hit++;
 		break;
 	    }
 	if (gldrs[gp] == NULL)
 	    if (gp < NGRPS) {
-		gldrs[gp++] = getcpy (gl -> gl_name);
+		gldrs[gp++] = getcpy (gl->gl_name);
 		gldrs[gp] = NULL;
 	    }
 	    else {
@@ -519,11 +501,11 @@ ldr_ship () {
 
     setglent ();
     while (gl = getglent ())
-	for (cp = gl -> gl_ldr; *cp; cp++) {
+	for (cp = gl->gl_ldr; *cp; cp++) {
 	    if (!check (*cp)) {
 		setup ();
 		fprintf (out, "group %s has unknown leader %s\n",
-			gl -> gl_name, *cp);
+			gl->gl_name, *cp);
 		hit++;
 	    }
 
@@ -531,7 +513,7 @@ ldr_ship () {
 		if (strcmp (*cp, *dp) == 0) {
 		    setup ();
 		    fprintf (out, "group %s had duplicate leader %s\n",
-			    gl -> gl_name, *cp);
+			    gl->gl_name, *cp);
 		    hit++;
 		}
 	}
