@@ -1,115 +1,78 @@
 
 /*
- * dist.c - re-distribute a message
+ * dist.c -- re-distribute a message
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define	ANNOSW	0
-    "annotate", 0,
+    { "annotate", 0 },
 #define	NANNOSW	1
-    "noannotate", 0,
-
+    { "noannotate", 0 },
 #define	DFOLDSW	2
-    "draftfolder +folder", 0,
+    { "draftfolder +folder", 0 },
 #define	DMSGSW	3
-    "draftmessage msg", 0,
+    { "draftmessage msg", 0 },
 #define	NDFLDSW	4
-    "nodraftfolder", 0,
-
+    { "nodraftfolder", 0 },
 #define	EDITRSW	5
-    "editor editor", 0,
+    { "editor editor", 0 },
 #define	NEDITSW	6
-    "noedit", 0,
-
+    { "noedit", 0 },
 #define	FORMSW	7
-    "form formfile", 0,
-
+    { "form formfile", 0 },
 #define	INPLSW	8
-    "inplace", 0,
+    { "inplace", 0 },
 #define	NINPLSW	9
-    "noinplace", 0,
-
+    { "noinplace", 0 },
 #define	WHATSW	10
-    "whatnowproc program", 0,
+    { "whatnowproc program", 0 },
 #define	NWHATSW	11
-    "nowhatnowproc", 0,
-
+    { "nowhatnowproc", 0 },
 #define VERSIONSW 12
-    "version", 0,
+    { "version", 0 },
 #define	HELPSW	13
-    "help", 4,
-
+    { "help", 4 },
 #define	FILESW	14
-    "file file", -4,		/* interface from msh */
-
-    NULL, 0
+    { "file file", -4 },	/* interface from msh */
+    { NULL, 0 }
 };
 
 static struct swit aqrnl[] = {
 #define	NOSW	0
-    "quit", 0,
+    { "quit", 0 },
 #define	YESW	1
-    "replace", 0,
+    { "replace", 0 },
 #define	LISTDSW	2
-    "list", 0,
+    { "list", 0 },
 #define	REFILSW	3
-    "refile +folder", 0,
+    { "refile +folder", 0 },
 #define NEWSW	4
-    "new", 0,
-
-    NULL, 0
+    { "new", 0 },
+    { NULL, 0 }
 };
 
 
 static struct swit aqrl[] = {
-    "quit", 0,
-    "replace", 0,
-    "list", 0,
-    "refile +folder", 0,
-
-    NULL, 0
+    { "quit", 0 },
+    { "replace", 0 },
+    { "list", 0 },
+    { "refile +folder", 0 },
+    { NULL, 0 }
 };
 
 
 main (int argc, char **argv)
 {
-    int     anot = 0,
-            inplace = 0,
-	    nedit = 0,
-	    nwhat = 0,
-            i,
-            in,
-	    isdf = 0,
-            out;
-    char   *cp,
-	   *cwd,
-           *maildir,
-	   *msgnam,
-           *dfolder = NULL,
-           *dmsg = NULL,
-           *ed = NULL,
-           *file = NULL,
-           *folder = NULL,
-           *form = NULL,
-           *msg = NULL,
-            buf[100],
-	    drft[BUFSIZ],
-          **ap,
-          **argp,
-           *arguments[MAXARGS];
+    int anot = 0, inplace = 0, nedit = 0;
+    int nwhat = 0, i, in, isdf = 0, out;
+    char *cp, *cwd, *maildir, *msgnam, *dfolder = NULL;
+    char *dmsg = NULL, *ed = NULL, *file = NULL, *folder = NULL;
+    char *form = NULL, *msg = NULL, buf[100], drft[BUFSIZ];
+    char **ap, **argp, *arguments[MAXARGS];
     struct msgs *mp = NULL;
     struct stat st;
 
@@ -133,7 +96,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msg] [switches]", invo_name);
@@ -152,7 +115,7 @@ main (int argc, char **argv)
 
 		case EDITRSW: 
 		    if (!(ed = *argp++) || *ed == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    nedit = 0;
 		    continue;
 		case NEDITSW:
@@ -161,7 +124,7 @@ main (int argc, char **argv)
 		    
 		case WHATSW: 
 		    if (!(whatnowproc = *argp++) || *whatnowproc == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    nwhat = 0;
 		    continue;
 		case NWHATSW: 
@@ -170,14 +133,14 @@ main (int argc, char **argv)
 
 		case FILESW: 
 		    if (file)
-			adios (NULLCP, "only one file at a time!");
+			adios (NULL, "only one file at a time!");
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    file = path (cp, TFILE);
 		    continue;
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case INPLSW: 
@@ -189,17 +152,17 @@ main (int argc, char **argv)
 
 		case DFOLDSW: 
 		    if (dfolder)
-			adios (NULLCP, "only one draft folder at a time!");
+			adios (NULL, "only one draft folder at a time!");
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    dfolder = path (*cp == '+' || *cp == '@' ? cp + 1 : cp,
 			    *cp != '@' ? TFOLDER : TSUBCWF);
 		    continue;
 		case DMSGSW: 
 		    if (dmsg)
-			adios (NULLCP, "only one draft message at a time!");
+			adios (NULL, "only one draft message at a time!");
 		    if (!(dmsg = *argp++) || *dmsg == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case NDFLDSW: 
 		    dfolder = NULL;
@@ -208,13 +171,13 @@ main (int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
 	else
 	    if (msg)
-		adios (NULLCP, "only one message at a time!");
+		adios (NULL, "only one message at a time!");
 	    else
 		msg = cp;
     }
@@ -224,7 +187,7 @@ main (int argc, char **argv)
     if (!m_find ("path"))
 	free (path ("./", TFOLDER));
     if (file && (msg || folder))
-	adios (NULLCP, "can't mix files and folders/msgs");
+	adios (NULL, "can't mix files and folders/msgs");
 
     if (form) {
 	if ((in = open (libpath (form), 0)) == NOTOK)
@@ -259,7 +222,7 @@ try_it_again: ;
 			i = YESW;
 		    break;
 		default: 
-		    advise (NULLCP, "say what?");
+		    advise (NULL, "say what?");
 		    break;
 	    }
 	}
@@ -285,26 +248,26 @@ try_it_again: ;
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
-    if (mp -> hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
+    if (mp->hghmsg == 0)
+	adios (NULL, "no messages in %s", folder);
 
     if (!m_convert (mp, msg))
 	done (1);
     m_setseq (mp);
 
-    if (mp -> numsel > 1)
-	adios (NULLCP, "only one message at a time!");
+    if (mp->numsel > 1)
+	adios (NULL, "only one message at a time!");
 
 go_to_it: ;
-    if ((in = open (msgnam = file ? file : getcpy (m_name (mp -> lowsel)), 0))
+    if ((in = open (msgnam = file ? file : getcpy (m_name (mp->lowsel)), 0))
 	    == NOTOK)
 	adios (msgnam, "unable to open message");
 
     if (!file) {
 	m_replace (pfolder, folder);
-	if (mp -> lowsel != mp -> curmsg)
-	    m_setcur (mp, mp -> lowsel);
+	if (mp->lowsel != mp->curmsg)
+	    m_setcur (mp, mp->lowsel);
 	m_sync (mp);
 	m_update ();
     }
@@ -312,6 +275,6 @@ go_to_it: ;
     if (nwhat)
 	done (0);
     what_now (ed, nedit, NOUSE, drft, msgnam, 1, mp,
-	anot ? "Resent" : NULLCP, inplace, cwd);
+	anot ? "Resent" : NULL, inplace, cwd);
     done (1);
 }
