@@ -1,20 +1,13 @@
 
 /*
- * dp.c  - parse dates 822-style
+ * dp.c -- parse dates 822-style
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 #include "../h/formatsbr.h"
 #include "../zotnet/tws/tws.h"
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 #define	NDATES 100
 
@@ -24,29 +17,25 @@ static char ident[] = "$Id$";
 #define	FORMAT "%<(nodate{text})error: %{text}%|%(putstr(pretty{text}))%>"
 
 static struct swit switches[] = {
-#define	FORMSW	0
-    "form formatfile", 0,
-#define	FMTSW	1
-    "format string", 5,
-
-#define	WIDSW	2
-    "width columns", 0,
-
-#define VERSIONSW 3
-    "version", 0,
-#define	HELPSW	4
-    "help", 4,
-
-    NULL, 0
+#define	FORMSW                0
+    { "form formatfile", 0 },
+#define	FMTSW                 1
+    { "format string", 5 },
+#define	WIDSW                 2
+    { "width columns", 0 },
+#define VERSIONSW             3
+    { "version", 0 },
+#define	HELPSW                4
+    { "help", 4 },
+    { NULL, 0 }
 };
 
-
 static struct format *fmt;
 
 static int dat[5];
 
 /*
- * prototypes
+ * static prototypes
  */
 static int process (char *, int);
 
@@ -78,7 +67,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] dates ...", invo_name);
@@ -90,30 +79,30 @@ main (int argc, char **argv)
 
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    format = NULL;
 		    continue;
 		case FMTSW: 
 		    if (!(format = *argp++) || *format == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    form = NULL;
 		    continue;
 
 		case WIDSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    width = atoi (cp);
 		    continue;
 	    }
 	if (datep > NDATES)
-	    adios (NULLCP, "more than %d dates", NDATES);
+	    adios (NULL, "more than %d dates", NDATES);
 	else
 	    dates[datep++] = cp;
     }
     dates[datep] = NULL;
 
     if (datep == 0)
-	adios (NULLCP, "usage: %s [switches] dates ...", invo_name);
+	adios (NULL, "usage: %s [switches] dates ...", invo_name);
 
     nfs = new_fs (form, format, FORMAT);
     if (width == 0) {
@@ -145,7 +134,7 @@ process (char *date, int length)
 
     FINDCOMP (cptr, "text");
     if (cptr)
-	cptr -> c_text = date;
+	cptr->c_text = date;
     fmtscan (fmt, buffer, length, dat);
     fputs (buffer, stdout);
 
