@@ -1,9 +1,9 @@
 
-/* dropsbr.c - write to a mailbox */
-
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
+/*
+ * dropsbr.c -- write to a mailbox
+ *
+ * $Id$
+ */
 
 #include "../h/nmh.h"
 
@@ -30,21 +30,28 @@ static char ident[] = "$Id$";
 
 static int mbx_style = MMDF;
 
-static int mbx_create(), mbx_chk(), map_open();
-
 extern int errno;
 
-off_t lseek();
+/*
+ * static prototypes
+ */
+static int mbx_create (char *, uid_t, gid_t, mode_t);
+static int mbx_chk (int);
+static int map_open (char *, int *, int);
 
 
-int mbx_mmdf() {
+int
+mbx_mmdf(void)
+{
     int style = mbx_style;
 
     mbx_style = MMDF;
     return style;
 }
 
-int mbx_uucp() {
+int
+mbx_uucp(void)
+{
     int style = mbx_style;
 
     mbx_style = UUCP;
@@ -52,7 +59,8 @@ int mbx_uucp() {
 }
 
 
-int mbx_open (char *file, int uid, int gid, int mode)
+int
+mbx_open (char *file, uid_t uid, gid_t gid, mode_t mode)
 {
     int clear, fd;
 
@@ -81,12 +89,8 @@ int mbx_open (char *file, int uid, int gid, int mode)
 }
 
 
-int	mbx_Xopen (file, uid, gid, mode, clear)
-char   *file;
-int	uid,
-	gid,
-	mode,
-       *clear;
+int
+mbx_Xopen (char *file, uid_t uid, gid_t gid, mode_t mode, int *clear)
 {
     register int j;
     int	count, fd;
@@ -122,13 +126,10 @@ int	uid,
 }
 
 
-static int  mbx_create (file, uid, gid, mode)
-char   *file;
-int     uid,
-        gid,
-	mode;
+static int
+mbx_create (char *file, uid_t uid, gid_t gid, mode_t mode)
 {
-    int     fd;
+    int fd;
 
     if ((fd = creat (file, 0600)) == NOTOK)
 	return NOTOK;
@@ -144,8 +145,8 @@ int     uid,
 static int
 mbx_chk (int fd)
 {
-    int     count;
-    char    ldelim[BUFSIZ];
+    size_t count;
+    char ldelim[BUFSIZ];
 
     count = strlen (mmdlm2);
 
@@ -163,27 +164,19 @@ mbx_chk (int fd)
 }
 
 
-int	mbx_read (fp, pos, drops, noisy)
-register FILE  *fp;
-register long	pos;
-struct drop **drops;
-int	noisy;
+int
+mbx_read (FILE *fp, long pos, struct drop **drops, int noisy)
 {
-    register int    len,
-                    size;
-    register long     ld1,
-		    ld2;
-    register char  *bp;
-    char    buffer[BUFSIZ];
-    register struct drop   *cp,
-                           *dp,
-                           *ep,
-                           *pp;
+    register int len, size;
+    register long ld1, ld2;
+    register char *bp;
+    char buffer[BUFSIZ];
+    register struct drop *cp, *dp, *ep, *pp;
 
-    pp = (struct drop  *) calloc ((unsigned) (len = MAXFOLDER), sizeof *dp);
+    pp = (struct drop *) calloc ((size_t) (len = MAXFOLDER), sizeof *dp);
     if (pp == NULL) {
 	if (noisy)
-	    admonish (NULLCP, "unable to allocate drop storage");
+	    admonish (NULL, "unable to allocate drop storage");
 	return NOTOK;
     }
 
@@ -194,9 +187,9 @@ int	noisy;
     for (ep = (dp = pp) + len - 1; fgets (buffer, sizeof buffer, fp);) {
 	size = 0;
 	if (strcmp (buffer, mmdlm1) == 0)
-	    pos += ld1, dp -> d_start = (long) pos;
+	    pos += ld1, dp->d_start = (long) pos;
 	else {
-	    dp -> d_start = (long)pos , pos += (long) strlen (buffer);
+	    dp->d_start = (long)pos , pos += (long) strlen (buffer);
 	    for (bp = buffer; *bp; bp++, size++)
 		if (*bp == '\n')
 		    size++;
@@ -212,10 +205,10 @@ int	noisy;
 			size++;
 	    }
 
-	if (dp -> d_start != (long) pos) {
-	    dp -> d_id = 0;
-	    dp -> d_size = (long) size;
-	    dp -> d_stop = (long) pos;
+	if (dp->d_start != (long) pos) {
+	    dp->d_id = 0;
+	    dp->d_size = (long) size;
+	    dp->d_stop = (long) pos;
 	    dp++;
 	}
 	pos += ld2;
@@ -223,11 +216,11 @@ int	noisy;
 	if (dp >= ep) {
 	    register int    curlen = dp - pp;
 
-	    cp = (struct drop  *) realloc ((char *) pp,
-		                    (unsigned) (len += MAXFOLDER) * sizeof *pp);
+	    cp = (struct drop *) realloc ((char *) pp,
+		                    (size_t) (len += MAXFOLDER) * sizeof *pp);
 	    if (cp == NULL) {
 		if (noisy)
-		    admonish (NULLCP, "unable to allocate drop storage");
+		    admonish (NULL, "unable to allocate drop storage");
 		free ((char *) pp);
 		return 0;
 	    }
@@ -256,11 +249,11 @@ mbx_write(char *mailbox, int md, FILE *fp, int id, long last,
     j = strlen (mmdlm1);
     if (write (md, mmdlm1, j) != j)
 	return NOTOK;
-    start = (long) lseek (md, (off_t)0, 1);
+    start = (long) lseek (md, (off_t) 0, 1);
     size = 0;
 
     fseek (fp, pos, 0);
-    while (fgets (buffer, sizeof buffer, fp) != NULL && pos < stop) {
+    while (fgets (buffer, sizeof buffer, fp) && (pos < stop)) {
 	i = strlen (buffer);
 	for (j = 0; (j = stringdex (mmdlm1, buffer)) >= 0; buffer[j]++)
 	    continue;
@@ -391,15 +384,12 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 }
 
 
-int 	mbx_size (md, start, stop)
-int	md;
-long	start,
-	stop;
+int
+mbx_size (int md, long start, long stop)
 {
-    register int    i,
-                    fd;
-    register long   pos;
-    register FILE  *fp;
+    register int i, fd;
+    register long pos;
+    register FILE *fp;
 
     if ((fd = dup (md)) == NOTOK || (fp = fdopen (fd, "r")) == NULL) {
 	if (fd != NOTOK)
@@ -418,9 +408,8 @@ long	start,
 }
 
 
-int     mbx_close (mailbox, md)
-char   *mailbox;
-int     md;
+int
+mbx_close (char *mailbox, int md)
 {
     lkclose (md, mailbox);
 
@@ -430,7 +419,7 @@ int     md;
 
 /* This function is performed implicitly by getbbent.c:
 
-		bb -> bb_map = map_name (bb -> bb_file);
+		bb->bb_map = map_name (bb->bb_file);
 */
 
 char *
@@ -450,19 +439,13 @@ map_name (char *file)
 }
 
 
-int	map_read (file, pos, drops, noisy)
-char   *file;
-long	pos;
-struct drop **drops;
-int	noisy;
+int
+map_read (char *file, long pos, struct drop **drops, int noisy)
 {
-    register int    i, j,
-                    md,
-                    msgp;
-    register char  *cp;
+    register int i, j, md, msgp;
+    register char *cp;
     struct drop d;
-    register struct drop   *mp,
-                           *dp;
+    register struct drop *mp, *dp;
 
     if ((md = open (cp = map_name (file), 0)) == NOTOK
 	    || map_chk (cp, md, mp = &d, pos, noisy)) {
@@ -471,8 +454,8 @@ int	noisy;
 	return 0;
     }
 
-    msgp = mp ->d_id;
-    dp = (struct drop  *) calloc ((unsigned) (msgp + 1), sizeof *dp);
+    msgp = mp->d_id;
+    dp = (struct drop *) calloc ((size_t) (msgp + 1), sizeof *dp);
     if (dp == NULL) {
 	close (md);
 	return 0;
@@ -504,26 +487,15 @@ int	noisy;
 }
 
 
-int     map_write (mailbox, md, id, last, start, stop, pos, size, noisy)
-register char   *mailbox;
-int     md,
-        id,
-	size,
-	noisy;
-long   last,
-	start,
-        stop,
-        pos;
+int
+map_write (char *mailbox, int md, int id, long last, long start,
+           long stop, long pos, int size, int noisy)
 {
-    register int    i;
-    int     clear,
-            fd,
-            td;
-    char   *file;
-    register struct drop   *dp;
-    struct drop    d1,
-		   d2,
-                  *rp;
+    register int i;
+    int clear, fd, td;
+    char *file;
+    register struct drop *dp;
+    struct drop d1, d2, *rp;
     register FILE *fp;
 
     if ((fd = map_open (file = map_name (mailbox), &clear, md)) == NOTOK)
@@ -559,8 +531,8 @@ long   last,
 	    default:
 		d1.d_id = 0;
 		for (dp = rp; i-- >0; dp++) {
-		    if (dp -> d_start == start)
-			dp -> d_id = id;
+		    if (dp->d_start == start)
+			dp->d_id = id;
 		    lseek (fd, (off_t) (++d1.d_id * sizeof *dp), 0);
 		    if (write (fd, (char *) dp, sizeof *dp) != sizeof *dp) {
 			if (noisy)
@@ -610,33 +582,27 @@ long   last,
 }
 
 
-static int  map_open (file, clear, md)
-char   *file;
-int    *clear,
-	md;
+static int
+map_open (char *file, int *clear, int md)
 {
-    int	    mode;
-    struct  stat st;
+    mode_t mode;
+    struct stat st;
 
-    mode = fstat (md, &st) != NOTOK ? (int) (st.st_mode & 0777) : m_gmprot ();
+    mode = fstat (md, &st) != NOTOK ? (mode_t) (st.st_mode & 0777) : m_gmprot ();
     return mbx_Xopen (file, st.st_uid, st.st_gid, mode, clear);
 }
 
 
-int  map_chk (file, fd, dp, pos, noisy)
-char   *file;
-int     fd,
-	noisy;
-register struct drop *dp;
-long	pos;
+int
+map_chk (char *file, int fd, struct drop *dp, long pos, int noisy)
 {
-    long    count;
+    long count;
     struct drop d, tmpd;
-    register struct drop    *dl;
+    register struct drop *dl;
 
     if (read (fd, (char *) &tmpd, sizeof *dp) != sizeof *dp) {
 #ifdef	notdef
-	admonish (NULLCP, "%s: missing or partial index", file);
+	admonish (NULL, "%s: missing or partial index", file);
 #endif	/* notdef */
 	return NOTOK;
     }
@@ -649,35 +615,35 @@ long	pos;
     dp->d_stop = ntohl(tmpd.d_stop);
 #endif
     
-    if (dp -> d_size != DRVRSN) {
+    if (dp->d_size != DRVRSN) {
 	if (noisy)
-	    admonish (NULLCP, "%s: version mismatch (%d != %d)", file,
+	    admonish (NULL, "%s: version mismatch (%d != %d)", file,
 				dp->d_size, DRVRSN);
 	return NOTOK;
     }
 
-    if (dp -> d_stop != (long) pos) {
-	if (noisy && pos != (long)0)
-	    admonish (NULLCP,
+    if (dp->d_stop != (long) pos) {
+	if (noisy && pos != (long) 0)
+	    admonish (NULL,
 		    "%s: pointer mismatch or incomplete index (%ld!=%ld)", 
-		    file, dp -> d_stop, (long) pos);
+		    file, dp->d_stop, (long) pos);
 	return NOTOK;
     }
 
-    if ((long) ((dp -> d_id + 1) * sizeof *dp) != (long) lseek (fd, (off_t) 0, 2)) {
+    if ((long) ((dp->d_id + 1) * sizeof *dp) != (long) lseek (fd, (off_t) 0, 2)) {
 	if (noisy)
-	    admonish (NULLCP, "%s: corrupt index(1)", file);
+	    admonish (NULL, "%s: corrupt index(1)", file);
 	return NOTOK;
     }
 
     dl = &d;
     count = (long) strlen (mmdlm2);
-    lseek (fd, (off_t) (dp -> d_id * sizeof *dp), 0);
+    lseek (fd, (off_t) (dp->d_id * sizeof *dp), 0);
     if (read (fd, (char *) dl, sizeof *dl) != sizeof *dl
-	    || (ntohl(dl -> d_stop) != dp -> d_stop
-		&& ntohl(dl -> d_stop) + count != dp -> d_stop)) {
+	    || (ntohl(dl->d_stop) != dp->d_stop
+		&& ntohl(dl->d_stop) + count != dp->d_stop)) {
 	if (noisy)
-	    admonish (NULLCP, "%s: corrupt index(2)", file);
+	    admonish (NULL, "%s: corrupt index(2)", file);
 	return NOTOK;
     }
 
