@@ -11,47 +11,37 @@
  * control laws. This software is made available AS IS, and Xerox Corporation
  * makes no warranty about the software, its performance or its conformity to
  * any specification.
- * 
+ *
+ *  $Id$
  */
 
-#include "../h/nmh.h"
 #include "../h/mh.h"
 
-#ifdef notdef
-# include <sys/param.h>
-# include <sys/types.h>
-# include <sys/stat.h>
-#endif
-
 #define FALSE   0
 #define TRUE    1
 
 static struct swit switches[] = {
 #define ALPHASW         0
-    "alpha", 0,
+    { "alpha", 0 },
 #define NOALPHASW       1
-    "noalpha", 0,
-
+    { "noalpha", 0 },
 #define TOTAL           2
-    "total", 0,
+    { "total", 0 },
 #define NOTOTAL         3
-    "nototal", 0,
-
+    { "nototal", 0 },
 #define RECURSE         4
-    "recurse", 0,
+    { "recurse", 0 },
 #define NORECURSE       5
-    "norecurse", 0,
-
+    { "norecurse", 0 },
 #define ALLSW           6
-    "all", 0,
+    { "all", 0 },
 #define UNSEENSW        7
-    "unseen", 0,
-
+    { "unseen", 0 },
 #define VERSIONSW	8
-    "version", 0,
+    { "version", 0 },
 #define HELPSW          9
-    "help", 4,
-    NULL, NULL
+    { "help", 4 },
+    { NULL, NULL }
 };
 
 struct Folder {
@@ -77,7 +67,10 @@ int noTotal = FALSE;		/* display the folder name only? */
 int recurse = FALSE;		/* show nested folders? */
 char *unseenSequence;
 
-/* This keeps compiler happy on calls to qsort */
+/*
+ * Type for a compare function for qsort.  This keeps
+ * the compiler happy.
+ */
 typedef int (*qsort_comp) (const void *, const void *);
 
 /*
@@ -120,7 +113,7 @@ main(int argc, char **argv)
 		ambigsw(cp, switches);
 		done(1);
 	    case UNKWNSW:
-		adios(NULLCP, "-%s unknown", cp);
+		adios(NULL, "-%s unknown", cp);
 
 	    case HELPSW:
 		sprintf(buf, "%s [switches]", invo_name);
