@@ -1,22 +1,14 @@
 
 /*
- * fmtdump.c - compile format file and dump out instructions
+ * fmtdump.c -- compile format file and dump out instructions
+ *
+ * $Id$
  */
 
-#ifndef lint
-static char ident[] = "$Id$";
-#endif
-
 #include "../h/mh.h"
 #include "../h/formatsbr.h"
 #include "../h/fmtcompile.h"
 #include "../h/scansbr.h"
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 
 static struct swit switches[] = {
 #define	FORMSW	0
@@ -37,7 +29,7 @@ static 	struct format *lvec[128];
 static 	lused = 0;
 
 /*
- * prototypes
+ * static prototypes
  */
 static void fmt_dump (struct format *);
 static void dumpone(struct format *);
@@ -82,7 +74,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches]", invo_name);
@@ -94,18 +86,18 @@ main (int argc, char **argv)
 
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    format = NULL;
 		    continue;
 		case FMTSW: 
 		    if (!(format = *argp++) || *format == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    form = NULL;
 		    continue;
 
 	    }
 	if (form)
-	    adios (NULLCP, "only one form at a time!");
+	    adios (NULL, "only one form at a time!");
 	else
 	    form = cp;
     }
