@@ -1,20 +1,12 @@
 
 /*
- * folder(s).c - report on folders
+ * folder(s).c -- report on folders
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
 #include <errno.h>
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define	ALLSW	0
@@ -100,19 +92,20 @@ static char *folds[NFOLDERS + 1];
 static void dodir (char *);
 static int pfold (char *, char *);
 static int sfold (struct msgs *, char *);
-struct msgs *tfold (struct msgs *);
 static void addir (char *);
 static void addfold (char *);
 static int compare (char *, char *);
 static void dother (void);
 
+struct msgs *tfold (struct msgs *);
+
 
 main (int argc, char **argv)
 {
-    int all = 0, printsw = 0, listsw = 0,
-        pushsw = 0, popsw = 0;
-    char *cp, *dp, *msg = NULL, *argfolder = NULL,
-         **ap, **argp, buf[100], *arguments[MAXARGS];
+    int all = 0, printsw = 0, listsw = 0;
+    int pushsw = 0, popsw = 0;
+    char *cp, *dp, *msg = NULL, *argfolder = NULL;
+    char **ap, **argp, buf[100], *arguments[MAXARGS];
     struct stat st;
 
 #ifdef LOCALE
@@ -419,7 +412,7 @@ pfold (char *fold, char *msg)
     if (fshort)
 	goto out;
     foldtot++;
-    msgtot += mp -> nummsg;
+    msgtot += mp->nummsg;
 
     if (ftotonly)
 	goto out;
@@ -432,23 +425,23 @@ pfold (char *fold, char *msg)
     printf ("%22s%c ", fold, strcmp (folder, fold) ? ' ' : '+');
 
     hack = 0;
-    if (mp -> hghmsg == 0)
+    if (mp->hghmsg == 0)
 	printf ("has   no messages%*s",
-		mp -> msgflags & OTHERS ? DMAXFOLDER * 2 + 4 : 0, "");
+		mp->msgflags & OTHERS ? DMAXFOLDER * 2 + 4 : 0, "");
     else {
 	printf ("has %*d message%s (%*d-%*d)",
-		DMAXFOLDER, mp -> nummsg, (mp -> nummsg == 1) ? " " : "s",
-		DMAXFOLDER, mp -> lowmsg, DMAXFOLDER, mp -> hghmsg);
-	if (mp -> curmsg >= mp -> lowmsg && mp -> curmsg <= mp -> hghmsg)
-	    printf ("; cur=%*d", DMAXFOLDER, hack = mp -> curmsg);
+		DMAXFOLDER, mp->nummsg, (mp->nummsg == 1) ? " " : "s",
+		DMAXFOLDER, mp->lowmsg, DMAXFOLDER, mp->hghmsg);
+	if (mp->curmsg >= mp->lowmsg && mp->curmsg <= mp->hghmsg)
+	    printf ("; cur=%*d", DMAXFOLDER, hack = mp->curmsg);
     }
 
-    if (mp -> msgflags & OTHERS)
+    if (mp->msgflags & OTHERS)
 	printf (";%*s (others)", hack ? 0 : DMAXFOLDER + 6, "");
     printf (".\n");
 
 out: ;
-    others = mp -> msgflags & OTHERS;
+    others = mp->msgflags & OTHERS;
     m_fmsg (mp);
 
     if (frecurse && others)
@@ -463,12 +456,12 @@ sfold (struct msgs *mp, char *msg)
     if (!m_convert (mp, msg))
 	return 0;
 
-    if (mp -> numsel > 1) {
+    if (mp->numsel > 1) {
 	admonish (NULL, "only one message at a time!");
 	return 0;
     }
     m_setseq (mp);
-    m_setcur (mp, mp -> lowsel);
+    m_setcur (mp, mp->lowsel);
     m_sync (mp);
     m_update ();
 
@@ -479,16 +472,14 @@ sfold (struct msgs *mp, char *msg)
 struct msgs *
 tfold (struct msgs *mp)
 {
-    register int    hole,
-                    msgnum;
-    char    newmsg[BUFSIZ],
-            oldmsg[BUFSIZ];
+    register int hole, msgnum;
+    char newmsg[BUFSIZ], oldmsg[BUFSIZ];
 
-    if (mp -> lowmsg > 1 && (mp = m_remsg (mp, 1, mp -> hghmsg)) == NULL)
+    if (mp->lowmsg > 1 && (mp = m_remsg (mp, 1, mp->hghmsg)) == NULL)
 	adios (NULL, "unable to allocate folder storage");
 
-    for (msgnum = mp -> lowmsg, hole = 1; msgnum <= mp -> hghmsg; msgnum++)
-	if (mp -> msgstats[msgnum] & EXISTS) {
+    for (msgnum = mp->lowmsg, hole = 1; msgnum <= mp->hghmsg; msgnum++)
+	if (mp->msgstats[msgnum] & EXISTS) {
 	    if (msgnum != hole) {
 		strcpy (newmsg, m_name (hole));
 		strcpy (oldmsg, m_name (msgnum));
@@ -496,20 +487,20 @@ tfold (struct msgs *mp)
 		    printf ("message %s becomes %s\n", oldmsg, newmsg);
 		if (rename (oldmsg, newmsg) == NOTOK)
 		    adios (newmsg, "unable to rename %s to", oldmsg);
-		if (msgnum == mp -> curmsg)
-		    m_setcur (mp, mp -> curmsg = hole);
-		mp -> msgstats[hole] = mp -> msgstats[msgnum];
-		mp -> msgflags |= SEQMOD;
-		if (msgnum == mp -> lowsel)
-		    mp -> lowsel = hole;
-		if (msgnum == mp -> hghsel)
-		    mp -> hghsel = hole;
+		if (msgnum == mp->curmsg)
+		    m_setcur (mp, mp->curmsg = hole);
+		mp->msgstats[hole] = mp->msgstats[msgnum];
+		mp->msgflags |= SEQMOD;
+		if (msgnum == mp->lowsel)
+		    mp->lowsel = hole;
+		if (msgnum == mp->hghsel)
+		    mp->hghsel = hole;
 	    }
 	    hole++;
 	}
-    if (mp -> nummsg > 0) {
-	mp -> lowmsg = 1;
-	mp -> hghmsg = hole - 1;
+    if (mp->nummsg > 0) {
+	mp->lowmsg = 1;
+	mp->hghmsg = hole - 1;
     }
     m_sync (mp);
     m_update ();
@@ -540,7 +531,7 @@ addir (char *name)
 	return;
     }
     while (dp = readdir (dd))
-	if (strcmp (dp -> d_name, ".") && strcmp (dp -> d_name, "..")) {
+	if (strcmp (dp->d_name, ".") && strcmp (dp->d_name, "..")) {
 	    if (cp + NLENGTH(dp) + 2 >= name + BUFSIZ)
 		continue;
 	    strcpy (cp, dp->d_name);
@@ -555,9 +546,8 @@ addir (char *name)
 static void
 addfold (char *fold)
 {
-    register int    i,
-                    j;
-    register char  *cp;
+    register int i, j;
+    register char *cp;
 
     if (foldp > NFOLDERS)
 	adios (NULL, "more than %d folders to report on", NFOLDERS);
@@ -590,16 +580,16 @@ compare (char *s1, char *s2)
 static void
 dother (void)
 {
-    int	    atrlen;
-    char    atrcur[BUFSIZ];
-    register struct node   *np;
+    int	atrlen;
+    char atrcur[BUFSIZ];
+    register struct node *np;
 
     sprintf (atrcur, "atr-%s-", current);
     atrlen = strlen (atrcur);
 
     m_getdefs ();
-    for (np = m_defs; np; np = np -> n_next)
-	if (ssequal (atrcur, np -> n_name)
-		&& !ssequal (mhdir, np -> n_name + atrlen))
-	    pfold (np -> n_name + atrlen, NULL);
+    for (np = m_defs; np; np = np->n_next)
+	if (ssequal (atrcur, np->n_name)
+		&& !ssequal (mhdir, np->n_name + atrlen))
+	    pfold (np->n_name + atrlen, NULL);
 }
