@@ -1,21 +1,14 @@
 
 /*
- * forw.c - forward messages
+ * forw.c -- forward messages
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
 #include "../h/formatsbr.h"
 #include "../zotnet/tws/tws.h"
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 #ifndef	MIME
 # define MIMEminc(a) (a)
 #else
@@ -120,7 +113,6 @@ static struct swit aqrl[] = {
     NULL, 0
 };
 
-
 static char drft[BUFSIZ];
 
 static char delim3[] =
@@ -132,7 +124,7 @@ static struct msgs *mp = NULL;		/* used a lot */
 
 
 /*
- * prototypes
+ * static prototypes
  */
 static int build_form (char *, char *, int, int);
 static copy_draft (int, char *, char *, int, int, int);
@@ -197,7 +189,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
@@ -216,7 +208,7 @@ main (int argc, char **argv)
 
 		case EDITRSW: 
 		    if (!(ed = *argp++) || *ed == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    nedit = 0;
 		    continue;
 		case NEDITSW:
@@ -225,7 +217,7 @@ main (int argc, char **argv)
 
 		case WHATSW: 
 		    if (!(whatnowproc = *argp++) || *whatnowproc == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    nwhat = 0;
 		    continue;
 #ifdef MHE
@@ -238,20 +230,20 @@ main (int argc, char **argv)
 
 		case FILESW: 
 		    if (file)
-			adios (NULLCP, "only one file at a time!");
+			adios (NULL, "only one file at a time!");
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    file = path (cp, TFILE);
 		    continue;
 		case FILTSW:
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    filter = getcpy (libpath (cp));
 		    mime = 0;
 		    continue;
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case FRMTSW:
@@ -280,35 +272,35 @@ main (int argc, char **argv)
 
 		case DGSTSW: 
 		    if (!(digest = *argp++) || *digest == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    mime = 0;
 		    continue;
 		case ISSUESW:
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if ((issue = atoi (cp)) < 1)
-			adios (NULLCP, "bad argument %s %s", argp[-2], cp);
+			adios (NULL, "bad argument %s %s", argp[-2], cp);
 		    continue;
 		case VOLUMSW:
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if ((volume = atoi (cp)) < 1)
-			adios (NULLCP, "bad argument %s %s", argp[-2], cp);
+			adios (NULL, "bad argument %s %s", argp[-2], cp);
 		    continue;
 
 		case DFOLDSW: 
 		    if (dfolder)
-			adios (NULLCP, "only one draft folder at a time!");
+			adios (NULL, "only one draft folder at a time!");
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    dfolder = path (*cp == '+' || *cp == '@' ? cp + 1 : cp,
 				    *cp != '@' ? TFOLDER : TSUBCWF);
 		    continue;
 		case DMSGSW:
 		    if (dmsg)
-			adios (NULLCP, "only one draft message at a time!");
+			adios (NULL, "only one draft message at a time!");
 		    if (!(dmsg = *argp++) || *dmsg == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case NDFLDSW: 
 		    dfolder = NULL;
@@ -324,7 +316,7 @@ main (int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
@@ -337,7 +329,7 @@ main (int argc, char **argv)
     if (!m_find ("path"))
 	free (path ("./", TFOLDER));
     if (file && (msgp || folder))
-	adios (NULLCP, "can't mix files and folders/msgs");
+	adios (NULL, "can't mix files and folders/msgs");
 
 try_it_again: ;
 #ifndef MHE
@@ -345,7 +337,7 @@ try_it_again: ;
     if (stat (drft, &st) != NOTOK) {
 #else	/* MHE */
     strcpy (drft, buildsw ? m_maildir ("draft")
-			  : m_draft (dfolder, NULLCP, NOUSE, &isdf));
+			  : m_draft (dfolder, NULL, NOUSE, &isdf));
     if (!buildsw && stat (drft, &st) != NOTOK) {
 #endif	/* MHE */
 	printf ("Draft \"%s\" exists (%ld bytes).", drft, (long) st.st_size);
@@ -368,7 +360,7 @@ try_it_again: ;
 			i = YESW;
 		    break;
 		default: 
-		    advise (NULLCP, "say what?");
+		    advise (NULL, "say what?");
 		    break;
 	    }
 	}
@@ -388,9 +380,9 @@ try_it_again: ;
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
-    if (mp -> hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
+    if (mp->hghmsg == 0)
+	adios (NULL, "no messages in %s", folder);
 
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
@@ -460,16 +452,16 @@ go_to_it: ;
     }
 
     m_replace (pfolder, folder);
-    if (mp -> lowsel != mp -> curmsg)
-	m_setcur (mp, mp -> lowsel);
+    if (mp->lowsel != mp->curmsg)
+	m_setcur (mp, mp->lowsel);
     m_sync (mp);
     m_update ();
 
 edit_it: ;
     if (nwhat)
 	done (0);
-    what_now (ed, nedit, NOUSE, drft, NULLCP, 0, mp,
-	anot ? "Forwarded" : NULLCP, inplace, cwd);
+    what_now (ed, nedit, NOUSE, drft, NULL, 0, mp,
+	anot ? "Forwarded" : NULL, inplace, cwd);
     done (1);
 }
 
@@ -513,11 +505,11 @@ mhl_draft  (int out, char *digest, int volume, int issue,
 		sprintf(buf2, "%d", volume); vec[i++] = buf2;
 	    }
 	    vec[i++] = dashflg ? "-dashmunging" : "-nodashmunging";
-	    if (mp -> numsel >= MAXARGS - i)
-		adios (NULLCP, "more than %d messages for %s exec",
+	    if (mp->numsel >= MAXARGS - i)
+		adios (NULL, "more than %d messages for %s exec",
 			vec[0], MAXARGS - i);
-	    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-		if (mp -> msgstats[msgnum] & SELECTED)
+	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+		if (mp->msgstats[msgnum] & SELECTED)
 		    vec[i++] = getcpy (m_name (msgnum));
 	    vec[i] = NULL;
 
@@ -545,10 +537,10 @@ copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
 
 #ifdef MIME
     if (mime) {
-	sprintf (buffer, "#forw [] +%s", mp -> foldpath);
+	sprintf (buffer, "#forw [] +%s", mp->foldpath);
 	write (out, buffer, strlen (buffer));
-	for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	    if (mp -> msgstats[msgnum] & SELECTED) {
+	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	    if (mp->msgstats[msgnum] & SELECTED) {
 		sprintf (buffer, " %s", m_name (msgnum));
 		write (out, buffer, strlen (buffer));
 	    }
@@ -559,14 +551,14 @@ copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
 #endif /* MIME */
 
     msgcnt = 1;
-    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	if (mp -> msgstats[msgnum] & SELECTED) {
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (mp->msgstats[msgnum] & SELECTED) {
 	    if (digest)
-		strcpy (buffer, msgnum == mp -> lowsel ? delim3 : delim4);
+		strcpy (buffer, msgnum == mp->lowsel ? delim3 : delim4);
 	    else {
 		strcpy (bp = buffer, "\n-------"), bp += strlen (bp);
-		if (msgnum == mp -> lowsel)
-		    sprintf (bp, " Forwarded Message%s", mp -> numsel > 1 ? "s" : "");
+		if (msgnum == mp->lowsel)
+		    sprintf (bp, " Forwarded Message%s", mp->numsel > 1 ? "s" : "");
 		else
 		    sprintf (bp, " Message %d", msgcnt);
 		bp += strlen (bp);
@@ -588,7 +580,7 @@ copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
 	strcpy (buffer, delim4);
     else
 	sprintf (buffer, "\n------- End of Forwarded Message%s\n\n",
-		mp -> numsel > 1 ? "s" : "");
+		mp->numsel > 1 ? "s" : "");
     write (out, buffer, strlen (buffer));
 
     if (digest) {
@@ -615,7 +607,7 @@ build_form (char *form, char *digest, int volume, int issue)
     struct format *fmt;
     int dat[5];
 
-    nfs = new_fs (form, NULLCP, NULLCP);
+    nfs = new_fs (form, NULL, NULL);
     fmtsize = strlen (nfs) + 256;
     fmt_compile (nfs, &fmt);
 
@@ -639,8 +631,8 @@ build_form (char *form, char *digest, int volume, int issue)
     if ((in = dup (fileno (tmp))) == NOTOK)
 	adios ("dup", "unable to");
 
-    if ((line = malloc ((unsigned) fmtsize)) == NULLCP)
-	adios (NULLCP, "unable to allocate format line storage");
+    if ((line = malloc ((unsigned) fmtsize)) == NULL)
+	adios (NULL, "unable to allocate format line storage");
     fmtscan (fmt, line, fmtsize, dat);
     fputs (line, tmp);
     free (line);
