@@ -1,12 +1,10 @@
 
 /*
  * inc.c -- incorporate messages from a maildrop into a folder
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #ifdef MAILGROUP
 /* Revised: Sat Apr 14 17:08:17 PDT 1990 (marvit@hplabs)
  *    Added hpux hacks to set and reset gid to be "mail" as needed. The reset
@@ -19,7 +17,6 @@ static char ident[] = "$Id$";
  */
 #endif
 
-#include "../h/nmh.h"
 #include "../h/mh.h"
 
 #ifdef POP
@@ -41,10 +38,6 @@ static char ident[] = "$Id$";
 #include <errno.h>
 #include <signal.h>
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 #ifndef	MF
 # define MFminc(a) (a)
 #else
@@ -76,94 +69,77 @@ static char ident[] = "$Id$";
 #endif
 
 static struct swit  switches[] = {
-#define	AUDSW	0
-    "audit audit-file", 0,
-#define	NAUDSW	1
-    "noaudit", 0,
-
-#define	CHGSW	2
-    "changecur", 0,
-#define	NCHGSW	3
-    "nochangecur", 0,
-
-#define	DECRSW	4
-    "decrypt", TMAminc (-7),
-#define	NDECRSW	5
-    "nodecrypt", TMAminc (-9),
-
-#define	MSW	6
-    "file name", 0,
-
-#define	FORMSW	7
-    "form formatfile", 0,
-#define	FMTSW	8
-    "format string", 5,
-
-#define	HOSTSW	9
-    "host host", POPminc (-4),
-#define	USERSW	10
-    "user user", POPminc (-4),
-#define	PACKSW	11
-    "pack file", POPminc (-4),
-#define	NPACKSW	12
-    "nopack", POPminc (-6),
-
-#define	APOPSW	13
-    "apop", APOPminc (-4),
-#define	NAPOPSW	14
-    "noapop", APOPminc (-6),
-
-#define	RPOPSW	15
-    "rpop", RPOPminc (-4),
-#define	NRPOPSW	16
-    "norpop", RPOPminc (-6),
-
-#define	SILSW	17
-    "silent", 0,
-#define	NSILSW	18
-    "nosilent", 0,
-
-#define	TRNCSW	19
-    "truncate", 0,
-#define	NTRNCSW	20
-    "notruncate", 0,
-
-#define	UUCPSW	21
-    "uucp", MFminc (-4),
-#define	NUUCPSW	22
-    "nouucp", MFminc (-6),
-
-#define	WIDSW	23
-    "width columns", 0,
-
-#define VERSIONSW 24
-    "version", 0,
-#define	HELPSW	25
-    "help", 4,
-
-    NULL, 0
+#define	AUDSW                      0
+    { "audit audit-file", 0 },
+#define	NAUDSW                     1
+    { "noaudit", 0 },
+#define	CHGSW                      2
+    { "changecur", 0 },
+#define	NCHGSW                     3
+    { "nochangecur", 0 },
+#define	DECRSW                     4
+    { "decrypt", TMAminc (-7) },
+#define	NDECRSW                    5
+    { "nodecrypt", TMAminc (-9) },
+#define	MSW                        6
+    { "file name", 0 },
+#define	FORMSW                     7
+    { "form formatfile", 0 },
+#define	FMTSW                      8
+    { "format string", 5 },
+#define	HOSTSW                     9
+    { "host host", POPminc (-4) },
+#define	USERSW                    10
+    { "user user", POPminc (-4) },
+#define	PACKSW                    11
+    { "pack file", POPminc (-4) },
+#define	NPACKSW                   12
+    { "nopack", POPminc (-6) },
+#define	APOPSW                    13
+    { "apop", APOPminc (-4) },
+#define	NAPOPSW                   14
+    { "noapop", APOPminc (-6) },
+#define	RPOPSW                    15
+    { "rpop", RPOPminc (-4) },
+#define	NRPOPSW                   16
+    { "norpop", RPOPminc (-6) },
+#define	SILSW                     17
+    { "silent", 0 },
+#define	NSILSW                    18
+    { "nosilent", 0 },
+#define	TRNCSW                    19
+    { "truncate", 0 },
+#define	NTRNCSW                   20
+    { "notruncate", 0 },
+#define	UUCPSW                    21
+    { "uucp", MFminc (-4) },
+#define	NUUCPSW                   22
+    { "nouucp", MFminc (-6) },
+#define	WIDSW                     23
+    { "width columns", 0 },
+#define VERSIONSW                 24
+    { "version", 0 },
+#define	HELPSW                    25
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 extern int errno;
 
-#ifdef	POP
-int  snoop = 0;
+#ifdef POP
+int snoop = 0;
 extern char response[];
 
-static  char *file = NULL;
-static int  size;
+static char *file = NULL;
+static int size;
 static long pos;
 static long start;
 static long stop;
 
 static int pd = NOTOK;
 static FILE *pf = NULL;
-
-static int pop_action(), pop_pack();
-static int map_count();
 #endif	/* POP */
 
-char *map_name(char *);
 
 /*
  * For setting and returning to "mail" gid
@@ -172,6 +148,22 @@ char *map_name(char *);
 static int return_gid;
 #endif
 
+/*
+ * prototypes
+ */
+char *map_name(char *);
+
+#ifdef POP
+void done(int);
+static int pop_action(char *);
+static int pop_pack(char *);
+static int map_count(void);
+#endif
+
+#ifdef MF
+void get_uucp_mail(void);
+#endif
+
 
 main (int argc, char **argv)
 {
@@ -192,7 +184,7 @@ main (int argc, char **argv)
     char *host = NULL;
 
 #ifdef	POP
-    char **pass = NULL;
+    char *pass = NULL;
 #endif
 
     char *newmail, buf[100], **ap;
@@ -224,7 +216,7 @@ main (int argc, char **argv)
      *        use MAILHOST environment variable if present,
      *  else try Hesiod.
      *  If that fails, use the default (if any)
-     *  provided by mtstailor in mts_init()
+     *  provided by mts.conf in mts_init()
      */
     if ((tmphost = getenv("MAILHOST")) != NULL)
 	pophost = tmphost;
@@ -255,7 +247,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [switches]", invo_name);
@@ -267,7 +259,7 @@ main (int argc, char **argv)
 
 		case AUDSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    audfile = getcpy (m_maildir (cp));
 		    continue;
 		case NAUDSW: 
@@ -286,7 +278,7 @@ main (int argc, char **argv)
 		    continue;
 		case MSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    from = path (cp, TFILE);/* fall */
 		case NTRNCSW: 
 		    trnflag = 0;
@@ -301,18 +293,18 @@ main (int argc, char **argv)
 
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    format = NULL;
 		    continue;
 		case FMTSW: 
 		    if (!(format = *argp++) || *format == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    form = NULL;
 		    continue;
 
 		case WIDSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    width = atoi (cp);
 		    continue;
 
@@ -336,24 +328,24 @@ main (int argc, char **argv)
 
 		case HOSTSW:
 		    if (!(host = *argp++) || *host == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case USERSW:
 		    if (!(user = *argp++) || *user == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case PACKSW:
 #ifndef	POP
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 #else	/* POP */
 		    if (!(file = *argp++) || *file == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 #endif	/* POP */
 		    continue;
 		case NPACKSW:
 #ifdef	POP
-		    file = NULLCP;
+		    file = NULL;
 #endif	/* POP */
 		    continue;
 		case APOPSW:
@@ -369,12 +361,12 @@ main (int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
 	else
-	    adios (NULLCP, "usage: %s [+folder] [switches]", invo_name);
+	    adios (NULL, "usage: %s [+folder] [switches]", invo_name);
     }
 
 #ifdef MAILGROUP
@@ -394,7 +386,7 @@ main (int argc, char **argv)
 	host = NULL;
 #endif	/* POP */
 	if (stat (newmail, &s1) == NOTOK || s1.st_size == 0)
-	    adios (NULLCP, "no mail to incorporate");
+	    adios (NULL, "no mail to incorporate");
     }
 #ifdef	POP
     else if (host) {
@@ -407,12 +399,12 @@ main (int argc, char **argv)
 
 	if (pop_init (host, user, pass, snoop, rpop) == NOTOK
 		|| pop_stat (&nmsgs, &nbytes) == NOTOK)
-	    adios (NULLCP, "%s", response);
+	    adios (NULL, "%s", response);
 	if (rpop > 0)
 	    setuid (getuid ());
 	if (nmsgs == 0) {
 	    pop_quit();
-	    adios (NULLCP, "no mail to incorporate");
+	    adios (NULL, "no mail to incorporate");
 	}
     }
 #endif	/* POP */
@@ -425,10 +417,10 @@ main (int argc, char **argv)
 	    if (uucp && umincproc && *umincproc)
 		get_uucp_mail ();
 #endif	/* MF */
-	    newmail = concat (MAILDIR, "/", MAILFIL, NULLCP);
+	    newmail = concat (MAILDIR, "/", MAILFIL, NULL);
 	}
 	if (stat (newmail, &s1) == NOTOK || s1.st_size == 0)
-	    adios (NULLCP, "no mail to incorporate");
+	    adios (NULL, "no mail to incorporate");
     }
 
 #ifdef	POP
@@ -444,18 +436,18 @@ main (int argc, char **argv)
     if (stat (maildir, &st) == NOTOK) {
 	if (errno != ENOENT)
 	    adios (maildir, "error on folder");
-	cp = concat ("Create folder \"", maildir, "\"? ", NULLCP);
+	cp = concat ("Create folder \"", maildir, "\"? ", NULL);
 	if (noisy && !getanswer (cp))
 	    done (1);
 	free (cp);
 	if (!makedir (maildir))
-	    adios (NULLCP, "unable to create folder %s", maildir);
+	    adios (NULL, "unable to create folder %s", maildir);
     }
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
 
 #ifdef	POP
 go_to_it: ;
@@ -479,7 +471,7 @@ go_to_it: ;
 	setgid(return_gid);	/* Reset gid to lock mail file */
 #endif	/* MAILGROUP */
 	if ((in = lkfopen (newmail, "r")) == NULL)
-	    adios (NULLCP, "unable to lock and fopen %s", newmail);
+	    adios (NULL, "unable to lock and fopen %s", newmail);
 #ifdef MAILGROUP
 	setgid(getgid());	/* Return us to normal privileges */
 #endif	/* MAILGROUP */
@@ -492,7 +484,7 @@ go_to_it: ;
 
     if (audfile) {
 	if ((i = stat (audfile, &st)) == NOTOK)
-	    advise (NULLCP, "Creating Receive-Audit: %s", audfile);
+	    advise (NULL, "Creating Receive-Audit: %s", audfile);
 	if ((aud = fopen (audfile, "a")) == NULL)
 	    adios (audfile, "unable to append to");
 	else
@@ -512,7 +504,7 @@ go_to_it: ;
 
 #ifdef MHE
     if (m_find ("mhe")) {
-	cp = concat (maildir, "/++", NULLCP);
+	cp = concat (maildir, "/++", NULL);
 	i = stat (cp, &st);
 	if ((mhe = fopen (cp, "a")) == NULL)
 	    admonish (cp, "unable to append to");
@@ -537,7 +529,7 @@ go_to_it: ;
 	    if (stat (file, &st) == NOTOK) {
 		if (errno != ENOENT)
 		    adios (file, "error on file");
-		cp = concat ("Create file \"", file, "\"? ", NULLCP);
+		cp = concat ("Create file \"", file, "\"? ", NULL);
 		if (noisy && !getanswer (cp))
 		    done (1);
 		free (cp);
@@ -547,12 +539,12 @@ go_to_it: ;
 		    == NOTOK)
 		adios (file, "unable to open");
 	    if ((pf = fdopen (pd, "w+")) == NULL)
-		adios (NULLCP, "unable to fdopen %s", file);
+		adios (NULL, "unable to fdopen %s", file);
 	}
 	else {
-	    hghnum = msgnum = mp -> hghmsg;
-	    if ((mp = m_remsg (mp, 0, mp -> hghmsg + nmsgs)) == NULL)
-		adios (NULLCP, "unable to allocate folder storage");
+	    hghnum = msgnum = mp->hghmsg;
+	    if ((mp = m_remsg (mp, 0, mp->hghmsg + nmsgs)) == NULL)
+		adios (NULL, "unable to allocate folder storage");
 	}
 
 	for (i = 1; i <= nmsgs; i++) {
@@ -565,7 +557,7 @@ go_to_it: ;
 		start = ftell (pf);
 
 		if (pop_retr (i, pop_pack) == NOTOK)
-		    adios (NULLCP, "%s", response);
+		    adios (NULL, "%s", response);
 
 		fseek (pf, 0L, 1);
 		stop = ftell (pf);
@@ -581,14 +573,14 @@ go_to_it: ;
 		start = stop = 0L;
 
 		if (pop_retr (i, pop_action) == NOTOK)
-		    adios (NULLCP, "%s", response);
+		    adios (NULL, "%s", response);
 
 		if (fflush (pf))
 		    adios (cp, "write error on");
 		fseek (pf, 0L, 0);
 	    }
 	    switch (p = scan (pf, msgnum, 0, nfs, width,
-			file ? 0 : msgnum == mp -> hghmsg + 1 && chgflag,
+			file ? 0 : msgnum == mp->hghmsg + 1 && chgflag,
 			1,	/* check UNSEEN? */
 			0, stop - start, noisy)) {
 		case SCNEOF: 
@@ -617,19 +609,19 @@ go_to_it: ;
 		    if (noisy)
 			fflush (stdout);
 		    if (!file) {
-			mp -> msgstats[msgnum] = EXISTS;
+			mp->msgstats[msgnum] = EXISTS;
 #ifdef	TMA
 			if (p == SCNENC) {
-			    if (mp -> lowsel == 0 || msgnum < mp -> lowsel)
-				mp -> lowsel = msgnum;
-			    if (mp -> hghsel == 0 || msgnum > mp -> hghsel)
-				mp -> hghsel = msgnum;
-			    mp -> numsel++;
-			    mp -> msgstats[msgnum] |= SELECTED;
+			    if (mp->lowsel == 0 || msgnum < mp->lowsel)
+				mp->lowsel = msgnum;
+			    if (mp->hghsel == 0 || msgnum > mp->hghsel)
+				mp->hghsel = msgnum;
+			    mp->numsel++;
+			    mp->msgstats[msgnum] |= SELECTED;
 			}
 #endif	/* TMA */
-			mp -> msgstats[msgnum] |= UNSEEN;
-			mp -> msgflags |= SEQMOD;
+			mp->msgstats[msgnum] |= UNSEEN;
+			mp->msgflags |= SEQMOD;
 		    }
 		    break;
 		}
@@ -656,10 +648,10 @@ go_to_it: ;
 	    }
 
 	    if (trnflag && pop_dele (i) == NOTOK)
-		adios (NULLCP, "%s", response);
+		adios (NULL, "%s", response);
 	}
 	if (pop_quit () == NOTOK)
-	    adios (NULLCP, "%s", response);
+	    adios (NULL, "%s", response);
 	if (file) {
 	    mbx_close (file, pd);
 	    pd = NOTOK;
@@ -669,11 +661,11 @@ go_to_it: ;
 #endif	/* POP */
 
     m_unknown (in);		/* the MAGIC invocation... */
-    hghnum = msgnum = mp -> hghmsg;
+    hghnum = msgnum = mp->hghmsg;
     for (i = 0;;) {
-	if (msgnum >= mp -> hghoff)
-	    if ((mp = m_remsg (mp, 0, mp -> hghoff + MAXFOLDER)) == NULL) {
-		advise (NULLCP, "unable to allocate folder storage");
+	if (msgnum >= mp->hghoff)
+	    if ((mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER)) == NULL) {
+		advise (NULL, "unable to allocate folder storage");
 		i = NOTOK;
 		break;
 	    }
@@ -691,17 +683,17 @@ go_to_it: ;
 	    case SCNERR:
 		if (aud)
 		    fputs ("inc aborted!\n", aud);
-		advise (NULLCP, "aborted!");	/* doesn't clean up locks! */
+		advise (NULL, "aborted!");	/* doesn't clean up locks! */
 		break;
 
 	    case SCNNUM: 
-		advise (NULLCP,
+		advise (NULL,
 			"more than %d messages in folder %s, %s not zero'd",
 			MAXFOLDER, folder, newmail);
 		break;
 
 	    default: 
-		advise (NULLCP, "scan() botch (%d)", i);
+		advise (NULL, "scan() botch (%d)", i);
 		break;
 
 	    case SCNMSG:
@@ -715,20 +707,20 @@ go_to_it: ;
 		if (noisy)
 		    fflush (stdout);
 
-		msgnum++, mp -> hghmsg++;
-		mp -> msgstats[msgnum] = EXISTS;
+		msgnum++, mp->hghmsg++;
+		mp->msgstats[msgnum] = EXISTS;
 #ifdef	TMA
 		if (i == SCNENC) {
-		    if (mp -> lowsel == 0 || mp -> lowsel > msgnum)
-			mp -> lowsel = msgnum;
-		    if (mp -> hghsel == 0 || mp -> hghsel < msgnum)
-			mp -> hghsel = msgnum;
-		    mp -> numsel++;
-		    mp -> msgstats[msgnum] |= SELECTED;
+		    if (mp->lowsel == 0 || mp->lowsel > msgnum)
+			mp->lowsel = msgnum;
+		    if (mp->hghsel == 0 || mp->hghsel < msgnum)
+			mp->hghsel = msgnum;
+		    mp->numsel++;
+		    mp->msgstats[msgnum] |= SELECTED;
 		}
 #endif	/* TMA */
-		mp -> msgstats[msgnum] |= UNSEEN;
-		mp -> msgflags |= SEQMOD;
+		mp->msgstats[msgnum] |= UNSEEN;
+		mp->msgflags |= SEQMOD;
 		continue;
 	}
 	break;
@@ -754,7 +746,7 @@ go_to_it: ;
 #endif	/* MAILGROUP */
 	else
 	    fclose (in);
-	adios (NULLCP, "failed");
+	adios (NULL, "failed");
     }
 
     if (aud)
@@ -775,7 +767,7 @@ go_to_it: ;
 #endif	/* POP */
     if (trnflag) {
 	if (stat (newmail, &st) != NOTOK && s1.st_mtime != st.st_mtime)
-	    advise (NULLCP, "new messages have arrived!\007");
+	    advise (NULL, "new messages have arrived!\007");
 	else {
 	    if ((i = creat (newmail, 0600)) != NOTOK)
 		close (i);
@@ -789,16 +781,16 @@ go_to_it: ;
 	    printf ("%s not zero'd\n", newmail);
 
     if (msgnum == hghnum)
-	admonish (NULLCP, "no messages incorporated");
+	admonish (NULL, "no messages incorporated");
     else {
 	m_replace (pfolder, folder);
 	if (chgflag)
-	    mp -> curmsg = hghnum + 1;
-	mp -> hghmsg = msgnum;
-	if (mp -> lowmsg == 0)
-	    mp -> lowmsg = 1;
+	    mp->curmsg = hghnum + 1;
+	mp->hghmsg = msgnum;
+	if (mp->lowmsg == 0)
+	    mp->lowmsg = 1;
 	if (chgflag)		/* sigh... */
-	    m_setcur (mp, mp -> curmsg);
+	    m_setcur (mp, mp->curmsg);
     }
 
 #ifdef	POP
@@ -823,22 +815,22 @@ go_to_it: ;
     m_update ();
 
 #ifdef	TMA
-    if (decflag && mp -> numsel > 0) {
+    if (decflag && mp->numsel > 0) {
 	if (noisy) {
 	    printf ("\nIncorporating encrypted mail into %s...\n\n", folder);
 	    fflush (stdout);
 	}
 
 	tmastart (0);
-	for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	    if (mp -> msgstats[msgnum] & SELECTED && decipher (msgnum) == OK) {
+	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	    if (mp->msgstats[msgnum] & SELECTED && decipher (msgnum) == OK) {
 		if ((in = fopen (cp = m_name (msgnum), "r")) == NULL) {
 		    admonish (cp, "unable to open message");
 		    free (cp);
 		    continue;
 		}
 		switch (scan (in, msgnum, 0, nfs, width,
-			msgnum == mp -> curmsg,
+			msgnum == mp->curmsg,
 			1,	/* check UNSEEN? */
 			0,
 			fstat (fileno (in), &st) != NOTOK ? (long) st.st_size
@@ -864,16 +856,6 @@ go_to_it: ;
     done (0);
 }
 
-#ifdef	POP
-void
-done (int status)
-{
-    if (file && pd != NOTOK)
-	mbx_close (file, pd);
-
-    exit (status);
-}
-#endif	/* POP */
 
 #ifdef MF
 void
@@ -893,7 +875,7 @@ get_uucp_mail (void)
 	    break;
 
 	case OK: 
-	    execlp (umincproc, r1bindex (umincproc, '/'), NULLCP);
+	    execlp (umincproc, r1bindex (umincproc, '/'), NULL);
 	    fprintf (stderr, "unable to exec ");
 	    perror (umincproc);
 	    _exit (-1);
@@ -905,7 +887,18 @@ get_uucp_mail (void)
 }
 #endif	/* MF */
 
+
 #ifdef POP
+void
+done (int status)
+{
+    if (file && pd != NOTOK)
+	mbx_close (file, pd);
+
+    exit (status);
+}
+
+
 static int
 pop_action (char *s)
 {
@@ -929,9 +922,11 @@ pop_pack (char *s)
     size += strlen (buffer) + 1;
 }
 
-static int  map_count () {
-    int     md;
-    char   *cp;
+static int
+map_count (void)
+{
+    int md;
+    char *cp;
     struct drop d;
     struct stat st;
 
