@@ -1,49 +1,36 @@
 
 /*
  * mark.c -- mark messages
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
-#define	ADDSW	0
-    "add", 0,
-#define	DELSW	1
-    "delete", 0,
-#define	LSTSW	2
-    "list", 0,
-
-#define	SEQSW	3
-    "sequence name", 0,
-
-#define	PUBLSW	4
-    "public", 0,
-#define	NPUBLSW	5
-    "nopublic", 0,
-
-#define	ZEROSW	6
-    "zero", 0,
-#define	NZEROSW	7
-    "nozero", 0,
-
-#define VERSIONSW 8
-    "version", 0,
-#define	HELPSW	9
-    "help", 4,
-
-#define	DEBUGSW	10
-    "debug", -5,
-
-    NULL, 0
+#define	ADDSW               0
+    { "add", 0 },
+#define	DELSW               1
+    { "delete", 0 },
+#define	LSTSW               2
+    { "list", 0 },
+#define	SEQSW               3
+    { "sequence name", 0 },
+#define	PUBLSW              4
+    { "public", 0 },
+#define	NPUBLSW             5
+    { "nopublic", 0 },
+#define	ZEROSW              6
+    { "zero", 0 },
+#define	NZEROSW             7
+    { "nozero", 0 },
+#define VERSIONSW           8
+    { "version", 0 },
+#define	HELPSW              9
+    { "help", 4 },
+#define	DEBUGSW            10
+    { "debug", -5 },
+    { NULL, 0 }
 };
 
 
@@ -54,7 +41,7 @@ main (int argc, char **argv)
     int seqp = 0, msgp = 0, i, msgnum;
     char *cp, *maildir, *folder = NULL, buf[100];
     char **ap, **argp, *arguments[MAXARGS];
-    char *seqs[NATTRS + 1], *msgs[MAXARGS];
+    char *seqs[NUMATTRS + 1], *msgs[MAXARGS];
     struct msgs *mp;
 
 #ifdef LOCALE
@@ -77,7 +64,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown\n", cp);
+		    adios (NULL, "-%s unknown\n", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
@@ -102,11 +89,11 @@ main (int argc, char **argv)
 
 		case SEQSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
-		    if (seqp < NATTRS)
+			adios (NULL, "missing argument to %s", argp[-2]);
+		    if (seqp < NUMATTRS)
 			seqs[seqp++] = cp;
 		    else
-			adios (NULLCP, "only %d sequences allowed!", NATTRS);
+			adios (NULL, "only %d sequences allowed!", NUMATTRS);
 		    continue;
 
 		case PUBLSW: 
@@ -129,7 +116,7 @@ main (int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
@@ -154,18 +141,18 @@ main (int argc, char **argv)
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
-    if (mp -> hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
+    if (mp->hghmsg == 0)
+	adios (NULL, "no messages in %s", folder);
 
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
 
     if (publicsw == -1)
-	publicsw = mp -> msgflags & READONLY ? 0 : 1;
-    if (publicsw && (mp -> msgflags & READONLY))
-	adios (NULLCP, "folder %s is read-only, so -public not allowed",
+	publicsw = mp->msgflags & READONLY ? 0 : 1;
+    if (publicsw && (mp->msgflags & READONLY))
+	adios (NULL, "folder %s is read-only, so -public not allowed",
 		folder);
 
     if (debugsw) {
@@ -174,23 +161,23 @@ main (int argc, char **argv)
 	printf ("ctxpath=%s context flags=%s\n",
 		ctxpath, sprintb (buf, (unsigned) ctxflags, DBITS));
 	printf ("foldpath=%s flags=%s\n",
-		mp -> foldpath,
-		sprintb (buf, (unsigned) mp -> msgflags, FBITS));
+		mp->foldpath,
+		sprintb (buf, (unsigned) mp->msgflags, FBITS));
 	printf ("lowmsg=%d hghmsg=%d nummsg=%d curmsg=%d\n",
-		mp -> lowmsg, mp -> hghmsg, mp -> nummsg, mp -> curmsg);
+		mp->lowmsg, mp->hghmsg, mp->nummsg, mp->curmsg);
 	printf ("lowsel=%d hghsel=%d numsel=%d\n",
-		mp -> lowsel, mp -> hghsel, mp -> numsel);
+		mp->lowsel, mp->hghsel, mp->numsel);
 #ifndef	MTR
 	printf ("lowoff=%d hghoff=%d\n",
-		mp -> lowoff, mp -> hghoff);
+		mp->lowoff, mp->hghoff);
 #else	/* MTR */
 	printf ("lowoff=%d hghoff=%d msgbase=0x%x msgstats=0x%x\n",
-		mp -> lowoff, mp -> hghoff, mp -> msgbase, mp -> msgstats);
+		mp->lowoff, mp->hghoff, mp->msgbase, mp->msgstats);
 #endif	/* MTR */
     }
 
     if (seqp == 0 && (addsw || deletesw))
-	adios (NULLCP, "-%s requires at least one -sequence argument",
+	adios (NULL, "-%s requires at least one -sequence argument",
 		addsw ? "add" : "delete");
     seqs[seqp] = NULL;
 
@@ -198,8 +185,8 @@ main (int argc, char **argv)
 	for (seqp = 0; seqs[seqp]; seqp++) {
 	    if (zerosw && !m_seqnew (mp, seqs[seqp], publicsw))
 		done (1);
-	    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-		if (mp -> msgstats[msgnum] & SELECTED)
+	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+		if (mp->msgstats[msgnum] & SELECTED)
 		    if (!m_seqadd (mp, seqs[seqp], msgnum, publicsw))
 			done (1);
 	}
@@ -207,12 +194,12 @@ main (int argc, char **argv)
     if (deletesw)
 	for (seqp = 0; seqs[seqp]; seqp++) {
 	    if (zerosw)
-		for (msgnum = mp -> lowmsg; msgnum <= mp -> hghmsg; msgnum++)
-		    if (mp -> msgstats[msgnum] & EXISTS)
+		for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
+		    if (mp->msgstats[msgnum] & EXISTS)
 			if (!m_seqadd (mp, seqs[seqp], msgnum, publicsw))
 			    done (1);
-	    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-		if (mp -> msgstats[msgnum] & SELECTED)
+	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+		if (mp->msgstats[msgnum] & SELECTED)
 		    if (!m_seqdel (mp, seqs[seqp], msgnum))
 			done (1);
 	}
@@ -221,20 +208,20 @@ main (int argc, char **argv)
 	int bits = FFATTRSLOT;
 
 	if (seqp == 0)
-	    for (i = 0; mp -> msgattrs[i]; i++)
-		printf ("%s%s: %s\n", mp -> msgattrs[i],
-			mp -> attrstats & (1 << (bits + i))
+	    for (i = 0; mp->msgattrs[i]; i++)
+		printf ("%s%s: %s\n", mp->msgattrs[i],
+			mp->attrstats & (1 << (bits + i))
 			    ? " (private)" : "",
-			m_seq (mp, mp -> msgattrs[i]));
+			m_seq (mp, mp->msgattrs[i]));
 	else
 	    for (seqp = 0; seqs[seqp]; seqp++)
 		printf ("%s: %s\n", seqs[seqp], m_seq (mp, seqs[seqp]));
 
 	if (debugsw)
-	    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-		if (mp -> msgstats[msgnum] & SELECTED)
+	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+		if (mp->msgstats[msgnum] & SELECTED)
 		    printf ("%*d: %s\n", DMAXFOLDER, msgnum,
-			sprintb (buf, (unsigned) mp -> msgstats[msgnum],
+			sprintb (buf, (unsigned) mp->msgstats[msgnum],
 			    m_seqbits (mp)));
     }
 
