@@ -1,34 +1,26 @@
 
 /*
- * mhpath.c -- print full pathnames of MH messages and folders
+ * mhpath.c -- print full pathnames of nmh messages and folders
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define VERSIONSW 0
-    "version", 0,
+    { "version", 0 },
 #define	HELPSW	1
-    "help", 4,
-
-    NULL, 0
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 
 main(int argc, char **argv)
 {
     int msgp = 0, msgnum;
-    char *cp, *maildir, *folder = NULL, buf[100],
-         **ap, **argp, *arguments[MAXARGS], *msgs[MAXARGS];
+    char *cp, *maildir, *folder = NULL, buf[100];
+    char **ap, **argp, *arguments[MAXARGS], *msgs[MAXARGS];
     struct msgs *mp;
 
 #ifdef LOCALE
@@ -51,7 +43,7 @@ main(int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
@@ -63,7 +55,7 @@ main(int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
@@ -85,26 +77,25 @@ main(int argc, char **argv)
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
 
     if ((mp = m_remsg (mp, 0, MAXFOLDER)) == NULL)
-	adios (NULLCP, "unable to allocate folder storage");
-    mp -> msgflags |= MHPATH;
+	adios (NULL, "unable to allocate folder storage");
+    mp->msgflags |= MHPATH;
 
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
     m_setseq (mp);
 
-    if (mp -> numsel > MAXARGS - 2)
-	adios (NULLCP, "more than %d messages", MAXARGS - 2);
+    if (mp->numsel > MAXARGS - 2)
+	adios (NULL, "more than %d messages", MAXARGS - 2);
 
-    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	if (mp -> msgstats[msgnum] & SELECTED)
-	    printf ("%s/%s\n", mp -> foldpath, m_name (msgnum));
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (mp->msgstats[msgnum] & SELECTED)
+	    printf ("%s/%s\n", mp->foldpath, m_name (msgnum));
 
     m_sync (mp);
     m_update ();
-
     done (0);
 }
