@@ -1,24 +1,15 @@
 
 /*
  * msgchk.c -- check for mail
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
 #include "../zotnet/mts/mts.h"
 #include "../zotnet/tws/tws.h"
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <pwd.h>
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 #ifdef HESIOD
 # include <hesiod.h>
 #endif
@@ -80,7 +71,6 @@ static struct swit  switches[] = {
 #define	NT_NMAI	0x2
 #define	NT_ALL	(NT_MAIL | NT_NMAI)
 
-
 #define	NONEOK	0x0
 #define	UUCPOLD	0x1
 #define	UUCPNEW	0x2
@@ -90,14 +80,8 @@ static struct swit  switches[] = {
 #define	MMDFOK	(MMDFOLD | MMDFNEW)
 
 
-#ifdef	SYS5
-# ifndef __STDC__
-struct passwd	*getpwuid(), *getpwnam();
-# endif /* !__STDC__ */
-#endif	/* SYS5 */
-
 /*
- * prototypes
+ * static prototypes
  */
 static int donote (char *, int);
 static int checkmail (char *, char *, int, int, int);
@@ -106,13 +90,13 @@ static int remotemail (char *, char *, int, int, int, int);
 
 main (int argc, char **argv)
 {
-    int datesw = 1, notifysw = NT_ALL,
-	rpop = 1, status = 0, snoop = 0,
-	vecp = 0;
-    int uid = getuid ();
-    char *cp, *host = NULL, buf[80], **ap,
-         **argp, *arguments[MAXARGS], *vec[50];
-    char *user = getusr();
+    int datesw = 1, notifysw = NT_ALL;
+    int rpop = 1, status = 0, snoop = 0;
+    int vecp = 0;
+    uid_t uid;
+    char *cp, *host = NULL, buf[80], **ap;
+    char **argp, *arguments[MAXARGS], *vec[50];
+    char *user;
     struct passwd *pw;
 
 #ifdef HESIOD
@@ -123,8 +107,12 @@ main (int argc, char **argv)
 #ifdef LOCALE
 	setlocale(LC_ALL, "");
 #endif
+
+    uid = getuid ();
+    user = getusr();
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
+
 #ifdef	POP
     if ((cp = getenv ("MHPOPDEBUG")) && *cp)
 	snoop++;
@@ -146,7 +134,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] [users ...]", invo_name);
@@ -165,22 +153,22 @@ main (int argc, char **argv)
 
 		case NOTESW:
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    notifysw |= donote (cp, 1);
 		    continue;
 		case NNOTESW:
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    notifysw &= ~donote (cp, 0);
 		    continue;
 
 		case HOSTSW: 
 		    if (!(host = *argp++) || *host == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case USERSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    vec[vecp++] = cp;
 		    continue;
 		case APOPSW: 
@@ -205,7 +193,7 @@ main (int argc, char **argv)
 	 *        use MAILHOST environment variable if present,
 	 *  else try Hesiod.
 	 *  If that fails, use the default (if any)
-	 *  provided by mtstailor in mts_init()
+	 *  provided by mts.conf in mts_init()
 	 */
 	if ((tmphost = getenv("MAILHOST")) != NULL)
 	    pophost = tmphost;
@@ -233,7 +221,7 @@ main (int argc, char **argv)
 	      {
 		pw = getpwnam (user);
 		if (pw == NULL)
-		  adios (NULLCP, "unable to get information about user");
+		  adios (NULL, "unable to get information about user");
 		if (home == NULL)
 		  home = pw->pw_dir;
 	      }
@@ -252,7 +240,7 @@ main (int argc, char **argv)
 		if (pw = getpwnam (cp))
 		    status += checkmail (pw->pw_name, pw->pw_dir, datesw, notifysw, 0);
 		else
-		    advise (NULLCP, "no such user as %s", cp);
+		    advise (NULL, "no such user as %s", cp);
     }
 
     done (status);
@@ -279,7 +267,7 @@ donote (char *cp, int ntflag)
 	    ambigsw (cp, ntswitches);
 	    done (1);
 	case UNKWNSW: 
-	    adios (NULLCP, "-%snotify %s unknown", ntflag ? "" : "no", cp);
+	    adios (NULL, "-%snotify %s unknown", ntflag ? "" : "no", cp);
 
 	case NALLSW: 
 	    return NT_ALL;
@@ -381,7 +369,7 @@ remotemail (char *host, char *user, int rpop, int notifysw, int personal, int sn
     if (pop_init (host, user, pass, snoop, rpop) == NOTOK
 	    || pop_stat (&nmsgs, &nbytes) == NOTOK
 	    || pop_quit () == NOTOK) {
-	advise (NULLCP, "%s", response);
+	advise (NULL, "%s", response);
 	return 1;
     }
 
