@@ -1,78 +1,66 @@
 
 /*
- * pick.c - select messages by content
+ * pick.c -- select messages by content
+ *
+ * $Id$
  */
 
-#ifndef lint
-static char ident[] = "$Id$";
-#endif	/*  lint */
-
 #include "../h/mh.h"
 #include "../zotnet/tws/tws.h"
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
-#define	ANDSW	0
-    "and", 0,
-#define	ORSW	1
-    "or", 0,
-#define	NOTSW	2
-    "not", 0,
-#define	LBRSW	3
-    "lbrace", 0,
-#define	RBRSW	4
-    "rbrace", 0,
-
-#define	CCSW	5
-    "cc  pattern", 0,
-#define	DATESW	6
-    "date  pattern", 0,
-#define	FROMSW	7
-    "from  pattern", 0,
-#define	SRCHSW	8
-    "search  pattern", 0,
-#define	SUBJSW	9
-    "subject  pattern", 0,
-#define	TOSW	10
-    "to  pattern", 0,
-#define	OTHRSW	11
-    "-othercomponent  pattern", 0,
-#define	AFTRSW	12
-    "after date", 0,
-#define	BEFRSW	13
-    "before date", 0,
-#define	DATFDSW	14
-    "datefield field", 5,
-
-#define	SEQSW	15
-    "sequence name", 0,
-#define	PUBLSW	16
-    "public", 0,
-#define	NPUBLSW	17
-    "nopublic", 0,
-#define	ZEROSW	18
-    "zero", 0,
-#define	NZEROSW	19
-    "nozero", 0,
-
-#define	LISTSW	20
-    "list", 0,
-#define	NLISTSW	21
-    "nolist", 0,
-
-#define VERSIONSW 22
-    "version", 0,
-#define	HELPSW	23
-    "help", 4,
-
-    NULL, 0
+#define	ANDSW                   0
+    { "and", 0 },
+#define	ORSW                    1
+    { "or", 0 },
+#define	NOTSW                   2
+    { "not", 0 },
+#define	LBRSW                   3
+    { "lbrace", 0 },
+#define	RBRSW                   4
+    { "rbrace", 0 },
+#define	CCSW                    5
+    { "cc  pattern", 0 },
+#define	DATESW                  6
+    { "date  pattern", 0 },
+#define	FROMSW                  7
+    { "from  pattern", 0 },
+#define	SRCHSW                  8
+    { "search  pattern", 0 },
+#define	SUBJSW                  9
+    { "subject  pattern", 0 },
+#define	TOSW                   10
+    { "to  pattern", 0 },
+#define	OTHRSW                 11
+    { "-othercomponent  pattern", 0 },
+#define	AFTRSW                 12
+    { "after date", 0 },
+#define	BEFRSW                 13
+    { "before date", 0 },
+#define	DATFDSW                14
+    { "datefield field", 5 },
+#define	SEQSW                  15
+    { "sequence name", 0 },
+#define	PUBLSW                 16
+    { "public", 0 },
+#define	NPUBLSW                17
+    { "nopublic", 0 },
+#define	ZEROSW                 18
+    { "zero", 0 },
+#define	NZEROSW                19
+    { "nozero", 0 },
+#define	LISTSW                 20
+    { "list", 0 },
+#define	NLISTSW                21
+    { "nolist", 0 },
+#define VERSIONSW              22
+    { "version", 0 },
+#define	HELPSW                 23
+    { "help", 4 },
+    { NULL, 0 }
 };
 
-static int  listsw = 0;
+static int listsw = 0;
 
 
 main (int argc, char **argv)
@@ -81,7 +69,7 @@ main (int argc, char **argv)
     int seqp = 0, vecp = 0, lo, hi, msgnum;
     char *maildir, *folder = NULL, buf[100];
     char *cp, **ap, **argp, *arguments[MAXARGS];
-    char *msgs[MAXARGS], *seqs[NATTRS + 1], *vec[MAXARGS];
+    char *msgs[MAXARGS], *seqs[NUMATTRS + 1], *vec[MAXARGS];
     struct msgs *mp;
     register FILE *fp;
 
@@ -109,7 +97,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
@@ -132,11 +120,11 @@ main (int argc, char **argv)
 		    vec[vecp++] = --cp;
 	    pattern: ;
 		    if (!(cp = *argp++))/* allow -xyz arguments */
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    vec[vecp++] = cp;
 		    continue;
 		case OTHRSW: 
-		    adios (NULLCP, "internal error!");
+		    adios (NULL, "internal error!");
 
 		case ANDSW:
 		case ORSW:
@@ -148,11 +136,11 @@ main (int argc, char **argv)
 
 		case SEQSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
-		    if (seqp < NATTRS)
+			adios (NULL, "missing argument to %s", argp[-2]);
+		    if (seqp < NUMATTRS)
 			seqs[seqp++] = cp;
 		    else
-			adios (NULLCP, "only %d sequences allowed!", NATTRS);
+			adios (NULL, "only %d sequences allowed!", NUMATTRS);
 		    listsw = 0;
 		    continue;
 		case PUBLSW: 
@@ -178,7 +166,7 @@ main (int argc, char **argv)
 	}
 	if (*cp == '+' || *cp == '@')
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	else
@@ -197,9 +185,9 @@ main (int argc, char **argv)
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
-    if (mp -> hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
+    if (mp->hghmsg == 0)
+	adios (NULL, "no messages in %s", folder);
 
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
@@ -209,19 +197,19 @@ main (int argc, char **argv)
     if (seqp == 0)
 	listsw++;
     if (publicsw == -1)
-	publicsw = mp -> msgflags & READONLY ? 0 : 1;
-    if (publicsw && (mp -> msgflags & READONLY))
-	adios (NULLCP, "folder %s is read-only, so -public not allowed",
+	publicsw = mp->msgflags & READONLY ? 0 : 1;
+    if (publicsw && (mp->msgflags & READONLY))
+	adios (NULL, "folder %s is read-only, so -public not allowed",
 		folder);
 
-    if (!pcompile (vec, NULLCP))
+    if (!pcompile (vec, NULL))
 	done (1);
 
-    lo = mp -> lowsel;
-    hi = mp -> hghsel;
+    lo = mp->lowsel;
+    hi = mp->hghsel;
 
-    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	if (mp -> msgstats[msgnum] & SELECTED) {
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (mp->msgstats[msgnum] & SELECTED) {
 	    if ((fp = fopen (cp = m_name (msgnum), "r")) == NULL)
 		admonish (cp, "unable to read message");
 	    if (fp && pmatches (fp, msgnum, 0L, 0L)) {
@@ -238,30 +226,30 @@ main (int argc, char **argv)
 		fclose (fp);
 	}
 
-    mp -> lowsel = lo;
-    mp -> hghsel = hi;
+    mp->lowsel = lo;
+    mp->hghsel = hi;
 
-    if (mp -> numsel <= 0)
-	adios (NULLCP, "no messages match specification");
+    if (mp->numsel <= 0)
+	adios (NULL, "no messages match specification");
 
     seqs[seqp] = NULL;
     for (seqp = 0; seqs[seqp]; seqp++) {
 	if (zerosw && !m_seqnew (mp, seqs[seqp], publicsw))
 	    done (1);
-	for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	    if (mp -> msgstats[msgnum] & SELECTED)
+	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	    if (mp->msgstats[msgnum] & SELECTED)
 		if (!m_seqadd (mp, seqs[seqp], msgnum, publicsw))
 		    done (1);
     }
 
     if (listsw) {
-	for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	    if (mp -> msgstats[msgnum] & SELECTED)
+	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	    if (mp->msgstats[msgnum] & SELECTED)
 		printf ("%s\n", m_name (msgnum));
     }
     else
-	printf ("%d hit%s\n", mp -> numsel,
-		mp -> numsel == 1 ? "" : "s");
+	printf ("%d hit%s\n", mp->numsel,
+		mp->numsel == 1 ? "" : "s");
 
     m_replace (pfolder, folder);
     m_sync (mp);
