@@ -1,64 +1,60 @@
 
-/* picksbr.c - routines to help pick along... */
-
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
+/*
+ * picksbr.c -- routines to help pick along...
+ *
+ * $Id$
+ */
 
 #include "../h/mh.h"
 #include "../zotnet/tws/tws.h"
-#include <stdio.h>
 
 static struct swit parswit[] = {
-#define	PRAND	0
-    "and", 0,
-#define	PROR	1
-    "or", 0,
-#define	PRNOT	2
-    "not", 0,
-#define	PRLBR	3
-    "lbrace", 0,
-#define	PRRBR	4
-    "rbrace", 0,
-
-#define	PRCC	5
-    "cc  pattern", 0,
-#define	PRDATE	6
-    "date  pattern", 0,
-#define	PRFROM	7
-    "from  pattern", 0,
-#define	PRSRCH	8
-    "search  pattern", 0,
-#define	PRSUBJ	9
-    "subject  pattern", 0,
-#define	PRTO	10
-    "to  pattern", 0,
-#define	PROTHR	11
-    "-othercomponent  pattern", 15,
-
-#define	PRAFTR	12
-    "after date", 0,
-#define	PRBEFR	13
-    "before date", 0,
-#define	PRDATF	14
-    "datefield field", 5,
-
-    NULL, 0
+#define	PRAND                   0
+    { "and", 0 },
+#define	PROR                    1
+    { "or", 0 },
+#define	PRNOT                   2
+    { "not", 0 },
+#define	PRLBR                   3
+    { "lbrace", 0 },
+#define	PRRBR                   4
+    { "rbrace", 0 },
+#define	PRCC                    5
+    { "cc  pattern", 0 },
+#define	PRDATE                  6
+    { "date  pattern", 0 },
+#define	PRFROM                  7
+    { "from  pattern", 0 },
+#define	PRSRCH                  8
+    { "search  pattern", 0 },
+#define	PRSUBJ                  9
+    { "subject  pattern", 0 },
+#define	PRTO                   10
+    { "to  pattern", 0 },
+#define	PROTHR                 11
+    { "-othercomponent  pattern", 15 },
+#define	PRAFTR                 12
+    { "after date", 0 },
+#define	PRBEFR                 13
+    { "before date", 0 },
+#define	PRDATF                 14
+    { "datefield field", 5 },
+    { NULL, 0 }
 };
 
 /* DEFINITIONS FOR PATTERN MATCHING */
 
-/* We really should be using re_comp() and re_exec() here.  Unfortunately,
-   pick advertises that lowercase characters matches characters of both
-   cases.  Since re_exec() doesn't exhibit this behavior, we are stuck
-   with this version.  Furthermore, we need to be able to save and restore
-   the state of the pattern matcher in order to do things "efficiently".
-
-   The matching power of this algorithm isn't as powerful as the re_xxx()
-   routines (no \(xxx\) and \n constructs).  Such is life.
+/*
+ * We really should be using re_comp() and re_exec() here.  Unfortunately,
+ * pick advertises that lowercase characters matches characters of both
+ * cases.  Since re_exec() doesn't exhibit this behavior, we are stuck
+ * with this version.  Furthermore, we need to be able to save and restore
+ * the state of the pattern matcher in order to do things "efficiently".
+ *
+ * The matching power of this algorithm isn't as powerful as the re_xxx()
+ * routines (no \(xxx\) and \n constructs).  Such is life.
  */
 
-
 #define	CCHR	2
 #define	CDOT	4
 #define	CCL	6
@@ -72,9 +68,10 @@ static struct swit parswit[] = {
 #define	ESIZE	256
 
 
-static char	linebuf[LBSIZE + 1];
+static char linebuf[LBSIZE + 1];
 
-static char cc[] = {		/* the magic array for case-independence */
+/* the magic array for case-independence */
+static char cc[] = {
 	0000,0001,0002,0003,0004,0005,0006,0007,
 	0010,0011,0012,0013,0014,0015,0016,0017,
 	0020,0021,0022,0023,0024,0025,0026,0027,
@@ -93,24 +90,15 @@ static char cc[] = {		/* the magic array for case-independence */
 	0170,0171,0172,0173,0174,0175,0176,0177,
 };
 
-/* DEFINITIONS FOR DATE MATCHING */
-
-static struct tws *tws_parse (), *tws_special ();
-
-
-long   time ();
-
 /* DEFINITIONS FOR NEXUS */
 
 #define	nxtarg()	(*argp ? *argp++ : NULL)
 #define	prvarg()	argp--
 
-
 #define	padvise		if (!talked++) advise
 
-
 struct nexus {
-    int     (*n_action) ();
+    int (*n_action)();
 
     union {
 	struct {		/* for {OR,AND,NOT}action */
@@ -143,28 +131,46 @@ struct nexus {
     }	un;
 };
 
-static	int   talked;
-static	int   pdebug = 0;
+static int talked;
+static int pdebug = 0;
 
-static  char *datesw;
-static  char **argp;
+static char *datesw;
+static char **argp;
 
-static  struct nexus *head;
+static struct nexus *head;
 
-static void	PRaction();
-static int	gcompile(), advance(), cclass(), tcompile();
+/*
+ * prototypes for date routines
+ */
+static struct tws *tws_parse();
+static struct tws *tws_special();
 
-static struct	nexus *parse (), *exp1 (), *exp2 (), *exp3 (), *newnexus ();
+/*
+ * static prototypes
+ */
+static void PRaction();
+static int gcompile();
+static int advance();
+static int cclass();
+static int tcompile();
 
-static int	ORaction (), ANDaction (), NOTaction (), GREPaction (),
-		TWSaction ();
+static struct nexus *parse();
+static struct nexus *exp1();
+static struct nexus *exp2();
+static struct nexus *exp3();
+static struct nexus *newnexus();
+
+static int ORaction();
+static int ANDaction();
+static int NOTaction();
+static int GREPaction();
+static int TWSaction();
 
 
-int	pcompile (vec, date)
-register char  **vec,
-	        *date;
+int
+pcompile (char **vec, char *date)
 {
-    register char  *cp;
+    register char *cp;
 
     if ((cp = getenv ("MHPDEBUG")) && *cp)
 	pdebug++;
@@ -178,7 +184,7 @@ register char  **vec,
 	return (talked ? 0 : 1);
 
     if (*argp) {
-	padvise (NULLCP, "%s unexpected", *argp);
+	padvise (NULL, "%s unexpected", *argp);
 	return 0;
     }
 
@@ -186,16 +192,17 @@ register char  **vec,
 }
 
 
-static struct nexus *parse () {
+static struct nexus *
+parse (void)
+{
     register char  *cp;
-    register struct nexus  *n,
-                           *o;
+    register struct nexus *n, *o;
 
     if ((n = exp1 ()) == NULL || (cp = nxtarg ()) == NULL)
 	return n;
 
     if (*cp != '-') {
-	padvise (NULLCP, "%s unexpected", cp);
+	padvise (NULL, "%s unexpected", cp);
 	return NULL;
     }
 
@@ -213,10 +220,10 @@ static struct nexus *parse () {
 
 	case PROR: 
 	    o = newnexus (ORaction);
-	    o -> n_L_child = n;
-	    if (o -> n_R_child = parse ())
+	    o->n_L_child = n;
+	    if (o->n_R_child = parse ())
 		return o;
-	    padvise (NULLCP, "missing disjunctive");
+	    padvise (NULL, "missing disjunctive");
 	    return NULL;
 
 header: ;
@@ -226,16 +233,17 @@ header: ;
     }
 }
 
-static struct nexus *exp1 () {
-    register char  *cp;
-    register struct nexus  *n,
-                           *o;
+static struct nexus *
+exp1 (void)
+{
+    register char *cp;
+    register struct nexus *n, *o;
 
     if ((n = exp2 ()) == NULL || (cp = nxtarg ()) == NULL)
 	return n;
 
     if (*cp != '-') {
-	padvise (NULLCP, "%s unexpected", cp);
+	padvise (NULL, "%s unexpected", cp);
 	return NULL;
     }
 
@@ -253,10 +261,10 @@ static struct nexus *exp1 () {
 
 	case PRAND: 
 	    o = newnexus (ANDaction);
-	    o -> n_L_child = n;
-	    if (o -> n_R_child = exp1 ())
+	    o->n_L_child = n;
+	    if (o->n_R_child = exp1 ())
 		return o;
-	    padvise (NULLCP, "missing conjunctive");
+	    padvise (NULL, "missing conjunctive");
 	    return NULL;
 
 header: ;
@@ -267,9 +275,11 @@ header: ;
 }
 
 
-static struct nexus *exp2 () {
-    register char  *cp;
-    register struct nexus  *n;
+static struct nexus *
+exp2 (void)
+{
+    register char *cp;
+    register struct nexus *n;
 
     if ((cp = nxtarg ()) == NULL)
 	return NULL;
@@ -293,9 +303,9 @@ static struct nexus *exp2 () {
 
 	case PRNOT: 
 	    n = newnexus (NOTaction);
-	    if (n -> n_L_child = exp3 ())
+	    if (n->n_L_child = exp3 ())
 		return n;
-	    padvise (NULLCP, "missing negation");
+	    padvise (NULL, "missing negation");
 	    return NULL;
 
 header: ;
@@ -305,18 +315,19 @@ header: ;
     }
 }
 
-static struct nexus *exp3 () {
-    int     i;
-    register char  *cp,
-                   *dp;
-    char    buffer[BUFSIZ], temp[64];
-    register struct nexus  *n;
+static struct nexus *
+exp3 (void)
+{
+    int i;
+    register char *cp, *dp;
+    char buffer[BUFSIZ], temp[64];
+    register struct nexus *n;
 
     if ((cp = nxtarg ()) == NULL)
 	return NULL;
 
     if (*cp != '-') {
-	padvise (NULLCP, "%s unexpected", cp);
+	padvise (NULL, "%s unexpected", cp);
 	return NULL;
     }
 
@@ -336,16 +347,16 @@ static struct nexus *exp3 () {
 
 	case PRLBR: 
 	    if ((n = parse ()) == NULL) {
-		padvise (NULLCP, "missing group");
+		padvise (NULL, "missing group");
 		return NULL;
 	    }
 	    if ((cp = nxtarg ()) == NULL) {
-		padvise (NULLCP, "missing -rbrace");
+		padvise (NULL, "missing -rbrace");
 		return NULL;
 	    }
 	    if (*cp++ == '-' && smatch (cp, parswit) == PRRBR)
 		return n;
-	    padvise (NULLCP, "%s unexpected", --cp);
+	    padvise (NULL, "%s unexpected", --cp);
 	    return NULL;
 
 	default: 
@@ -359,41 +370,41 @@ static struct nexus *exp3 () {
 	case PRSUBJ: 
 	    strncpy(temp, parswit[i].sw, sizeof(temp));
 	    temp[sizeof(temp) - 1] = '\0';
-	    dp = *brkstring (temp, " ", NULLCP);
+	    dp = *brkstring (temp, " ", NULL);
     header: ;
 	    if (!(cp = nxtarg ())) {/* allow -xyz arguments */
-		padvise (NULLCP, "missing argument to %s", argp[-2]);
+		padvise (NULL, "missing argument to %s", argp[-2]);
 		return NULL;
 	    }
 	    n = newnexus (GREPaction);
-	    n -> n_header = 1;
-	    (void) sprintf (buffer, "^%s[ \t]*:.*%s", dp, cp);
+	    n->n_header = 1;
+	    sprintf (buffer, "^%s[ \t]*:.*%s", dp, cp);
 	    dp = buffer;
 	    goto pattern;
 
 	case PRSRCH: 
 	    n = newnexus (GREPaction);
-	    n -> n_header = 0;
+	    n->n_header = 0;
 	    if (!(cp = nxtarg ())) {/* allow -xyz arguments */
-		padvise (NULLCP, "missing argument to %s", argp[-2]);
+		padvise (NULL, "missing argument to %s", argp[-2]);
 		return NULL;
 	    }
 	    dp = cp;
     pattern: ;
 	    if (!gcompile (n, dp)) {
-		padvise (NULLCP, "pattern error in %s %s", argp[-2], cp);
+		padvise (NULL, "pattern error in %s %s", argp[-2], cp);
 		return NULL;
 	    }
-	    n -> n_patbuf = getcpy (dp);
+	    n->n_patbuf = getcpy (dp);
 	    return n;
 
 	case PROTHR: 
-	    padvise (NULLCP, "internal error!");
+	    padvise (NULL, "internal error!");
 	    return NULL;
 
 	case PRDATF: 
 	    if (!(datesw = nxtarg ()) || *datesw == '-') {
-		padvise (NULLCP, "missing argument to %s", argp[-2]);
+		padvise (NULL, "missing argument to %s", argp[-2]);
 		return NULL;
 	    }
 	    return exp3 ();
@@ -401,13 +412,13 @@ static struct nexus *exp3 () {
 	case PRAFTR: 
 	case PRBEFR: 
 	    if (!(cp = nxtarg ())) {/* allow -xyz arguments */
-		padvise (NULLCP, "missing argument to %s", argp[-2]);
+		padvise (NULL, "missing argument to %s", argp[-2]);
 		return NULL;
 	    }
 	    n = newnexus (TWSaction);
-	    n -> n_datef = datesw;
-	    if (!tcompile (cp, &n -> n_tws, n -> n_after = i == PRAFTR)) {
-		padvise (NULLCP, "unable to parse %s %s", argp[-2], cp);
+	    n->n_datef = datesw;
+	    if (!tcompile (cp, &n->n_tws, n->n_after = i == PRAFTR)) {
+		padvise (NULL, "unable to parse %s %s", argp[-2], cp);
 		return NULL;
 	    }
 	    return n;
@@ -415,15 +426,15 @@ static struct nexus *exp3 () {
 }
 
 
-static struct nexus *newnexus (action)
-register int	(*action) ();
+static struct nexus *
+newnexus (int (*action)())
 {
-    register struct nexus   *p;
+    register struct nexus *p;
 
     if ((p = (struct nexus *) calloc ((unsigned) 1, sizeof *p)) == NULL)
-	adios (NULLCP, "unable to allocate component storage");
+	adios (NULL, "unable to allocate component storage");
 
-    p -> n_action = action;
+    p->n_action = action;
     return p;
 }
 
@@ -437,11 +448,8 @@ register int	(*action) ();
 	    long    start, \
 		    stop;
 
-int	pmatches (fp, msgnum, start, stop)
-register FILE *fp;
-int	msgnum;
-long	start,
-	stop;
+int
+pmatches (FILE *fp, int msgnum, long start, long stop)
 {
     if (!head)
 	return 1;
@@ -449,95 +457,93 @@ long	start,
     if (!talked++ && pdebug)
 	PRaction (head, 0);
 
-    return (*head -> n_action) (args (head));
+    return (*head->n_action) (args (head));
 }
 
 
-static	void PRaction (n, level)
-register struct nexus *n;
-register int	level;
+static void
+PRaction (struct nexus *n, int level)
 {
     register int    i;
 
     for (i = 0; i < level; i++)
 	fprintf (stderr, "| ");
 
-    if (n -> n_action == ORaction) {
+    if (n->n_action == ORaction) {
 	fprintf (stderr, "OR\n");
-	PRaction (n -> n_L_child, level + 1);
-	PRaction (n -> n_R_child, level + 1);
+	PRaction (n->n_L_child, level + 1);
+	PRaction (n->n_R_child, level + 1);
 	return;
     }
-    if (n -> n_action == ANDaction) {
+    if (n->n_action == ANDaction) {
 	fprintf (stderr, "AND\n");
-	PRaction (n -> n_L_child, level + 1);
-	PRaction (n -> n_R_child, level + 1);
+	PRaction (n->n_L_child, level + 1);
+	PRaction (n->n_R_child, level + 1);
 	return;
     }
-    if (n -> n_action == NOTaction) {
+    if (n->n_action == NOTaction) {
 	fprintf (stderr, "NOT\n");
-	PRaction (n -> n_L_child, level + 1);
+	PRaction (n->n_L_child, level + 1);
 	return;
     }
-    if (n -> n_action == GREPaction) {
+    if (n->n_action == GREPaction) {
 	fprintf (stderr, "PATTERN(%s) %s\n",
-		n -> n_header ? "header" : "body", n -> n_patbuf);
+		n->n_header ? "header" : "body", n->n_patbuf);
 	return;
     }
-    if (n -> n_action == TWSaction) {
+    if (n->n_action == TWSaction) {
 	fprintf (stderr, "TEMPORAL(%s) %s: %s\n",
-		n -> n_after ? "after" : "before", n -> n_datef,
-		dasctime (&n -> n_tws, TW_NULL));
+		n->n_after ? "after" : "before", n->n_datef,
+		dasctime (&n->n_tws, TW_NULL));
 	return;
     }
-    fprintf (stderr, "UNKNOWN(0x%x)\n", (*n -> n_action));
+    fprintf (stderr, "UNKNOWN(0x%x)\n", (*n->n_action));
 }
 
 
-static int  ORaction (params)
+static int
+ORaction (params)
 plist
 {
-    if ((*n -> n_L_child -> n_action) (args (n -> n_L_child)))
+    if ((*n->n_L_child->n_action) (args (n->n_L_child)))
 	return 1;
-    return (*n -> n_R_child -> n_action) (args (n -> n_R_child));
+    return (*n->n_R_child->n_action) (args (n->n_R_child));
 }
 
 
-static int  ANDaction (params)
+static int
+ANDaction (params)
 plist
 {
-    if (!(*n -> n_L_child -> n_action) (args (n -> n_L_child)))
+    if (!(*n->n_L_child->n_action) (args (n->n_L_child)))
 	return 0;
-    return (*n -> n_R_child -> n_action) (args (n -> n_R_child));
+    return (*n->n_R_child->n_action) (args (n->n_R_child));
 }
 
 
-static int  NOTaction (params)
+static int
+NOTaction (params)
 plist
 {
-    return (!(*n -> n_L_child -> n_action) (args (n -> n_L_child)));
+    return (!(*n->n_L_child->n_action) (args (n->n_L_child)));
 }
 
 
-static	int gcompile (n, astr)
-register struct nexus *n;
-register char *astr;
+static int
+gcompile (struct nexus *n, char *astr)
 {
-    register int    c;
-    int     cclcnt;
-    register char  *ep,
-		   *dp,
-                   *sp,
-                   *lastep;
+    register int c;
+    int cclcnt;
+    register char *ep, *dp, *sp, *lastep;
 
-    dp = (ep = n -> n_expbuf) + sizeof n -> n_expbuf;
+    dp = (ep = n->n_expbuf) + sizeof n->n_expbuf;
     sp = astr;
     if (*sp == '^') {
-	n -> n_circf = 1;
+	n->n_circf = 1;
 	sp++;
     }
     else
-	n -> n_circf = 0;
+	n->n_circf = 0;
     for (;;) {
 	if (ep >= dp)
 	    goto cerror;
@@ -596,26 +602,20 @@ cerror: ;
 }
 
 
-/* ARGSUSED */
-
-static int  GREPaction (params)
+static int
+GREPaction (params)
 plist
 {
-    int     c,
-            body,
-            lf;
-    long    pos = start;
-    register char  *p1,
-                   *p2,
-                   *ebp,
-                   *cbp;
-    char    ibuf[BUFSIZ];
+    int c, body, lf;
+    long pos = start;
+    register char *p1, *p2, *ebp, *cbp;
+    char ibuf[BUFSIZ];
 
-    (void) fseek (fp, start, 0);
+    fseek (fp, start, 0);
     body = 0;
     ebp = cbp = ibuf;
     for (;;) {
-	if (body && n -> n_header)
+	if (body && n->n_header)
 	    return 0;
 	p1 = linebuf;
 	p2 = cbp;
@@ -658,9 +658,9 @@ plist
 	*p1++ = 0;
 	cbp = p2;
 	p1 = linebuf;
-	p2 = n -> n_expbuf;
+	p2 = n->n_expbuf;
 
-	if (n -> n_circf) {
+	if (n->n_circf) {
 	    if (advance (p1, p2))
 		return 1;
 	    continue;
@@ -684,13 +684,10 @@ plist
 }
 
 
-static	int advance (alp, aep)
-register char  *alp,
-               *aep;
+static int
+advance (char *alp, char *aep)
 {
-    register char  *lp,
-                   *ep,
-                   *curlp;
+    register char *lp, *ep, *curlp;
 
     lp = alp;
     ep = aep;
@@ -758,14 +755,14 @@ register char  *alp,
 		return 0;
 
 	    default: 
-		admonish (NULLCP, "advance() botch -- you lose big");
+		admonish (NULL, "advance() botch -- you lose big");
 		return 0;
 	}
 }
 
 
-static	int cclass (aset, ac, af)
-register char   *aset;
+static int
+cclass (char *aset, int ac, int af)
 {
     register int    n;
     register char   c,
@@ -784,10 +781,8 @@ register char   *aset;
 }
 
 
-static	int tcompile (ap, tb, isafter)
-register char   *ap;
-register struct tws *tb;
-int     isafter;
+static int
+tcompile (char *ap, struct tws *tb, int isafter)
 {
     register struct tws *tw;
 
@@ -799,17 +794,15 @@ int     isafter;
 }
 
 
-static struct tws  *tws_parse (ap, isafter)
-register char   *ap;
-int     isafter;
+static struct tws *
+tws_parse (char *ap, int isafter)
 {
-    char    buffer[BUFSIZ];
-    register struct tws *tw,
-                        *ts;
+    char buffer[BUFSIZ];
+    register struct tws *tw, *ts;
 
     if ((tw = tws_special (ap)) != NULL) {
-	tw -> tw_sec = tw -> tw_min = isafter ? 59 : 0;
-	tw -> tw_hour = isafter ? 23 : 0;
+	tw->tw_sec = tw->tw_min = isafter ? 59 : 0;
+	tw->tw_hour = isafter ? 23 : 0;
 	return tw;
     }
     if ((tw = dparsetime (ap)) != NULL)
@@ -818,22 +811,22 @@ int     isafter;
     if ((ts = dtwstime ()) == NULL)
 	return NULL;
 
-    (void) sprintf (buffer, "%s %s", ap, dtwszone (ts));
+    sprintf (buffer, "%s %s", ap, dtwszone (ts));
     if ((tw = dparsetime (buffer)) != NULL)
 	return tw;
 
-    (void) sprintf (buffer, "%s %02d:%02d:%02d %s", ap,
-	    ts -> tw_hour, ts -> tw_min, ts -> tw_sec, dtwszone (ts));
+    sprintf (buffer, "%s %02d:%02d:%02d %s", ap,
+	    ts->tw_hour, ts->tw_min, ts->tw_sec, dtwszone (ts));
     if ((tw = dparsetime (buffer)) != NULL)
 	return tw;
 
-    (void) sprintf (buffer, "%02d %s %04d %s",
-	    ts -> tw_mday, tw_moty[ts -> tw_mon], ts -> tw_year, ap);
+    sprintf (buffer, "%02d %s %04d %s",
+	    ts->tw_mday, tw_moty[ts->tw_mon], ts->tw_year, ap);
     if ((tw = dparsetime (buffer)) != NULL)
 	return tw;
 
-    (void) sprintf (buffer, "%02d %s %04d %s %s",
-	    ts -> tw_mday, tw_moty[ts -> tw_mon], ts -> tw_year,
+    sprintf (buffer, "%02d %s %04d %s %s",
+	    ts->tw_mday, tw_moty[ts->tw_mon], ts->tw_year,
 	    ap, dtwszone (ts));
     if ((tw = dparsetime (buffer)) != NULL)
 	return tw;
@@ -842,14 +835,14 @@ int     isafter;
 }
 
 
-static struct tws  *tws_special (ap)
-register char   *ap;
+static struct tws *
+tws_special (char *ap)
 {
-    int     i;
-    long    clock;
+    int i;
+    long clock;
     register struct tws *tw;
 
-    (void) time (&clock);
+    time (&clock);
     if (uleq (ap, "Today"))
 	return dlocaltime (&clock);
     if (uleq (ap, "Yesterday")) {
@@ -867,7 +860,7 @@ register char   *ap;
     if (tw_ldotw[i]) {
 	if ((tw = dlocaltime (&clock)) == NULL)
 	    return NULL;
-	if ((i -= tw -> tw_wday) > 0)
+	if ((i -= tw->tw_wday) > 0)
 	    i -= 7;
     }
     else
@@ -892,7 +885,7 @@ plist
             name[NAMESZ];
     register struct tws *tw;
 
-    (void) fseek (fp, start, 0);
+    fseek (fp, start, 0);
     for (state = FLD, bp = NULL;;) {
 	switch (state = m_getfld (state, name, buf, sizeof buf, fp)) {
 	    case FLD: 
@@ -900,12 +893,12 @@ plist
 	    case FLDPLUS: 
 		if (bp != NULL)
 		    free (bp), bp = NULL;
-		bp = add (buf, NULLCP);
+		bp = add (buf, NULL);
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, name, buf, sizeof buf, fp);
 		    bp = add (buf, bp);
 		}
-		if (uleq (name, n -> n_datef))
+		if (uleq (name, n->n_datef))
 		    break;
 		if (state != FLDEOF)
 		    continue;
@@ -916,23 +909,23 @@ plist
 	    case LENERR: 
 	    case FMTERR: 
 		if (state == LENERR || state == FMTERR)
-		    advise (NULLCP, "format error in message %d", msgnum);
+		    advise (NULL, "format error in message %d", msgnum);
 		if (bp != NULL)
 		    free (bp);
 		return 0;
 
 	    default: 
-		adios (NULLCP, "internal error -- you lose");
+		adios (NULL, "internal error -- you lose");
 	}
 	break;
     }
 
     if ((tw = dparsetime (bp)) == NULL)
-	advise (NULLCP, "unable to parse %s field in message %d, matching...",
-		n -> n_datef, msgnum), state = 1;
+	advise (NULL, "unable to parse %s field in message %d, matching...",
+		n->n_datef, msgnum), state = 1;
     else
-	state = n -> n_after ? (twsort (tw, &n -> n_tws) > 0)
-	    : (twsort (tw, &n -> n_tws) < 0);
+	state = n->n_after ? (twsort (tw, &n->n_tws) > 0)
+	    : (twsort (tw, &n->n_tws) < 0);
 
     if (bp != NULL)
 	free (bp);
