@@ -1,26 +1,22 @@
 
 /*
- * popi.c - POP initiator - for MPOP
+ * popi.c -- POP initiator for MPOP
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	lint
-
 #include "../h/mh.h"
 #include "../h/formatsbr.h"
 #include "../h/scansbr.h"
 #include <errno.h>
-#include <stdio.h>
-#include <sys/types.h>
 
-#ifdef	SMTP
+#ifdef SMTP
 # include "../h/local.h"
 #else	/* SMTP */
 # include <sys/stat.h>
 #endif	/* SMTP */
 
-#include "../zotnet/mts.h"
+#include "../zotnet/mts/mts.h"
 
 #ifndef	RPOP
 # define RPOPminc(a) (a)
@@ -92,7 +88,7 @@ static struct swit  switches[] = {
 };
 
 
-static	char   *bulksw = NULLCP;
+static	char   *bulksw = NULL;
 static	int	snoop = 0;
 static	int	width = 0;
 
@@ -106,27 +102,14 @@ extern	int	errno;
 
 extern	char	response[];
 
-/*  */
-
-/* ARGSUSED */
 
 main (int argc, char **argv)
 {
-    int	    autosw = 1,
-	    noisy = 1,
-	    rpop;
-    char   *cp,
-	   *maildir,
-	   *folder = NULL,
-	   *form = NULL,
-	   *format = NULL,
-	   *host = NULL,
-	   *user = NULL,
-	   *pass = NULL,
-	    buf[100],
-	  **ap,
-	  **argp,
-	   *arguments[MAXARGS];
+    int	autosw = 1, noisy = 1, rpop;
+    char *cp, *maildir, *folder = NULL, *form = NULL;
+    char *format = NULL, *host = NULL, *user = NULL;
+    char *pass = NULL, buf[100], **ap, **argp;
+    char *arguments[MAXARGS];
     struct stat st;
 
     invo_name = r1bindex (argv[0], '/');
@@ -153,7 +136,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [switches]", invo_name);
@@ -172,33 +155,33 @@ main (int argc, char **argv)
 
 		case BULKSW: 
 		    if (!(bulksw = *argp++) || *bulksw == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    format = NULL;
 		    continue;
 		case FMTSW: 
 		    if (!(format = *argp++) || *format == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    form = NULL;
 		    continue;
 
 		case WIDSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    width = atoi (cp);
 		    continue;
 
 		case HOSTSW:
 		    if (!(host = *argp++) || *host == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case USERSW:
 		    if (!(user = *argp++) || *user == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case APOPSW:
@@ -214,23 +197,21 @@ main (int argc, char **argv)
 
 		case PROGSW:
 		    if (!(mshproc = *argp++) || *mshproc == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
 	else
-	    adios (NULLCP, "usage: %s [+folder] [switches]", invo_name);
+	    adios (NULL, "usage: %s [+folder] [switches]", invo_name);
     }
 
-/*  */
-
     if (!host)
-	adios (NULLCP, "usage: %s -host \"host\"", invo_name);
+	adios (NULL, "usage: %s -host \"host\"", invo_name);
 
 #ifdef	SMTP
     if (bulksw)
@@ -248,7 +229,7 @@ main (int argc, char **argv)
     sprintf (mailname, "PO box for %s@%s", user, host);
 
     if (pop_init (host, user, pass, snoop, rpop) == NOTOK)
-	adios (NULLCP, "%s", response);
+	adios (NULL, "%s", response);
     if (rpop > 0)
 	setuid (getuid ());
 
@@ -263,18 +244,18 @@ main (int argc, char **argv)
     if (stat (maildir, &st) == NOTOK) {
 	if (errno != ENOENT)
 	    adios (maildir, "error on folder");
-	cp = concat ("Create folder \"", maildir, "\"? ", NULLCP);
+	cp = concat ("Create folder \"", maildir, "\"? ", NULL);
 	if (noisy && !getanswer (cp))
 	    done (1);
 	free (cp);
 	if (!makedir (maildir))
-	    adios (NULLCP, "unable to create folder %s", maildir);
+	    adios (NULL, "unable to create folder %s", maildir);
     }
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
 
 #ifdef	BPOP
     if (autosw)
@@ -295,7 +276,6 @@ main (int argc, char **argv)
     /* NOTREACHED */
 }
 
-/*  */
 
 static struct swit popicmds[] = {
 #define	DELECMD	 0
@@ -326,17 +306,16 @@ static struct swit popicmds[] = {
     NULL, 0
 };
 
-/*  */
 
-static	popi ()
+static void
+popi (void)
 {
-    int	    eof;
+    int	eof = 0;
 
-    eof = 0;
     for (;;) {
-	int	i;
+	int i;
 	register char *cp;
-	char	buffer[BUFSIZ];
+	char buffer[BUFSIZ];
 
 	if (eof)
 	    return;
@@ -416,12 +395,12 @@ static	popi ()
 
 	    case RETRCMD:
 		if (!cp) {
-		    advise (NULLCP, "missing argument to %s", buffer);
+		    advise (NULL, "missing argument to %s", buffer);
 		    break;
 		}
-		retr_action (NULLCP, OK);
+		retr_action (NULL, OK);
 		pop_retr (atoi (++cp), retr_action);
-		retr_action (NULLCP, DONE);
+		retr_action (NULL, DONE);
 		printf ("%s\n", response);
 		break;
 
@@ -439,7 +418,7 @@ static	popi ()
 			    i++;
 		    i++;
 		    if ((ep = malloc ((unsigned) i)) == NULL)
-			adios (NULLCP, "out of memory");
+			adios (NULL, "out of memory");
 		    for (dp = nfs, fp = ep; *dp; dp++) {
 			if (*dp == '\n') {
 			    *fp++ = '\\', *fp++ = 'n';
@@ -467,23 +446,21 @@ static	popi ()
     }
 }
 
-/*  */
 
-static int  retr_action (rsp, flag)
-char   *rsp;
-int	flag;
+static int
+retr_action (char *rsp, int flag)
 {
-    static FILE    *fp;
+    static FILE *fp;
 
     if (rsp == NULL) {
-	static int    msgnum;
-	static char  *cp;
+	static int msgnum;
+	static char *cp;
 
 	if (flag == OK) {
-	    if ((mp = m_remsg (mp, 0, msgnum = mp -> hghmsg + 1)) == NULL)
-		adios (NULLCP, "unable to allocate folder storage");
+	    if ((mp = m_remsg (mp, 0, msgnum = mp->hghmsg + 1)) == NULL)
+		adios (NULL, "unable to allocate folder storage");
 
-	    cp = getcpy (m_name (mp -> hghmsg + 1));
+	    cp = getcpy (m_name (mp->hghmsg + 1));
 	    if ((fp = fopen (cp, "w+")) == NULL)
 		adios (cp, "unable to write");
 	    chmod (cp, m_gmprot ());
@@ -493,12 +470,12 @@ int	flag;
 
 	    fflush (fp);
 	    if (fstat (fileno (fp), &st) != NOTOK && st.st_size > 0) {
-		mp -> msgstats[msgnum] = EXISTS | UNSEEN;
-		mp -> msgflags |= SEQMOD;
+		mp->msgstats[msgnum] = EXISTS | UNSEEN;
+		mp->msgflags |= SEQMOD;
 
 		if (ferror (fp))
 		    advise (cp, "write error on");
-		mp -> hghmsg = msgnum;
+		mp->hghmsg = msgnum;
 	    }
 	    else
 		unlink (cp);
@@ -513,19 +490,16 @@ int	flag;
     fprintf (fp, "%s\n", rsp);
 }
 
-/*  */
 
-#ifdef	BPOP
-static	msh ()
+#ifdef BPOP
+static void
+msh (void)
 {
-    int	    child_id,
-	    vecp;
-    char    buf1[BUFSIZ],
-	    buf2[BUFSIZ],
-	   *vec[9];
+    int	child_id, vecp;
+    char buf1[BUFSIZ], buf2[BUFSIZ], *vec[9];
 
     if (pop_fd (buf1, buf2) == NOTOK)
-	adios (NULLCP, "%s", response);
+	adios (NULL, "%s", response);
 
     vecp = 0;
     vec[vecp++] = r1bindex (mshproc, '/');
@@ -555,48 +529,43 @@ static	msh ()
 }
 #endif
 
-/*  */
 
-#ifdef	SMTP
-#include "../zotnet/mts.h"
+#ifdef SMTP
+#include "../zotnet/mts/mts.h"
 #include "../mts/sendmail/smail.h"
 
 
-static int  dselect (d)
-register struct direct *d;
+static int
+dselect (struct direct *d)
 {
-    int	    i;
+    int	i;
 
-    if ((i = strlen (d -> d_name)) < sizeof "smtp"
-	    || strncmp (d -> d_name, "smtp", sizeof "smtp" - 1))
+    if ((i = strlen (d->d_name)) < sizeof "smtp"
+	    || strncmp (d->d_name, "smtp", sizeof "smtp" - 1))
 	return 0;
     return ((i -= (sizeof ".bulk" - 1)) > 0
-	        && !strcmp (d -> d_name + i, ".bulk"));
+	        && !strcmp (d->d_name + i, ".bulk"));
 }
 
 
-static int  dcompar (d1, d2)
-struct direct **d1,
-	      **d2;
+static int
+dcompar (struct direct *d1, struct direct *d2)
 {
-    struct stat s1,
-		s2;
+    struct stat s1, s2;
 
-    if (stat ((*d1) -> d_name, &s1) == NOTOK)
+    if (stat ((*d1)->d_name, &s1) == NOTOK)
 	return 1;
-    if (stat ((*d2) -> d_name, &s2) == NOTOK)
+    if (stat ((*d2)->d_name, &s2) == NOTOK)
 	return -1;
     return ((int) (s1.st_mtime - s2.st_mtime));
 }
 
 
-static	do_bulk (host)
-char   *host;
+static void
+do_bulk (char *host)
 {
-    register int    i;
-    int	    n,
-	    retval,
-	    sm;
+    register int i;
+    int	n, retval, sm;
     struct direct **namelist;
 
     if (chdir (bulksw) == NOTOK)
@@ -610,23 +579,23 @@ char   *host;
 	register struct direct *d = namelist[i];
 
 	if (sm == NOTOK) {
-	    if (rp_isbad (retval = sm_init (NULLCP, host, 1, 1, snoop)))
-		adios (NULLCP, "problem initializing server: %s",
+	    if (rp_isbad (retval = sm_init (NULL, host, 1, 1, snoop)))
+		adios (NULL, "problem initializing server: %s",
 		       rp_string (retval));
 	    else
 		sm = OK;
 	}
 
-	switch (retval = sm_bulk (d -> d_name)) {
+	switch (retval = sm_bulk (d->d_name)) {
 	    default:
 	        if (rp_isbad (retval))
-		    adios (NULLCP, "problem delivering msg %s: %s",
-			   d -> d_name, rp_string (retval));
+		    adios (NULL, "problem delivering msg %s: %s",
+			   d->d_name, rp_string (retval));
 		/* else fall... */
 	    case RP_OK:
 	    case RP_NO:
 	    case RP_NDEL:
-		advise (NULLCP, "msg %s: %s", d -> d_name, rp_string (retval));
+		advise (NULL, "msg %s: %s", d->d_name, rp_string (retval));
 		break;
 	}
     }
@@ -644,19 +613,19 @@ char   *host;
 		register struct direct *d = newlist[j];
 
 		for (i = 0; i < n; i++)
-		    if (strcmp (d -> d_name, namelist[i] -> d_name) == 0)
+		    if (strcmp (d->d_name, namelist[i]->d_name) == 0)
 			break;
 		if (i >= n) {
-		    switch (retval = sm_bulk (d -> d_name)) {
+		    switch (retval = sm_bulk (d->d_name)) {
 		        default:
 			    if (rp_isbad (retval))
-				adios (NULLCP, "problem delivering msg %s: %s",
-				       d -> d_name, rp_string (retval));
+				adios (NULL, "problem delivering msg %s: %s",
+				       d->d_name, rp_string (retval));
 			    /* else fall... */
 			case RP_OK:
 			case RP_NO:
 			case RP_NDEL:
-			    advise (NULLCP, "msg %s: %s", d -> d_name,
+			    advise (NULL, "msg %s: %s", d->d_name,
 				    rp_string (retval));
 			    break;
 		    }
@@ -677,7 +646,7 @@ char   *host;
     }
 
     if (sm == OK && rp_isbad (retval = sm_end (OK)))
-	adios (NULLCP, "problem finalizing server: %s", rp_string (retval));
+	adios (NULL, "problem finalizing server: %s", rp_string (retval));
 
     for (i = 0; i < n; i++)
 	free ((char *) namelist[i]);
