@@ -1,22 +1,13 @@
 
 /*
- * prompter.c - prompting editor front-end
+ * prompter.c -- prompting editor front-end
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
-#include <stdio.h>
 #include <errno.h>
 
-#ifdef SYS5
-# include <sys/types.h>
-# include <sys/ioctl.h>
-#endif
-
 #ifdef HAVE_TERMIOS_H
 # include <termios.h>
 #else
@@ -27,61 +18,55 @@ static char ident[] = "$Id$";
 # endif
 #endif
 
-#ifdef	BSD42
+#ifdef SYS5
+# include <sys/ioctl.h>
+#endif
+
+#ifdef BSD42
 # include <setjmp.h>
-#endif	/* BSD42 */
+#endif
 
 #include <signal.h>
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 #define	QUOTE	'\\'
 
 #ifndef	CKILL
-#define CKILL   '@'
-#endif	/* not CKILL */
+# define CKILL '@'
+#endif
 
 #ifndef	CERASE
-#define CERASE  '#'
-#endif	/* not CERASE */
+# define CERASE '#'
+#endif
 
 static struct swit switches[] = {
 #define	ERASESW	0
-    "erase chr", 0,
+    { "erase chr", 0 },
 #define	KILLSW	1
-    "kill chr", 0,
-
+    { "kill chr", 0 },
 #define	PREPSW	2
-    "prepend", 0,	
+    { "prepend", 0 },
 #define	NPREPSW	3
-    "noprepend", 0,	
-
+    { "noprepend", 0 },	
 #define	RAPDSW	4
-    "rapid", 0,	
+    { "rapid", 0 },
 #define	NRAPDSW	5
-    "norapid", 0,	
-
+    { "norapid", 0 },
 #define	BODYSW	6
-    "body", -4,
+    { "body", -4 },
 #define	NBODYSW	7
-    "nobody", -6,
-
+    { "nobody", -6 },
 #define	DOTSW	8
-    "doteof", 0,
+    { "doteof", 0 },
 #define	NDOTSW	9
-    "nodoteof", 0,
-
+    { "nodoteof", 0 },
 #define VERSIONSW 10
-    "version", 0,
+    { "version", 0 },
 #define	HELPSW	11
-    "help", 4,		
-
-    NULL, 0
+    { "help", 4 },
+    { NULL, 0 }
 };
 
-extern int  errno;
+extern int errno;
 
 #ifdef HAVE_TERMIOS_H
 static struct termios tio;
@@ -103,8 +88,8 @@ static struct tchars tc;
 # endif
 #endif
 
-static int  wtuser = 0;
-static int  sigint = 0;
+static int wtuser = 0;
+static int sigint = 0;
 
 #ifdef BSD42
 static jmp_buf sigenv;
@@ -148,7 +133,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buffer, "%s [switches] file", invo_name);
@@ -160,11 +145,11 @@ main (int argc, char **argv)
 
 		case ERASESW: 
 		    if (!(erasep = *argp++) || *erasep == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case KILLSW: 
 		    if (!(killp = *argp++) || *killp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case PREPSW: 
@@ -200,7 +185,7 @@ main (int argc, char **argv)
 		drft = cp;
 
     if (!drft)
-	adios (NULLCP, "usage: %s [switches] file", invo_name);
+	adios (NULL, "usage: %s [switches] file", invo_name);
     if ((in = fopen (drft, "r")) == NULL)
 	adios (drft, "unable to open");
 
@@ -361,7 +346,7 @@ no_body: ;
 		break;
 
 	    default: 
-		adios (NULLCP, "skeleton is poorly formatted");
+		adios (NULL, "skeleton is poorly formatted");
 	}
 	break;
     }
