@@ -1,30 +1,23 @@
 
 /*
  * rcvdist.c -- a rcvmail program to distribute messages
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 #include "../h/formatsbr.h"
 #include "../h/rcvmail.h"
 #include "../zotnet/tws/tws.h"
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define	FORMSW	0
-    "form formfile",  4,
+    { "form formfile",  4 },
 #define VERSIONSW 1
-    "version", 0,
+    { "version", 0 },
 #define	HELPSW	2
-    "help", 4,
-    NULL, 0
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 static char backup[BUFSIZ] = "";
@@ -42,8 +35,8 @@ main (int argc, char **argv)
 {
     pid_t child_id;
     int i, vecp = 1;
-    char *addrs = NULL, *cp, *form = NULL, buf[100],
-         **ap, **argp, *arguments[MAXARGS], *vec[MAXARGS];
+    char *addrs = NULL, *cp, *form = NULL, buf[100];
+    char **ap, **argp, *arguments[MAXARGS], *vec[MAXARGS];
     register FILE *fp;
 
 #ifdef LOCALE
@@ -81,14 +74,14 @@ main (int argc, char **argv)
 
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 	    }
 	addrs = addrs ? add (cp, add (", ", addrs)) : getcpy (cp);
     }
 
     if (addrs == NULL)
-	adios (NULLCP, "usage: %s [switches] [switches for postproc] address ...",
+	adios (NULL, "usage: %s [switches] [switches for postproc] address ...",
 	    invo_name);
 
     umask (~m_gmprot ());
@@ -113,7 +106,7 @@ main (int argc, char **argv)
 	sleep (5);
     switch (child_id) {
 	case NOTOK: 
-	    admonish (NULLCP, "unable to fork");/* fall */
+	    admonish (NULL, "unable to fork");/* fall */
 	case OK: 
 	    execvp (postproc, vec);
 	    fprintf (stderr, "unable to exec ");
@@ -160,52 +153,40 @@ static char *addrcomps[] = {
 static void
 rcvdistout (FILE *inb, char *form, char *addrs)
 {
-    register int    char_read = 0,
-                    format_len,
-                    i,
-                    state;
-    register char  *tmpbuf,
-                  **nxtbuf,
-		  **ap;
-    char   *cp,
-           *scanl,
-            name[NAMESZ];
-    register struct comp   *cptr,
-                          **savecomp;
-    FILE   *out;
+    register int char_read = 0, format_len, i, state;
+    register char *tmpbuf, **nxtbuf, **ap;
+    char *cp, *scanl, name[NAMESZ];
+    register struct comp *cptr, **savecomp;
+    FILE *out;
 
-    if ((out = fopen (drft, "w")) == NULL)
+    if (!(out = fopen (drft, "w")))
 	adios (drft, "unable to create");
     
-    cp = new_fs (form ? form : rcvdistcomps, NULLCP, NULLCP);
+    cp = new_fs (form ? form : rcvdistcomps, NULL, NULL);
     format_len = strlen (cp);
     ncomps = fmt_compile (cp, &fmt) + 1;
-    if ((nxtbuf = compbuffers = (char **)
-	    calloc ((unsigned) ncomps, sizeof (char *)))
-	    == (char **)NULL)
-	adios (NULLCP, "unable to allocate component buffers");
-    if ((savecomp = used_buf = (struct comp **)
-	    calloc ((unsigned) (ncomps + 1), sizeof (struct comp *)))
-	    == (struct comp **) NULL)
-	adios (NULLCP, "unable to allocate component buffer stack");
+    if (!(nxtbuf = compbuffers = (char **) calloc ((size_t) ncomps, sizeof(char *))))
+	adios (NULL, "unable to allocate component buffers");
+    if (!(savecomp = used_buf = (struct comp **) calloc ((size_t) (ncomps + 1), sizeof(struct comp *))))
+	adios (NULL, "unable to allocate component buffer stack");
     savecomp += ncomps + 1;
     *--savecomp = 0;
 
     for (i = ncomps; i--;)
-	if ((*nxtbuf++ = malloc (SBUFSIZ)) == NULL)
-	    adios (NULLCP, "unable to allocate component buffer");
+	if (!(*nxtbuf++ = malloc (SBUFSIZ)))
+	    adios (NULL, "unable to allocate component buffer");
     nxtbuf = compbuffers;
     tmpbuf = *nxtbuf++;
 
     for (ap = addrcomps; *ap; ap++) {
 	FINDCOMP (cptr, *ap);
 	if (cptr)
-	    cptr -> c_type |= CT_ADDR;
+	    cptr->c_type |= CT_ADDR;
     }
 
     FINDCOMP (cptr, "addresses");
     if (cptr)
-	cptr -> c_text = addrs;
+	cptr->c_text = addrs;
 
     for (state = FLD;;) {
 	switch (state = m_getfld (state, name, tmpbuf, SBUFSIZ, inb)) {
@@ -213,33 +194,33 @@ rcvdistout (FILE *inb, char *form, char *addrs)
 	    case FLDPLUS: 
 		if (cptr = wantcomp[CHASH (name)])
 		    do {
-			if (uleq (name, cptr -> c_name)) {
+			if (uleq (name, cptr->c_name)) {
 			    char_read += msg_count;
-			    if (!cptr -> c_text) {
-				cptr -> c_text = tmpbuf;
+			    if (!cptr->c_text) {
+				cptr->c_text = tmpbuf;
 				*--savecomp = cptr;
 				tmpbuf = *nxtbuf++;
 			    }
 			    else {
-				i = strlen (cp = cptr -> c_text) - 1;
+				i = strlen (cp = cptr->c_text) - 1;
 				if (cp[i] == '\n')
-				    if (cptr -> c_type & CT_ADDR) {
+				    if (cptr->c_type & CT_ADDR) {
 					cp[i] = 0;
 					cp = add (",\n\t", cp);
 				    }
 				    else
 					cp = add ("\t", cp);
-				cptr -> c_text = add (tmpbuf, cp);
+				cptr->c_text = add (tmpbuf, cp);
 			    }
 			    while (state == FLDPLUS) {
 				state = m_getfld (state, name, tmpbuf,
 						  SBUFSIZ, inb);
-				cptr -> c_text = add (tmpbuf, cptr -> c_text);
+				cptr->c_text = add (tmpbuf, cptr->c_text);
 				char_read += msg_count;
 			    }
 			    break;
 			}
-		    } while (cptr = cptr -> c_next);
+		    } while (cptr = cptr->c_next);
 
 		while (state == FLDPLUS)
 		    state = m_getfld (state, name, tmpbuf, SBUFSIZ, inb);
@@ -252,13 +233,13 @@ rcvdistout (FILE *inb, char *form, char *addrs)
 		goto finished;
 
 	    default: 
-		adios (NULLCP, "m_getfld() returned %d", state);
+		adios (NULL, "m_getfld() returned %d", state);
 	}
     }
 finished: ;
 
     i = format_len + char_read + 256;
-    scanl = malloc ((unsigned) i + 2);
+    scanl = malloc ((size_t) i + 2);
     dat[0] = dat[1] = dat[2] = dat[4] = 0;
     dat[3] = outputlinelen;
     fmtscan (fmt, scanl, i, dat);
@@ -270,7 +251,7 @@ finished: ;
 
     free (scanl);
     for (nxtbuf = compbuffers, i = ncomps; cptr = *savecomp++; nxtbuf++, i--)
-	free (cptr -> c_text);
+	free (cptr->c_text);
     while (i-- > 0)
         free (*nxtbuf++);
     free ((char *) compbuffers);
