@@ -1,32 +1,24 @@
 
 /*
  * rcvtty.c -- a rcvmail program (a lot like rcvalert) handling IPC ttys
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #ifndef	BSD42
 # undef TTYD
 #endif
 
-#include "../h/nmh.h"
 #include "../h/mh.h"
 #include "../h/rcvmail.h"
 #include "../h/scansbr.h"
 #include "../zotnet/tws/tws.h"
 #include <signal.h>
-#include <sys/stat.h>
 
 #ifndef	TTYD
 # include <utmp.h>
 #endif
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 #define	SCANFMT	\
 "%2(hour{dtimenow}):%02(min{dtimenow}): %<(size)%5(size) %>%<{encrypted}E%>\
 %<(mymbox{from})%<{to}To:%14(friendly{to})%>%>%<(zero)%17(friendly{from})%>  \
@@ -34,31 +26,27 @@ static char ident[] = "$Id$";
 
 static struct swit switches[] = {
 #define	BIFFSW	0
-    "biff", 0,
+    { "biff", 0 },
 #define	FORMSW	1
-    "form formatfile", 0,
+    { "form formatfile", 0 },
 #define	FMTSW	2
-    "format string", 5,
-
+    { "format string", 5 },
 #define NLSW    3
-    "newline", 0,
+    { "newline", 0 },
 #define NNLSW   4
-    "nonewline", 0,
+    { "nonewline", 0 },
 #define BELSW	5
-    "bell", 0,
+    { "bell", 0 },
 #define	NBELSW	6
-    "nobell", 0,
-
+    { "nobell", 0 },
 #define VERSIONSW 7
-    "version", 0,
+    { "version", 0 },
 #define	HELPSW	8
-    "help", 4,
-
-    NULL, 0
+    { "help", 4 },
+    { NULL, 0 }
 };
 
-static  jmp_buf myctx;
-
+static jmp_buf myctx;
 static int bell = 1;
 static int newline = 1;
 static int biff = 0;
@@ -69,7 +57,7 @@ static char *format = NULL;
  * prototypes
  */
 char *getusr(void);
-static  RETSIGTYPE alrmser (int);
+static RETSIGTYPE alrmser (int);
 static int message_fd (char **);
 static int header_fd (void);
 static void alert (char *, int);
@@ -78,8 +66,8 @@ static void alert (char *, int);
 main (int argc, char **argv)
 {
     int md, vecp = 0;
-    char *cp, *user, buf[100], **ap,
-         **argp, *arguments[MAXARGS], *vec[MAXARGS];
+    char *cp, *user, buf[100], **ap;
+    char **argp, *arguments[MAXARGS], *vec[MAXARGS];
 
 #ifndef	TTYD
     char tty[BUFSIZ];
@@ -125,12 +113,12 @@ main (int argc, char **argv)
 
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    format = NULL;
 		    continue;
 		case FMTSW: 
 		    if (!(format = *argp++) || *format == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    form = NULL;
 		    continue;
 
@@ -248,8 +236,8 @@ message_fd (char **vec)
 static int
 header_fd (void)
 {
-    int     fd;
-    char    tmpfil[BUFSIZ];
+    int fd;
+    char tmpfil[BUFSIZ];
 
     strcpy (tmpfil, m_tmpfil (invo_name));
     if ((fd = creat (tmpfil, 0600)) == NOTOK)
@@ -276,20 +264,18 @@ header_fd (void)
 static void
 alert (char *tty, int md)
 {
-    int     i,
-            td;
-    char    buffer[BUFSIZ],
-            ttyspec[BUFSIZ];
+    int i, td;
+    char buffer[BUFSIZ], ttyspec[BUFSIZ];
     struct stat st;
 
     sprintf (ttyspec, "/dev/%s", tty);
     if (stat (ttyspec, &st) == NOTOK ||
 	(st.st_mode & (biff ? S_IEXEC :
-#ifdef	BSD43
+#ifdef BSD43
 		       (S_IWRITE >> 3)
-#else	/* BSD43 */
+#else /* BSD43 */
 		       02
-#endif	/* BSD43 */
+#endif /* BSD43 */
 		       )) == 0)
 	return;
 
@@ -325,7 +311,7 @@ alert (char *user, int md)
     int i, td;
     char buffer[BUFSIZ];
 
-    if ((td = ttyw ("notify", NULLCP, NULLCP, user)) == NOTOK)
+    if ((td = ttyw ("notify", NULL, NULL, user)) == NOTOK)
 	return;
     signal (SIGPIPE, SIG_IGN);
 
