@@ -1,21 +1,12 @@
 
 /*
- * refile.c - file messages away
+ * refile.c -- file messages away
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 #include <errno.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define	DRAFTSW	0
@@ -52,44 +43,33 @@ static struct swit switches[] = {
 
 extern int  errno;
 
-
 static char maildir[BUFSIZ];
 
 struct st_fold {
-    char   *f_name;
+    char *f_name;
     struct msgs *f_mp;
 };
 
-
 /*
- * prototypes
+ * static prototypes
  */
 static void opnfolds (struct st_fold *, int);
 static void clsfolds (struct st_fold *, int);
 static void removeit (struct msgs *, int, char **);
-int m_file (char *, struct st_fold *, int, int);
+static int m_file (char *, struct st_fold *, int, int);
 
 
 main (int argc, char **argv)
 {
-    int	    linkf = 0,
-            prsrvf = 0,
-	    filep = 0,
-            foldp = 0,
-            msgp = 0,
-	    isdf = 0,
-	    i,
-            msgnum;
-    char   *cp,
-           *folder = NULL,
-            buf[100],
-          **ap,
-          **argp,
-           *arguments[MAXARGS],
-	   *filevec[NFOLDERS + 2],
-          **files = &filevec[1],	/* leave room for removeit:vec[0] */
-           *msgs[MAXARGS];
-    struct st_fold   folders[NFOLDERS + 1];
+    int	linkf = 0, prsrvf = 0, filep = 0;
+    int foldp = 0, msgp = 0, isdf = 0;
+    int i, msgnum;
+    char *cp, *folder = NULL, buf[100];
+    char **ap, **argp, *arguments[MAXARGS];
+    char *filevec[NFOLDERS + 2];
+    char **files = &filevec[1];		/* leave room for removeit:vec[0] */
+    char *msgs[MAXARGS];
+    struct st_fold folders[NFOLDERS + 1];
     struct msgs *mp;
 
 #ifdef LOCALE
@@ -112,7 +92,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown\n", cp);
+		    adios (NULL, "-%s unknown\n", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [msgs] [switches] +folder ...", invo_name);
@@ -138,29 +118,29 @@ main (int argc, char **argv)
 
 		case SRCSW: 
 		    if (folder)
-			adios (NULLCP, "only one source folder at a time!");
+			adios (NULL, "only one source folder at a time!");
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    folder = path (*cp == '+' || *cp == '@' ? cp + 1 : cp,
 				   *cp != '@' ? TFOLDER : TSUBCWF);
 		    continue;
 		case DRAFTSW:
 		    if (filep > NFOLDERS)
-			adios (NULLCP, "only %d files allowed!", NFOLDERS);
+			adios (NULL, "only %d files allowed!", NFOLDERS);
 		    isdf = 0;
-		    files[filep++] = getcpy (m_draft (NULLCP, NULLCP, 1, &isdf));
+		    files[filep++] = getcpy (m_draft (NULL, NULL, 1, &isdf));
 		    continue;
 		case FILESW: 
 		    if (filep > NFOLDERS)
-			adios (NULLCP, "only %d files allowed!", NFOLDERS);
+			adios (NULL, "only %d files allowed!", NFOLDERS);
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    files[filep++] = path (cp, TFILE);
 		    continue;
 
 		case RPROCSW: 
 		    if (!(rmmproc = *argp++) || *rmmproc == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case NRPRCSW: 
 		    rmmproc = (char *)0;
@@ -168,7 +148,7 @@ main (int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (foldp > NFOLDERS)
-		adios (NULLCP, "only %d folders allowed!", NFOLDERS);
+		adios (NULL, "only %d folders allowed!", NFOLDERS);
 	    folders[foldp++].f_name =
 		    path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
@@ -179,7 +159,7 @@ main (int argc, char **argv)
     if (!m_find ("path"))
 	free (path ("./", TFOLDER));
     if (foldp == 0)
-	adios (NULLCP, "no folder specified");
+	adios (NULL, "no folder specified");
 
 #ifdef	WHATNOW
     if (!msgp && !foldp && !filep && (cp = getenv ("mhdraft")) && *cp)
@@ -188,7 +168,7 @@ main (int argc, char **argv)
 
     if (filep > 0) {
 	if (folder || msgp)
-	    adios (NULLCP, "use -file or some messages, not both");
+	    adios (NULL, "use -file or some messages, not both");
 	opnfolds (folders, foldp);
 	for (i = 0; i < filep; i++)
 	    if (m_file (files[i], folders, foldp, prsrvf))
@@ -207,9 +187,9 @@ main (int argc, char **argv)
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
-    if (mp -> hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
+    if (mp->hghmsg == 0)
+	adios (NULL, "no messages in %s", folder);
 
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
@@ -217,27 +197,27 @@ main (int argc, char **argv)
     m_setseq (mp);
 
     opnfolds (folders, foldp);
-    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	if (mp -> msgstats[msgnum] & SELECTED) {
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (mp->msgstats[msgnum] & SELECTED) {
 	    cp = getcpy (m_name (msgnum));
 	    if (m_file (cp, folders, foldp, prsrvf))
 		done (1);
 	    free (cp);
 	    if (!linkf) {
 #ifdef	notdef
-		mp -> msgstats[msgnum] |= DELETED;
+		mp->msgstats[msgnum] |= DELETED;
 #endif	/* notdef */
-		mp -> msgstats[msgnum] &= ~EXISTS;
+		mp->msgstats[msgnum] &= ~EXISTS;
 	    }
 	}
     if (!linkf)
-	mp -> msgflags |= SEQMOD;
+	mp->msgflags |= SEQMOD;
     clsfolds (folders, foldp);
 
     m_replace (pfolder, folder);
-    if (mp -> hghsel != mp -> curmsg
-	    && (mp -> numsel != mp -> nummsg || linkf))
-	m_setcur (mp, mp -> hghsel);
+    if (mp->hghsel != mp->curmsg
+	    && (mp->numsel != mp->nummsg || linkf))
+	m_setcur (mp, mp->hghsel);
     m_sync (mp);
     m_update ();
 
@@ -251,35 +231,34 @@ main (int argc, char **argv)
 static void
 opnfolds (struct st_fold *folders, int nfolders)
 {
-    register char  *cp;
-    char    nmaildir[BUFSIZ];
-    register struct st_fold *fp,
-                            *ep;
-    register struct msgs   *mp;
+    register char *cp;
+    char nmaildir[BUFSIZ];
+    register struct st_fold *fp, *ep;
+    register struct msgs *mp;
     struct stat st;
 
     for (ep = (fp = folders) + nfolders; fp < ep; fp++) {
 	chdir (m_maildir (""));
-	strcpy (nmaildir, m_maildir (fp -> f_name));
+	strcpy (nmaildir, m_maildir (fp->f_name));
 
 	if (stat (nmaildir, &st) == NOTOK) {
 	    if (errno != ENOENT)
 		adios (nmaildir, "error on folder");
-	    cp = concat ("Create folder \"", nmaildir, "\"? ", NULLCP);
+	    cp = concat ("Create folder \"", nmaildir, "\"? ", NULL);
 	    if (!getanswer (cp))
 		done (1);
 	    free (cp);
 	    if (!makedir (nmaildir))
-		adios (NULLCP, "unable to create folder %s", nmaildir);
+		adios (NULL, "unable to create folder %s", nmaildir);
 	}
 
 	if (chdir (nmaildir) == NOTOK)
 	    adios (nmaildir, "unable to change directory to");
-	if (!(mp = m_gmsg (fp -> f_name)))
-	    adios (NULLCP, "unable to read folder %s", fp -> f_name);
-	mp -> curmsg = 0;
+	if (!(mp = m_gmsg (fp->f_name)))
+	    adios (NULL, "unable to read folder %s", fp->f_name);
+	mp->curmsg = 0;
 
-	fp -> f_mp = mp;
+	fp->f_mp = mp;
 
 	chdir (maildir);
     }
@@ -289,12 +268,11 @@ opnfolds (struct st_fold *folders, int nfolders)
 static void
 clsfolds (struct st_fold *folders, int nfolders)
 {
-    register struct st_fold *fp,
-                           *ep;
-    register struct msgs   *mp;
+    register struct st_fold *fp, *ep;
+    register struct msgs *mp;
 
     for (ep = (fp = folders) + nfolders; fp < ep; fp++) {
-	mp = fp -> f_mp;
+	mp = fp->f_mp;
 	m_setseq (mp);
 	m_sync (mp);
     }
@@ -304,10 +282,8 @@ clsfolds (struct st_fold *folders, int nfolders)
 static void
 removeit (struct msgs *mp, int filep, char **files)
 {
-    register int    i,
-                    vecp;
-    register char  *cp,
-                  **vec;
+    register int i, vecp;
+    register char *cp, **vec;
 
     if (rmmproc) {
 	if (filep > 0) {
@@ -315,15 +291,15 @@ removeit (struct msgs *mp, int filep, char **files)
 	    files[filep] = NULL;
 	}
 	else {
-	    if (mp -> numsel > MAXARGS - 2)
-		adios (NULLCP, "more than %d messages for %s exec",
+	    if (mp->numsel > MAXARGS - 2)
+		adios (NULL, "more than %d messages for %s exec",
 			MAXARGS - 2, rmmproc);
-	    vec = (char **) calloc ((unsigned) (mp -> numsel + 2), sizeof *vec);
+	    vec = (char **) calloc ((unsigned) (mp->numsel + 2), sizeof *vec);
 	    if (vec == NULL)
-		adios (NULLCP, "unable to allocate exec vector");
+		adios (NULL, "unable to allocate exec vector");
 	    vecp = 1;
-	    for (i = mp -> lowsel; i <= mp -> hghsel; i++)
-		if (mp -> msgstats[i] & SELECTED)
+	    for (i = mp->lowsel; i <= mp->hghsel; i++)
+		if (mp->msgstats[i] & SELECTED)
 		    vec[vecp++] = getcpy (m_name (i));
 	    vec[vecp] = NULL;
 	}
@@ -341,66 +317,61 @@ removeit (struct msgs *mp, int filep, char **files)
 		admonish (files[i], "unable to unlink");
     }
     else
-	for (i = mp -> lowsel; i <= mp -> hghsel; i++)
-	    if (mp -> msgstats[i] & SELECTED)
+	for (i = mp->lowsel; i <= mp->hghsel; i++)
+	    if (mp->msgstats[i] & SELECTED)
 		if (unlink (cp = m_name (i)) == NOTOK)
 		    admonish (cp, "unable to unlink");
 }
 
 
-int
+static int
 m_file (char *msg, struct st_fold *folders, int nfolders, int prsrvf)
 {
-    int     in,
-            out,
-            linkerr,
-            msgnum;
-    register char  *nmsg;
-    char    newmsg[BUFSIZ];
-    register struct st_fold *fp,
-			    *ep;
+    int in, out, linkerr, msgnum;
+    register char *nmsg;
+    char newmsg[BUFSIZ];
+    register struct st_fold *fp, *ep;
     register struct msgs *mp;
-    struct stat st,
-                s1;
+    struct stat st, s1;
 
     for (ep = (fp = folders) + nfolders; fp < ep; fp++) {
-	mp = fp -> f_mp;
+	mp = fp->f_mp;
 	if (prsrvf && (msgnum = m_atoi (nmsg = msg)) > 0) {
-	    if (msgnum >= mp -> hghoff)
+	    if (msgnum >= mp->hghoff)
 		if (mp = m_remsg (mp, 0, msgnum + MAXFOLDER))
-		    fp -> f_mp = mp;
+		    fp->f_mp = mp;
 		else
-		    adios (NULLCP, "unable to allocate folder storage");
-	    if (!(mp -> msgstats[msgnum] & EXISTS)) {
-		mp -> msgstats[msgnum] |= EXISTS;
+		    adios (NULL, "unable to allocate folder storage");
+	    if (!(mp->msgstats[msgnum] & EXISTS)) {
+		mp->msgstats[msgnum] |= EXISTS;
 #ifdef	notdef
-		mp -> msgstats[msgnum] &= ~DELETED;
+		mp->msgstats[msgnum] &= ~DELETED;
 #endif	/* notdef */
-		mp -> nummsg++;
+		mp->nummsg++;
 	    }
-	    mp -> msgstats[msgnum] |= SELECTED;		    
-	    if (msgnum > mp -> hghmsg)
-		mp -> hghmsg = msgnum;
+	    mp->msgstats[msgnum] |= SELECTED;		    
+	    if (msgnum > mp->hghmsg)
+		mp->hghmsg = msgnum;
 	}
 	else {
-	    if (mp -> hghmsg >= mp -> hghoff)
-		if (mp = m_remsg (mp, 0, mp -> hghoff + MAXFOLDER))
-		    fp -> f_mp = mp;
+	    if (mp->hghmsg >= mp->hghoff)
+		if (mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER))
+		    fp->f_mp = mp;
 		else
-		    adios (NULLCP, "unable to allocate folder storage");
+		    adios (NULL, "unable to allocate folder storage");
 
-	    nmsg = m_name (msgnum = ++mp -> hghmsg);
-	    mp -> nummsg++;
-	    mp -> msgstats[msgnum] |= EXISTS | SELECTED;
+	    nmsg = m_name (msgnum = ++mp->hghmsg);
+	    mp->nummsg++;
+	    mp->msgstats[msgnum] |= EXISTS | SELECTED;
 	}
-	if (mp -> lowmsg == 0)
-	    mp -> lowmsg = msgnum;
-	if (mp -> lowsel == 0 || msgnum < mp -> lowsel)
-	    mp -> lowsel = msgnum;
-	if (msgnum > mp -> hghsel)
-	    mp -> hghsel = msgnum;
+	if (mp->lowmsg == 0)
+	    mp->lowmsg = msgnum;
+	if (mp->lowsel == 0 || msgnum < mp->lowsel)
+	    mp->lowsel = msgnum;
+	if (msgnum > mp->hghsel)
+	    mp->hghsel = msgnum;
 
-	sprintf (newmsg, "%s/%s", mp -> foldpath, nmsg);
+	sprintf (newmsg, "%s/%s", mp->foldpath, nmsg);
 	if (link (msg, newmsg) == NOTOK) {
 #ifndef	EISREMOTE
 	    linkerr = errno;
@@ -414,8 +385,8 @@ m_file (char *msg, struct st_fold *folders, int nfolders, int prsrvf)
 			|| stat (msg, &s1) == NOTOK
 			|| stat (newmsg, &st) == NOTOK
 			|| s1.st_ino != st.st_ino) {
-		    advise (NULLCP, "message %s:%s already exists",
-			    fp -> f_name, newmsg);
+		    advise (NULL, "message %s:%s already exists",
+			    fp->f_name, newmsg);
 		    return 1;
 		}
 		continue;
