@@ -1,19 +1,12 @@
 
 /*
- * repl.c - reply to a message
+ * repl.c -- reply to a message
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 static struct swit switches[] = {
 #define	ANNOSW	0
     "annotate", 0,
@@ -192,7 +185,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s: [+folder] [msg] [switches]", invo_name);
@@ -211,18 +204,18 @@ main (int argc, char **argv)
 
 		case CCSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    docc (cp, 1);
 		    continue;
 		case NCCSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    docc (cp, 0);
 		    continue;
 
 		case EDITRSW: 
 		    if (!(ed = *argp++) || *ed == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    nedit = 0;
 		    continue;
 		case NEDITSW:
@@ -231,7 +224,7 @@ main (int argc, char **argv)
 		    
 		case WHATSW: 
 		    if (!(whatnowproc = *argp++) || *whatnowproc == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    nwhat = 0;
 		    continue;
 #ifdef	MHE
@@ -244,7 +237,7 @@ main (int argc, char **argv)
 
 		case FCCSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    dp = NULL;
 		    if (*cp == '@')
 			cp = dp = path (cp + 1, TSUBCWF);
@@ -257,19 +250,19 @@ main (int argc, char **argv)
 
 		case FILESW: 
 		    if (file)
-			adios (NULLCP, "only one file at a time!");
+			adios (NULL, "only one file at a time!");
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    file = path (cp, TFILE);
 		    continue;
 		case FILTSW:
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    filter = getcpy (libpath (cp));
 		    continue;
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case FRMTSW: 
@@ -295,24 +288,24 @@ main (int argc, char **argv)
 
 		case WIDTHSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if ((outputlinelen = atoi (cp)) < 10)
-			adios (NULLCP, "impossible width %d", outputlinelen);
+			adios (NULL, "impossible width %d", outputlinelen);
 		    continue;
 
 		case DFOLDSW: 
 		    if (dfolder)
-			adios (NULLCP, "only one draft folder at a time!");
+			adios (NULL, "only one draft folder at a time!");
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    dfolder = path (*cp == '+' || *cp == '@' ? cp + 1 : cp,
 				    *cp != '@' ? TFOLDER : TSUBCWF);
 		    continue;
 		case DMSGSW:
 		    if (dmsg)
-			adios (NULLCP, "only one draft message at a time!");
+			adios (NULL, "only one draft message at a time!");
 		    if (!(dmsg = *argp++) || *dmsg == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case NDFLDSW: 
 		    dfolder = NULL;
@@ -321,13 +314,13 @@ main (int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
 	else
 	    if (msg)
-		adios (NULLCP, "only one message at a time!");
+		adios (NULL, "only one message at a time!");
 	    else
 		msg = cp;
     }
@@ -337,7 +330,7 @@ main (int argc, char **argv)
     if (!m_find ("path"))
 	free (path ("./", TFOLDER));
     if (file && (msg || folder))
-	adios (NULLCP, "can't mix files and folders/msgs");
+	adios (NULL, "can't mix files and folders/msgs");
 
 try_it_again: ;
 #ifndef MHE
@@ -345,7 +338,7 @@ try_it_again: ;
     if (stat (drft, &st) != NOTOK) {
 #else	/* MHE */
     strcpy (drft, buildsw ? m_maildir ("reply")
-			  : m_draft (dfolder, NULLCP, NOUSE, &isdf));
+			  : m_draft (dfolder, NULL, NOUSE, &isdf));
     if (!buildsw && stat (drft, &st) != NOTOK) {
 #endif	/* MHE */
 	printf ("Draft \"%s\" exists (%ld bytes).", drft, st.st_size);
@@ -368,7 +361,7 @@ try_it_again: ;
 			i = YESW;
 		    break;
 		default: 
-		    advise (NULLCP, "say what?");
+		    advise (NULL, "say what?");
 		    break;
 	    }
 	}
@@ -388,25 +381,25 @@ try_it_again: ;
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
-    if (mp -> hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
+    if (mp->hghmsg == 0)
+	adios (NULL, "no messages in %s", folder);
 
     if (!m_convert (mp, msg))
 	done (1);
     m_setseq (mp);
 
-    if (mp -> numsel > 1)
-	adios (NULLCP, "only one message at a time!");
+    if (mp->numsel > 1)
+	adios (NULL, "only one message at a time!");
 
     m_replace (pfolder, folder);
-    if (mp -> lowsel != mp -> curmsg)
-	m_setcur (mp, mp -> lowsel);
+    if (mp->lowsel != mp->curmsg)
+	m_setcur (mp, mp->lowsel);
     m_sync (mp);
     m_update ();
 
 go_to_it: ;
-    msg = file ? file : getcpy (m_name (mp -> lowsel));
+    msg = file ? file : getcpy (m_name (mp->lowsel));
 
     if ((in = fopen (msg, "r")) == NULL)
 	adios (msg, "unable to open");
@@ -417,7 +410,7 @@ go_to_it: ;
     if (nwhat)
 	done (0);
     what_now (ed, nedit, NOUSE, drft, msg, 0, mp,
-	    anot ? "Replied" : NULLCP, inplace, cwd);
+	    anot ? "Replied" : NULL, inplace, cwd);
     done (1);
 }
 
@@ -429,7 +422,7 @@ docc (char *cp, int ccflag)
 	    ambigsw (cp, ccswitches);
 	    done (1);
 	case UNKWNSW: 
-	    adios (NULLCP, "-%scc %s unknown", ccflag ? "" : "no", cp);
+	    adios (NULL, "-%scc %s unknown", ccflag ? "" : "no", cp);
 
 	case CTOSW: 
 	    ccto = ccflag;
