@@ -1,13 +1,10 @@
 
 /*
  * replsbr.c -- routines to help repl along...
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
 #include "../h/addrsbr.h"
 #include "../h/formatsbr.h"
@@ -92,22 +89,22 @@ replout (FILE *inb, char *msg, char *drft)
     if ((out = fopen (drft, "w")) == NULL)
 	adios (drft, "unable to create");
 
-    cp = new_fs (form ? form : replcomps, NULLCP, NULLCP);
+    cp = new_fs (form ? form : replcomps, NULL, NULL);
     format_len = strlen (cp);
     ncomps = fmt_compile (cp, &fmt) + 1;
     if ((nxtbuf = compbuffers = (char **)
 	    calloc((unsigned)ncomps,sizeof(char *))) 
 	    == (char **)NULL)
-	adios (NULLCP, "unable to allocate component buffers");
+	adios (NULL, "unable to allocate component buffers");
     if ((savecomp = used_buf = (struct comp **)
 	    calloc((unsigned)(ncomps+1),sizeof(struct comp *)))
 	    == (struct comp **)NULL)
-	adios (NULLCP, "unable to allocate component buffer stack");
+	adios (NULL, "unable to allocate component buffer stack");
     savecomp += ncomps + 1;
     *--savecomp = (struct comp *)0;	/* point at zero'd end minus 1 */
     for (i = ncomps; i--; )
 	if ((*nxtbuf++ = malloc( SBUFSIZ )) == NULL)
-	    adios (NULLCP, "unable to allocate component buffer");
+	    adios (NULL, "unable to allocate component buffer");
 
     nxtbuf = compbuffers;		/* point at start */
     tmpbuf = *nxtbuf++;
@@ -115,7 +112,7 @@ replout (FILE *inb, char *msg, char *drft)
     for (ap = addrcomps; *ap; ap++) {
 	FINDCOMP (cptr, *ap);
 	if (cptr)
-	    cptr -> c_type |= CT_ADDR;
+	    cptr->c_type |= CT_ADDR;
     }
 
     /* ignore any components killed by command line switches */
@@ -195,7 +192,7 @@ replout (FILE *inb, char *msg, char *drft)
 		goto finished;
 
 	    default: 
-		adios (NULLCP, "m_getfld() returned %d", state);
+		adios (NULL, "m_getfld() returned %d", state);
 	}
     }
     /*
@@ -269,7 +266,7 @@ static unsigned int bufsiz=0;	/* current size of buf */
 		dst = buf + i;\
 		last_dst = buf + n;\
 		if (! buf)\
-		    adios (NULLCP, "formataddr: couldn't get buffer space");\
+		    adios (NULL, "formataddr: couldn't get buffer space");\
 		bufend = buf + bufsiz;\
 	    }
 
@@ -300,7 +297,7 @@ formataddr (char *orig, char *str)
     if (bufsiz == 0) {
 	buf = malloc (BUFINCR);
 	if (! buf)
-	    adios (NULLCP, "formataddr: couldn't allocate buffer space");
+	    adios (NULL, "formataddr: couldn't allocate buffer space");
 	last_dst = buf;		/* XXX */
 	bufsiz = BUFINCR - 6;  /* leave some slop */
 	bufend = buf + bufsiz;
@@ -363,16 +360,16 @@ insert (struct mailname *np)
     char    buffer[BUFSIZ];
     register struct mailname *mp;
 
-    if (np -> m_mbox == NULL)
+    if (np->m_mbox == NULL)
 	return 0;
 
-    for (mp = &mq; mp -> m_next; mp = mp -> m_next) {
+    for (mp = &mq; mp->m_next; mp = mp->m_next) {
 #ifdef BERK
-	if (uleq (np -> m_mbox, mp -> m_next -> m_mbox))
+	if (uleq (np->m_mbox, mp->m_next->m_mbox))
 	    return 0;
 #else	/* not BERK */
-	if (uleq (np -> m_host, mp -> m_next -> m_host)
-		&& uleq (np -> m_mbox, mp -> m_next -> m_mbox))
+	if (uleq (np->m_host, mp->m_next->m_host)
+		&& uleq (np->m_mbox, mp->m_next->m_mbox))
 	    return 0;
 #endif	/* BERK */
     }
@@ -384,7 +381,7 @@ insert (struct mailname *np)
 	if (!gans (buffer, anoyes))
 	return 0;
     }
-    mp -> m_next = np;
+    mp->m_next = np;
 #ifdef	ISI
     if (ismymbox (np))
 	ccme = 0;
@@ -420,7 +417,7 @@ replfilter (FILE *in, FILE *out)
 	    dup2 (fileno (out), fileno (stdout));
 	    closefds (3);
 
-	    execlp (mhlproc, mhl, "-form", filter, "-noclear", NULLCP);
+	    execlp (mhlproc, mhl, "-form", filter, "-noclear", NULL);
 	    fprintf (stderr, "unable to exec ");
 	    perror (mhlproc);
 	    _exit (-1);
