@@ -1,19 +1,12 @@
 
 /*
  * rmf.c -- remove a folder
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 static struct swit switches[] = {
 #define	INTRSW	0
     "interactive", 0,
@@ -59,7 +52,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [switches]", invo_name);
@@ -78,12 +71,12 @@ main (int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
 	else
-	    adios (NULLCP, "usage: %s [+folder] [switches]", invo_name);
+	    adios (NULL, "usage: %s [+folder] [switches]", invo_name);
     }
 
     if (!m_find ("path"))
@@ -93,7 +86,7 @@ main (int argc, char **argv)
 	defolder++;
     }
     if (strcmp (m_mailpath (folder), pwd ()) == 0)
-	adios (NULLCP, "sorry, you can't remove the current working directory");
+	adios (NULL, "sorry, you can't remove the current working directory");
 
     if (interactive == -1)
 	interactive = defolder;
@@ -110,7 +103,7 @@ main (int argc, char **argv)
 	strcpy (newfolder, (cp = m_find (inbox)) ? cp : defalt);
 
     if (interactive) {
-	cp = concat ("Remove folder \"", folder, "\"? ", NULLCP);
+	cp = concat ("Remove folder \"", folder, "\"? ", NULL);
 	if (!getanswer (cp))
 	    done (0);
 	free (cp);
@@ -129,10 +122,10 @@ static int
 rmf (char *folder)
 {
     int i, j, others;
-    register char  *maildir;
-    char    cur[BUFSIZ];
+    register char *maildir;
+    char cur[BUFSIZ];
     register struct dirent *dp;
-    register DIR * dd;
+    register DIR *dd;
 
     switch (i = chdir (maildir = m_maildir (folder))) {
 	case OK: 
@@ -145,21 +138,21 @@ rmf (char *folder)
 		printf ("[+%s de-referenced]\n", folder);
 		return OK;
 	    }
-	    advise (NULLCP, "you have no profile entry for the %s folder +%s",
+	    advise (NULL, "you have no profile entry for the %s folder +%s",
 		    i == NOTOK ? "unreadable" : "read-only", folder);
 	    return NOTOK;
     }
 
     if ((dd = opendir (".")) == NULL)
-	adios (NULLCP, "unable to read folder +%s", folder);
+	adios (NULL, "unable to read folder +%s", folder);
     others = 0;
 
     j = strlen(BACKUP_PREFIX);
     while (dp = readdir (dd)) {
-	switch (dp -> d_name[0]) {
+	switch (dp->d_name[0]) {
 	    case '.': 
-		if (strcmp (dp -> d_name, ".") == 0
-			|| strcmp (dp -> d_name, "..") == 0)
+		if (strcmp (dp->d_name, ".") == 0
+			|| strcmp (dp->d_name, "..") == 0)
 		    continue;	/* else fall */
 
 	    case ',': 
@@ -173,19 +166,19 @@ rmf (char *folder)
 		break;
 
 	    default: 
-		if (m_atoi (dp -> d_name))
+		if (m_atoi (dp->d_name))
 		    break;
-		if (strcmp (dp -> d_name, LINK) == 0
-			|| strncmp (dp -> d_name, BACKUP_PREFIX, j) == 0)
+		if (strcmp (dp->d_name, LINK) == 0
+			|| strncmp (dp->d_name, BACKUP_PREFIX, j) == 0)
 		    break;
 
-		admonish (NULLCP, "file \"%s/%s\" not deleted",
-			folder, dp -> d_name);
+		admonish (NULL, "file \"%s/%s\" not deleted",
+			folder, dp->d_name);
 		others++;
 		continue;
 	}
-	if (unlink (dp -> d_name) == NOTOK) {
-	    admonish (dp -> d_name, "unable to unlink %s:", folder);
+	if (unlink (dp->d_name) == NOTOK) {
+	    admonish (dp->d_name, "unable to unlink %s:", folder);
 	    others++;
 	}
     }
@@ -198,34 +191,35 @@ rmf (char *folder)
     if (others == 0 && remdir (maildir))
 	return OK;
 
-    advise (NULLCP, "folder +%s not removed", folder);
+    advise (NULL, "folder +%s not removed", folder);
     return NOTOK;
 }
 
+
 static void
 rma (char *folder)
 {
     register int alen, j, plen;
-    register char  *cp;
+    register char *cp;
     register struct node *np, *pp;
 
     alen = strlen ("atr-");
     plen = strlen (cp = m_mailpath (folder)) + 1;
 
     m_getdefs ();
-    for (np = m_defs, pp = NULL; np; np = np -> n_next)
-	if (ssequal ("atr-", np -> n_name)
-		&& (j = strlen (np -> n_name) - plen) > alen
-		&& *(np -> n_name + j) == '-'
-		&& strcmp (cp, np -> n_name + j + 1) == 0) {
-	    if (!np -> n_context)
-		admonish (NULLCP, "bug: m_delete(key=\"%s\")", np -> n_name);
+    for (np = m_defs, pp = NULL; np; np = np->n_next)
+	if (ssequal ("atr-", np->n_name)
+		&& (j = strlen (np->n_name) - plen) > alen
+		&& *(np->n_name + j) == '-'
+		&& strcmp (cp, np->n_name + j + 1) == 0) {
+	    if (!np->n_context)
+		admonish (NULL, "bug: m_delete(key=\"%s\")", np->n_name);
 	    if (pp) {
-		pp -> n_next = np -> n_next;
+		pp->n_next = np->n_next;
 		np = pp;
 	    }
 	    else
-		m_defs = np -> n_next;
+		m_defs = np->n_next;
 	    ctxflags |= CTXMOD;
 	}
 	else
