@@ -1,18 +1,11 @@
 
 /*
  * rmm.c -- remove a message
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define VERSIONSW 0
@@ -51,7 +44,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown\n", cp);
+		    adios (NULL, "-%s unknown\n", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
@@ -63,7 +56,7 @@ main (int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
@@ -82,38 +75,38 @@ main (int argc, char **argv)
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
-    if (mp -> hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
+    if (mp->hghmsg == 0)
+	adios (NULL, "no messages in %s", folder);
 
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
     m_setseq (mp);
 
-    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	if (mp -> msgstats[msgnum] & SELECTED) {
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (mp->msgstats[msgnum] & SELECTED) {
 #ifdef	notdef
-	    mp -> msgstats[msgnum] |= DELETED;
+	    mp->msgstats[msgnum] |= DELETED;
 #endif	/* notdef */
-	    mp -> msgstats[msgnum] &= ~EXISTS;
+	    mp->msgstats[msgnum] &= ~EXISTS;
 	}
-    mp -> msgflags |= SEQMOD;
+    mp->msgflags |= SEQMOD;
 
     m_replace (pfolder, folder);
     m_sync (mp);
     m_update ();
 
     if (rmmproc) {
-	if (mp -> numsel > MAXARGS - 2)
-	    adios (NULLCP, "more than %d messages for %s exec", MAXARGS - 2,
+	if (mp->numsel > MAXARGS - 2)
+	    adios (NULL, "more than %d messages for %s exec", MAXARGS - 2,
 		    rmmproc);
-	vec = (char **) calloc ((unsigned) (mp -> numsel + 2), sizeof *vec);
+	vec = (char **) calloc ((unsigned) (mp->numsel + 2), sizeof *vec);
 	if (vec == NULL)
-	    adios (NULLCP, "unable to allocate exec vector");
+	    adios (NULL, "unable to allocate exec vector");
 	vecp = 1;
-	for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	    if (mp -> msgstats[msgnum] & SELECTED)
+	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	    if (mp->msgstats[msgnum] & SELECTED)
 		vec[vecp++] = getcpy (m_name (msgnum));
 	vec[vecp] = NULL;
 
@@ -123,8 +116,8 @@ main (int argc, char **argv)
 	adios (rmmproc, "unable to exec");
     }
 
-    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	if (mp -> msgstats[msgnum] & SELECTED) {
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (mp->msgstats[msgnum] & SELECTED) {
 	    strcpy (buf, m_backup (dp = m_name (msgnum)));
 	    if (rename (dp, buf) == NOTOK)
 		admonish (buf, "unable to rename %s to", dp);
