@@ -1,60 +1,47 @@
 
 /*
- * scan.c - display a one-line "scan" listing
+ * scan.c -- display a one-line "scan" listing
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 #include "../h/formatsbr.h"
 #include "../h/scansbr.h"
 #include "../zotnet/tws/tws.h"
 #include <errno.h>
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define	CLRSW	0
-    "clear", 0,
+    { "clear", 0 },
 #define	NCLRSW	1
-    "noclear", 0,
-
+    { "noclear", 0 },
 #define	FORMSW	2
-    "form formatfile", 0,
+    { "form formatfile", 0 },
 #define	FMTSW	3
-    "format string", 5,
-
+    { "format string", 5 },
 #define	HEADSW	4
-    "header", 0,
+    { "header", 0 },
 #define	NHEADSW	5
-    "noheader", 0,
-
+    { "noheader", 0 },
 #define	WIDSW	6
-    "width columns", 0,
-
+    { "width columns", 0 },
 #define	REVSW	7
-    "reverse", 0,
+    { "reverse", 0 },
 #define	NREVSW	8
-    "noreverse", 0,
-
+    { "noreverse", 0 },
 #define	FILESW	9
-    "file file", 4,
-
+    { "file file", 4 },
 #define VERSIONSW 10
-    "version", 0,
+    { "version", 0 },
 #define	HELPSW	11
-    "help", 4,
-
-    NULL, 0
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 extern int errno;
-#ifdef	LBL	/* global for sbr/formatsbr.c - yech! */
+
+#ifdef LBL	/* global for sbr/formatsbr.c - yech! */
 extern struct msgs *fmt_current_folder;	
 #endif
 
@@ -64,7 +51,6 @@ extern struct msgs *fmt_current_folder;
 void clear_screen(void);
 
 
-
 main (int argc, char **argv)
 {
      int    clearflag = 0,
@@ -113,7 +99,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
@@ -132,12 +118,12 @@ main (int argc, char **argv)
 
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    format = NULL;
 		    continue;
 		case FMTSW: 
 		    if (!(format = *argp++) || *format == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    form = NULL;
 		    continue;
 
@@ -150,7 +136,7 @@ main (int argc, char **argv)
 
 		case WIDSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    width = atoi (cp);
 		    continue;
 		case REVSW:
@@ -162,14 +148,14 @@ main (int argc, char **argv)
 
 		case FILESW:
 		    if (!(cp = *argp++) || (cp[0] == '-' && cp[1]))
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if (strcmp (file = cp, "-"))
 			file = path (cp, TFILE);
 		    continue;
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
@@ -184,9 +170,9 @@ main (int argc, char **argv)
 
     if (file) {
 	if (msgp)
-	    adios (NULLCP, "\"msgs\" not allowed with -file");
+	    adios (NULL, "\"msgs\" not allowed with -file");
 	if (folder)
-	    adios (NULLCP, "\"+folder\" not allowed with -file");
+	    adios (NULL, "\"+folder\" not allowed with -file");
 	/* we've been asked to scan a maildrop file */
 	if (strcmp (file, "-")) {
 	    in = fopen (file, "r");
@@ -225,9 +211,9 @@ main (int argc, char **argv)
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
-    if (mp -> hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
+    if (mp->hghmsg == 0)
+	adios (NULL, "no messages in %s", folder);
 
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
@@ -256,10 +242,10 @@ main (int argc, char **argv)
 	fmt_current_folder = mp;
 #endif
 
-    for (msgnum = revflag ? mp -> hghsel : mp -> lowsel;
-	    (revflag ? msgnum >= mp -> lowsel : msgnum <= mp -> hghsel);
+    for (msgnum = revflag ? mp->hghsel : mp->lowsel;
+	    (revflag ? msgnum >= mp->lowsel : msgnum <= mp->hghsel);
 	    msgnum += revflag ? (-1) : 1)
-	if (mp -> msgstats[msgnum] & SELECTED) {
+	if (mp->msgstats[msgnum] & SELECTED) {
 	    if ((in = fopen (cp = m_name (msgnum), "r")) == NULL) {
 #ifdef	notdef
 		if (errno != EACCES)
@@ -280,8 +266,8 @@ main (int argc, char **argv)
 	    }
 #endif	/* JLR */
 	    switch (state = scan (in, msgnum, 0, nfs, width,
-			msgnum == mp -> curmsg,
-			mp -> msgstats[msgnum] & bits,
+			msgnum == mp->curmsg,
+			mp->msgstats[msgnum] & bits,
 			hdrflag ? folder : (char *)0, 0L, 1)) {
 		case SCNMSG: 
 		case SCNENC: 
@@ -289,13 +275,13 @@ main (int argc, char **argv)
 		    break;
 
 		default: 
-		    adios (NULLCP, "scan() botch (%d)", state);
+		    adios (NULL, "scan() botch (%d)", state);
 
 		case SCNEOF: 
 #ifdef	notdef
 		    printf ("%*d  empty\n", DMAXFOLDER, msgnum);
 #else
-		    advise (NULLCP, "message %d: empty", msgnum);
+		    advise (NULL, "message %d: empty", msgnum);
 #endif
 		    break;
 	    }
