@@ -1,21 +1,14 @@
 
 /*
- * send.c - send a composed message
+ * send.c -- send a composed message
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
 #include <errno.h>
 #include <signal.h>
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 #ifndef	TMA
 # define TMAminc(a) (a)
 #else	/* TMA */
@@ -154,21 +147,11 @@ extern int   errno;
 
 main (int argc, char **argv)
 {
-    int     msgp = 0,
-	    distsw = 0,
-            vecp = 1,
-            isdf = 0,
-            msgnum,
-            status;
-    char   *cp,
-           *dfolder = NULL,
-           *maildir = NULL,
-            buf[100],
-          **ap,
-          **argp,
-           *arguments[MAXARGS],
-           *msgs[MAXARGS],
-           *vec[MAXARGS];
+    int msgp = 0, distsw = 0, vecp = 1;
+    int isdf = 0, msgnum, status;
+    char *cp, *dfolder = NULL, *maildir = NULL;
+    char buf[100], **ap, **argp, *arguments[MAXARGS];
+    char *msgs[MAXARGS], *vec[MAXARGS];
     struct msgs *mp;
     struct stat st;
 #ifdef	UCI
@@ -198,7 +181,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown\n", cp);
+		    adios (NULL, "-%s unknown\n", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [file] [switches]", invo_name);
@@ -214,15 +197,15 @@ main (int argc, char **argv)
 
 		case DFOLDSW: 
 		    if (dfolder)
-			adios (NULLCP, "only one draft folder at a time!");
+			adios (NULL, "only one draft folder at a time!");
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    dfolder = path (*cp == '+' || *cp == '@' ? cp + 1 : cp,
 			    *cp != '@' ? TFOLDER : TSUBCWF);
 		    continue;
 		case DMSGSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    msgs[msgp++] = cp;
 		    continue;
 		case NDFLDSW: 
@@ -239,7 +222,7 @@ main (int argc, char **argv)
 
 		case SPLITSW: 
 		    if (!(cp = *argp++) || sscanf (cp, "%d", &splitsw) != 1)
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case UNIQSW: 
@@ -304,7 +287,7 @@ main (int argc, char **argv)
 		case SERVSW: 
 		    vec[vecp++] = --cp;
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    vec[vecp++] = cp;
 		    continue;
 	    }
@@ -328,10 +311,10 @@ main (int argc, char **argv)
 		goto go_to_it;
 	    }
 #endif	/* WHATNOW */
-	    msgs[msgp++] = getcpy (m_draft (NULLCP, NULLCP, 1, &isdf));
+	    msgs[msgp++] = getcpy (m_draft (NULL, NULL, 1, &isdf));
 	    if (stat (msgs[0], &st) == NOTOK)
 		adios (msgs[0], "unable to stat draft file");
-	    cp = concat ("Use \"", msgs[0], "\"? ", NULLCP);
+	    cp = concat ("Use \"", msgs[0], "\"? ", NULL);
 	    for (status = LISTDSW; status != YESW;) {
 		if (!(argp = getans (cp, anyl)))
 		    done (1);
@@ -344,7 +327,7 @@ main (int argc, char **argv)
 			showfile (++argp, msgs[0]);
 			break;
 		    default:
-			advise (NULLCP, "say what?");
+			advise (NULL, "say what?");
 			break;
 		}
 	    }
@@ -364,24 +347,24 @@ main (int argc, char **argv)
 	if (chdir (maildir) == NOTOK)
 	    adios (maildir, "unable to change directory to");
 	if (!(mp = m_gmsg (dfolder)))
-	    adios (NULLCP, "unable to read folder %s", dfolder);
-	if (mp -> hghmsg == 0)
-	    adios (NULLCP, "no messages in %s", dfolder);
+	    adios (NULL, "unable to read folder %s", dfolder);
+	if (mp->hghmsg == 0)
+	    adios (NULL, "no messages in %s", dfolder);
 
 	for (msgnum = 0; msgnum < msgp; msgnum++)
 	    if (!m_convert (mp, msgs[msgnum]))
 		done (1);
 	m_setseq (mp);
 
-	for (msgp = 0, msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	    if (mp -> msgstats[msgnum] & SELECTED) {
+	for (msgp = 0, msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	    if (mp->msgstats[msgnum] & SELECTED) {
 		msgs[msgp++] = getcpy (m_name (msgnum));
 #ifdef	notdef
-		mp -> msgstats[msgnum] |= DELETED;
+		mp->msgstats[msgnum] |= DELETED;
 #endif	/* notdef */
-		mp -> msgstats[msgnum] &= ~EXISTS;
+		mp->msgstats[msgnum] &= ~EXISTS;
 	    }
-	mp -> msgflags |= SEQMOD;
+	mp->msgflags |= SEQMOD;
 
 	m_sync (mp);
     }
