@@ -1,56 +1,47 @@
 
 /*
- * sendsbr.c - routines to help WhatNow/Send along
+ * sendsbr.c -- routines to help WhatNow/Send along
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
+#include "../h/signals.h"
 #include <setjmp.h>
-#include <stdio.h>
 #include <signal.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 
-int     debugsw = 0;		/* global */
-int     forwsw = 1;
-int     inplace = 0;
-int	mime = 0;
-int     pushsw = 0;
-int     splitsw = -1;
-int     unique = 0;
-int	verbsw = 0;
+int debugsw = 0;		/* global */
+int forwsw = 1;
+int inplace = 0;
+int mime = 0;
+int pushsw = 0;
+int splitsw = -1;
+int unique = 0;
+int verbsw = 0;
 
-char   *altmsg = NULL;		/*  .. */
-char   *annotext = NULL;
-char   *distfile = NULL;
+char *altmsg = NULL;		/*  .. */
+char *annotext = NULL;
+char *distfile = NULL;
 
 static int armed = 0;
 static jmp_buf env;
 
-
-char *getusr ();
-off_t lseek ();
-long time ();
-
 /*
- * prototypes
+ * static prototypes
  */
-int sendsbr (char **, int, char *, struct stat *);
 static int sendaux (char **, int, char *, struct stat *);
 static void alert (char *, int);
 static int tmp_fd (void);
 static void anno (int, struct stat *);
 static void annoaux (int);
-void done (int);
-
 #ifdef MIME
 static int sendaux2 (char **, int, char *, struct stat *);
 #endif
 
+int sendsbr (char **, int, char *, struct stat *);
+void done (int);
+char *getusr();
+
 
 int
 sendsbr (char **vec, int vecp, char *drft, struct stat *st)
@@ -81,22 +72,12 @@ sendsbr (char **vec, int vecp, char *drft, struct stat *st)
 static int
 sendaux (char **vec, int vecp, char *drft, struct stat *st)
 {
-    int	    compnum,
-	    nparts,
-	    partno,
-	    state,
-	    status;
-    long    clock,
-	    pos,
-	    start;
-    char   *cp,
-	   *dp,
-	    buffer[BUFSIZ],
-	    msgid[BUFSIZ],
-	    name[NAMESZ],
-	    partnum[BUFSIZ];
+    int	compnum, nparts, partno, state, status;
+    long clock, pos, start;
+    char *cp, *dp, buffer[BUFSIZ], msgid[BUFSIZ];
+    char name[NAMESZ], partnum[BUFSIZ];
     struct stat sts;
-    FILE   *in;
+    FILE *in;
 
     if (splitsw < 0
 	    || distfile
@@ -128,7 +109,7 @@ one_shot: ;
 		}
 		else
 		    if (uprf (name, XXX_FIELD_PRF)) {
-			dp = add (concat (name, ":", buffer, NULLCP), dp);
+			dp = add (concat (name, ":", buffer, NULL), dp);
 			while (state == FLDPLUS) {
 			    state = m_getfld (state, name, buffer,
 					      sizeof buffer, in);
@@ -136,7 +117,7 @@ one_shot: ;
 			}
 		    }
 		    else {
-			cp = add (concat (name, ":", buffer, NULLCP), cp);
+			cp = add (concat (name, ":", buffer, NULL), cp);
 			while (state == FLDPLUS) {
 			    state = m_getfld (state, name, buffer,
 					      sizeof buffer, in);
@@ -155,17 +136,17 @@ one_shot: ;
 
 	   case LENERR:
 	   case FMTERR:
-		adios (NULLCP, "message format error in component #%d",
+		adios (NULL, "message format error in component #%d",
 		       compnum);
 
 	   default:
-		adios (NULLCP, "getfld () returned %d", state);
+		adios (NULL, "getfld () returned %d", state);
 	}
 
 	break;
     }
     if (cp == NULL)
-	adios (NULLCP, "headers missing from draft");
+	adios (NULL, "headers missing from draft");
 
     nparts = 1, pos = start;
     while (fgets (buffer, sizeof buffer - 1, in)) {
@@ -230,7 +211,7 @@ one_shot: ;
 	    if (!fgets (buffer, sizeof buffer - 1, in)) {
 		if (partno == nparts)
 		    break;
-		adios (NULLCP, "premature eof");
+		adios (NULL, "premature eof");
 	    }
 	    
 	    if ((pos += (len = strlen (buffer))) > CPERMSG) {
@@ -313,7 +294,7 @@ sendaux2 (char **vec, int vecp, char *drft, struct stat *st)
 	    vec[vecp++] = buf;
 	}
 	else
-	    admonish (NULLCP, "unable to create file for annotation list");
+	    admonish (NULL, "unable to create file for annotation list");
     if (distfile && distout (drft, distfile, backup) == NOTOK)
 	done (1);
     vec[vecp] = NULL;
@@ -350,7 +331,7 @@ sendaux2 (char **vec, int vecp, char *drft, struct stat *st)
 		    close (fd);
 		}
 		else
-		    advise (NULLCP, "message not delivered to anyone");
+		    advise (NULL, "message not delivered to anyone");
 		if (annotext && fd2 != NOTOK)
 		    close (fd2);
 		if (distfile) {
@@ -407,7 +388,7 @@ alert (char *file, int out)
 			forwsw ? "enclosed draft" : file);
 
 	    execlp (mailproc, r1bindex (mailproc, '/'), getusr (),
-		    "-subject", buf, NULLCP);
+		    "-subject", buf, NULL);
 	    fprintf (stderr, "unable to exec ");
 	    perror (mailproc);
 	    _exit (-1);
@@ -421,8 +402,8 @@ alert (char *file, int out)
 static int
 tmp_fd (void)
 {
-    int     fd;
-    char    tmpfil[BUFSIZ];
+    int fd;
+    char tmpfil[BUFSIZ];
 
     strcpy (tmpfil, m_tmpfil (invo_name));
     if ((fd = creat (tmpfil, 0600)) == NOTOK)
@@ -432,7 +413,7 @@ tmp_fd (void)
     if ((fd = open (tmpfil, 2)) == NOTOK)
 	return NOTOK;
     if (debugsw)
-	advise (NULLCP, "temporary file %s selected", tmpfil);
+	advise (NULL, "temporary file %s selected", tmpfil);
     else
 	if (unlink (tmpfil) == NOTOK)
 	    advise (tmpfil, "unable to remove");
@@ -444,17 +425,17 @@ static void
 anno (int fd, struct stat *st)
 {
     pid_t child_id;
-    RETSIGTYPE (*hstat) (), (*istat) (), (*qstat) (), (*tstat) ();
+    SIGNAL_HANDLER hstat, istat, qstat, tstat;
     static char *cwd = NULL;
     struct stat st2;
 
     if (altmsg &&
 	    (stat (altmsg, &st2) == NOTOK
-		|| st -> st_mtime != st2.st_mtime
-		|| st -> st_dev != st2.st_dev
-		|| st -> st_ino != st2.st_ino)) {
+		|| st->st_mtime != st2.st_mtime
+		|| st->st_dev != st2.st_dev
+		|| st->st_ino != st2.st_ino)) {
 	if (debugsw)
-	    admonish (NULLCP, "$mhaltmsg mismatch");
+	    admonish (NULL, "$mhaltmsg mismatch");
 	return;
     }
 
@@ -462,7 +443,7 @@ anno (int fd, struct stat *st)
     switch (child_id) {
 	case NOTOK: 		/* oops */
 	    if (!debugsw)
-		advise (NULLCP,
+		advise (NULL,
 			    "unable to fork, so doing annotations by hand...");
 	    if (cwd == NULL)
 		cwd = getcpy (pwd ());
@@ -495,20 +476,15 @@ anno (int fd, struct stat *st)
 static void
 annoaux (int fd)
 {
-    int	    fd2,
-	    fd3,
-	    msgnum;
-    char   *cp,
-	   *folder,
-	   *maildir,
-            buffer[BUFSIZ],
-          **ap;
-    FILE   *fp;
+    int	fd2, fd3, msgnum;
+    char *cp, *folder, *maildir;
+    char buffer[BUFSIZ], **ap;
+    FILE *fp;
     struct msgs *mp;
 
     if ((folder = getenv ("mhfolder")) == NULL || *folder == 0) {
 	if (debugsw)
-	    admonish (NULLCP, "$mhfolder not set");
+	    admonish (NULL, "$mhfolder not set");
 	return;
     }
     maildir = m_maildir (folder);
@@ -519,18 +495,18 @@ annoaux (int fd)
     }
     if (!(mp = m_gmsg (folder))) {
 	if (debugsw)
-	    admonish (NULLCP, "unable to read folder %s");
+	    admonish (NULL, "unable to read folder %s");
 	return;
     }
-    if (mp -> hghmsg == 0) {
+    if (mp->hghmsg == 0) {
 	if (debugsw)
-	    admonish (NULLCP, "no messages in %s", folder);
+	    admonish (NULL, "no messages in %s", folder);
 	goto oops;
     }
 
     if ((cp = getenv ("mhmessages")) == NULL || *cp == 0) {
 	if (debugsw)
-	    admonish (NULLCP, "$mhmessages not set");
+	    admonish (NULL, "$mhmessages not set");
 	goto oops;
     }
     if (!debugsw			/* MOBY HACK... */
@@ -542,21 +518,21 @@ annoaux (int fd)
     }
     else
 	fd2 = NOTOK;
-    for (ap = brkstring (cp = getcpy (cp), " ", NULLCP); *ap; ap++)
+    for (ap = brkstring (cp = getcpy (cp), " ", NULL); *ap; ap++)
 	m_convert (mp, *ap);
     free (cp);
     if (fd2 != NOTOK)
 	dup2 (fd2, fileno (stderr));
-    if (mp -> numsel == 0) {
+    if (mp->numsel == 0) {
 	if (debugsw)
-	    admonish (NULLCP, "no messages to annotate");
+	    admonish (NULL, "no messages to annotate");
 	goto oops;
     }
 
     lseek (fd, (off_t) 0, 0);
     if ((fp = fdopen (fd, "r")) == NULL) {
 	if (debugsw)
-	    admonish (NULLCP, "unable to fdopen annotation list");
+	    admonish (NULL, "unable to fdopen annotation list");
 	goto oops;
     }
     cp = NULL;
@@ -565,12 +541,12 @@ annoaux (int fd)
     fclose (fp);
 
     if (debugsw)
-	advise (NULLCP, "annotate%s with %s: \"%s\"",
+	advise (NULL, "annotate%s with %s: \"%s\"",
 		inplace ? " inplace" : "", annotext, cp);
-    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	if (mp -> msgstats[msgnum] & SELECTED) {
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (mp->msgstats[msgnum] & SELECTED) {
 	    if (debugsw)
-		advise (NULLCP, "annotate message %d", msgnum);
+		advise (NULL, "annotate message %d", msgnum);
 	    annotate (m_name (msgnum), annotext, cp, inplace, 1);
 	}
 
