@@ -1,19 +1,11 @@
 
 /*
- * show.c - show/list messages
+ * show.c -- show/list messages
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <ctype.h>
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define	DRFTSW	0
@@ -52,10 +44,10 @@ static struct swit switches[] = {
 };
 
 /*
- * prototypes
+ * static prototypes
  */
 #ifdef	MIME
-static int  nontext(char *);
+static int nontext(char *);
 #endif
 
 #define	SHOW  0
@@ -64,26 +56,11 @@ static int  nontext(char *);
 
 main (int argc, char **argv)
 {
-    int     draftsw = 0,
-            headersw = 1,
-            nshow = 0,
-            msgp = 0,
-            vecp = 1,
-	    procp = 1,
-	    isdf = 0,
-	    mode = SHOW,
-            msgnum;
-    char   *cp,
-           *maildir,
-           *file = NULL,
-           *folder = NULL,
-           *proc,
-            buf[100],
-          **ap,
-          **argp,
-           *arguments[MAXARGS],
-           *msgs[MAXARGS],
-           *vec[MAXARGS];
+    int draftsw = 0, headersw = 1, nshow = 0, msgp = 0;
+    int vecp = 1, procp = 1, isdf = 0, mode = SHOW, msgnum;
+    char *cp, *maildir, *file = NULL, *folder = NULL, *proc;
+    char buf[100], **ap, **argp, *arguments[MAXARGS];
+    char *msgs[MAXARGS], *vec[MAXARGS];
     struct msgs *mp;
 
 #ifdef LOCALE
@@ -126,21 +103,21 @@ main (int argc, char **argv)
 
 		case DRFTSW: 
 		    if (file)
-			adios (NULLCP, "only one file at a time!");
+			adios (NULL, "only one file at a time!");
 		    draftsw++;
 		    if (mode == SHOW)
 			continue;
 	    usage:  ;
-		    adios (NULLCP,
+		    adios (NULL,
 			    "usage: %s [+folder] [switches] [switches for showproc]",
 			    invo_name);
 		case FILESW: 
 		    if (mode != SHOW)
 			goto usage;
 		    if (draftsw || file)
-			adios (NULLCP, "only one file at a time!");
+			adios (NULL, "only one file at a time!");
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    file = path (cp, TFILE);
 		    continue;
 
@@ -154,7 +131,7 @@ main (int argc, char **argv)
 		case FORMSW:
 		    vec[vecp++] = --cp;
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    vec[vecp++] = getcpy (libpath(cp));
 		    continue;
 
@@ -163,13 +140,13 @@ main (int argc, char **argv)
 		case WIDSW:
 		    vec[vecp++] = --cp;
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    vec[vecp++] = cp;
 		    continue;
 
 		case SHOWSW: 
 		    if (!(showproc = *argp++) || *showproc == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    nshow = 0;
 		    continue;
 		case NSHOWSW: 
@@ -178,7 +155,7 @@ main (int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
@@ -195,20 +172,20 @@ main (int argc, char **argv)
 
     if (draftsw || file) {
 	if (msgp)
-	    adios (NULLCP, "only one file at a time!");
+	    adios (NULL, "only one file at a time!");
 	vec[vecp++] = draftsw
 	    ? getcpy (m_draft (folder, msgp ? msgs[0] : NULL, 1, &isdf))
 	    : file;
 	goto go_to_it;
     }
 
-#ifdef	WHATNOW
+#ifdef WHATNOW
     if (!msgp && !folder && mode == SHOW && (cp = getenv ("mhdraft")) && *cp) {
 	draftsw++;
 	vec[vecp++] = cp;
 	goto go_to_it;
     }
-#endif	/* WHATNOW */
+#endif /* WHATNOW */
 
     if (!msgp)
 	msgs[msgp++] = mode == NEXT ? "next" : mode == PREV ? "prev" : "cur";
@@ -219,28 +196,28 @@ main (int argc, char **argv)
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
-    if (mp -> hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
+    if (mp->hghmsg == 0)
+	adios (NULL, "no messages in %s", folder);
 
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	if (mp -> msgstats[msgnum] & SELECTED)
-	    mp -> msgstats[msgnum] |= UNSEEN;
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (mp->msgstats[msgnum] & SELECTED)
+	    mp->msgstats[msgnum] |= UNSEEN;
     m_setseq (mp);
     m_setvis (mp, 1);
 
-    if (mp -> numsel > MAXARGS - 2)
-	adios (NULLCP, "more than %d messages for show exec", MAXARGS - 2);
-    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-	if (mp -> msgstats[msgnum] & SELECTED)
+    if (mp->numsel > MAXARGS - 2)
+	adios (NULL, "more than %d messages for show exec", MAXARGS - 2);
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (mp->msgstats[msgnum] & SELECTED)
 	    vec[vecp++] = getcpy (m_name (msgnum));
 
     m_replace (pfolder, folder);
-    if (mp -> hghsel != mp -> curmsg)
-	m_setcur (mp, mp -> hghsel);
+    if (mp->hghsel != mp->curmsg)
+	m_setcur (mp, mp->hghsel);
     m_sync (mp);
     m_update ();
 
@@ -252,7 +229,7 @@ go_to_it: ;
 
     vec[vecp] = NULL;
 
-#ifdef	MIME
+#ifdef MIME
     if (!nshow && !getenv ("NOMHNPROC")) {
 	if (!(cp = m_find ("mhnproc")))
 	    cp = "mhn";
@@ -266,8 +243,8 @@ go_to_it: ;
 	    }
 	}
 	else
-	    for (msgnum = mp -> lowsel; msgnum <= mp -> hghsel; msgnum++)
-		if ((mp -> msgstats[msgnum] & SELECTED)
+	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+		if ((mp->msgstats[msgnum] & SELECTED)
 		        && nontext (m_name (msgnum))) {
 use_mmp: ;
 		    proc = cp;
@@ -276,7 +253,7 @@ use_mmp: ;
 		    goto finish;
 		}
     }
-#endif	/* MIME */
+#endif /* MIME */
     if (nshow)
 	proc = "/bin/cat";
     else {
@@ -292,14 +269,14 @@ use_mmp: ;
 
     if (!draftsw
 	    && !file
-	    && chdir (maildir = concat (m_maildir (""), "/", NULLCP))
+	    && chdir (maildir = concat (m_maildir (""), "/", NULL))
 	    != NOTOK) {
-	mp -> foldpath = concat (mp -> foldpath, "/", NULLCP);
-	cp = ssequal (maildir, mp -> foldpath)
-	    ? mp -> foldpath + strlen (maildir)
-	    : mp -> foldpath;
+	mp->foldpath = concat (mp->foldpath, "/", NULL);
+	cp = ssequal (maildir, mp->foldpath)
+	    ? mp->foldpath + strlen (maildir)
+	    : mp->foldpath;
 	for (msgnum = procp; msgnum < vecp; msgnum++)
-	    vec[msgnum] = concat (cp, vec[msgnum], NULLCP);
+	    vec[msgnum] = concat (cp, vec[msgnum], NULL);
     }
 
 finish:;
@@ -308,10 +285,11 @@ finish:;
     adios (proc, "unable to exec");
 }
 
-/* Cheat:  we are loaded with adrparse, which wants a routine called
-   OfficialName().  We call adrparse:getm() with the correct arguments
-   to prevent OfficialName() from being called.  Hence, the following
-   is to keep the loader happy.
+/*
+ * Cheat:  we are loaded with adrparse, which wants a routine called
+ * OfficialName().  We call adrparse:getm() with the correct arguments
+ * to prevent OfficialName() from being called.  Hence, the following
+ * is to keep the loader happy.
  */
 
 char *
@@ -320,8 +298,9 @@ OfficialName (char *name)
     return name;
 }
 
+
 #ifdef MIME
-#include "../h/mhn.h"
+# include "../h/mhn.h"
 
 static int
 nontext (char *msgnam)
@@ -330,7 +309,7 @@ nontext (char *msgnam)
     register char *bp, *dp;
     char *chset, *cp;
     char buf[BUFSIZ], name[NAMESZ];
-    FILE   *fp;
+    FILE *fp;
 
     if ((fp = fopen (msgnam, "r")) == NULL)
 	return 0;
@@ -347,7 +326,7 @@ nontext (char *msgnam)
 		    int	    passno;
 		    char     c;
 
-		    cp = add (buf, NULLCP);
+		    cp = add (buf, NULL);
 		    while (state == FLDPLUS) {
 			state = m_getfld (state, name, buf, sizeof buf, fp);
 			cp = add (buf, cp);
@@ -443,7 +422,7 @@ out: ;
 		    break;
 		}
 	        if (uleq (name, ENCODING_FIELD)) {
-		    cp = add (buf, NULLCP);
+		    cp = add (buf, NULL);
 		    while (state == FLDPLUS) {
 			state = m_getfld (state, name, buf, sizeof buf, fp);
 			cp = add (buf, cp);
@@ -473,4 +452,4 @@ out: ;
 		return 0;
 	}
 }
-#endif	/* MIME */
+#endif /* MIME */
