@@ -1,12 +1,10 @@
 
 /*
- * slocal.c -- MH style mailer to write to a local user's mailbox
+ * slocal.c -- nmh style mailer to write to a local user's mailbox
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 /*
  *  This program implements mail delivery in the MH/MMDF style.
  *
@@ -26,7 +24,6 @@ static char ident[] = "$Id$";
  *  or "mts mmdf1" set in your MH configuration.
  */
 
-#include "../h/nmh.h"
 #include "../h/mh.h"
 #include "../h/dropsbr.h"
 #include "../h/rcvmail.h"
@@ -35,13 +32,8 @@ static char ident[] = "$Id$";
 #include <pwd.h>
 #include <signal.h>
 #include <sys/ioctl.h>
-#include <sys/stat.h>
 #include <utmp.h>
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 #ifdef MSGID
 # undef DBM		/* used by ndbm.h */
 # include <ndbm.h>
@@ -63,37 +55,32 @@ static char ident[] = "$Id$";
 
 static struct swit switches[] = {
 #define	ADDRSW	0
-    "addr address", 0,
+    { "addr address", 0 },
 #define	USERSW	1
-    "user name", 0,
+    { "user name", 0 },
 #define	FILESW	2
-    "file file", 0,
+    { "file file", 0 },
 #define	SENDSW	3
-    "sender address", 0,
+    { "sender address", 0 },
 #define	MBOXSW	4
-    "mailbox file", 0,
+    { "mailbox file", 0 },
 #define	HOMESW	5
-    "home directory", -4,
+    { "home directory", -4 },
 #define	INFOSW	6
-    "info data", 0,
-
+    { "info data", 0 },
 #define	MAILSW	7
-    "maildelivery file", 0,
-
+    { "maildelivery file", 0 },
 #define	VERBSW	8
-    "verbose", 0,
+    { "verbose", 0 },
 #define	NVERBSW	9
-    "noverbose", 0,
-
+    { "noverbose", 0 },
 #define	DEBUGSW	10
-    "debug", 0,
-
+    { "debug", 0 },
 #define VERSIONSW 11
-    "version", 0,
+    { "version", 0 },
 #define	HELPSW	12
-    "help", 4,
-
-    NULL, 0
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 static int  debug = 0;
@@ -102,14 +89,14 @@ static int  parsed = 0;
 static int  utmped = 0;
 static int  verbose = 0;
 
-static char *addr = NULLCP;
-static char *user = NULLCP;
-static char *info = NULLCP;
-static char *file = NULLCP;
-static char *sender = NULLCP;
-static char *unixfrom = NULLCP;
-static char *mbox = NULLCP;
-static char *home = NULLCP;
+static char *addr = NULL;
+static char *user = NULL;
+static char *info = NULL;
+static char *file = NULL;
+static char *sender = NULL;
+static char *unixfrom = NULL;
+static char *mbox = NULL;
+static char *home = NULL;
 
 static struct passwd *pw;
 
@@ -161,12 +148,6 @@ static struct pair  vars[] = {
 
 extern char **environ;
 
-#ifndef	__STDC__
-# ifdef	SYS5
-struct passwd *getpwnam();
-# endif
-#endif
-
 /*
  * static prototypes
  */
@@ -184,8 +165,11 @@ static int usr_pipe (int, char *, char *, char **);
 static RETSIGTYPE alrmser (int);
 static copyinfo (FILE *fp, char *);
 static int copyfile (int, char *, int);
-static void adorn ();
+static void adorn (char *, char *, ...);
+
+#ifdef MSGID
 static int check_msgid (int, char *);
+#endif
 
 
 main (int argc, char **argv)
@@ -200,7 +184,7 @@ main (int argc, char **argv)
 	setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (*argv, '/');
-    m_foil (NULLCP);
+    m_foil (NULL);
     mts_init (invo_name);
 
     while (cp = *argp++) {
@@ -210,7 +194,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] [address info sender]", invo_name);
@@ -222,38 +206,38 @@ main (int argc, char **argv)
 
 		case ADDRSW: 
 		    if (!(addr = *argp++))/* allow -xyz arguments */
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case INFOSW: 
 		    if (!(info = *argp++))/* allow -xyz arguments */
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case USERSW: 
 		    if (!(user = *argp++))/* allow -xyz arguments */
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case FILESW: 
 		    if (!(file = *argp++) || *file == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case SENDSW: 
 		    if (!(sender = *argp++))/* allow -xyz arguments */
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case MBOXSW: 
 		    if (!(mbox = *argp++) || *mbox == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case HOMESW: 
 		    if (!(home = *argp++) || *home == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case MAILSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if (mdlvr)
-			adios (NULLCP, "only one maildelivery file at a time!");
+			adios (NULL, "only one maildelivery file at a time!");
 		    mdlvr = cp;
 		    continue;
 
@@ -289,9 +273,9 @@ main (int argc, char **argv)
     if (user == NULL)
 	user = (cp = strchr(addr, '.')) ? ++cp : addr;
     if ((pw = getpwnam (user)) == NULL)
-	adios (NULLCP, "no such local user as %s", user);
+	adios (NULL, "no such local user as %s", user);
 
-    if (chdir (pw -> pw_dir) == NOTOK)
+    if (chdir (pw->pw_dir) == NOTOK)
 	chdir ("/");
     umask (0077);
 
@@ -313,17 +297,17 @@ main (int argc, char **argv)
     if (info == NULL)
 	info = "";
 
-    setbuf (stdin, NULLCP);
+    setbuf (stdin, NULL);
 
     if (file == NULL) {
 	if ((fd = copyfile (fileno (stdin), file = tmpfil, 1)) == NOTOK)
-	    adios (NULLCP, "unable to create temporary file");
+	    adios (NULL, "unable to create temporary file");
 	if (debug)
 	    fprintf (stderr, "temporary file \"%s\" selected\n", tmpfil);
 	else
 	    unlink (tmpfil);
    	if ((fp = fdopen (fd, "r+")) == NULL)
-	    adios (NULLCP, "unable to access temporary file");
+	    adios (NULL, "unable to access temporary file");
     }
     else
 	fd = fileno (stdin);
@@ -335,15 +319,15 @@ main (int argc, char **argv)
 
     if (mbox == NULL) {
 	sprintf (mailbox, "%s/%s",
-		mmdfldir[0] ? mmdfldir : pw -> pw_dir,
-		mmdflfil[0] ? mmdflfil : pw -> pw_name);
+		mmdfldir[0] ? mmdfldir : pw->pw_dir,
+		mmdflfil[0] ? mmdflfil : pw->pw_name);
 	mbox = mailbox;
     }
     if (home == NULL)
-	home = pw -> pw_dir;
+	home = pw->pw_dir;
 
     if ((now = dtwstime ()) == NULL)
-	adios (NULLCP, "unable to ascertain local time");
+	adios (NULL, "unable to ascertain local time");
     sprintf (ddate, "Delivery-Date: %s\n", dtimenow ());
 
     if (debug) {
@@ -352,7 +336,7 @@ main (int argc, char **argv)
 	fprintf (stderr, "sender=\"%s\" mbox=\"%s\" home=\"%s\" from=\"%s\"\n",
 		sender, mbox, home, from);
 	fprintf (stderr, "ddate=\"%s\" now=%02d:%02d\n",
-		ddate, now -> tw_hour, now -> tw_min);
+		ddate, now->tw_hour, now->tw_min);
     }
 
     done (localmail (fd, from, mdlvr) != NOTOK ? RCV_MOK : RCV_MBX);
@@ -361,7 +345,7 @@ main (int argc, char **argv)
 static int
 localmail (int fd, char *from, char *mdlvr)
 {
-#ifdef	MSGID
+#ifdef MSGID
     struct stat st;
 
     if (stat (".maildelivery.pag", &st) != NOTOK
@@ -403,11 +387,11 @@ usr_delivery (int fd, char *delivery, int su, char *from)
     if ((fp = fopen (delivery, "r")) == NULL)
 	return NOTOK;
     if (fstat (fileno (fp), &st) == NOTOK
-	    || (st.st_uid != 0 && (su || st.st_uid != pw -> pw_uid))
+	    || (st.st_uid != 0 && (su || st.st_uid != pw->pw_uid))
 	    || st.st_mode & 0022) {
 	if (verbose) {
 	    printf ("%s: ownership/modes bad (%d, %d,%d,0%o)\n",
-		    delivery, su, pw -> pw_uid, st.st_uid, st.st_mode);
+		    delivery, su, pw->pw_uid, st.st_uid, st.st_mode);
 	    fflush (stdout);
 	}
 	return NOTOK;
@@ -481,7 +465,7 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 		}
 		if ((p = lookup (hdrs, field)) == NULL
 			|| (p->p_value == NULL)			/* XXX */
-			|| !matches (p -> p_value, pattern)) {
+			|| !matches (p->p_value, pattern)) {
 			next = 0;
 			continue;
 		}
@@ -520,14 +504,14 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 #ifdef	RPATHS
 		status = usr_file (fd, string,  from);	/* UUCP format? */
 #else
-		status = usr_file (fd, string,  NULLCP);
+		status = usr_file (fd, string,  NULL);
 #endif
 		break;
 
 	    case 'm':
 		if (!uleq (action, "mbox"))
 		    continue;
-		status = usr_file (fd, string,  NULLCP);
+		status = usr_file (fd, string,  NULL);
 		break;
 
 	    case 'd': 
@@ -605,25 +589,25 @@ parse (int fd)
     rewind (in);
 
     if (p = lookup (hdrs, "source"))
-	p -> p_value = getcpy (sender);
+	p->p_value = getcpy (sender);
     if (p = lookup (hdrs, "addr"))
-	p -> p_value = getcpy (addr);
+	p->p_value = getcpy (addr);
 
     for (i = 0, state = FLD;;) {
 	switch (state = m_getfld (state, name, field, sizeof field, in)) {
 	    case FLD: 
 	    case FLDEOF: 
 	    case FLDPLUS: 
-		lp = add (field, NULLCP);
+		lp = add (field, NULL);
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, name, field, sizeof field, in);
 		    lp = add (field, lp);
 		}
-		for (p = hdrs; p -> p_name; p++)
-		    if (uleq (p -> p_name, name)) {
-			if (!(p -> p_flags & P_HID)) {
-			    if (cp = p -> p_value)
-				if (p -> p_flags & P_ADR) {
+		for (p = hdrs; p->p_name; p++)
+		    if (uleq (p->p_name, name)) {
+			if (!(p->p_flags & P_HID)) {
+			    if (cp = p->p_value)
+				if (p->p_flags & P_ADR) {
 				    dp = cp + strlen (cp) - 1;
 				    if (*dp == '\n')
 					*dp = 0;
@@ -631,17 +615,17 @@ parse (int fd)
 				}
 				else
 				    cp = add ("\t", cp);
-			    p -> p_value = add (lp, cp);
+			    p->p_value = add (lp, cp);
 			}
 			free (lp);
 			break;
 		    }
-		if (p -> p_name == NULL && i < NVEC) {
-		    p -> p_name = getcpy (name);
-		    p -> p_value = lp;
-		    p -> p_flags = P_NIL;
+		if (p->p_name == NULL && i < NVEC) {
+		    p->p_name = getcpy (name);
+		    p->p_value = lp;
+		    p->p_flags = P_NIL;
 		    p++, i++;
-		    p -> p_name = NULL;
+		    p->p_name = NULL;
 		}
 		if (state != FLDEOF)
 		    continue;
@@ -654,11 +638,11 @@ parse (int fd)
 
 	    case LENERR: 
 	    case FMTERR: 
-		advise (NULLCP, "format error in message");
+		advise (NULL, "format error in message");
 		break;
 
 	    default: 
-		advise (NULLCP, "internal error");
+		advise (NULL, "internal error");
 		fclose (in);
 		return NOTOK;
 	}
@@ -667,18 +651,18 @@ parse (int fd)
     fclose (in);
 
     if (p = lookup (vars, "reply-to")) {
-	if ((q = lookup (hdrs, "reply-to")) == NULL || q -> p_value == NULL)
+	if ((q = lookup (hdrs, "reply-to")) == NULL || q->p_value == NULL)
 	    q = lookup (hdrs, "from");
-	p -> p_value = getcpy (q ? q -> p_value : "");
-	p -> p_flags &= ~P_CHK;
+	p->p_value = getcpy (q ? q->p_value : "");
+	p->p_flags &= ~P_CHK;
 	if (debug)
 	    fprintf (stderr, "vars[%d]: name=\"%s\" value=\"%s\"\n",
-		    p - vars, p -> p_name, p -> p_value);
+		    p - vars, p->p_name, p->p_value);
     }
     if (debug)
-	for (p = hdrs; p -> p_name; p++)
+	for (p = hdrs; p->p_name; p++)
 	    fprintf (stderr, "hdrs[%d]: name=\"%s\" value=\"%s\"\n",
-		p - hdrs, p -> p_name, p -> p_value);
+		p - hdrs, p->p_name, p->p_value);
 
     return OK;
 }
@@ -707,10 +691,10 @@ expand (char *s1, char *s2, int fd)
 	    }
 	    *s2++ = 0;
 	    if (p = lookup (vars, cp)) {
-		if (!parsed && (p -> p_flags & P_CHK))
+		if (!parsed && (p->p_flags & P_CHK))
 		    parse (fd);
 
-		strcpy (s1, p -> p_value);
+		strcpy (s1, p->p_value);
 		s1 += strlen (s1);
 	    }
 	}
@@ -741,7 +725,7 @@ glob (int fd)
     if (debug)
 	for (p = vars; p->p_name; p++)
 	    fprintf (stderr, "vars[%d]: name=\"%s\" value=\"%s\"\n",
-		    p - vars, p -> p_name, p->p_value);
+		    p - vars, p->p_name, p->p_value);
 }
 
 static struct pair *
@@ -800,8 +784,8 @@ timely (char *t1, char *t2)
     check (t2hours, 0, 23);
     check (t2mins, 0, 59);
 
-    cmpar (now -> tw_hour, now -> tw_min, t1hours, t1mins);
-    cmpar (t2hours, t2mins, now -> tw_hour, now -> tw_min);
+    cmpar (now->tw_hour, now->tw_min, t1hours, t1mins);
+    cmpar (t2hours, t2mins, now->tw_hour, now->tw_min);
 
     return NOTOK;
 }
@@ -830,7 +814,7 @@ usr_file (int fd, char *mailbox, char *from)
     if (verbose)
 	fflush (stdout);
 
-    if ((md = mbx_open (mailbox, pw -> pw_uid, pw -> pw_gid, m_gmprot ()))
+    if ((md = mbx_open (mailbox, pw->pw_uid, pw->pw_gid, m_gmprot ()))
 	    == NOTOK) {
 	adorn ("", "unable to open:");
 	return NOTOK;
@@ -862,13 +846,13 @@ usr_hook (int fd, char *mailbox)
 	    adorn ("unable to copy message; skipping hook\n");
 	return NOTOK;
     }
-    chown (tmpfil, pw -> pw_uid, pw -> pw_gid);
+    chown (tmpfil, pw->pw_uid, pw->pw_gid);
 
     vecp = 1;
-    sprintf (receive, "%s/.mh_receive", pw -> pw_dir);
+    sprintf (receive, "%s/.mh_receive", pw->pw_dir);
     switch (access (receive, 01)) {
 	case NOTOK: 
-	    sprintf (receive, "%s/bin/rcvmail", pw -> pw_dir);
+	    sprintf (receive, "%s/bin/rcvmail", pw->pw_dir);
 	    if (access (receive, 01) == NOTOK) {
 		unlink (tmpfil);
 		if (verbose) {
@@ -931,7 +915,7 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 
 #ifdef	TIOCNOTTY
 	    if ((fd = open ("/dev/tty", 2)) != NOTOK) {
-		ioctl (fd, TIOCNOTTY, NULLCP);
+		ioctl (fd, TIOCNOTTY, NULL);
 		close (fd);
 	    }
 #endif	/* TIOCNOTTY */
@@ -941,9 +925,9 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 #endif	/* BSD42 */
 
 	    *environ = NULL;
-	    m_putenv ("USER", pw -> pw_name);
-	    m_putenv ("HOME", pw -> pw_dir);
-	    m_putenv ("SHELL", pw -> pw_shell);
+	    m_putenv ("USER", pw->pw_name);
+	    m_putenv ("HOME", pw->pw_dir);
+	    m_putenv ("SHELL", pw->pw_shell);
 
 	    execvp (pgm, vec);
 	    _exit (-1);
@@ -998,6 +982,7 @@ alrmser (int i)
     longjmp (myctx, DONE);
 }
 
+
 static
 copyinfo (FILE *fp, char *from)
 {
@@ -1008,7 +993,7 @@ copyinfo (FILE *fp, char *from)
     if (unixfrom)	/* interface from copyfile */
 	strcpy (from, unixfrom);
     else if (fgets (from, BUFSIZ, fp) == NULL)
-	adios (NULLCP, "no message");
+	adios (NULL, "no message");
 
     if (strncmp (from, "From ", i = strlen ("From "))) {
 	rewind (fp);
@@ -1140,27 +1125,24 @@ you_lose: ;
     return fd1;
 }
 
-/* VARARGS2 */
 
 static void
-adorn (what, fmt, a, b, c, d, e, f)
-char *what,
-     *fmt,
-     *a,
-     *b,
-     *c,
-     *d,
-     *e,
-     *f;
+adorn (char *what, char *fmt, ...)
 {
-    char *cp = invo_name;
+    va_list ap;
+    char *cp;
 
     if (!verbose)
 	return;
     printf (", ");
 
+    cp = invo_name;
     invo_name = NULL;
-    advise (what, fmt, a, b, c, d, e, f);
+
+    va_start(ap, fmt);
+    advertise (what, NULL, fmt, ap);
+    va_end(ap);
+
     invo_name = cp;
 }
 
@@ -1194,7 +1176,7 @@ check_msgid (int fd, char *file)
 		    continue;
 		}
 
-		cp = add (buf, NULLCP);
+		cp = add (buf, NULL);
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, name, buf, sizeof buf, in);
 		    cp = add (buf, cp);
@@ -1240,7 +1222,7 @@ out: ;
 		value = dbm_fetch (db, key);
 		if (value.dptr != NULL) {
 		    if (debug)
-		        advise (NULLCP,
+		        advise (NULL,
 				"Message-ID: %s already received on\n\tDate:       %s",
 				cp, value.dptr);
 		    free (cp);
@@ -1276,4 +1258,4 @@ out: ;
     fclose (in);
     return OK;
 }
-#endif  /* MSGID */
+#endif /* MSGID */
