@@ -1,25 +1,12 @@
 
 /*
  * sortm.c -- sort messages in a folder by date/time
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
 #include "../zotnet/tws/tws.h"
-#define getws _getws
-#include <stdio.h>
-
-#undef getws
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <ctype.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 #if defined(SYS5) && defined(AUX)
 # define u_short ushort
@@ -27,32 +14,27 @@ static char ident[] = "$Id$";
 #endif
 
 static struct swit switches[] = {
-#define DATESW  0
-     "datefield field", 0,
-
-#define	TEXTSW 1
-     "textfield field", 0,
-#define	NSUBJSW	2
-     "notextfield", 0,
-
-#define SUBJSW 3
-     "subject", -3,		/* backward-compatibility */
-#define LIMSW 4
-     "limit days", 0,
-#define	NLIMSW 5
-     "nolimit", 0,
-
-#define VERBSW  6
-     "verbose", 0,
-#define NVERBSW 7
-     "noverbose", 0,
-
-#define VERSIONSW 8
-     "version", 0,
-#define HELPSW  9
-     "help", 4,
-
-     NULL, 0
+#define DATESW                 0
+     { "datefield field", 0 },
+#define	TEXTSW                 1
+     { "textfield field", 0 },
+#define	NSUBJSW                2
+     { "notextfield", 0 },
+#define SUBJSW                 3
+     { "subject", -3 },		   /* backward-compatibility */
+#define LIMSW                  4
+     { "limit days", 0 },
+#define	NLIMSW                 5
+     { "nolimit", 0 },
+#define VERBSW                 6
+     { "verbose", 0 },
+#define NVERBSW                7
+     { "noverbose", 0 },
+#define VERSIONSW              8
+     { "version", 0 },
+#define HELPSW                 9
+     { "help", 4 },
+     { NULL, 0 }
 };
 
 struct smsg {
@@ -62,18 +44,18 @@ struct smsg {
 };
 
 static struct smsg *smsgs;
-int 	nmsgs;
+int nmsgs;
 
-char   *subjsort = (char *)0;           /* sort on subject if != 0 */
-u_long	datelimit = 0;
-int	submajor = 0;		/* if true, sort on subject-major */
-int 	verbose;
+char *subjsort = (char *) 0;    /* sort on subject if != 0 */
+u_long datelimit = 0;
+int submajor = 0;		/* if true, sort on subject-major */
+int verbose;
 
 /* This keeps compiler happy on calls to qsort */
 typedef int (*qsort_comp) (const void *, const void *);
 
 /*
- * prototypes
+ * static prototypes
  */
 static int read_hdrs (struct msgs *, char *);
 static int getws (char *, int, struct smsg *);
@@ -87,9 +69,9 @@ static void rename_msgs (struct msgs *, struct smsg **);
 main (int argc, char **argv)
 {
     int	msgp = 0, i, msgnum;
-    char *cp, *maildir, *datesw = NULL, *folder = NULL,
-	 buf[100], **ap, **argp,
-	 *arguments[MAXARGS], *msgs[MAXARGS];
+    char *cp, *maildir, *datesw = NULL;
+    char *folder = NULL, buf[100], **ap, **argp;
+    char *arguments[MAXARGS], *msgs[MAXARGS];
     struct msgs *mp;
     struct smsg **dlist;
 
@@ -113,7 +95,7 @@ main (int argc, char **argv)
 		ambigsw (cp, switches);
 		done (1);
 	    case UNKWNSW:
-		adios (NULLCP, "-%s unknown", cp);
+		adios (NULL, "-%s unknown", cp);
 
 	    case HELPSW:
 		sprintf(buf, "%s [+folder] [msgs] [switches]", invo_name);
@@ -125,16 +107,16 @@ main (int argc, char **argv)
 
 	    case DATESW:
 		if (datesw)
-		    adios (NULLCP, "only one date field at a time");
+		    adios (NULL, "only one date field at a time");
 		if (!(datesw = *argp++) || *datesw == '-')
-		    adios (NULLCP, "missing argument to %s", argp[-2]);
+		    adios (NULL, "missing argument to %s", argp[-2]);
 		continue;
 
 	    case TEXTSW:
 		if (subjsort)
-		    adios (NULLCP, "only one text field at a time");
+		    adios (NULL, "only one text field at a time");
 		if (!(subjsort = *argp++) || *subjsort == '-')
-		    adios (NULLCP, "missing argument to %s", argp[-2]);
+		    adios (NULL, "missing argument to %s", argp[-2]);
 		continue;
 
 	    case SUBJSW:
@@ -146,7 +128,7 @@ main (int argc, char **argv)
 
 	    case LIMSW:
 		if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		while (*cp == '0')
 		    cp++;		/* skip any leading zeros */
 		if (!*cp) {		/* hit end of string */
@@ -154,7 +136,7 @@ main (int argc, char **argv)
 		    continue;
 		}
 		if (!isdigit(*cp) || !(datelimit = atoi(cp)))
-		    adios (NULLCP, "impossible limit %s", cp);
+		    adios (NULL, "impossible limit %s", cp);
 		datelimit *= 60*60*24;
 		continue;
 	    case NLIMSW:
@@ -171,7 +153,7 @@ main (int argc, char **argv)
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
-		adios (NULLCP, "only one folder at a time!");
+		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
 	}
@@ -192,9 +174,9 @@ main (int argc, char **argv)
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
     if (!(mp = m_gmsg (folder)))
-	adios (NULLCP, "unable to read folder %s", folder);
+	adios (NULL, "unable to read folder %s", folder);
     if (mp->hghmsg == 0)
-	adios (NULLCP, "no messages in %s", folder);
+	adios (NULL, "no messages in %s", folder);
 
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
@@ -202,14 +184,14 @@ main (int argc, char **argv)
     m_setseq (mp);
 
     if ((nmsgs = read_hdrs (mp, datesw)) <= 0)
-	adios (NULLCP, "no messages to sort");
+	adios (NULL, "no messages to sort");
 
     /*
      * sort a list of pointers to our "messages to be sorted".
      */
     dlist = (struct smsg **) malloc ((nmsgs+1) * sizeof(*dlist));
     if (! dlist)
-	adios (NULLCP, "couldn't allocate sort memory");
+	adios (NULL, "couldn't allocate sort memory");
     for (i = 0; i < nmsgs; i++)
 	dlist[i] = &smsgs[i];
     dlist[nmsgs] = 0;
@@ -232,15 +214,12 @@ main (int argc, char **argv)
      * two sorts.
      */
     if (!submajor && subjsort) {	/* already date sorted */
-	struct smsg 		**slist,
-		    		**flist;
-	register struct smsg   ***il,
-				**fp,
-				**dp;
+	struct smsg **slist, **flist;
+	register struct smsg ***il, **fp, **dp;
 
 	slist = (struct smsg **) malloc ((nmsgs+1) * sizeof(*slist));
 	if (! slist)
-	    adios (NULLCP, "couldn't allocate sort memory");
+	    adios (NULL, "couldn't allocate sort memory");
 	memcpy((char *)slist, (char *)dlist, (nmsgs+1)*sizeof(*slist));
 	qsort((char *)slist, nmsgs, sizeof(*slist), (qsort_comp) subsort);
 
@@ -251,7 +230,7 @@ main (int argc, char **argv)
 	 */
 	il = (struct smsg ***) calloc (mp->hghsel+1, sizeof(*il));
 	if (! il)
-	    adios (NULLCP, "couldn't allocate msg list");
+	    adios (NULL, "couldn't allocate msg list");
 	for (i = 0; i < nmsgs; i++)
 	    il[slist[i]->s_msg] = &slist[i];
 	/*
@@ -260,7 +239,7 @@ main (int argc, char **argv)
 	 */
 	flist = (struct smsg **) malloc ((nmsgs+1) * sizeof(*flist));
 	if (! flist)
-	    adios (NULLCP, "couldn't allocate msg list");
+	    adios (NULL, "couldn't allocate msg list");
 	fp = flist;
 	for (dp = dlist; *dp;) {
 	    register struct smsg **s = il[(*dp++)->s_msg];
@@ -310,7 +289,7 @@ read_hdrs (struct msgs *mp, char *datesw)
 	calloc ((unsigned) (mp->hghsel - mp->lowsel + 2),
 	    sizeof *smsgs);
     if (smsgs == NULL)
-	adios (NULLCP, "unable to allocate sort storage");
+	adios (NULL, "unable to allocate sort storage");
 
     s = smsgs;
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
@@ -332,7 +311,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
     int compnum;
     char *msgnam, buf[BUFSIZ], nam[NAMESZ];
     register struct tws *tw;
-    register char *datecomp = NULLCP, *subjcomp = NULLCP;
+    register char *datecomp = NULL, *subjcomp = NULL;
     register FILE *in;
 
     if ((in = fopen (msgnam = m_name (msg), "r")) == NULL) {
@@ -378,7 +357,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
 	case LENERR:
 	case FMTERR:
 	    if (state == LENERR || state == FMTERR)
-		admonish (NULLCP, "format error in message %d (header #%d)",
+		admonish (NULL, "format error in message %d (header #%d)",
 		      msg, compnum);
 	    if (datecomp)
 		free (datecomp);
@@ -388,7 +367,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
 	    return (0);
 
 	default:
-	    adios (NULLCP, "internal error -- you lose");
+	    adios (NULL, "internal error -- you lose");
 	}
 	break;
     }
@@ -396,7 +375,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
     if (!datecomp || (tw = dparsetime (datecomp)) == NULL) {
 	struct stat st;
 
-	admonish (NULLCP, "can't parse %s field in message %d",
+	admonish (NULL, "can't parse %s field in message %d",
 	      datesw, msg);
 
 	/* use the modify time of the file as its date */
