@@ -4,25 +4,17 @@
  *
  * This is a simpler, faster, replacement for "post" for use when "sendmail"
  * is the transport system.  It is currently only used when BERK is defined.
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include <ctype.h>
-#include <stdio.h>
-#include <signal.h>
 #include "../h/mh.h"
+#include <signal.h>
 #include "../h/addrsbr.h"
 #include "../h/aliasbr.h"
 #include "../h/dropsbr.h"
 #include "../zotnet/tws/tws.h"
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
 #define	uptolow(c)	((isalpha(c) && isupper (c)) ? tolower (c) : c)
 
 #define MAX_SM_FIELD	1476	/* < largest hdr field sendmail will accept */
@@ -191,9 +183,10 @@ static char *fccfold[FCCS];	/* foldernames for FCC'ing */
 static struct headers  *hdrtab;	/* table for the message we're doing */
 static FILE *out;		/* output (temp) file */
 
-extern char *getfullname (), *getusr ();
 extern char *sendmail;
 
+extern char *getfullname (), *getusr ();
+
 /*
  * static prototypes
  */
@@ -207,6 +200,7 @@ static void insert_fcc (struct headers *, char *);
 static void make_bcc_file (void);
 static void file (char *);
 static void fcc (char *, char *);
+static void die (char *, char *, ...);
 
 
 main (int argc, char **argv)
@@ -242,7 +236,7 @@ main (int argc, char **argv)
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] file", invo_name);
@@ -266,7 +260,7 @@ main (int argc, char **argv)
 
 		case FILTSW:
 		    if (!(filter = *argp++) || *filter == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case NFILTSW:
 		    filter = NULL;
@@ -309,12 +303,12 @@ main (int argc, char **argv)
 
 		case ALIASW:
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if (aliasflg < 0)
 			alias (AliasFile);/* load default aka's */
 		    aliasflg = 1;
 		    if ((state = alias(cp)) != AK_OK)
-			adios (NULLCP, "aliasing error in file %s - %s",
+			adios (NULL, "aliasing error in file %s - %s",
 			       cp, akerror(state) );
 		    continue;
 		case NALIASW:
@@ -323,7 +317,7 @@ main (int argc, char **argv)
 
 		case WIDTHSW:
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    outputlinelen = atoi (cp);
 		    if (outputlinelen <= 10)
 			outputlinelen = 72;
@@ -333,11 +327,11 @@ main (int argc, char **argv)
 		case ANNOSW:
 		    /* -library & -idanno switch ignored */
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 	    }
 	if (msg)
-	    adios (NULLCP, "only one message at a time!");
+	    adios (NULL, "only one message at a time!");
 	else
 	    msg = cp;
     }
@@ -346,7 +340,7 @@ main (int argc, char **argv)
 	alias (AliasFile);	/* load default aka's */
 
     if (!msg)
-	adios (NULLCP, "usage: %s [switches] file", invo_name);
+	adios (NULL, "usage: %s [switches] file", invo_name);
 
     if ((in = fopen (msg, "r")) == NULL)
 	adios (msg, "unable to open");
@@ -399,11 +393,11 @@ main (int argc, char **argv)
 
 	    case LENERR: 
 	    case FMTERR: 
-		adios (NULLCP, "message format error in component #%d",
+		adios (NULL, "message format error in component #%d",
 			compnum);
 
 	    default: 
-		adios (NULLCP, "getfld() returned %d", state);
+		adios (NULL, "getfld() returned %d", state);
 	}
 	break;
     }
@@ -482,19 +476,19 @@ putfmt (char *name, char *str, FILE *out)
     }
 
     hdr = &hdrtab[i];
-    if (hdr -> flags & HIGN)
+    if (hdr->flags & HIGN)
 	return;
-    if (hdr -> flags & HBAD) {
-	advise (NULLCP, "illegal header line -- %s:", name);
+    if (hdr->flags & HBAD) {
+	advise (NULL, "illegal header line -- %s:", name);
 	badmsg++;
 	return;
     }
-    msgflags |= hdr -> set;
+    msgflags |= hdr->set;
 
-    if (hdr -> flags & HSUB)
+    if (hdr->flags & HSUB)
 	subject = subject ? add (str, add ("\t", subject)) : getcpy (str);
 
-    if (hdr -> flags & HFCC) {
+    if (hdr->flags & HFCC) {
 	if (cp = strrchr(str, '\n'))
 	    *cp = 0;
 	for (cp = pp = str; cp = strchr(pp, ','); pp = cp) {
@@ -506,7 +500,7 @@ putfmt (char *name, char *str, FILE *out)
     }
 
 #ifdef notdef
-    if (hdr -> flags & HBCC) {
+    if (hdr->flags & HBCC) {
 	insert_bcc(str);
 	return;
     }
@@ -524,7 +518,7 @@ putfmt (char *name, char *str, FILE *out)
 	    register struct mailname *mp = 0;
 
 	    while (cp = getname( str ) ) {
-		mp = getm( cp, NULLCP, 0, AD_HOST, NULLCP);
+		mp = getm( cp, NULL, 0, AD_HOST, NULL);
 		if (f == 0) {
 		    f = mp;
 		    mp->m_next = mp;
@@ -591,7 +585,7 @@ finish_headers (FILE *out)
     }
 
     if (badmsg)
-	adios (NULLCP, "re-format message and try again");
+	adios (NULL, "re-format message and try again");
 }
 
 
@@ -600,8 +594,8 @@ get_header (char *header, struct headers *table)
 {
     struct headers *h;
 
-    for (h = table; h -> value; h++)
-	if (uleq (header, h -> value))
+    for (h = table; h->value; h++)
+	if (uleq (header, h->value))
 	    return (h - table);
 
     return NOTOK;
@@ -643,7 +637,7 @@ putadr (char *name, struct mailname *nl)
 			    fprintf (out, "\n%s: ", name);
 			    linepos = namelen;
 		    }
-		    mp2 = getm( cp, NULLCP, 0, AD_HOST, NULLCP);
+		    mp2 = getm( cp, NULL, 0, AD_HOST, NULL);
 		    if (akvisible()) {
 			mp2->m_pers = getcpy(mp->m_mbox);
 			linepos = putone( adrformat(mp2), linepos, namelen );
@@ -704,7 +698,7 @@ insert_fcc (struct headers *hdr, char *pp)
 	return;
 
     if (fccind >= FCCS)
-	adios (NULLCP, "too many %ss", hdr -> value);
+	adios (NULL, "too many %ss", hdr->value);
     fccfold[fccind++] = getcpy (cp);
 }
 
@@ -733,7 +727,7 @@ make_bcc_file (void)
 
     if (filter == NULL) {
 	if ((fd = open (tmpfil, 0)) == NOTOK)
-	    adios (NULLCP, "unable to re-open");
+	    adios (NULL, "unable to re-open");
 	cpydgst (fd, fileno (out), tmpfil, bccfil);
 	close (fd);
     }
@@ -831,17 +825,19 @@ fcc (char *file, char *folder)
     fflush (stdout);
 }
 
-/* TERMINATION */
 
-/* VARARGS2 */
+/*
+ * TERMINATION
+ */
 
-static die (what, fmt, a, b, c, d)
-char   *what,
-       *fmt,
-       *a,
-       *b,
-       *c,
-       *d;
+static void
+die (char *what, char *fmt, ...)
 {
-    adios (what, fmt, a, b, c, d);
+    va_list ap;
+
+    va_start(ap, fmt);
+    advertise (what, NULL, fmt, ap);
+    va_end(ap);
+
+    done (1);
 }
