@@ -1,12 +1,10 @@
 
 /*
- * umhook.c - one attempt at a rcvmail hook for UUCP mail
+ * umhook.c -- one attempt at a rcvmail hook for UUCP mail
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	lint
-
 /* I don't comment my code heavily, so read this...
 
     You run this program from your .login file.  The invocation is simply
@@ -24,17 +22,10 @@ static char ident[] = "$Id$";
 
 #include "../h/mh.h"
 #include "../zotnet/mf.h"
-#include <stdio.h>
 #include "../zotnet/mts.h"
 #include <pwd.h>
 #include <signal.h>
 #include <sys/ioctl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define	SLEEPSW	0
@@ -60,17 +51,8 @@ static char myuser[BUFSIZ] = "";
 
 int	sigser ();
 
-off_t    lseek ();
-#ifdef	SYS5
-#ifndef __STDC__
-struct passwd  *getpwuid ();
-#endif /* !__STDC__ */
-#endif	SYS5
 
-
-main (argc, argv)
-int     argc;
-char  **argv;
+main (int argc, char **argv)
 {
     char   *cp,
           **ap,
@@ -100,7 +82,7 @@ char  **argv;
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches]", invo_name);
@@ -112,43 +94,43 @@ char  **argv;
 
 		case SLEEPSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if ((snooze = atoi (cp)) < 0)
-			adios (NULLCP, "bad argument %s %s", argp[-2], cp);
+			adios (NULL, "bad argument %s %s", argp[-2], cp);
 		    continue;
 	    }
-	adios (NULLCP, "usage: %s [switches]", invo_name);
+	adios (NULL, "usage: %s [switches]", invo_name);
     }
 
     if ((pw = getpwuid (getuid ())) == NULL)
-	adios (NULLCP, "you lose big");
+	adios (NULL, "you lose big");
 
     *environ = NULL;
-    m_putenv ("USER", pw -> pw_name);
-    m_putenv ("HOME", pw -> pw_dir);
-    m_putenv ("SHELL", pw -> pw_shell);
-    if (chdir (pw -> pw_dir) == NOTOK)
+    m_putenv ("USER", pw->pw_name);
+    m_putenv ("HOME", pw->pw_dir);
+    m_putenv ("SHELL", pw->pw_shell);
+    if (chdir (pw->pw_dir) == NOTOK)
 	chdir ("/");
     umask (0077);
 
     if (geteuid () == 0) {
 #ifdef	BSD41A
-	inigrp (pw -> pw_name, pw -> pw_gid);
+	inigrp (pw->pw_name, pw->pw_gid);
 #endif	BSD41A
-	setgid (pw -> pw_gid);
+	setgid (pw->pw_gid);
 #ifdef	BSD42
-	initgroups (pw -> pw_name, pw -> pw_gid);
+	initgroups (pw->pw_name, pw->pw_gid);
 #endif	BSD42
-	setuid (pw -> pw_uid);
+	setuid (pw->pw_uid);
     }
 
     sprintf (mymail, "%s/%s",
-	    uucpldir[0] ? uucpldir : pw -> pw_dir,
-	    uucplfil[0] ? uucplfil : pw -> pw_name);
-    strcpy (myuser, pw -> pw_name);
-    sprintf (myaddr, "%s@%s", pw -> pw_name, LocalName ());
-    strcpy (myhome, pw -> pw_dir);
-    sprintf (mystat, ".%s_%d", invo_name, pw -> pw_uid);
+	    uucpldir[0] ? uucpldir : pw->pw_dir,
+	    uucplfil[0] ? uucplfil : pw->pw_name);
+    strcpy (myuser, pw->pw_name);
+    sprintf (myaddr, "%s@%s", pw->pw_name, LocalName ());
+    strcpy (myhome, pw->pw_dir);
+    sprintf (mystat, ".%s_%d", invo_name, pw->pw_uid);
 
     if (access (slocalproc, 1) == NOTOK)
 	adios (slocalproc, "unable to execute");
@@ -223,7 +205,7 @@ struct stat *st;
     register FILE *fp;
 
     if ((uucp = lkopen (mymail, 0)) == NOTOK)
-	adios (NULLCP, "unable to lock and open %s", mymail);
+	adios (NULL, "unable to lock and open %s", mymail);
     if (lseek (uucp, (off_t) offset, 0) == (off_t) NOTOK)
 	adios (mymail, "unable to position to %ld offset on", (long) offset);
 
@@ -240,10 +222,10 @@ struct stat *st;
 
     switch (uucp2mmdf (uucp, td1, FALSE)) {
 	case MFPRM: 
-	    adios (NULLCP, "internal error while filtering UUCP mail");
+	    adios (NULL, "internal error while filtering UUCP mail");
 
 	case MFSIO: 
-	    adios (NULLCP, "no free file pointers");
+	    adios (NULL, "no free file pointers");
 
 	case MFERR: 
 	    adios ("UUCP mail", "i/o error while filtering");
@@ -252,8 +234,8 @@ struct stat *st;
 	case MFROM: 
 	case MFHDR: 
 	case MFTXT: 
-	    timep[0] = st -> st_atime;
-	    timep[1] = st -> st_mtime;
+	    timep[0] = st->st_atime;
+	    timep[1] = st->st_mtime;
 	    utime (mymail, timep);
 	    st_update (st);
 	    break;
@@ -266,7 +248,7 @@ struct stat *st;
 
     lseek (td2, (off_t)0, 0);
     if ((fp = fdopen (td2, "r")) == NULL)
-	adios (NULLCP, "no free file pointers");
+	adios (NULL, "no free file pointers");
 
     while (hook (fp))
 	continue;
@@ -305,7 +287,7 @@ register FILE *in;
 	adios ("file descriptor", "unable to dup");
 
     if ((out = fdopen (fd1, "w")) == NULL)
-	adios (NULLCP, "no free file pointers");
+	adios (NULL, "no free file pointers");
 
     for (done = TRUE;;) {
 	if (fgets (buffer, sizeof buffer, in) == NULL)
@@ -337,7 +319,7 @@ register FILE *in;
 	    closefds (4);
 #ifdef	TIOCNOTTY
 	    if ((i = open ("/dev/tty", 2)) != NOTOK) {
-		ioctl (i, TIOCNOTTY, NULLCP);
+		ioctl (i, TIOCNOTTY, NULL);
 		close (i);
 	    }
 #endif	TIOCNOTTY
@@ -348,7 +330,7 @@ register FILE *in;
 	    execlp (slocalproc, r1bindex (slocalproc, '/'),
 		    "-file", myfile, "-mailbox", mymail,
 		    "-home", myhome, "-addr", myaddr,
-		    "-user", myuser, "-sender", mysndr, NULLCP);
+		    "-user", myuser, "-sender", mysndr, NULL);
 	    adios (slocalproc, "unable to exec");/* NOTREACHED */
 
 	default: 
@@ -374,7 +356,7 @@ char   *mysndr;
     if ((fd2 = dup (fd1)) == NOTOK)
 	adios ("file descriptor", "unable to dup");
     if ((in = fdopen (fd2, "r")) == NULL)
-	adios (NULLCP, "no free file pointers");
+	adios (NULL, "no free file pointers");
 
     for (from[0] = sender[0] = NULL; mfgets (in, &hp) != DONE;)
 	if ((bp = index (hp, ':')) != NULL) {
@@ -400,15 +382,15 @@ char   *addr,
 
     if ((adrxp = seekadrx (bp)) == NULL)
 	return;
-    if (adrxp -> err || !adrxp -> mbox)
+    if (adrxp->err || !adrxp->mbox)
 	return;
 
-    if (adrxp -> host)
-	sprintf (addr, "%s@%s", adrxp -> mbox, adrxp -> host);
+    if (adrxp->host)
+	sprintf (addr, "%s@%s", adrxp->mbox, adrxp->host);
     else
-	strcpy (addr, adrxp -> mbox);
+	strcpy (addr, adrxp->mbox);
 
-    while (seekadrx (NULLCP))
+    while (seekadrx (NULL))
 	continue;
 }
 
@@ -421,9 +403,9 @@ struct stat *st;
 
     if ((fd = open (mystat, 0)) == NOTOK
 	    || read (fd, (char *) st, sizeof *st) != (sizeof *st)) {
-	st -> st_ino = (ino_t) 0;
-	st -> st_size = (off_t) 0;
-	st -> st_mtime = (time_t) 0;
+	st->st_ino = (ino_t) 0;
+	st->st_size = (off_t) 0;
+	st->st_mtime = (time_t) 0;
     }
     if (fd != NOTOK)
 	close (fd);
