@@ -1,13 +1,12 @@
 
 /*
- * vmh.c - visual front-end to mh
+ * vmh.c -- visual front-end to nmh
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
+#include "../h/mh.h"
+#include "../h/signals.h"
 
 #if 0
 #if defined(SYS5) && !defined(TERMINFO)
@@ -47,7 +46,6 @@ static char ident[] = "$Id$";
 #endif	/* TERMINFO */
 #endif
 
-#include "../h/mh.h"
 #include "../h/vmhsbr.h"
 #include <ctype.h>
 #include <errno.h>
@@ -62,18 +60,13 @@ static char ident[] = "$Id$";
 # undef SIGTSTP
 #endif	/* ridge */
 
-#ifndef	BSD42
-struct iovec {
-    char   *iov_base;
-    int     iov_len;
-};
-#else	/* BSD42 */
-# include <sys/types.h>
+#ifdef HAVE_WRITEV
 # include <sys/uio.h>
-#endif	/* BSD42 */
-
-#ifdef LOCALE
-# include <locale.h>
+#else
+struct iovec {
+    char *iov_base;
+    int   iov_len;
+};
 #endif
 
 #ifdef hpux
@@ -97,7 +90,7 @@ void __cputchar __P((int));
 #define	PAUSE	((unsigned int) 2)
 
 #ifndef	abs
-# define abs(a)	 ((a) > 0 ? (a) : -(a))
+# define abs(a)	((a) > 0 ? (a) : -(a))
 #endif
 
 #define	SMALLMOVE	1
@@ -106,17 +99,17 @@ void __cputchar __P((int));
 #define	XYZ			/* XXX */
 
 static struct swit switches[] = {
-#define	PRMPTSW	0
-    "prompt string", 6,
-#define	PROGSW	1
-    "vmhproc program", 7,
-#define	NPROGSW	2
-    "novmhproc", 9,
-#define VERSIONSW 3
-    "version", 0,
-#define	HELPSW	4
-    "help", 4,
-    NULL, 0
+#define	PRMPTSW               0
+    { "prompt string", 6 },
+#define	PROGSW                1
+    { "vmhproc program", 7 },
+#define	NPROGSW               2
+    { "novmhproc", 9 },
+#define VERSIONSW             3
+    { "version", 0 },
+#define	HELPSW                4
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 					/* PEERS */
@@ -140,8 +133,8 @@ WINDOW *windows[NWIN + 1];
 					/* LINES */
 
 struct line {
-    int     l_no;
-    char   *l_buf;
+    int l_no;
+    char *l_buf;
     struct line *l_prev;
     struct line *l_next;
 };
@@ -199,27 +192,27 @@ char *tgoto();
 #endif	/* SIGTSTP */
 
 					/* SIGNALS */
-static RETSIGTYPE ALRMser(), PIPEser(), SIGser();
+static RETSIGTYPE ALRMser(int);
+static RETSIGTYPE PIPEser(int);
+static RETSIGTYPE SIGser(int);
 #ifdef	SIGTSTP
-static RETSIGTYPE	TSTPser();
+static RETSIGTYPE TSTPser(int);
 #endif	/* SIGTSTP */
 
 
 					/* MISCELLANY */
-extern int  errno;
-#ifndef	BSD44
-extern int  sys_nerr;
-extern char *sys_errlist[];
-#endif
+extern int errno;
 
-static void adorn ();
+/*
+ * static prototypes
+ */
+static void adorn (char *, char *, ...);
 
 static	vmh(), lreset(), linsert(), ladvance(), lretreat(), lgo();
 static	TTYon(), TTYoff(), foreground();
 static int PEERinit(), pINI(), pLOOP(), pTTY(), pWIN(), WINinit();
 static int WINgetstr(), WINless(), WINputc(), TTYinit(), pWINaux();
 
-/* ARGSUSED */
 
 main (int argc, char **argv)
 {
@@ -261,12 +254,12 @@ main (int argc, char **argv)
 
 		case PRMPTSW:
 		    if (!(myprompt = *argp++) || *myprompt == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case PROGSW: 
 		    if (!(vmhproc = *argp++) || *vmhproc == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case NPROGSW:
 		    nprog++;
@@ -298,7 +291,7 @@ vmh (void)
     char buffer[BUFSIZ];
 
     for (;;) {
-	pLOOP (RC_QRY, NULLCP);
+	pLOOP (RC_QRY, NULL);
 
 	wmove (Command, 0, 0);
 	wprintw (Command, myprompt, invo_name);
@@ -320,7 +313,7 @@ vmh (void)
     }
 }
 
-/*    PEERS */
+/* PEERS */
 
 static int
 PEERinit (int vecp, char *vec[])
@@ -388,7 +381,7 @@ pINI (void)
     sprintf (bp, "%d %d", RC_VRSN, numwins);
     bp += strlen (bp);
     for (w = windows; *w; w++) {
-	sprintf (bp, " %d", (*w) -> _maxy);
+	sprintf (bp, " %d", (*w)->_maxy);
 	bp += strlen (bp);
     }
 
@@ -397,16 +390,16 @@ pINI (void)
 	    return OK;
 
 	case RC_ERR: 
-	    if (rc -> rc_len)
-		adios (NULLCP, "%s", rc -> rc_data);
+	    if (rc->rc_len)
+		adios (NULL, "%s", rc->rc_data);
 	    else
-		adios (NULLCP, "pINI peer error");
+		adios (NULL, "pINI peer error");
 
 	case RC_XXX: 
-	    adios (NULLCP, "%s", rc -> rc_data);
+	    adios (NULL, "%s", rc->rc_data);
 
 	default:
-	    adios (NULLCP, "pINI protocol screw-up");
+	    adios (NULL, "pINI protocol screw-up");
     }
 /* NOTREACHED */
 }
@@ -430,7 +423,7 @@ pLOOP (char *code, char *str)
 		break;
 
 	    case RC_WIN:
-		if (sscanf (rc -> rc_data, "%d", &i) != 1
+		if (sscanf (rc->rc_data, "%d", &i) != 1
 			|| i <= 0
 			|| i > numwins) {
 		    fmt2peer (RC_ERR, "no such window \"%s\"", rc->rc_data);
@@ -444,36 +437,36 @@ pLOOP (char *code, char *str)
 		return OK;
 
 	    case RC_ERR:
-		if (rc -> rc_len)
-		    adorn (NULLCP, "%s", rc -> rc_data);
+		if (rc->rc_len)
+		    adorn (NULL, "%s", rc->rc_data);
 		else
-		    adorn (NULLCP, "pLOOP(%s) peer error",
+		    adorn (NULL, "pLOOP(%s) peer error",
 			    code == RC_QRY ? "QRY" : "CMD");
 		return NOTOK;
 
 	    case RC_FIN:
-		if (rc -> rc_len)
-		    adorn (NULLCP, "%s", rc -> rc_data);
+		if (rc->rc_len)
+		    adorn (NULL, "%s", rc->rc_data);
 		rcdone ();
 		i = pidwait (PEERpid, OK);
 		PEERpid = NOTOK;
 		done (i);
 
 	    case RC_XXX: 
-		adios (NULLCP, "%s", rc -> rc_data);
+		adios (NULL, "%s", rc->rc_data);
 
 	    default:
-		adios (NULLCP, "pLOOP(%s) protocol screw-up",
+		adios (NULL, "pLOOP(%s) protocol screw-up",
 			code == RC_QRY ? "QRY" : "CMD");
 	}
 }
 
 
-static int  pTTY (r)
-register struct record *r;
+static int
+pTTY (struct record *r)
 {
-    RETSIGTYPE (*hstat) (), (*istat) (), (*qstat) (), (*tstat) ();
-    struct record   rcs;
+    SIGNAL_HANDLER hstat, istat, qstat, tstat;
+    struct record rcs;
     register struct record *rc = &rcs;
 
     initrc (rc);
@@ -485,7 +478,7 @@ register struct record *r;
     qstat = signal (SIGQUIT, SIG_IGN);
     tstat = signal (SIGTERM, SIG_IGN);
 
-    rc2rc (RC_ACK, 0, NULLCP, rc);
+    rc2rc (RC_ACK, 0, NULL, rc);
 
     signal (SIGHUP, hstat);
     signal (SIGINT, istat);
@@ -522,23 +515,23 @@ register struct record *r;
     wrefresh (curscr);
 
 no_refresh: ;
-    switch (rc -> rc_type) {
+    switch (rc->rc_type) {
 	case RC_EOF: 
-	    rc2peer (RC_ACK, 0, NULLCP);
+	    rc2peer (RC_ACK, 0, NULL);
 	    return OK;
 
 	case RC_ERR: 
-	    if (rc -> rc_len)
-		adorn (NULLCP, "%s", rc -> rc_data);
+	    if (rc->rc_len)
+		adorn (NULL, "%s", rc->rc_data);
 	    else
-		adorn (NULLCP, "pTTY peer error");
+		adorn (NULL, "pTTY peer error");
 	    return NOTOK;
 
 	case RC_XXX: 
-	    adios (NULLCP, "%s", rc -> rc_data);
+	    adios (NULL, "%s", rc->rc_data);
 
 	default:
-	    adios (NULLCP, "pTTY protocol screw-up");
+	    adios (NULL, "pTTY protocol screw-up");
     }
 /* NOTREACHED */
 }
@@ -578,11 +571,11 @@ pWINaux (WINDOW *w)
 #endif	/* XYZ */
 
     for (eol = 0;;)
-	switch (rc2rc (RC_ACK, 0, NULLCP, rc)) {
+	switch (rc2rc (RC_ACK, 0, NULL, rc)) {
 	    case RC_DATA: 
 		if (eol && WINputc (w, '\n') == ERR && WINless (w, 0))
 		    goto flush;
-		for (bp = rc -> rc_data, n = rc -> rc_len; n-- > 0; ) {
+		for (bp = rc->rc_data, n = rc->rc_len; n-- > 0; ) {
 		    if ((c = *bp++) == '\n')
 		        linsert (w);
 		    if (WINputc (w, c) == ERR)
@@ -603,7 +596,7 @@ flush: ;
 		break;
 
 	    case RC_EOF: 
-		rc2peer (RC_ACK, 0, NULLCP);
+		rc2peer (RC_ACK, 0, NULL);
 #ifdef	XYZ
 		if (w == Status)
 		    wstandend (w);
@@ -612,17 +605,17 @@ flush: ;
 		return OK;
 
 	    case RC_ERR: 
-		if (rc -> rc_len)
-		    adorn (NULLCP, "%s", rc -> rc_data);
+		if (rc->rc_len)
+		    adorn (NULL, "%s", rc->rc_data);
 		else
-		    adorn (NULLCP, "pWIN peer error");
+		    adorn (NULL, "pWIN peer error");
 		return NOTOK;
 
 	    case RC_XXX: 
-		adios (NULLCP, "%s", rc -> rc_data);
+		adios (NULL, "%s", rc->rc_data);
 
 	    default:
-		adios (NULLCP, "pWIN protocol screw-up");
+		adios (NULL, "pWIN protocol screw-up");
 	}
 /* NOTREACHED */
 }
@@ -636,7 +629,7 @@ pFIN (void)
     if (PEERpid <= OK)
 	return OK;
 
-    rc2peer (RC_FIN, 0, NULLCP);
+    rc2peer (RC_FIN, 0, NULL);
     rcdone ();
 
     switch (setjmp (PEERctx)) {
@@ -659,10 +652,10 @@ pFIN (void)
     return status;
 }
 
-/*    WINDOWS */
+/* WINDOWS */
 
 static int
-WINinit (nprog)
+WINinit (int nprog)
 {
     register int nlines,	/* not "lines" because terminfo uses that */
                  top,
@@ -673,7 +666,7 @@ WINinit (nprog)
 	if (nprog)
 	    return NOTOK;
 	else
-	    adios (NULLCP, "could not initialize terminal");
+	    adios (NULL, "could not initialize terminal");
 #ifdef	SIGTSTP
     signal (SIGTSTP, SIG_DFL);
 #endif	/* SIGTSTP */
@@ -687,7 +680,7 @@ WINinit (nprog)
 	if (nprog)
 	    return NOTOK;
 	else
-	    adios (NULLCP,
+	    adios (NULL,
 		    "sorry, your terminal isn't powerful enough to run %s",
 		    invo_name);
 
@@ -705,7 +698,7 @@ WINinit (nprog)
 #endif	/* TERMINFO */
 
     if ((nlines = LINES - 1) < 11)
-	adios (NULLCP, "screen too small");
+	adios (NULL, "screen too small");
     if ((top = nlines / 3 + 1) > LINES / 4 + 2)
 	top--;
     bottom = nlines - top - 2;
@@ -720,18 +713,15 @@ WINinit (nprog)
     Command = newwin (1, COLS - 1, top + 1 + bottom, 0);
     windows[numwins] = NULL;
 
-    largemove = Display -> _maxy / 2 + 2;
+    largemove = Display->_maxy / 2 + 2;
     return OK;
 }
 
-/*  */
 
-static int WINgetstr (w, buffer)
-register WINDOW *w;
-char   *buffer;
+static int WINgetstr (WINDOW *w, char *buffer)
 {
-    register int    c;
-    register char  *bp;
+    register int c;
+    register char *bp;
 
     bp = buffer;
     *bp = 0;
@@ -739,7 +729,7 @@ char   *buffer;
     for (;;) {
 	switch (c = toascii (wgetch (w))) {
 	    case ERR: 
-		adios (NULLCP, "wgetch lost");
+		adios (NULL, "wgetch lost");
 
 	    case '\f':
 		wrefresh (curscr);
@@ -750,7 +740,7 @@ char   *buffer;
 		*bp = 0;
 		if (bp > buffer) {
 		    leaveok (curscr, FALSE);
-		    wmove (w, 0, w -> _curx - (bp - buffer));
+		    wmove (w, 0, w->_curx - (bp - buffer));
 		    wrefresh (w);
 		    leaveok (curscr, TRUE);
 		}
@@ -774,14 +764,14 @@ char   *buffer;
 		if (c == ERASE) {
 		    if (bp <= buffer)
 			continue;
-		    bp--, w -> _curx--;
+		    bp--, w->_curx--;
 		    wclrtoeol (w);
 		    break;
 		}
 		if (c == KILL) {
 		    if (bp <= buffer)
 			continue;
-		    w -> _curx -= bp - buffer;
+		    w->_curx -= bp - buffer;
 		    bp = buffer;
 		    wclrtoeol (w);
 		    break;
@@ -790,15 +780,15 @@ char   *buffer;
 		    if (bp <= buffer)
 			continue;
 		    do {
-			bp--, w -> _curx--;
+			bp--, w->_curx--;
 		    } while (isspace (*bp) && bp > buffer);
 
 		    if (bp > buffer) {
 			do {
-			    bp--, w -> _curx--;
+			    bp--, w->_curx--;
 			} while (!isspace (*bp) && bp > buffer);
 			if (isspace (*bp))
-			    bp++, w -> _curx++;
+			    bp++, w->_curx++;
 		    }
 		    wclrtoeol (w);
 		    break;
@@ -813,19 +803,16 @@ char   *buffer;
     }
 }
 
-/*  */
 
-static int  WINwritev (w, iov, n)
-register WINDOW *w;
-register struct iovec   *iov;
-register int     n;
+static int
+WINwritev (WINDOW *w, struct iovec *iov, int n)
 {
-    register int    i;
+    register int i;
 
     werase (w);
     wmove (w, 0, 0);
     for (i = 0; i < n; i++, iov++)
-	wprintw (w, "%*.*s", iov -> iov_len, iov -> iov_len, iov -> iov_base);
+	wprintw (w, "%*.*s", iov->iov_len, iov->iov_len, iov->iov_base);
     wrefresh (w);
 
     sleep (PAUSE);
@@ -833,7 +820,6 @@ register int     n;
     return OK;
 }
 
-/*  */
 
 static struct {
     char   *h_msg;
@@ -852,22 +838,18 @@ static struct {
                     NULL, NULL
 };
 
-/*  */
 
-static int  WINless (w, fin)
-register WINDOW *w;
-int	fin;
+static int
+WINless (WINDOW *w, int fin)
 {
-    register int    c,
-                    i,
-                    n;
-    int     nfresh,
-#ifdef	notdef
-	    nlatch,
-#endif	/* notdef */
-            nwait;
-    char   *cp;
-    register struct line   *lbottom;
+    register int c, i, n;
+    char *cp;
+    register struct line *lbottom;
+    int nfresh, nwait;
+
+#ifdef notdef
+    int nlatch;
+#endif
 
     did_less++;
 
@@ -894,23 +876,23 @@ once_only: ;
 
 	    if (ltop == NULL)
 		if (fin) {
-		    lgo (ltail -> l_no - w -> _maxy + 1);
+		    lgo (ltail->l_no - w->_maxy + 1);
 		    if (ltop == NULL)
 			ltop = lhead;
 		}
 		else
-		    ltop = lbottom && lbottom -> l_prev ? lbottom -> l_prev
+		    ltop = lbottom && lbottom->l_prev ? lbottom->l_prev
 			    : lbottom;
 
-	    for (lbottom = ltop; lbottom; lbottom = lbottom -> l_next)
-		if (waddstr (w, lbottom -> l_buf) == ERR
+	    for (lbottom = ltop; lbottom; lbottom = lbottom->l_next)
+		if (waddstr (w, lbottom->l_buf) == ERR
 			|| waddch (w, '\n') == ERR)
 		    break;
 	    if (lbottom == NULL)
 		if (fin) {
 #ifdef	notdef
-		    if (nlatch && (ltail -> l_no >= w -> _maxy)) {
-			lgo (ltail -> l_no - w -> _maxy + 1);
+		    if (nlatch && (ltail->l_no >= w->_maxy)) {
+			lgo (ltail->l_no - w->_maxy + 1);
 			nlatch = 0;
 			goto once_only;
 		    }
@@ -937,7 +919,7 @@ once_only: ;
 	}
 	else
 	    wprintw (Command, fin ? "top:%d bot:%d end:%d" : "top:%d bot:%d",
-		    ltop -> l_no, lbottom -> l_no, ltail -> l_no);
+		    ltop->l_no, lbottom->l_no, ltail->l_no);
 	wprintw (Command, ">> ");
 	wclrtoeol (Command);
 	wrefresh (Command);
@@ -956,7 +938,7 @@ once_only: ;
 again: 	;
 	switch (c) {
 	    case ' ': 
-		ltop = lbottom -> l_next;
+		ltop = lbottom->l_next;
 		nfresh++;
 		break;
 
@@ -999,7 +981,7 @@ again: 	;
 		break;
 
 	    case 'G': 
-		if (lgo (n ? n : ltail -> l_no - w -> _maxy + 1))
+		if (lgo (n ? n : ltail->l_no - w->_maxy + 1))
 		    nfresh++;
 		break;
 
@@ -1056,14 +1038,11 @@ again: 	;
     }
 }
 
-/*  */
 
-static int  WINputc (w, c)
-register WINDOW *w;
-register char c;
+static int
+WINputc (WINDOW *w, char c)
 {
-    register int    x,
-                    y;
+    register int x, y;
 
     switch (c) {
 	default: 
@@ -1088,8 +1067,8 @@ register char c;
     if (w != Scan)
 	return waddch (w, c);
 
-    if ((x = w -> _curx) < 0 || x >= w -> _maxx
-	    || (y = w -> _cury) < 0 || y >= w -> _maxy)
+    if ((x = w->_curx) < 0 || x >= w->_maxx
+	    || (y = w->_cury) < 0 || y >= w->_maxy)
 	return DONE;
 
     switch (c) {
@@ -1100,14 +1079,14 @@ register char c;
 	    break;
 
 	case '\n': 
-	    if (++y < w -> _maxy) 
+	    if (++y < w->_maxy) 
 		waddch (w, c);
 	    else
 		wclrtoeol (w);
 	    break;
 
 	default: 
-	    if (++x < w -> _maxx) 
+	    if (++x < w->_maxx) 
 		waddch (w, c);
 	    break;
     }
@@ -1115,37 +1094,38 @@ register char c;
     return DONE;
 }
 
-/*    LINES */
+/* LINES */
 
-static  lreset () {
-    register struct line   *lp,
-                           *mp;
+static void
+lreset (void)
+{
+    register struct line *lp, *mp;
 
     for (lp = lhead; lp; lp = mp) {
-	mp = lp -> l_next;
-	free (lp -> l_buf);
+	mp = lp->l_next;
+	free (lp->l_buf);
 	free ((char *) lp);
     }
     lhead = ltop = ltail = NULL;
 }
 
 
-static	linsert (w)
-WINDOW *w;
+static void
+linsert (WINDOW *w)
 {
-    register char  *cp;
-    register struct line   *lp;
+    register char *cp;
+    register struct line *lp;
 
     if ((lp = (struct line  *) calloc ((unsigned) 1, sizeof *lp)) == NULL)
-	adios (NULLCP, "unable to allocate line storage");
+	adios (NULL, "unable to allocate line storage");
 
-    lp -> l_no = (ltail ? ltail -> l_no : 0) + 1;
+    lp->l_no = (ltail ? ltail->l_no : 0) + 1;
 #ifndef	BSD44
-    lp -> l_buf = getcpy (w -> _y[w -> _cury]);
+    lp->l_buf = getcpy (w->_y[w->_cury]);
 #else
-    lp -> l_buf = getcpy (w -> lines[w -> _cury]->line);
+    lp->l_buf = getcpy (w->lines[w->_cury]->line);
 #endif
-    for (cp = lp -> l_buf + strlen (lp -> l_buf) - 1; cp >= lp -> l_buf; cp--)
+    for (cp = lp->l_buf + strlen (lp->l_buf) - 1; cp >= lp->l_buf; cp--)
 	if (isspace (*cp))
 	    *cp = 0;
 	else
@@ -1156,20 +1136,19 @@ WINDOW *w;
     if (ltop == NULL)
 	ltop = lp;
     if (ltail)
-	ltail -> l_next = lp;
-    lp -> l_prev = ltail;
+	ltail->l_next = lp;
+    lp->l_prev = ltail;
     ltail = lp;
 }
 
-/*  */
 
-static int  ladvance (n)
-int	n;
+static int
+ladvance (int n)
 {
-    register int    i;
-    register struct line   *lp;
+    register int i;
+    register struct line *lp;
 
-    for (i = 0, lp = ltop; i < n && lp; i++, lp = lp -> l_next)
+    for (i = 0, lp = ltop; i < n && lp; i++, lp = lp->l_next)
 	continue;
 
     if (ltop == lp)
@@ -1180,14 +1159,14 @@ int	n;
 }
 
 
-static int  lretreat (n)
-int	n;
+static int
+lretreat (int n)
 {
-    register int    i;
-    register struct line   *lp;
+    register int i;
+    register struct line *lp;
 
-    for (i = 0, lp = ltop; i < n && lp; i++, lp = lp -> l_prev)
-	if (!lp -> l_prev)
+    for (i = 0, lp = ltop; i < n && lp; i++, lp = lp->l_prev)
+	if (!lp->l_prev)
 	    break;
 
     if (ltop == lp)
@@ -1197,29 +1176,27 @@ int	n;
     return 1;
 }
 
-/*  */
 
-static int  lgo (n)
-int	n;
+static int
+lgo (int n)
 {
-    register int    i,
-                    j;
-    register struct line   *lp;
+    register int i, j;
+    register struct line *lp;
 
-    if ((i = n - (lp = lhead) -> l_no)
-	    > (j = abs (n - (ltop ? ltop : ltail) -> l_no)))
+    if ((i = n - (lp = lhead)->l_no)
+	    > (j = abs (n - (ltop ? ltop : ltail)->l_no)))
 	i = j, lp = ltop ? ltop : ltail;
-    if (i > (j = abs (ltail -> l_no - n)))
+    if (i > (j = abs (ltail->l_no - n)))
 	i = j, lp = ltail;
 
-    if (n >= lp -> l_no) {
-	for (; lp; lp = lp -> l_next)
-	    if (lp -> l_no == n)
+    if (n >= lp->l_no) {
+	for (; lp; lp = lp->l_next)
+	    if (lp->l_no == n)
 		break;
     }
     else {
-	for (; lp; lp = lp -> l_prev)
-	    if (lp -> l_no == n)
+	for (; lp; lp = lp->l_prev)
+	    if (lp->l_no == n)
 		break;
 	if (!lp)
 	    lp = lhead;
@@ -1232,14 +1209,16 @@ int	n;
     return 1;
 }
 
-/*    TTYS */
+/* TTYS */
 
-static int  TTYinit (nprog) {
+static int
+TTYinit (int nprog)
+{
     if (!isatty (fileno (stdin)) || !isatty (fileno (stdout)))
 	if (nprog)
 	    return NOTOK;
 	else
-	    adios (NULLCP, "not a tty");
+	    adios (NULL, "not a tty");
 
     foreground ();
 #ifndef	SYS5
@@ -1270,9 +1249,10 @@ static int  TTYinit (nprog) {
     return OK;
 }
 
-/*  */
 
-static	TTYon () {
+static void
+TTYon (void)
+{
     if (tty_ready == DONE)
 	return;
 
@@ -1300,9 +1280,10 @@ static	TTYon () {
 #endif	/* SIGTSTP */
 }
 
-/*  */
 
-static	TTYoff () {
+static void
+TTYoff (void)
+{
     if (tty_ready == NOTOK)
 	return;
 
@@ -1339,11 +1320,12 @@ static	TTYoff () {
 }
 
 
-static  foreground () {
+static void
+foreground (void)
+{
 #ifdef	TIOCGPGRP
-    int     pgrp,
-            tpgrp;
-    RETSIGTYPE     (*tstat) ();
+    int pgrp, tpgrp;
+    SIGNAL_HANDLER tstat;
 
     if ((pgrp = getpgrp()) == NOTOK)
 	adios ("process group", "unable to determine");
@@ -1365,7 +1347,9 @@ static  foreground () {
 }
 
 
-sideground () {
+void
+sideground (void)
+{
 #ifdef	TIOCGPGRP
     signal (SIGTTIN, SIG_DFL);
     signal (SIGTTOU, SIG_DFL);
@@ -1373,12 +1357,11 @@ sideground () {
 #endif	/* TIOCGPGRP */
 }
 
-/*    SIGNALS */
+/* SIGNALS */
 
-/* ARGSUSED */
 
-static RETSIGTYPE  ALRMser (sig)
-int     sig;
+static RETSIGTYPE
+ALRMser (int sig)
 {
      longjmp (PEERctx, DONE);
 }
@@ -1388,14 +1371,14 @@ int     sig;
 /* ARGSUSED */
 #endif	/* BSD42 */
 
-static RETSIGTYPE  PIPEser (sig)
-int	sig;
+static RETSIGTYPE
+PIPEser (int sig)
 {
 #ifndef	BSD42
     signal (sig, SIG_IGN);
 #endif	/* BSD42 */
 
-    adios (NULLCP, "lost peer");
+    adios (NULL, "lost peer");
 }
 
 
@@ -1403,8 +1386,8 @@ int	sig;
 /* ARGSUSED */
 #endif	/* BSD42 */
 
-static RETSIGTYPE  SIGser (sig)
-int     sig;
+static RETSIGTYPE
+SIGser (int sig)
 {
 #ifndef	BSD42
     signal (sig, SIG_IGN);
@@ -1415,8 +1398,8 @@ int     sig;
 
 
 #ifdef	SIGTSTP
-static RETSIGTYPE  TSTPser (sig)
-int     sig;
+static RETSIGTYPE
+TSTPser (int sig)
 {
 #ifndef	TERMINFO
     tputs (tgoto (CM, 0, LINES - 1), 0, _putchar);
@@ -1443,10 +1426,11 @@ int     sig;
 }
 #endif	/* SIGTSTP */
 
-/*    MISCELLANY */
 
-void	done (status)
-int	status;
+/* MISCELLANY */
+
+void
+done (int status)
 {
     TTYoff ();
     pFIN ();
@@ -1454,86 +1438,68 @@ int	status;
     exit (status);
 }
 
-/*  */
 
-/* VARARGS2 */
-
-static void  adorn (what, fmt, a, b, c, d, e, f)
-char   *what,
-       *fmt,
-       *a,
-       *b,
-       *c,
-       *d,
-       *e,
-       *f;
+static void
+adorn (char *what, char *fmt, ...)
 {
-    char   *cp = invo_name;
+    va_list ap;
+    char *cp;
 
+    cp = invo_name;
     invo_name = NULL;
-    advise (what, fmt, a, b, c, d, e, f);
+
+    va_start(ap, fmt);
+    advertise (what, NULL, fmt, ap);
+    va_end(ap);
+
     invo_name = cp;
 }
 
-/*  */
 
-/* VARARGS3 */
-
-void advertise (what, tail, fmt, a, b, c, d, e, f)
-char   *what,
-       *tail,
-       *fmt,
-       *a,
-       *b,
-       *c,
-       *d,
-       *e,
-       *f;
+void
+advertise (char *what, char *tail, char *fmt, va_list ap)
 {
-    int	    eindex = errno;
-    char    buffer[BUFSIZ],
-            err[BUFSIZ];
-    struct iovec    iob[20];
-    register struct iovec  *iov = iob;
+    int	eindex = errno;
+    char buffer[BUFSIZ], err[BUFSIZ];
+    struct iovec iob[20];
+    register struct iovec *iov = iob;
 
     fflush (stdout);
-
     fflush (stderr);
 
     if (invo_name) {
-	iov -> iov_len = strlen (iov -> iov_base = invo_name);
+	iov->iov_len = strlen (iov->iov_base = invo_name);
 	iov++;
-	iov -> iov_len = strlen (iov -> iov_base = ": ");
+	iov->iov_len = strlen (iov->iov_base = ": ");
 	iov++;
     }
     
-    sprintf (buffer, fmt, a, b, c, d, e, f);
-    iov -> iov_len = strlen (iov -> iov_base = buffer);
+    vsprintf (buffer, fmt, ap);
+    iov->iov_len = strlen (iov->iov_base = buffer);
     iov++;
     if (what) {
 	if (*what) {
-	    iov -> iov_len = strlen (iov -> iov_base = " ");
+	    iov->iov_len = strlen (iov->iov_base = " ");
 	    iov++;
-	    iov -> iov_len = strlen (iov -> iov_base = what);
+	    iov->iov_len = strlen (iov->iov_base = what);
 	    iov++;
-	    iov -> iov_len = strlen (iov -> iov_base = ": ");
+	    iov->iov_len = strlen (iov->iov_base = ": ");
 	    iov++;
 	}
-	if (eindex > 0 && eindex < sys_nerr)
-	    iov -> iov_len = strlen (iov -> iov_base = sys_errlist[eindex]);
-	else {
+	if (!(iov->iov_base = strerror (eindex))) {
 	    sprintf (err, "Error %d", eindex);
-	    iov -> iov_len = strlen (iov -> iov_base = err);
+	    iov->iov_base = err;
 	}
+	iov->iov_len = strlen (iov->iov_base);
 	iov++;
     }
     if (tail && *tail) {
-	iov -> iov_len = strlen (iov -> iov_base = ", ");
+	iov->iov_len = strlen (iov->iov_base = ", ");
 	iov++;
-	iov -> iov_len = strlen (iov -> iov_base = tail);
+	iov->iov_len = strlen (iov->iov_base = tail);
 	iov++;
     }
-    iov -> iov_len = strlen (iov -> iov_base = "\n");
+    iov->iov_len = strlen (iov->iov_base = "\n");
     iov++;
 
     if (tty_ready == DONE)
@@ -1542,23 +1508,3 @@ char   *what,
 	writev (fileno (stderr), iob, iov - iob);
 }
 
-/*  */
-
-#ifndef	BSD42
-static int     writev (fd, iov, n)
-register int     fd;
-register struct iovec   *iov;
-register int     n;
-{
-    register int    i,
-                    j;
-
-    for (i = j = 0; i < n; i++, iov++)
-	if (write (fd, iov -> iov_base, iov -> iov_len) != iov -> iov_len)
-	    break;
-	else
-	    j += iov -> iov_len;
-
-    return j;
-}
-#endif	/* BSD42 */
