@@ -1,20 +1,12 @@
 
 /*
- * vmhtest.c - test out vmh protocol
+ * vmhtest.c -- test out vmh protocol
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	lint
-
 #include "../h/mh.h"
 #include "../h/vmhsbr.h"
-#include <ctype.h>
-#include <stdio.h>
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
 
 static struct swit switches[] = {
 #define	READSW	0
@@ -28,7 +20,6 @@ static struct swit switches[] = {
     NULL, NULL
 };
 
-
 #define	NWIN	20
 static	int	numwins = 0;
 static	int	windows[NWIN + 1];
@@ -58,7 +49,7 @@ char  **argv,
 	setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    m_foil (NULLCP);
+    m_foil (NULL);
 
     while (cp = *argp++)
 	if (*cp == '-')
@@ -67,7 +58,7 @@ char  **argv,
 		    ambigsw (cp, switches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buffer, "%s [switches]", invo_name);
@@ -79,19 +70,19 @@ char  **argv,
 
 		case READSW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if ((fd1 = atoi (cp)) < 1)
-			adios (NULLCP, "bad argument %s %s", argp[-2], cp);
+			adios (NULL, "bad argument %s %s", argp[-2], cp);
 		    continue;
 		case WRITESW: 
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    if ((fd2 = atoi (cp)) < 1)
-			adios (NULLCP, "bad argument %s %s", argp[-2], cp);
+			adios (NULL, "bad argument %s %s", argp[-2], cp);
 		    continue;
 	    }
 	else
-	    adios (NULLCP, "usage: %s [switches]", invo_name);
+	    adios (NULL, "usage: %s [switches]", invo_name);
 
     rcinit (fd1, fd2);
     pINI ();
@@ -112,12 +103,12 @@ static int  pINI () {
 
     switch (peer2rc (rc)) {
 	case RC_INI: 
-	    bp = rc -> rc_data;
+	    bp = rc->rc_data;
 	    while (isspace (*bp))
 		bp++;
 	    if (sscanf (bp, "%d", &vrsn) != 1) {
 	bad_init: ;
-		fmt2peer (RC_ERR, "bad init \"%s\"", rc -> rc_data);
+		fmt2peer (RC_ERR, "bad init \"%s\"", rc->rc_data);
 		done (1);
 	    }
 	    if (vrsn != RC_VRSN) {
@@ -142,11 +133,11 @@ static int  pINI () {
 		if (sscanf (bp, "%d", &windows[i]) != 1 || windows[i] <= 0)
 		    goto bad_init;
 	    }
-	    rc2peer (RC_ACK, 0, NULLCP);
+	    rc2peer (RC_ACK, 0, NULL);
 	    return OK;
 
 	case RC_XXX: 
-	    adios (NULLCP, "%s", rc -> rc_data);
+	    adios (NULL, "%s", rc->rc_data);
 
 	default: 
 	    fmt2peer (RC_ERR, "pINI protocol screw-up");
@@ -164,18 +155,18 @@ static int  pLOOP () {
     for (;;)
 	switch (peer2rc (rc)) {
 	    case RC_QRY: 
-		pQRY (rc -> rc_data);
+		pQRY (rc->rc_data);
 		break;
 
 	    case RC_CMD: 
-		pCMD (rc -> rc_data);
+		pCMD (rc->rc_data);
 		break;
 
 	    case RC_FIN: 
 		done (0);
 
 	    case RC_XXX: 
-		adios (NULLCP, "%s", rc -> rc_data);
+		adios (NULL, "%s", rc->rc_data);
 
 	    default: 
 		fmt2peer (RC_ERR, "pLOOP protocol screw-up");
@@ -187,7 +178,7 @@ static int  pLOOP () {
 static int  pQRY (str)
 char   *str;
 {
-    rc2peer (RC_EOF, 0, NULLCP);
+    rc2peer (RC_EOF, 0, NULL);
     return OK;
 }
 
@@ -197,7 +188,7 @@ char   *str;
 {
     if ((selcmd () ? pTTY (str) : pWIN (str)) == NOTOK)
 	return NOTOK;
-    rc2peer (RC_EOF, 0, NULLCP);
+    rc2peer (RC_EOF, 0, NULL);
     return OK;
 }
 
@@ -210,7 +201,7 @@ char   *str;
 
     initrc (rc);
 
-    switch (rc2rc (RC_TTY, 0, NULLCP, rc)) {
+    switch (rc2rc (RC_TTY, 0, NULL, rc)) {
 	case RC_ACK: 
 	    break;
 
@@ -218,7 +209,7 @@ char   *str;
 	    return NOTOK;
 
 	case RC_XXX: 
-	    adios (NULLCP, "%s", rc -> rc_data);
+	    adios (NULL, "%s", rc->rc_data);
 
 	default: 
 	    fmt2peer (RC_ERR, "pTTY protocol screw-up");
@@ -227,12 +218,12 @@ char   *str;
 
     system (str);
 
-    switch (rc2rc (RC_EOF, 0, NULLCP, rc)) {
+    switch (rc2rc (RC_EOF, 0, NULL, rc)) {
 	case RC_ACK: 
 	    return OK;
 
 	case RC_XXX: 
-	    adios (NULLCP, "%s", rc -> rc_data);/* NOTREACHED */
+	    adios (NULL, "%s", rc->rc_data);/* NOTREACHED */
 
 	default: 
 	    fmt2peer (RC_ERR, "pTTY protocol screw-up");
@@ -262,7 +253,7 @@ char   *str;
 	    return NOTOK;
 
 	case RC_XXX: 
-	    adios (NULLCP, "%s", rc -> rc_data);
+	    adios (NULL, "%s", rc->rc_data);
 
 	default: 
 	    fmt2peer (RC_ERR, "pWIN protocol screw-up");
@@ -286,7 +277,7 @@ char   *str;
 	    dup2 (pd[1], 2);
 	    close (pd[0]);
 	    close (pd[1]);
-	    execlp ("/bin/sh", "sh", "-c", str, NULLCP);
+	    execlp ("/bin/sh", "sh", "-c", str, NULL);
 	    write (2, "no shell\n", strlen ("no shell\n"));
 	    _exit (1);
 
@@ -303,19 +294,19 @@ char   *str;
 			return NOTOK;
 
 		    case RC_XXX: 
-			adios (NULLCP, "%s", rc -> rc_data);
+			adios (NULL, "%s", rc->rc_data);
 
 		    default: 
 			fmt2peer (RC_ERR, "pWIN protocol screw-up");
 			done (1);
 		}
 	    if (i == OK)
-		switch (rc2rc (RC_EOF, 0, NULLCP, rc)) {
+		switch (rc2rc (RC_EOF, 0, NULL, rc)) {
 		    case RC_ACK: 
 			break;
 
 		    case RC_XXX: 
-			adios (NULLCP, "%s", rc -> rc_data);
+			adios (NULL, "%s", rc->rc_data);
 
 		    default: 
 			fmt2peer (RC_ERR, "pWIN protocol screw-up");
