@@ -1,15 +1,11 @@
 
 /*
- * whatnow.c - the MH WhatNow? shell
+ * whatnow.c -- the nmh `WhatNow' shell
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#ifdef LOCALE
-# include <locale.h>
-#endif
+#include "../h/mh.h"
 
 main (int argc, char **argv)
 {
