@@ -1,14 +1,11 @@
 
 /*
  * whatnowproc.c -- exec whatnowproc
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../h/mh.h"
-#include <stdio.h>
 
 int
 what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
@@ -24,14 +21,14 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 
     m_putenv ("mhdraft", file);
     if (mp)
-	m_putenv ("mhfolder", mp -> foldpath);
+	m_putenv ("mhfolder", mp->foldpath);
     else
 	unputenv ("mhfolder");
     if (altmsg)
 	if (mp == NULL || *altmsg == '/' || cwd == NULL)
 	    m_putenv ("mhaltmsg", altmsg);
 	else {
-	    sprintf (buffer, "%s/%s", mp -> foldpath, altmsg);
+	    sprintf (buffer, "%s/%s", mp->foldpath, altmsg);
 	    m_putenv ("mhaltmsg", buffer);
 	}
     else
@@ -50,15 +47,15 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
     unputenv ("mhmessages");
     unputenv ("mhannotate");
     unputenv ("mhinplace");
-    if (text && mp && !(mp -> msgflags & READONLY)) {
+    if (text && mp && !(mp->msgflags & READONLY)) {
 	found = 0;
 	bp = buffer;
-	for (msgnum = mp -> lowmsg; msgnum <= mp -> hghmsg; msgnum++)
-	    if (mp -> msgstats[msgnum] & SELECTED) {
+	for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
+	    if (mp->msgstats[msgnum] & SELECTED) {
 		sprintf (bp, "%s%s", found ? " " : "", m_name (msgnum));
 		bp += strlen (bp);
 		for (k = msgnum + 1;
-			k <= mp -> hghmsg && mp -> msgstats[k] & SELECTED;
+			k <= mp->hghmsg && mp->msgstats[k] & SELECTED;
 			k++)
 		    continue;
 		if (--k > msgnum) {
