@@ -1,13 +1,10 @@
 
 /*
  * whatnowsbr.c -- the WhatNow shell
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
-#include "../h/nmh.h"
 #include "../h/mh.h"
 #include <signal.h>
 
@@ -18,61 +15,56 @@ static char ident[] = "$Id$";
 #endif
 
 static struct swit whatnowswitches[] = {
-#define	DFOLDSW	0
-    "draftfolder +folder", 0,
-#define	DMSGSW	1
-    "draftmessage msg", 0,
-#define	NDFLDSW	2
-    "nodraftfolder", 0,
-
-#define	EDITRSW	3
-    "editor editor", 0,
-#define	NEDITSW	4
-    "noedit", 0,
-
-#define	PRMPTSW	5
-    "prompt string", 4,
-
-#define VERSIONSW 6
-    "version", 0,
-#define	HELPSW	7
-    "help", 4,
-
-    NULL, 0
+#define	DFOLDSW                   0
+    { "draftfolder +folder", 0 },
+#define	DMSGSW                    1
+    { "draftmessage msg", 0 },
+#define	NDFLDSW                   2
+    { "nodraftfolder", 0 },
+#define	EDITRSW                   3
+    { "editor editor", 0 },
+#define	NEDITSW                   4
+    { "noedit", 0 },
+#define	PRMPTSW                   5
+    { "prompt string", 4 },
+#define VERSIONSW                 6
+    { "version", 0 },
+#define	HELPSW                    7
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 static struct swit aleqs[] = {
-#define	DISPSW	0
-    "display [<switches>]", 0,
-#define	EDITSW	1
-    "edit [<editor> <switches>]", 0,
-#define	LISTSW	2
-    "list [<switches>]", 0,
-#define	PUSHSW	3
-    "push [<switches>]", 0,
-#define	QUITSW	4
-    "quit [-delete]", 0,
-#define	REFILEOPT 5
-    "refile [<switches>] +folder", 0,
-#define	SENDSW	6
-    "send [<switches>]", 0,
-#define	WHOMSW	7
-    "whom [<switches>]", 0,
-
-    NULL, 0
+#define	DISPSW                           0
+    { "display [<switches>]", 0 },
+#define	EDITSW                           1
+    { "edit [<editor> <switches>]", 0 },
+#define	LISTSW                           2
+    { "list [<switches>]", 0 },
+#define	PUSHSW                           3
+    { "push [<switches>]", 0 },
+#define	QUITSW                           4
+    { "quit [-delete]", 0 },
+#define	REFILEOPT                        5
+    { "refile [<switches>] +folder", 0 },
+#define	SENDSW                           6
+    { "send [<switches>]", 0 },
+#define	WHOMSW                           7
+    { "whom [<switches>]", 0 },
+    { NULL, 0 }
 };
 
 static char *myprompt = "\nWhat now? ";
 
 /*
- * prototypes
+ * static prototypes
  */
 static int editfile (char **, char **, char *, int, struct msgs *, char *, char *);
 static sendfile (char **, char *, int);
 static void sendit (char *, char **, char *, int);
 static int whomfile (char **, char *);
 
-#ifdef  BSD42
+#ifdef BSD42
 static int copyf (char *, char *);
 #endif
 
@@ -84,20 +76,11 @@ static int mhnfile (char *);
 int
 WhatNow (int argc, char **argv)
 {
-    int     isdf = 0,
-	    nedit = 0,
-	    use = 0;
-    char   *cp,
-           *dfolder = NULL,
-           *dmsg = NULL,
-           *ed = NULL,
-           *drft = NULL,
-           *msgnam = NULL,
-            buf[100],
-	    prompt[BUFSIZ],
-          **ap,
-          **argp,
-           *arguments[MAXARGS];
+    int isdf = 0, nedit = 0, use = 0;
+    char *cp, *dfolder = NULL, *dmsg = NULL;
+    char *ed = NULL, *drft = NULL, *msgnam = NULL;
+    char buf[100], prompt[BUFSIZ];
+    char **ap, **argp, *arguments[MAXARGS];
     struct stat st;
 
     invo_name = r1bindex (argv[0], '/');
@@ -118,7 +101,7 @@ WhatNow (int argc, char **argv)
 		    ambigsw (cp, whatnowswitches);
 		    done (1);
 		case UNKWNSW: 
-		    adios (NULLCP, "-%s unknown", cp);
+		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] [file]", invo_name);
@@ -130,17 +113,17 @@ WhatNow (int argc, char **argv)
 
 		case DFOLDSW: 
 		    if (dfolder)
-			adios (NULLCP, "only one draft folder at a time!");
+			adios (NULL, "only one draft folder at a time!");
 		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    dfolder = path (*cp == '+' || *cp == '@' ? cp + 1 : cp,
 			    *cp != '@' ? TFOLDER : TSUBCWF);
 		    continue;
 		case DMSGSW: 
 		    if (dmsg)
-			adios (NULLCP, "only one draft message at a time!");
+			adios (NULL, "only one draft message at a time!");
 		    if (!(dmsg = *argp++) || *dmsg == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case NDFLDSW: 
 		    dfolder = NULL;
@@ -149,7 +132,7 @@ WhatNow (int argc, char **argv)
 
 		case EDITRSW: 
 		    if (!(ed = *argp++) || *ed == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    nedit = 0;
 		    continue;
 		case NEDITSW: 
@@ -158,24 +141,24 @@ WhatNow (int argc, char **argv)
 
 		case PRMPTSW:
 		    if (!(myprompt = *argp++) || *myprompt == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 	    }
 	if (drft)
-	    adios (NULLCP, "only one draft at a time!");
+	    adios (NULL, "only one draft at a time!");
 	else
 	    drft = cp;
     }
 
     if (drft == NULL && (drft = getenv ("mhdraft")) == NULL || *drft == 0)
 	drft = getcpy (m_draft (dfolder, dmsg, 1, &isdf));
-    msgnam = (cp = getenv ("mhaltmsg")) && *cp ? getcpy (cp) : NULLCP;
+    msgnam = (cp = getenv ("mhaltmsg")) && *cp ? getcpy (cp) : NULL;
     if (ed == NULL && ((ed = getenv ("mheditor")) == NULL || *ed == 0))
 	ed = NULL, nedit++;
     if ((cp = getenv ("mhuse")) && *cp)
 	use = atoi (cp);
     if (!nedit
-	    && editfile (&ed, NULLVP, drft, use, NULLMP, msgnam, NULLCP) < 0)
+	    && editfile (&ed, NULL, drft, use, NULLMP, msgnam, NULL) < 0)
 	done (1);
 
     sprintf (prompt, myprompt, invo_name);
@@ -189,13 +172,13 @@ WhatNow (int argc, char **argv)
 		if (msgnam)
 		    showfile (++argp, msgnam);
 		else
-		    advise (NULLCP, "no alternate message to display");
+		    advise (NULL, "no alternate message to display");
 		break;
 
 	    case EDITSW: 
 		if (*++argp)
 		    ed = *argp++;
-		if (editfile (&ed, argp, drft, NOUSE, NULLMP, msgnam, NULLCP)
+		if (editfile (&ed, argp, drft, NOUSE, NULLMP, msgnam, NULL)
 			== NOTOK)
 		    done (1);
 		break;
@@ -216,7 +199,7 @@ WhatNow (int argc, char **argv)
 		}
 		else
 		    if (stat (drft, &st) != NOTOK)
-			advise (NULLCP, "draft left on %s", drft);
+			advise (NULL, "draft left on %s", drft);
 		done (1);
 
 	    case PUSHSW: 
@@ -234,7 +217,7 @@ WhatNow (int argc, char **argv)
 		break;
 
 	    default: 
-		advise (NULLCP, "say what?");
+		advise (NULL, "say what?");
 		break;
 	}
     }
@@ -254,17 +237,19 @@ editfile (char **ed, char **arg, char *file, int use,
     int pid, status;
     register int vecp;
     register char *cp;
-    char altpath[BUFSIZ], linkpath[BUFSIZ], *vec[MAXARGS];
+    char altpath[BUFSIZ], linkpath[BUFSIZ];
+    char *vec[MAXARGS];
     struct stat st;
 
 #ifdef BSD42
 #ifdef	notdef
-    int     oumask;	/* PJS: for setting permissions on symlinks. */
+    int oumask;	/* PJS: for setting permissions on symlinks. */
 #endif
-    int	    slinked;
+    int	slinked;
 #endif	/* BSD42 */
 
-    if (!reedit) {		/* set initial editor */
+    /* set initial editor */
+    if (!reedit) {
 	if (*ed == NULL && (*ed = m_find ("editor")) == NULL)
 	    *ed = sysed;
     }
@@ -273,7 +258,7 @@ editfile (char **ed, char **arg, char *file, int use,
 	    *ed = edsave;
 	    if ((cp = r1bindex (*ed, '/')) == NULL)
 		cp = *ed;
-	    cp = concat (cp, "-next", NULLCP);
+	    cp = concat (cp, "-next", NULL);
 	    if ((cp = m_find (cp)) != NULL)
 		*ed = cp;
 	}
@@ -282,7 +267,7 @@ editfile (char **ed, char **arg, char *file, int use,
 	if (mp == NULL || *altmsg == '/' || cwd == NULL)
 	    strcpy (altpath, altmsg);
 	else
-	    sprintf (altpath, "%s/%s", mp -> foldpath, altmsg);
+	    sprintf (altpath, "%s/%s", mp->foldpath, altmsg);
 	if (cwd == NULL)
 	    strcpy (linkpath, LINK);
 	else
@@ -323,7 +308,7 @@ editfile (char **ed, char **arg, char *file, int use,
 		chdir (cwd);
 	    if (altmsg) {
 		if (mp)
-		    m_putenv ("mhfolder", mp -> foldpath);
+		    m_putenv ("mhfolder", mp->foldpath);
 		m_putenv ("editalt", altpath);
 	    }
 
@@ -353,11 +338,11 @@ editfile (char **ed, char **arg, char *file, int use,
 			&& (!reedit || (status & 0x00ff)))
 		    if (!use && (status & 0xff00) &&
 			    (rename (file, cp = m_backup (file)) != NOTOK)) {
-			advise (NULLCP, "problems with edit--draft left in %s",
+			advise (NULL, "problems with edit--draft left in %s",
 				cp);
 		    }
 		    else
-			advise (NULLCP, "problems with edit--%s preserved",
+			advise (NULL, "problems with edit--%s preserved",
 				file);
 		status = -2;	/* maybe "reedit ? -2 : -1"? */
 		break;
@@ -370,7 +355,7 @@ editfile (char **ed, char **arg, char *file, int use,
 #ifdef BSD42
 	    if (altmsg
 		    && mp
-		    && (!mp -> msgflags & READONLY)
+		    && (!mp->msgflags & READONLY)
 		    && (slinked
 		           ? lstat (linkpath, &st) != NOTOK
 				&& (st.st_mode & S_IFMT) == S_IFREG
@@ -383,7 +368,7 @@ editfile (char **ed, char **arg, char *file, int use,
 #else	/* not BSD42 */
 	    if (altmsg
 		    && mp
-		    && (!mp -> msgflags & READONLY)
+		    && (!mp->msgflags & READONLY)
 		    && stat (linkpath, &st) != NOTOK
 		    && st.st_nlink == 1
 		    && (unlink (altpath) == NOTOK
@@ -401,7 +386,7 @@ editfile (char **ed, char **arg, char *file, int use,
 }
 
 
-#ifdef	BSD42
+#ifdef BSD42
 static int
 copyf (char *ifile, char *ofile)
 {
@@ -432,7 +417,7 @@ copyf (char *ifile, char *ofile)
 
     return i;
 }
-#endif	/* BSD42 */
+#endif /* BSD42 */
 
 
 /* SEND */
@@ -448,8 +433,8 @@ sendfile (char **arg, char *file, int pushsw)
     if ((cp = m_find ("automhnproc"))
 	    && !getenv ("NOMHNPROC")
 	    && mhnfile (file)
-	    && (i = editfile (&cp, NULLVP, file, NOUSE, NULLMP, NULLCP,
-			      NULLCP)))
+	    && (i = editfile (&cp, NULL, file, NOUSE, NULLMP, NULL,
+			      NULL)))
 	return 0;
 #endif
 
@@ -467,7 +452,7 @@ sendfile (char **arg, char *file, int pushsw)
 	sleep (5);
     switch (child_id) {
 	case NOTOK: 
-	    advise (NULLCP, "unable to fork, so sending directly...");
+	    advise (NULL, "unable to fork, so sending directly...");
 	case OK: 
 	    vecp = 0;
 	    vec[vecp++] = invo_name;
@@ -662,20 +647,17 @@ extern char *distfile;
 static void
 sendit (char *sp, char **arg, char *file, int pushed)
 {
-#ifndef	lint
-    int	    distsw = 0;
-#endif	/* not lint */
-    int	    vecp = 1;
-    char   *cp,
-            buf[100],
-          **ap,
-          **argp,
-           *arguments[MAXARGS],
-           *vec[MAXARGS];
+    int	vecp = 1;
+    char *cp, buf[100], **ap, **argp;
+    char *arguments[MAXARGS], *vec[MAXARGS];
     struct stat st;
-#ifdef	UCI
-    FILE   *fp;
-#endif	/* UCI */
+
+#ifndef	lint
+    int	distsw = 0;
+#endif
+#ifdef UCI
+    FILE *fp;
+#endif
 
     if (arg)
 	copyip (arg, vec);
@@ -701,7 +683,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
 		    ambigsw (cp, sendswitches);
 		    return;
 		case UNKWNSW: 
-		    advise (NULLCP, "-%s unknown\n", cp);
+		    advise (NULL, "-%s unknown\n", cp);
 		    return;
 
 		case SHELPSW: 
@@ -721,7 +703,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
 
 		case SPLITSW: 
 		    if (!(cp = *argp++) || sscanf (cp, "%d", &splitsw) != 1) {
-			advise (NULLCP, "missing argument to %s", argp[-2]);
+			advise (NULL, "missing argument to %s", argp[-2]);
 			return;
 		    }
 		    continue;
@@ -776,7 +758,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
 		case SERVSW: 
 		    vec[vecp++] = --cp;
 		    if (!(cp = *argp++) || *cp == '-') {
-			advise (NULLCP, "missing argument to %s", argp[-2]);
+			advise (NULL, "missing argument to %s", argp[-2]);
 			return;
 		    }
 		    vec[vecp++] = cp;
@@ -785,13 +767,13 @@ sendit (char *sp, char **arg, char *file, int pushed)
 		case SDRFSW: 
 		case SDRMSW: 
 		    if (!(cp = *argp++) || *cp == '-') {
-			advise (NULLCP, "missing argument to %s", argp[-2]);
+			advise (NULL, "missing argument to %s", argp[-2]);
 			return;
 		    }
 		case SNDRFSW: 
 		    continue;
 	    }
-	advise (NULLCP, "usage: %s [switches]", sp);
+	advise (NULL, "usage: %s [switches]", sp);
 	return;
     }
     if (cp = m_find ("Aliasfile")) {	/* allow Aliasfile: profile entry */
