@@ -1,50 +1,34 @@
 
 /*
- * wmh.c - window front-end to mh
+ * wmh.c -- window front-end to nmh
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	lint
-
-/* TODO:
-	Pass signals to client during execution
-
-	Figure out a way for the user to say how big the Scan/Display
-	windows should be, and where all the windows should be.
+/*
+ * TODO:
+ * Pass signals to client during execution
+ *
+ * Figure out a way for the user to say how big the Scan/Display
+ * windows should be, and where all the windows should be.
  */
 
-#include <stdio.h>
-#include "../h/nmh.h"
 #include "../h/mh.h"
+#include "../h/signals.h"
 #include "../h/vmhsbr.h"
-#include <ctype.h>
 #include <errno.h>
 #include <setjmp.h>
 #include <signal.h>
 
-#ifndef	sigmask
-# define sigmask(s) (1 << ((s) - 1))
-#endif	not sigmask
-
-#include <sys/types.h>
 #include <sys/uio.h>
 #include <vt.h>
 #include <bitmap.h>
 #include <tools.h>
 
-#ifdef LOCALE
-# include <locale.h>
-#endif
-
-
-#define	ALARM	((unsigned int) 10)
-#define	PAUSE	((unsigned int) 2)
-
-#define	abs(a)	((a) > 0 ? (a) : -(a))
-
-#define	SZ(a)	(sizeof a / sizeof a[0])
+#define	ALARM ((unsigned int) 10)
+#define	PAUSE ((unsigned int) 2)
 
+#define	SZ(a) (sizeof a / sizeof a[0])
 
 static struct swit switches[] = {
 #define	PRMPTSW	0
@@ -59,14 +43,12 @@ static struct swit switches[] = {
     "help", 4,
     NULL, NULL
 };
-
 					/* PEERS */
 static int  PEERpid = NOTOK;
 
 static  jmp_buf PEERctx;
 
 
-
 					/* WINDOWS */
 static int dfd = NOTOK;
 
@@ -74,7 +56,6 @@ static int twd = NOTOK;
 
 static char *myprompt = "(%s) ";
 
-
 struct line {
     int     l_no;
     char   *l_buf;
@@ -82,7 +63,6 @@ struct line {
     struct line *l_next;
 };
 
-
 typedef struct {
     int	    w_fd;
 
@@ -121,54 +101,50 @@ static  WINDOW *Status;
 static  WINDOW *Display;
 static  WINDOW *Command;
 
-
-#define	NWIN	4
+#define	NWIN 4
 static	int numwins;
 WINDOW *windows[NWIN + 1];
 
-
 WINDOW *WINnew ();
 
 
-					/* SIGNALS */
-#define	ERASE	sg.sg_erase
-#define	KILL	sg.sg_kill
-static struct sgttyb    sg;
-
-#define	EOFC	tc.t_eofc
-#define	INTR	tc.t_intrc
-static struct tchars    tc;
+#ifdef HAVE_TERMIOS_H
+static struct termios tio;
+# define ERASE tio.c_cc[VERASE]
+# define KILL  tio.c_cc[VKILL]
+# define INTR  tio.c_cc[VINTR]
+#else
+# ifdef HAVE_TERMIO_H
+static struct termio tio;
+#  define ERASE tio.c_cc[VERASE]
+#  define KILL  tio.c_cc[VKILL]
+#  define INTR  tio.c_cc[VINTR]
+# else
+static struct sgttyb tio;
+static struct tchars tc;
+#define	ERASE tio.sg_erase
+#define	KILL  tio.sg_kill
+#define	INTR  tc.t_intrc
+#define	EOFC  tc.t_eofc
+# endif
+#endif
 
 #define	WERASC	ltc.t_werasc
 static struct ltchars ltc;
 
+int ALRMser (), PIPEser (), SIGser ();
+int ADJser (), REFser ();
 
-int     ALRMser (), PIPEser (), SIGser ();
-int	ADJser (), REFser ();
-
-
-					/* MISCELLANY */
 extern int  errno;
-#ifndef	BSD44
-extern int  sys_nerr;
-extern char *sys_errlist[];
-#endif
 
 void adorn();
 
 
-/* ARGSUSED */
-
 main (int argc, char **argv)
 {
-    int     vecp = 1,
-	    nprog = 0;
-    char   *cp,
-            buffer[BUFSIZ],
-          **ap,
-          **argp,
-           *arguments[MAXARGS],
-           *vec[MAXARGS];
+    int vecp = 1, nprog = 0;
+    char *cp, buffer[BUFSIZ], **ap, **argp;
+    char *arguments[MAXARGS], *vec[MAXARGS];
 
 #ifdef LOCALE
 	setlocale(LC_ALL, "");
@@ -203,12 +179,12 @@ main (int argc, char **argv)
 
 		case PRMPTSW:
 		    if (!(myprompt = *argp++) || *myprompt == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 
 		case PROGSW: 
 		    if (!(vmhproc = *argp++) || *vmhproc == '-')
-			adios (NULLCP, "missing argument to %s", argp[-2]);
+			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case NPROGSW:
 		    nprog++;
@@ -233,12 +209,13 @@ main (int argc, char **argv)
 }
 
 
-static  vmh () {
-    char    buffer[BUFSIZ],
-            prompt[BUFSIZ];
+static void
+vmh (void)
+{
+    char buffer[BUFSIZ], prompt[BUFSIZ];
 
     for (;;) {
-	pLOOP (RC_QRY, NULLCP);
+	pLOOP (RC_QRY, NULL);
 
 	sprintf (prompt, myprompt, invo_name);
 
@@ -259,14 +236,11 @@ static  vmh () {
 
 /* PEERS */
 
-static int  PEERinit (vecp, vec)
-int	vecp;
-char   *vec[];
+static int
+PEERinit (int vecp, char *vec[])
 {
-    int	    pfd0[2],
-            pfd1[2];
-    char    buf1[BUFSIZ],
-            buf2[BUFSIZ];
+    int	pfd0[2], pfd1[2];
+    char buf1[BUFSIZ], buf2[BUFSIZ];
     register WINDOW **w;
 
     signal (SIGPIPE, PIPEser);
@@ -279,8 +253,8 @@ char   *vec[];
 
 	case OK: 
 	    for (w = windows; *w; w++)
-		if ((*w) -> w_fd != NOTOK)
-		    close ((*w) -> w_fd);
+		if ((*w)->w_fd != NOTOK)
+		    close ((*w)->w_fd);
 	    close (pfd0[0]);
 	    close (pfd1[1]);
 
@@ -311,20 +285,22 @@ char   *vec[];
 }
 
 
-static int  pINI () {
-    register char  *bp;
-    char    buffer[BUFSIZ];
-    struct record   rcs;
-    register struct record *rc = &rcs;
-    register WINDOW **w;
+static int
+pINI (void)
+{
+    register char *bp;
+    char buffer[BUFSIZ];
+    struct record rcs, *rc;
+    WINDOW **w;
 
+    rc = &rcs;
     initrc (rc);
 
     bp = buffer;
     sprintf (bp, "%d %d", RC_VRSN, numwins);
     bp += strlen (bp);
     for (w = windows; *w; w++) {
-	sprintf (bp, " %d", (*w) -> w_height);
+	sprintf (bp, " %d", (*w)->w_height);
 	bp += strlen (bp);
     }
 
@@ -333,30 +309,29 @@ static int  pINI () {
 	    return OK;
 
 	case RC_ERR: 
-	    if (rc -> rc_len)
-		adios (NULLCP, "%s", rc -> rc_data);
+	    if (rc->rc_len)
+		adios (NULL, "%s", rc->rc_data);
 	    else
-		adios (NULLCP, "pINI peer error");
+		adios (NULL, "pINI peer error");
 
 	case RC_XXX: 
-	    adios (NULLCP, "%s", rc -> rc_data);
+	    adios (NULL, "%s", rc->rc_data);
 
 	default:
-	    adios (NULLCP, "pINI protocol screw-up");
+	    adios (NULL, "pINI protocol screw-up");
     }
 /* NOTREACHED */
 }
 
 
-static int  pLOOP (code, str)
-char	code,
-       *str;
+static int
+pLOOP (char code, char *str)
 {
-    int	    i;
-    struct record   rcs;
-    register struct record *rc = &rcs;
+    int	i;
+    struct record rcs, *rc;
     WINDOW *w;
 
+    rc = &rcs;
     initrc (rc);
 
     str2peer (code, str);
@@ -368,14 +343,14 @@ char	code,
 		break;
 
 	    case RC_WIN:
-		if (sscanf (rc -> rc_data, "%d", &i) != 1
+		if (sscanf (rc->rc_data, "%d", &i) != 1
 			|| i <= 0
 			|| i > numwins) {
-		    fmt2peer (RC_ERR, "no such window \"%s\"", rc -> rc_data);
+		    fmt2peer (RC_ERR, "no such window \"%s\"", rc->rc_data);
 		    return NOTOK;
 		}
-		if ((w = windows[i - 1]) -> w_flags & W_CMND) {
-		    fmt2peer (RC_ERR, "not a display window \"%s\"", rc -> rc_data);
+		if ((w = windows[i - 1])->w_flags & W_CMND) {
+		    fmt2peer (RC_ERR, "not a display window \"%s\"", rc->rc_data);
 		    return NOTOK;
 		}
 		if (pWIN (w) == NOTOK)
@@ -386,36 +361,38 @@ char	code,
 		return OK;
 
 	    case RC_ERR:
-		if (rc -> rc_len)
-		    adorn (NULLCP, "%s", rc -> rc_data);
+		if (rc->rc_len)
+		    adorn (NULL, "%s", rc->rc_data);
 		else
-		    adorn (NULLCP, "pLOOP(%s) peer error",
+		    adorn (NULL, "pLOOP(%s) peer error",
 			    code == RC_QRY ? "QRY" : "CMD");
 		return NOTOK;
 
 	    case RC_FIN:
-		if (rc -> rc_len)
-		    adorn (NULLCP, "%s", rc -> rc_data);
+		if (rc->rc_len)
+		    adorn (NULL, "%s", rc->rc_data);
 		rcdone ();
 		i = pidwait (PEERpid, OK);
 		PEERpid = NOTOK;
 		done (i);
 
 	    case RC_XXX: 
-		adios (NULLCP, "%s", rc -> rc_data);
+		adios (NULL, "%s", rc->rc_data);
 
 	    default:
-		adios (NULLCP, "pLOOP(%s) protocol screw-up",
+		adios (NULL, "pLOOP(%s) protocol screw-up",
 			code == RC_QRY ? "QRY" : "CMD");
 	}
 }
 
 
-static int  pTTY () {
-    RETSIGTYPE     (*hstat) (), (*istat) (), (*qstat) (), (*tstat) ();
-    struct record   rcs;
-    register struct record *rc = &rcs;
+static int
+pTTY (void)
+{
+    SIGNAL_HANDLER hstat, istat, qstat, tstat;
+    struct record rcs, *rc;
 
+    rc = &rcs;
     initrc (rc);
 
     if (ChangeWindowDepth (dfd, twd, 0) == NOTOK)
@@ -426,39 +403,39 @@ static int  pTTY () {
     qstat = signal (SIGQUIT, SIG_IGN);
     tstat = signal (SIGTERM, SIG_IGN);
 
-    rc2rc (RC_ACK, 0, NULLCP, rc);
+    rc2rc (RC_ACK, 0, NULL, rc);
 
     signal (SIGHUP, hstat);
     signal (SIGINT, istat);
     signal (SIGQUIT, qstat);
     signal (SIGTERM, tstat);
 
-    switch (rc -> rc_type) {
+    switch (rc->rc_type) {
 	case RC_EOF: 
-	    rc2peer (RC_ACK, 0, NULLCP);
+	    rc2peer (RC_ACK, 0, NULL);
 	    return OK;
 
 	case RC_ERR: 
-	    if (rc -> rc_len)
-		adorn (NULLCP, "%s", rc -> rc_data);
+	    if (rc->rc_len)
+		adorn (NULL, "%s", rc->rc_data);
 	    else
-		adorn (NULLCP, "pTTY peer error");
+		adorn (NULL, "pTTY peer error");
 	    return NOTOK;
 
 	case RC_XXX: 
-	    adios (NULLCP, "%s", rc -> rc_data);
+	    adios (NULL, "%s", rc->rc_data);
 
 	default:
-	    adios (NULLCP, "pTTY protocol screw-up");
+	    adios (NULL, "pTTY protocol screw-up");
     }
 /* NOTREACHED */
 }
 
 
-static int  pWIN (w)
-register WINDOW *w;
+static int
+pWIN (WINDOW *w)
 {
-    int     i;
+    int i;
 
     if ((i = pWINaux (w)) == OK)
 	WINless (w);
@@ -467,63 +444,64 @@ register WINDOW *w;
 }
 
 
-static int  pWINaux (w)
-register WINDOW *w;
+static int
+pWINaux (WINDOW *w)
 {
-    register int    n;
-    register char  *bp;
-    register struct line   *lp,
-                           *mp;
-    struct record   rcs;
-    register struct record *rc = &rcs;
+    register int n;
+    register char *bp;
+    register struct line *lp, *mp;
+    struct record rcs, *rc;
 
+    rc = &rcs;
     initrc (rc);
 
-    for (lp = w -> w_head; lp; lp = mp) {
-	mp = lp -> l_next;
-	free (lp -> l_buf);
+    for (lp = w->w_head; lp; lp = mp) {
+	mp = lp->l_next;
+	free (lp->l_buf);
 	free ((char *) lp);
     }
-    w -> w_head = w -> w_top = w -> w_bottom = w -> w_tail = NULL;
-    w -> w_bufpos = 0;
+    w->w_head = w->w_top = w->w_bottom = w->w_tail = NULL;
+    w->w_bufpos = 0;
 
     for (;;)
-	switch (rc2rc (RC_ACK, 0, NULLCP, rc)) {
+	switch (rc2rc (RC_ACK, 0, NULL, rc)) {
 	    case RC_DATA: 
-		for (bp = rc -> rc_data, n = rc -> rc_len; n-- > 0; )
+		for (bp = rc->rc_data, n = rc->rc_len; n-- > 0; )
 		    WINputc (w, *bp++);
 		break;
 
 	    case RC_EOF: 
-		rc2peer (RC_ACK, 0, NULLCP);
-		if (w -> w_bufpos)
+		rc2peer (RC_ACK, 0, NULL);
+		if (w->w_bufpos)
 		    WINputc (w, '\n');
 		return OK;
 
 	    case RC_ERR: 
-		if (rc -> rc_len)
-		    adorn (NULLCP, "%s", rc -> rc_data);
+		if (rc->rc_len)
+		    adorn (NULL, "%s", rc->rc_data);
 		else
-		    adorn (NULLCP, "pWIN peer error");
+		    adorn (NULL, "pWIN peer error");
 		return NOTOK;
 
 	    case RC_XXX: 
-		adios (NULLCP, "%s", rc -> rc_data);
+		adios (NULL, "%s", rc->rc_data);
 
 	    default:
-		adios (NULLCP, "pWIN protocol screw-up");
+		adios (NULL, "pWIN protocol screw-up");
 	}
 /* NOTREACHED */
 }
 
 
-static int  pFIN () {
-    int     status;
+static int
+pFIN (void)
+{
+    int status;
 
     if (PEERpid <= OK)
 	return OK;
 
-    rc2peer (RC_FIN, 0, NULLCP);
+    rc2peer (RC_FIN, 0, NULL);
     rcdone ();
 
     switch (setjmp (PEERctx)) {
@@ -563,18 +541,15 @@ static int  pFIN () {
 #define	ESLOP	5		/*   .. slop */
 
 
-static int  WINinit (nprog) {
-    short   wx,
-            wy,
-            wh,
-	    sy;
-    struct gconfig   gc;
+static intWINinit (nprog) {
+    short wx, wy, wh, sy;
+    struct gconfig gc;
 
     if (GetGraphicsConfig (fileno (stderr), &gc) == NOTOK)
 	if (nprog)
 	    return NOTOK;
 	else
-	    adios (NULLCP, "not a window");
+	    adios (NULL, "not a window");
 
     if ((dfd = open ("/dev/ttyw0", 2)) == NOTOK)
 	adios ("/dev/ttyw0", "unable to open");
@@ -603,72 +578,67 @@ static int  WINinit (nprog) {
 }
 
 
-WINDOW *WINnew (wx, wy, ww, wh, name, flags)
-short	wx,
-	wy,
-	ww,
-	wh;
-char   *name;
-int	flags;
+WINDOW *
+WINnew (short wx, short wy, short ww, short wh, char *name, int flags)
 {
     register WINDOW *w;
 
     if ((w = (WINDOW *) calloc (1, sizeof *w)) == NULL)
-	adios (NULLCP, "unable to allocate window");
+	adios (NULL, "unable to allocate window");
 
-    if ((w -> w_flags = flags) & W_FAKE) {
-	w -> w_fd = NOTOK;
-	w -> w_height = 1;
+    if ((w->w_flags = flags) & W_FAKE) {
+	w->w_fd = NOTOK;
+	w->w_height = 1;
 
 	goto out;
     }
 
-    if (w -> w_flags & W_EBAR)
+    if (w->w_flags & W_EBAR)
 	ww += EWIDTH + ESLOP;
     else
 	wx += EWIDTH + ESLOP;
 
-    if ((w -> w_fd = OpenWindow (wx, wy, ww, wh, name)) == NOTOK)
+    if ((w->w_fd = OpenWindow (wx, wy, ww, wh, name)) == NOTOK)
 	adios ("failed", "OpenWindow");
-    if ((w -> w_wd = GetTopWindow (dfd)) == NOTOK)
+    if ((w->w_wd = GetTopWindow (dfd)) == NOTOK)
 	adios ("failed", "GetTopWindow");
-    if (GetWindowState (w -> w_fd, &w -> w_ws) == NOTOK)
+    if (GetWindowState (w->w_fd, &w->w_ws) == NOTOK)
 	adios ("failed", "GetWindowState");
-    if (SetLineDisc (w -> w_fd, TWSDISC) == NOTOK)
+    if (SetLineDisc (w->w_fd, TWSDISC) == NOTOK)
 	adios ("failed", "SetLineDisc");
 
-    SetBuf (w -> w_fd, 1024);
-    SetAdjust (w -> w_fd, numwins, ADJser);
-    SetRefresh (w -> w_fd, numwins, REFser);
+    SetBuf (w->w_fd, 1024);
+    SetAdjust (w->w_fd, numwins, ADJser);
+    SetRefresh (w->w_fd, numwins, REFser);
 
-    SetAddressing (w -> w_fd, VT_ABSOLUTE);
+    SetAddressing (w->w_fd, VT_ABSOLUTE);
 
-    if (w -> w_flags & W_EBAR) {
-	w -> w_eb = CreateElevatorBar (w -> w_fd, 0, 0, EWIDTH,
-			w -> w_ws.height, VT_Gray50, 1, EB_VERTICAL,
-			EB_ARROWS, w -> w_ebloc = 0, w -> w_ebsize = EB_MAX,
+    if (w->w_flags & W_EBAR) {
+	w->w_eb = CreateElevatorBar (w->w_fd, 0, 0, EWIDTH,
+			w->w_ws.height, VT_Gray50, 1, EB_VERTICAL,
+			EB_ARROWS, w->w_ebloc = 0, w->w_ebsize = EB_MAX,
 			VT_White);
-	if (w -> w_eb == NULL)
-	    adios (NULLCP, "CreateElevatorBar failed");
-	RefreshElevatorBar (w -> w_eb);
+	if (w->w_eb == NULL)
+	    adios (NULL, "CreateElevatorBar failed");
+	RefreshElevatorBar (w->w_eb);
     }
 
-    if ((w -> w_cbase = CharacterBaseline (w -> w_ws.font)) <= 0)
-	w -> w_cbase = 14;
+    if ((w->w_cbase = CharacterBaseline (w->w_ws.font)) <= 0)
+	w->w_cbase = 14;
 
-    if ((w -> w_cheight = CharacterHeight (w -> w_ws.font)) <= 0)
-	w -> w_cheight = 20;
-    w -> w_height = w -> w_ws.height / w -> w_cheight;
-    if (w -> w_height < 1)
-	w -> w_height = 1;
+    if ((w->w_cheight = CharacterHeight (w->w_ws.font)) <= 0)
+	w->w_cheight = 20;
+    w->w_height = w->w_ws.height / w->w_cheight;
+    if (w->w_height < 1)
+	w->w_height = 1;
 
 						/* 1 em */
-    if ((w -> w_cwidth = CharacterWidth (w -> w_ws.font, 'm')) <= 0)
-	w -> w_cwidth = 10;
-    w -> w_width = (w -> w_ws.width - (w -> w_eb ? (EWIDTH + ESLOP) : 0))
-		    / w -> w_cwidth;
-    if (w -> w_width < 1)
-	w -> w_width = 1;
+    if ((w->w_cwidth = CharacterWidth (w->w_ws.font, 'm')) <= 0)
+	w->w_cwidth = 10;
+    w->w_width = (w->w_ws.width - (w->w_eb ? (EWIDTH + ESLOP) : 0))
+		    / w->w_cwidth;
+    if (w->w_width < 1)
+	w->w_width = 1;
 
 out: ;
     windows[numwins++] = w;
@@ -677,29 +647,26 @@ out: ;
 }
 
 
-static int  WINgetstr (w, prompt, buffer)
-register WINDOW *w;
-char   *prompt,
-       *buffer;
+static int
+WINgetstr (WINDOW *w, char *prompt, char *buffer)
 {
-    register int    c;
-    register char  *bp,
-                   *ip;
-    char    image[BUFSIZ];
-    struct vtseq    vts;
+    register int c;
+    register char *bp, *ip;
+    char image[BUFSIZ];
+    struct vtseq vts;
     register struct vtseq  *vt = &vts;
 
-    if (w -> w_eb != NULL)
-	adios (NULLCP, "internal error--elevator bar found");
+    if (w->w_eb != NULL)
+	adios (NULL, "internal error--elevator bar found");
 
-    if (w -> w_head == NULL
-	    && (w -> w_head = (struct line *) calloc (1, sizeof *w -> w_head))
+    if (w->w_head == NULL
+	    && (w->w_head = (struct line *) calloc (1, sizeof *w->w_head))
 		== NULL)
-	adios (NULLCP, "unable to allocate line storage");
-    w -> w_head -> l_buf = image;
-    w -> w_top = w -> w_bottom = w -> w_tail = w -> w_head;
+	adios (NULL, "unable to allocate line storage");
+    w->w_head->l_buf = image;
+    w->w_top = w->w_bottom = w->w_tail = w->w_head;
 
-    if (ChangeWindowDepth (dfd, w -> w_wd, 0) == NOTOK)
+    if (ChangeWindowDepth (dfd, w->w_wd, 0) == NOTOK)
 	adios ("failed", "ChangeWindowDepth");
 
     strcpy (image, prompt);
@@ -708,13 +675,13 @@ char   *prompt,
     Redisplay (w, 0);
 
     for (;;)
-	switch (getvtseq (w -> w_fd, vt)) {
+	switch (getvtseq (w->w_fd, vt)) {
 	    case VT_HARDKEY: 
-		DisplayStatus (w -> w_fd, "no hardkeys, please");
+		DisplayStatus (w->w_fd, "no hardkeys, please");
 		break;
 
 	    case VT_ASCII: 
-		switch (c = toascii (vt -> u.ascii)) {
+		switch (c = toascii (vt->u.ascii)) {
 		    case '\f': 	/* refresh? */
 			break;
 
@@ -725,7 +692,7 @@ char   *prompt,
 
 		    default: 
 			if (c == INTR) {
-			    adorn (NULLCP, "Interrupt");
+			    adorn (NULL, "Interrupt");
 			    return NOTOK;
 			}
 
@@ -775,17 +742,17 @@ char   *prompt,
 		break;
 
 	    case VT_MOUSE: 
-		switch (vt -> u.mouse.buttons
+		switch (vt->u.mouse.buttons
 			& (VT_MOUSE_LEFT | VT_MOUSE_MIDDLE | VT_MOUSE_RIGHT)) {
 		    case VT_MOUSE_LEFT: 
-			DisplayStatus (w -> w_fd, "use middle or right button");
+			DisplayStatus (w->w_fd, "use middle or right button");
 			break;
 
 #define	WPOP	"WMH\0Advance\0Burst\0Exit\0EOF\0"
 		    case VT_MOUSE_MIDDLE: 
-			SetPosition (w -> w_fd, vt -> u.mouse.x,
-				vt -> u.mouse.y);
-			switch (DisplayPopUp (w -> w_fd, WPOP)) {
+			SetPosition (w->w_fd, vt->u.mouse.x,
+				vt->u.mouse.y);
+			switch (DisplayPopUp (w->w_fd, WPOP)) {
 			    case 1: /* Advance */
 			do_advance: ;
 				strcpy (buffer, "advance");
@@ -814,22 +781,21 @@ char   *prompt,
 		break;
 
 	    case VT_EOF: 
-		adios (NULLCP, "end-of-file on window");/* NOTREACHED */
+		adios (NULL, "end-of-file on window");/* NOTREACHED */
 
 	    default: 
-		DisplayStatus (w -> w_fd, "unknown VT sequence");
+		DisplayStatus (w->w_fd, "unknown VT sequence");
 		break;
 	}
 }
 
 
-static int  WINputc (w, c)
-register WINDOW *w;
-register char c;
+static int
+WINputc (WINDOW *w, char c)
 {
     register int i;
-    register char  *cp;
-    register struct line   *lp;
+    register char *cp;
+    register struct line *lp;
 
     switch (c) {
 	default: 
@@ -847,14 +813,14 @@ register char c;
 	    break;
 
 	case '\t': 
-	    for (i = 8 - (w -> w_bufpos & 0x07); i > 0; i--)
+	    for (i = 8 - (w->w_bufpos & 0x07); i > 0; i--)
 		if (WINputc (w, ' ') == NOTOK)
 		    return NOTOK;
 	    return OK;
 
 	case '\b':
-	    if (w -> w_bufpos > 0)
-		w -> w_bufpos--;
+	    if (w->w_bufpos > 0)
+		w->w_bufpos--;
 	    return OK;
 
 	case '\n': 
@@ -862,34 +828,34 @@ register char c;
     }
 
     if (c != '\n') {
-	w -> w_buffer[w -> w_bufpos++] = c;
+	w->w_buffer[w->w_bufpos++] = c;
 	return OK;
     }
 
-    w -> w_buffer[w -> w_bufpos] = NULL;
-    w -> w_bufpos = 0;
+    w->w_buffer[w->w_bufpos] = NULL;
+    w->w_bufpos = 0;
 
     if ((lp = (struct line *) calloc (1, sizeof *lp)) == NULL)
-	adios (NULLCP, "unable to allocate line storage");
+	adios (NULL, "unable to allocate line storage");
 
-    lp -> l_no = (w -> w_tail ? w -> w_tail -> l_no : 0) + 1;
-    lp -> l_buf = getcpy (w -> w_buffer);
-    for (cp = lp -> l_buf + strlen (lp -> l_buf) - 1; cp >= lp -> l_buf; cp--)
+    lp->l_no = (w->w_tail ? w->w_tail->l_no : 0) + 1;
+    lp->l_buf = getcpy (w->w_buffer);
+    for (cp = lp->l_buf + strlen (lp->l_buf) - 1; cp >= lp->l_buf; cp--)
 	if (isspace (*cp))
 	    *cp = NULL;
 	else
 	    break;
 
-    if (w -> w_head == NULL)
-	w -> w_head = lp;
-    if (w -> w_top == NULL)
-	w -> w_top = lp;
-    if (w -> w_bottom == NULL)
-	w -> w_bottom = lp;
-    if (w -> w_tail)
-	w -> w_tail -> l_next = lp;
-    lp -> l_prev = w -> w_tail;
-    w -> w_tail = lp;
+    if (w->w_head == NULL)
+	w->w_head = lp;
+    if (w->w_top == NULL)
+	w->w_top = lp;
+    if (w->w_bottom == NULL)
+	w->w_bottom = lp;
+    if (w->w_tail)
+	w->w_tail->l_next = lp;
+    lp->l_prev = w->w_tail;
+    w->w_tail = lp;
 
     return DONE;
 }
@@ -913,39 +879,36 @@ static struct menu mymenu = { "Goto", SZ (myquestions), myquestions };
 static int *myanswers[] = { (int *) mylineno, (int *) cancel };
 
 
-static	WINless (w)
-register WINDOW *w;
+static void
+WINless (WINDOW *w)
 {
-    int     clear,
-	    pos,
-            forw,
-	    refresh;
-    struct vtseq    vts;
-    register struct vtseq  *vt = &vts;
+    int clear, pos, forw, refresh;
+    struct vtseq vts;
+    register struct vtseq *vt = &vts;
 
-    if (w -> w_fd == NOTOK) {
-	if (w -> w_head)
-	    DisplayStatus (dfd, w -> w_top -> l_buf);
+    if (w->w_fd == NOTOK) {
+	if (w->w_head)
+	    DisplayStatus (dfd, w->w_top->l_buf);
 	else
 	    RemoveStatus (dfd);
 
 	return;
     }
 
-    if (ChangeWindowDepth (dfd, w -> w_wd, 0) == NOTOK)
+    if (ChangeWindowDepth (dfd, w->w_wd, 0) == NOTOK)
 	adios ("failed", "ChangeWindowDepth");
 
     Redisplay (w, 0);
 
-    if (w -> w_bottom == w -> w_tail)
+    if (w->w_bottom == w->w_tail)
 	return;
 
-    if (w -> w_eb == NULL)
-	adios (NULLCP, "internal error--no elevator bar");
+    if (w->w_eb == NULL)
+	adios (NULL, "internal error--no elevator bar");
 
     for (clear = refresh = 0, forw = 1;;) {
 	if (clear) {
-	    RemoveStatus (w -> w_fd);
+	    RemoveStatus (w->w_fd);
 	    clear = 0;
 	}
 	if (refresh) {
@@ -953,78 +916,78 @@ register WINDOW *w;
 	    refresh = 0;
 	}
 
-	switch (getvtseq (w -> w_fd, vt)) {
+	switch (getvtseq (w->w_fd, vt)) {
 	    case VT_HARDKEY: 
 	    case VT_ASCII: 
-		DisplayStatus (w -> w_fd, "use the mouse");
+		DisplayStatus (w->w_fd, "use the mouse");
 		clear++;
 		break;
 
 	    case VT_MOUSE: 
-		switch (vt -> u.mouse.buttons
+		switch (vt->u.mouse.buttons
 			& (VT_MOUSE_LEFT | VT_MOUSE_MIDDLE | VT_MOUSE_RIGHT)) {
 		    case VT_MOUSE_LEFT: 
-			if ((pos = vt -> u.mouse.x) < EWIDTH) {
-			    pos = w -> w_ebloc = DoElevatorBar (w -> w_eb, pos,
-				    vt -> u.mouse.y);
-			    refresh = WINgoto (w, ((pos * (w -> w_tail -> l_no
-						- w -> w_head -> l_no))
-					/ EB_MAX) + w -> w_head -> l_no);
+			if ((pos = vt->u.mouse.x) < EWIDTH) {
+			    pos = w->w_ebloc = DoElevatorBar (w->w_eb, pos,
+				    vt->u.mouse.y);
+			    refresh = WINgoto (w, ((pos * (w->w_tail->l_no
+						- w->w_head->l_no))
+					/ EB_MAX) + w->w_head->l_no);
 			}
 			break;
 
 #define	WPOP "Paging\0Next\0Prev\0Left\0Right\0First\0Last\0Goto ...\0Exit\0"
 		    case VT_MOUSE_MIDDLE: 
-			SetPosition (w -> w_fd, vt -> u.mouse.x,
-				vt -> u.mouse.y);
-			switch (DisplayPopUp (w -> w_fd, WPOP)) {
+			SetPosition (w->w_fd, vt->u.mouse.x,
+				vt->u.mouse.y);
+			switch (DisplayPopUp (w->w_fd, WPOP)) {
 			    case 1: /* Next */
 			do_next_page: ;
-				if (w -> w_bottom == w -> w_tail)
+				if (w->w_bottom == w->w_tail)
 				    forw = 0;
-				refresh = WINgoto (w, w -> w_bottom -> l_no + 1 - PSLOP);
+				refresh = WINgoto (w, w->w_bottom->l_no + 1 - PSLOP);
 				break;
 
 			    case 2: /* Prev */
 			do_prev_page: ;
-				if (w -> w_top == w -> w_head)
+				if (w->w_top == w->w_head)
 				    forw = 1;
-				refresh = WINgoto (w, w -> w_top -> l_no
-					- w -> w_height + PSLOP);
+				refresh = WINgoto (w, w->w_top->l_no
+					- w->w_height + PSLOP);
 				break;
 
 			    case 3: /* Left */
 			    case 4: /* Right */
-				DisplayStatus (w -> w_fd, "not yet");
+				DisplayStatus (w->w_fd, "not yet");
 				clear++;
 				break;
 
 			    case 5: /* First */
 				forw = 1;
-				refresh = WINgoto (w, w -> w_head -> l_no);
+				refresh = WINgoto (w, w->w_head->l_no);
 				break;
 
 			    case 6: /* Last */
 				forw = 0;
-				refresh = WINgoto (w, w -> w_tail -> l_no
-					- w -> w_height + 1);
+				refresh = WINgoto (w, w->w_tail->l_no
+					- w->w_height + 1);
 				break;
 
 			    case 7: /* Goto ... */
 				sprintf (mylineno, "%d",
-					w -> w_top -> l_no);
+					w->w_top->l_no);
 				cancel[0] = 0;
 				if (PresentMenu (&mymenu, myanswers)
 					|| cancel[0])
 				    break;
 				if (sscanf (mylineno, "%d", &pos) != 1) {
-				    DisplayStatus (w -> w_fd, "bad format");
+				    DisplayStatus (w->w_fd, "bad format");
 				    clear++;
 				    break;
 				}
-				if (pos < w -> w_head -> l_no
-					|| pos > w -> w_tail -> l_no) {
-				    DisplayStatus (w -> w_fd, "no such line");
+				if (pos < w->w_head->l_no
+					|| pos > w->w_tail->l_no) {
+				    DisplayStatus (w->w_fd, "no such line");
 				    clear++;
 				    break;
 				}
@@ -1042,7 +1005,7 @@ register WINDOW *w;
 
 		    case VT_MOUSE_RIGHT: 
 			if (forw) {
-			    if (w -> w_bottom == w -> w_tail)
+			    if (w->w_bottom == w->w_tail)
 				return;
 			    else
 				goto do_next_page;
@@ -1053,10 +1016,10 @@ register WINDOW *w;
 		break;
 
 	    case VT_EOF: 
-		adios (NULLCP, "end-of-file on window");/* NOTREACHED */
+		adios (NULL, "end-of-file on window");/* NOTREACHED */
 
 	    default: 
-		DisplayStatus (w -> w_fd, "unknown VT sequence");
+		DisplayStatus (w->w_fd, "unknown VT sequence");
 		clear++;
 		break;
 	}
@@ -1064,192 +1027,180 @@ register WINDOW *w;
 }
 
 
-static int  WINgoto (w, n)
-register WINDOW *w;
-register int	n;
+static int
+WINgoto (WINDOW *w, int n)
 {
-    register int    i,
-                    j;
-    register struct line   *lp;
+    register int i, j;
+    register struct line *lp;
 
-    if (n > (i = w -> w_tail -> l_no - w -> w_height + 1))
+    if (n > (i = w->w_tail->l_no - w->w_height + 1))
 	n = i;
-    if (n < w -> w_head -> l_no)
-	n = w -> w_head -> l_no;
+    if (n < w->w_head->l_no)
+	n = w->w_head->l_no;
 
-    if ((i = n - (lp = w -> w_head) -> l_no)
-	    > (j = abs (n - w -> w_top -> l_no)))
-	i = j, lp = w -> w_top;
+    if ((i = n - (lp = w->w_head)->l_no)
+	    > (j = abs (n - w->w_top->l_no)))
+	i = j, lp = w->w_top;
 
-    if (i > (j = abs (w -> w_tail -> l_no - n)))
-	i = j, lp = w -> w_tail;
+    if (i > (j = abs (w->w_tail->l_no - n)))
+	i = j, lp = w->w_tail;
 
-    if (n >= lp -> l_no) {
-	for (; lp; lp = lp -> l_next)
-	    if (lp -> l_no == n)
+    if (n >= lp->l_no) {
+	for (; lp; lp = lp->l_next)
+	    if (lp->l_no == n)
 		break;
     }
     else {
-	for (; lp; lp = lp -> l_prev)
-	    if (lp -> l_no == n)
+	for (; lp; lp = lp->l_prev)
+	    if (lp->l_no == n)
 		break;
 	if (!lp)
-	    lp = w -> w_head;
+	    lp = w->w_head;
     }
 
-    if (w -> w_top == lp)
+    if (w->w_top == lp)
 	return 0;
 
-    w -> w_top = lp;
+    w->w_top = lp;
 
     return 1;
 }
 
 
-static int  ADJser (id, ww, wh)
-int     id;
-short   ww,
-        wh;
+static int
+ADJser (int id, short ww, short wh)
 {
     register WINDOW *w;
 
     if (id < 0 || id >= numwins)
-	adios (NULLCP, "ADJser on bogus window (%d)", id);
+	adios (NULL, "ADJser on bogus window (%d)", id);
     w = windows[id];
-    if (w -> w_fd == NOTOK)
-	adios (NULLCP, "ADJser on closed window (%d)", id);
+    if (w->w_fd == NOTOK)
+	adios (NULL, "ADJser on closed window (%d)", id);
 
-    w -> w_ws.width = w -> w_ws.tw = ww;
-    w -> w_ws.height = w -> w_ws.th = wh;
+    w->w_ws.width = w->w_ws.tw = ww;
+    w->w_ws.height = w->w_ws.th = wh;
 
-    if (w -> w_eb) {
-	DeleteElevatorBar (w -> w_eb);
-	w -> w_eb = CreateElevatorBar (w -> w_fd, 0, 0, EWIDTH,
-			w -> w_ws.height, VT_Gray50, 1, EB_VERTICAL,
-			EB_ARROWS, w -> w_ebloc = 0, w -> w_ebsize = EB_MAX,
+    if (w->w_eb) {
+	DeleteElevatorBar (w->w_eb);
+	w->w_eb = CreateElevatorBar (w->w_fd, 0, 0, EWIDTH,
+			w->w_ws.height, VT_Gray50, 1, EB_VERTICAL,
+			EB_ARROWS, w->w_ebloc = 0, w->w_ebsize = EB_MAX,
 			VT_White);
-	if (w -> w_eb == NULL)
-	    adios (NULLCP, "CreateElevatorBar failed");
+	if (w->w_eb == NULL)
+	    adios (NULL, "CreateElevatorBar failed");
     }
 
     Redisplay (w, 1);
 }
 
 
-/* ARGSUSED */
-
-static int  REFser (id, wx, wy, ww, wh)
-int     id;
-short   wx,
-        wy,
-        ww,
-        wh;
+static int
+REFser (int id, short wx, short wy, short ww, short wh)
 {
-    short   cx,
-            cy,
-            cw,
-            ch;
+    short cx, cy, cw, ch;
     register WINDOW *w;
 
     if (id < 0 || id >= numwins)
-	adios (NULLCP, "REFser on bogus window (%d)", id);
+	adios (NULL, "REFser on bogus window (%d)", id);
     w = windows[id];
-    if (w -> w_fd == NOTOK)
-	adios (NULLCP, "REFser on closed window (%d)", id);
+    if (w->w_fd == NOTOK)
+	adios (NULL, "REFser on closed window (%d)", id);
 
 
-    if (GetWindowState (w -> w_fd, &w -> w_ws) == NOTOK)
+    if (GetWindowState (w->w_fd, &w->w_ws) == NOTOK)
 	adios ("failed", "GetWindowState");
 
-    GetPermanentClipping (w -> w_fd, &cx, &cy, &cw, &ch);
-    SetPermanentClipping (w -> w_fd, wx, wy, ww, wh);
+    GetPermanentClipping (w->w_fd, &cx, &cy, &cw, &ch);
+    SetPermanentClipping (w->w_fd, wx, wy, ww, wh);
     Redisplay (w, 1);
-    SetPermanentClipping (w -> w_fd, cx, cy, cw, ch);
+    SetPermanentClipping (w->w_fd, cx, cy, cw, ch);
 }
 
 
-static  Redisplay (w, doeb)
-register WINDOW *w;
-int	doeb;
+static void
+Redisplay (WINDOW *w, int doeb)
 {
-    register int    y;
-    short   sx;
-    register struct line   *lp;
+    register int y;
+    short sx;
+    register struct line *lp;
 
-    if (w -> w_fd == NOTOK)
+    if (w->w_fd == NOTOK)
 	return;
 
-    sx = w -> w_eb ? (EWIDTH + ESLOP) : 0;
-    w -> w_height = w -> w_ws.height / w -> w_cheight;
-    if (w -> w_height < 1)
-	w -> w_height = 1;
+    sx = w->w_eb ? (EWIDTH + ESLOP) : 0;
+    w->w_height = w->w_ws.height / w->w_cheight;
+    if (w->w_height < 1)
+	w->w_height = 1;
 
-    w -> w_width = (w -> w_ws.width - (w -> w_eb ? (EWIDTH + ESLOP) : 0))
-	/ w -> w_cwidth;
-    if (w -> w_width < 1)
-	w -> w_width = 1;
+    w->w_width = (w->w_ws.width - (w->w_eb ? (EWIDTH + ESLOP) : 0))
+	/ w->w_cwidth;
+    if (w->w_width < 1)
+	w->w_width = 1;
 
-    SetPosition (w -> w_fd, sx, 0);
-    SetColor (w -> w_fd, VT_White);
-    PaintRectangleInterior (w -> w_fd, w -> w_ws.width, w -> w_ws.height);
+    SetPosition (w->w_fd, sx, 0);
+    SetColor (w->w_fd, VT_White);
+    PaintRectangleInterior (w->w_fd, w->w_ws.width, w->w_ws.height);
 
-    if (w -> w_head) {
-	SetColor (w -> w_fd, VT_Black);
-	for (lp = w -> w_top, y = 0;
-		lp && y < w -> w_height;
-		w -> w_bottom = lp, lp = lp -> l_next, y++) {
-	    SetPosition (w -> w_fd, sx, y * w -> w_cheight + w -> w_cbase);
-	    PaintString (w -> w_fd, VT_STREND, lp -> l_buf);
+    if (w->w_head) {
+	SetColor (w->w_fd, VT_Black);
+	for (lp = w->w_top, y = 0;
+		lp && y < w->w_height;
+		w->w_bottom = lp, lp = lp->l_next, y++) {
+	    SetPosition (w->w_fd, sx, y * w->w_cheight + w->w_cbase);
+	    PaintString (w->w_fd, VT_STREND, lp->l_buf);
 	}
     }
 
-    if (w -> w_eb) {
-	if ((y = EB_LOC (w)) != w -> w_ebloc)
-	    MoveElevator (w -> w_eb, w -> w_ebloc = y);
-	if ((y = EB_SIZE (w)) != w -> w_ebsize)
-	    SizeElevator (w -> w_eb, w -> w_ebsize = y);
+    if (w->w_eb) {
+	if ((y = EB_LOC (w)) != w->w_ebloc)
+	    MoveElevator (w->w_eb, w->w_ebloc = y);
+	if ((y = EB_SIZE (w)) != w->w_ebsize)
+	    SizeElevator (w->w_eb, w->w_ebsize = y);
 	if (doeb)
-	    RefreshElevatorBar (w -> w_eb);
+	    RefreshElevatorBar (w->w_eb);
     }
 
-    Flush (w -> w_fd);
+    Flush (w->w_fd);
 }
 
 
-static int  EB_SIZE (w)
-register WINDOW *w;
+static int
+EB_SIZE (WINDOW *w)
 {
-    register int    i;
+    register int i;
 
-    if (w -> w_head == NULL)
+    if (w->w_head == NULL)
 	return 0;
 
-    if ((i = w -> w_tail -> l_no - w -> w_head -> l_no) <= 0)
+    if ((i = w->w_tail->l_no - w->w_head->l_no) <= 0)
 	return EB_MAX;
 
-    return (((w -> w_bottom -> l_no - w -> w_top -> l_no) * EB_MAX) / i);
+    return (((w->w_bottom->l_no - w->w_top->l_no) * EB_MAX) / i);
 }
 
 
-static int  EB_LOC (w)
-register WINDOW *w;
+static int
+EB_LOC (WINDOW *w)
 {
-    register int    i;
+    register int i;
 
-    if (w -> w_head == NULL)
+    if (w->w_head == NULL)
 	return 0;
 
-    if ((i = w -> w_tail -> l_no - w -> w_head -> l_no) <= 0)
+    if ((i = w->w_tail->l_no - w->w_head->l_no) <= 0)
 	return EB_MAX;
 
-    return (((w -> w_top -> l_no - w -> w_head -> l_no) * EB_MAX) / i);
+    return (((w->w_top->l_no - w->w_head->l_no) * EB_MAX) / i);
 }
 
 /* SIGNALS */
 
-static	SIGinit () {
+static void
+SIGinit (void)
+{
     foreground ();
-    if (ioctl (fileno (stdin), TIOCGETP, (char *) &sg) == NOTOK)
+    if (ioctl (fileno (stdin), TIOCGETP, (char *) &tio) == NOTOK)
 	adios ("failed", "ioctl TIOCGETP");
     if (ioctl (fileno (stdin), TIOCGETC, (char *) &tc) == NOTOK)
 	adios ("failed", "ioctl TIOCGETC");
@@ -1263,11 +1214,12 @@ static	SIGinit () {
 }
 
 
-static  foreground () {
-#ifdef	TIOCGPGRP
-    int     pgrp,
-            tpgrp;
-    RETSIGTYPE     (*tstat) ();
+static void
+foreground (void)
+{
+#ifdef TIOCGPGRP
+    int pgrp, tpgrp;
+    SIGNAL_HANDLER tstat;
 
     if ((pgrp = getpgrp (0)) == NOTOK)
 	adios ("process group", "unable to determine");
@@ -1289,7 +1241,9 @@ static  foreground () {
 }
 
 
-static	sideground () {
+static void
+sideground (void)
+{
 #ifdef	TIOCGPGRP
     signal (SIGTTIN, SIG_DFL);
     signal (SIGTTOU, SIG_DFL);
@@ -1298,8 +1252,8 @@ static	sideground () {
 }
 
 
-static int  ALRMser (sig)
-int     sig;
+static int
+ALRMser (int sig)
 {
      longjmp (PEERctx, DONE);
 }
@@ -1309,14 +1263,14 @@ int     sig;
 /* ARGSUSED */
 #endif	BSD42
 
-static int  PIPEser (sig)
-int	sig;
+static int
+PIPEser (int sig)
 {
 #ifndef	BSD42
     signal (sig, SIG_IGN);
 #endif	BSD42
 
-    adios (NULLCP, "lost peer");
+    adios (NULL, "lost peer");
 }
 
 
@@ -1324,8 +1278,8 @@ int	sig;
 /* ARGSUSED */
 #endif	BSD42
 
-static int  SIGser (sig)
-int     sig;
+static int
+SIGser (int sig)
 {
 #ifndef	BSD42
     signal (sig, SIG_IGN);
@@ -1334,10 +1288,9 @@ int     sig;
     done (1);
 }
 
-/* MISCELLANY */
 
-void	done (status)
-int	status;
+void
+done (int status)
 {
     if (dfd != NOTOK)
 	RemoveStatus (dfd);
@@ -1348,83 +1301,68 @@ int	status;
 }
 
 
-/* VARARGS2 */
-
-static void  adorn (what, fmt, a, b, c, d, e, f)
-char   *what,
-       *fmt,
-       *a,
-       *b,
-       *c,
-       *d,
-       *e,
-       *f;
+static void
+adorn (char *what, char *fmt, ...)
 {
-    char   *cp = invo_name;
+    va_list ap
+    char *cp;
 
+    cp = invo_name;
     invo_name = NULL;
-    advise (what, fmt, a, b, c, d, e, f);
+
+    va_start(ap, fmt);
+    advertise (what, NULL, fmt, ap);
+    va_end(ap);
+
     invo_name = cp;
 }
 
 
-/* VARARGS3 */
-
-void advertise (what, tail, fmt, a, b, c, d, e, f)
-char   *what,
-       *tail,
-       *fmt,
-       *a,
-       *b,
-       *c,
-       *d,
-       *e,
-       *f;
+void
+advertise (char *what, char *tail, va_list ap)
 {
-    int	    eindex = errno;
-    char    buffer[BUFSIZ],
-            err[BUFSIZ];
-    struct iovec    iob[20];
-    register struct iovec  *iov = iob;
+    int	eindex = errno;
+    char buffer[BUFSIZ], err[BUFSIZ];
+    struct iovec iob[20];
+    register struct iovec *iov = iob;
 
     fflush (stdout);
 
     fflush (stderr);
 
     if (invo_name) {
-	iov -> iov_len = strlen (iov -> iov_base = invo_name);
+	iov->iov_len = strlen (iov->iov_base = invo_name);
 	iov++;
-	iov -> iov_len = strlen (iov -> iov_base = ": ");
+	iov->iov_len = strlen (iov->iov_base = ": ");
 	iov++;
     }
     
-    sprintf (buffer, fmt, a, b, c, d, e, f);
-    iov -> iov_len = strlen (iov -> iov_base = buffer);
+    vsprintf (buffer, fmt, ap);
+    iov->iov_len = strlen (iov->iov_base = buffer);
     iov++;
     if (what) {
 	if (*what) {
-	    iov -> iov_len = strlen (iov -> iov_base = " ");
+	    iov->iov_len = strlen (iov->iov_base = " ");
 	    iov++;
-	    iov -> iov_len = strlen (iov -> iov_base = what);
+	    iov->iov_len = strlen (iov->iov_base = what);
 	    iov++;
-	    iov -> iov_len = strlen (iov -> iov_base = ": ");
+	    iov->iov_len = strlen (iov->iov_base = ": ");
 	    iov++;
 	}
-	if (eindex > 0 && eindex < sys_nerr)
-	    iov -> iov_len = strlen (iov -> iov_base = sys_errlist[eindex]);
-	else {
-	    sprintf (err, "Error %d", eindex);
-	    iov -> iov_len = strlen (iov -> iov_base = err);
+	if (!(iov->iov_base = strerror (eindex))) {
+	    sprintf (err, "unknown error %d", eindex);
+	    iov->iov_base = err;
 	}
+	iov->iov_len = strlen (iov->iov_base);
 	iov++;
     }
     if (tail && *tail) {
-	iov -> iov_len = strlen (iov -> iov_base = ", ");
+	iov->iov_len = strlen (iov->iov_base = ", ");
 	iov++;
-	iov -> iov_len = strlen (iov -> iov_base = tail);
+	iov->iov_len = strlen (iov->iov_base = tail);
 	iov++;
     }
-    iov -> iov_len = strlen (iov -> iov_base = "\n");
+    iov->iov_len = strlen (iov->iov_base = "\n");
     iov++;
 
     if (dfd != NOTOK)
@@ -1434,17 +1372,16 @@ char   *what,
 }
 
 
-static	DisplayVector (iov, n)
-register struct iovec   *iov;
-register int     n;
+static void
+DisplayVector (struct iovec *iov, int n)
 {
-    register int    i;
-    register char  *cp;
-    char    buffer[BUFSIZ];
+    register int i;
+    register char *cp;
+    char buffer[BUFSIZ];
 
     for (i = 0, cp = NULL; i < n; i++, iov++) {
-	sprintf (buffer, "%*.*s", iov -> iov_len, iov -> iov_len,
-		iov -> iov_base);
+	sprintf (buffer, "%*.*s", iov->iov_len, iov->iov_len,
+		iov->iov_base);
 	cp = add (buffer, cp);
     }
 
