@@ -1,21 +1,13 @@
 
 /*
- * getbbent.c - subroutines for accessing the BBoards file
+ * getbbent.c -- subroutines for accessing the BBoards file
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
+#include "../../h/nmh.h"
 
-/* LINTLIBRARY */
-
-#include "../../config.h"
-#include "bboards.h"
-
-#ifndef	MMDFONLY
-# include "../../h/nmh.h"
-# include <sys/types.h>
-#else	/* MMDFONLY */
+#ifdef MMDFONLY
 # include "util.h"
 # include "mmdf.h"
 # include "strings.h"
@@ -27,6 +19,8 @@ static char ident[] = "$Id$";
 #include <stdio.h>
 #include <sys/stat.h>
 
+#include "bboards.h"
+
 #ifndef	MMDFONLY
 #define	NOTOK	(-1)
 #define	OK	0
@@ -47,20 +41,20 @@ static char ident[] = "$Id$";
 #define	DSTFILE	".dist"
 #define	MAPFILE ".map"
 
-static int  BBuid = -1;
+static int BBuid = -1;
 
-static unsigned int  BBflags = SB_NULL;
+static unsigned int BBflags = SB_NULL;
 
 static char BBName[BUFSIZ] = BBOARDS;
 static char BBDir[BUFSIZ] = "";
 static char BBData[BUFSIZ] = "";
 
-static  FILE *BBfile = NULL;
+static FILE *BBfile = NULL;
 
-static struct bboard    BB;
-static struct bboard   *bb = &BB;
+static struct bboard BB;
+static struct bboard *bb = &BB;
 
-static int  BBload = 1;
+static int BBload = 1;
 
 static char BBFile[BUFSIZ];
 static char BBArchive[BUFSIZ];
@@ -93,12 +87,15 @@ char *bbs[101];
 
 
 /*
- * prototypes
+ * static prototypes
  */
-static int setpwaux(), getbbitem(), bblose();
-static void BBread();
-static char *getcpy ();
+static int setbbaux (char *, char *);
+static int setpwaux (struct passwd *, char *);
+static void BBread (void);
+static int getbbitem (struct bboard *, char *, int (*)());
+static int  bblose (char *, ...);
 static char *bbskip (char *, char);
+static char *getcpy (char *);
 
 
 int
@@ -160,9 +157,9 @@ setbbaux (char *name, char *file)
 static int
 setpwaux (struct passwd *pw, char *file)
 {
-    strcpy (BBName, pw -> pw_name);
-    BBuid = pw -> pw_uid;
-    strcpy (BBDir, pw -> pw_dir);
+    strcpy (BBName, pw->pw_name);
+    BBuid = pw->pw_uid;
+    strcpy (BBDir, pw->pw_dir);
     sprintf (BBData, "%s/%s",
 	    *file != '/' ? BBDir : "",
 	    *file != '/' ? file : file + 1);
@@ -256,27 +253,27 @@ retry: ;
 	goto retry;
     }
     
-    bb -> bb_name = p;
+    bb->bb_name = p;
     p = q = bbskip (p, COLON);
-    p = bb -> bb_file = bbskip (p, COLON);
-    bb -> bb_archive = bb -> bb_info = bb -> bb_map = "";
-    p = bb -> bb_passwd = bbskip (p, COLON);
+    p = bb->bb_file = bbskip (p, COLON);
+    bb->bb_archive = bb->bb_info = bb->bb_map = "";
+    p = bb->bb_passwd = bbskip (p, COLON);
     p = r = bbskip (p, COLON);
-    p = bb -> bb_addr = bbskip (p, COLON);
-    p = bb -> bb_request = bbskip (p, COLON);
-    p = bb -> bb_relay = bbskip (p, COLON);
+    p = bb->bb_addr = bbskip (p, COLON);
+    p = bb->bb_request = bbskip (p, COLON);
+    p = bb->bb_relay = bbskip (p, COLON);
     p = d = bbskip (p, COLON);
     p = f = bbskip (p, COLON);
     bbskip (p, NEWLINE);
 
-    s = bb -> bb_aka = BBAkas;
+    s = bb->bb_aka = BBAkas;
     while (*q) {
 	*s++ = q;
 	q = bbskip (q, COMMA);
     }
     *s = 0;
 
-    s = bb -> bb_leader = BBLeaders;
+    s = bb->bb_leader = BBLeaders;
     if (*r == 0) {
 	if (!(BBflags & SB_FAST)) {
 	    *s++ = BBName;
@@ -291,7 +288,7 @@ retry: ;
         *s = 0;
     }
 
-    s = bb -> bb_dist = BBDists;
+    s = bb->bb_dist = BBDists;
     while (*d) {
 	*s++ = d;
 	d = bbskip (d, COMMA);
@@ -299,12 +296,12 @@ retry: ;
     *s = 0;
 
     if (*f)
-	sscanf (f, "%o", &bb -> bb_flags);
+	sscanf (f, "%o", &bb->bb_flags);
     else
-	bb -> bb_flags = BB_NULL;
-    bb -> bb_count = bb -> bb_maxima = 0;
-    bb -> bb_date = NULL;
-    bb -> bb_next = bb -> bb_link = bb -> bb_chain = NULL;
+	bb->bb_flags = BB_NULL;
+    bb->bb_count = bb->bb_maxima = 0;
+    bb->bb_date = NULL;
+    bb->bb_next = bb->bb_link = bb->bb_chain = NULL;
 
 #ifdef UCL
 	/*
@@ -348,7 +345,7 @@ getbbnam (char *name)
     if (!setbbent (SB_NULL))
 	return NULL;
     BBload = 0;
-    while ((b = getbbent ()) && strcmp (name, b -> bb_name))
+    while ((b = getbbent ()) && strcmp (name, b->bb_name))
 	continue;
     BBload = 1;
     endbbent ();
@@ -370,7 +367,7 @@ getbbaka (char *aka)
 	return NULL;
     BBload = 0;
     while ((b = getbbent ()) != NULL)
-	for (ap = b -> bb_aka; *ap; ap++)
+	for (ap = b->bb_aka; *ap; ap++)
 	    if (strcmp (aka, *ap) == 0)
 		goto hit;
 hit: ;
@@ -396,65 +393,65 @@ BBread (void)
     if (BBflags & SB_FAST)
 	return;
 
-    p = strchr(bb -> bb_request, '@');
-    r = strchr(bb -> bb_addr, '@');
+    p = strchr(bb->bb_request, '@');
+    r = strchr(bb->bb_addr, '@');
     BBRequest[0] = 0;
 
-    if (*bb -> bb_request == '-')
+    if (*bb->bb_request == '-')
 	if (p == NULL && r && *r == '@')
-	    sprintf (BBRequest, "%s%s%s", bb -> bb_name, bb -> bb_request, r);
+	    sprintf (BBRequest, "%s%s%s", bb->bb_name, bb->bb_request, r);
 	else
-	    sprintf (BBRequest, "%s%s", bb -> bb_name, bb -> bb_request);
+	    sprintf (BBRequest, "%s%s", bb->bb_name, bb->bb_request);
     else
-	if (p == NULL && r && *r == '@' && *bb -> bb_request)
-	    sprintf (BBRequest, "%s%s", bb -> bb_request, r);
+	if (p == NULL && r && *r == '@' && *bb->bb_request)
+	    sprintf (BBRequest, "%s%s", bb->bb_request, r);
 
     if (BBRequest[0])
-	bb -> bb_request = BBRequest;
+	bb->bb_request = BBRequest;
     else
-	if (*bb -> bb_request == 0)
-	    bb -> bb_request = *bb -> bb_addr ? bb -> bb_addr
-		: bb -> bb_leader[0];
+	if (*bb->bb_request == 0)
+	    bb->bb_request = *bb->bb_addr ? bb->bb_addr
+		: bb->bb_leader[0];
 
-    if (*bb -> bb_addr == '@') {
-	sprintf (BBAddr, "%s%s", bb -> bb_name, bb -> bb_addr);
-	bb -> bb_addr = BBAddr;
+    if (*bb->bb_addr == '@') {
+	sprintf (BBAddr, "%s%s", bb->bb_name, bb->bb_addr);
+	bb->bb_addr = BBAddr;
     }
     else
-	if (*bb -> bb_addr == 0)
-	    bb -> bb_addr = bb -> bb_name;
+	if (*bb->bb_addr == 0)
+	    bb->bb_addr = bb->bb_name;
 
-    if (*bb -> bb_file == 0)
+    if (*bb->bb_file == 0)
 	return;
-    if (*bb -> bb_file != '/') {
-	sprintf (BBFile, "%s/%s", BBDir, bb -> bb_file);
-	bb -> bb_file = BBFile;
+    if (*bb->bb_file != '/') {
+	sprintf (BBFile, "%s/%s", BBDir, bb->bb_file);
+	bb->bb_file = BBFile;
     }
 
-    if ((cp = strrchr(bb -> bb_file, '/')) == NULL || *++cp == 0)
-	strcpy (prf, ""), cp = bb -> bb_file;
+    if ((cp = strrchr(bb->bb_file, '/')) == NULL || *++cp == 0)
+	strcpy (prf, ""), cp = bb->bb_file;
     else
-	sprintf (prf, "%.*s", cp - bb -> bb_file, bb -> bb_file);
+	sprintf (prf, "%.*s", cp - bb->bb_file, bb->bb_file);
     if ((dp = strchr(cp, '.')) == NULL)
 	dp = cp + strlen (cp);
 
     sprintf (BBArchive, "%s%s/%s", prf, ARCHIVE, cp);
-    bb -> bb_archive = BBArchive;
+    bb->bb_archive = BBArchive;
     sprintf (BBInfo, "%s.%.*s%s", prf, dp - cp, cp, CNTFILE);
-    bb -> bb_info = BBInfo;
+    bb->bb_info = BBInfo;
     sprintf (BBMap, "%s.%.*s%s", prf, dp - cp, cp, MAPFILE);
-    bb -> bb_map = BBMap;
+    bb->bb_map = BBMap;
 
-    if ((info = fopen (bb -> bb_info, "r")) == NULL)
+    if ((info = fopen (bb->bb_info, "r")) == NULL)
 	return;
 
     if (fgets (line, sizeof line, info) && (i = atoi (line)) > 0)
-	bb -> bb_maxima = (unsigned) i;
+	bb->bb_maxima = (unsigned) i;
     if (!feof (info) && fgets (line, sizeof line, info)) {
 	strcpy (BBDate, line);
 	if (cp = strchr(BBDate, NEWLINE))
 	    *cp = 0;
-	bb -> bb_date = BBDate;
+	bb->bb_date = BBDate;
     }
 
     fclose (info);
@@ -465,8 +462,8 @@ int
 ldrbb (struct bboard *b)
 {
     register char *p, **q, **r;
-    static int  uid = 0,
-                gid = 0;
+    static uid_t uid = 0;
+    static gid_t gid = 0;
     static char username[10] = "";
     register struct passwd *pw;
     register struct group  *gr;
@@ -480,20 +477,20 @@ ldrbb (struct bboard *b)
 	if ((pw = getpwuid (uid = getuid ())) == NULL)
 	    return 0;
 	gid = getgid ();
-	strcpy (username, pw -> pw_name);
+	strcpy (username, pw->pw_name);
     }
 
     if (uid == BBuid)
 	return 1;
 
-    q = b -> bb_leader;
+    q = b->bb_leader;
     while (p = *q++)
 	if (*p == '=') {
 	    if ((gr = getgrnam (++p)) == NULL)
 		continue;
-	    if (gid == gr -> gr_gid)
+	    if (gid == gr->gr_gid)
 		return 1;
-	    r = gr -> gr_mem;
+	    r = gr->gr_mem;
 	    while (p = *r++)
 		if (strcmp (username, p) == 0)
 		    return 1;
@@ -512,11 +509,11 @@ ldrchk (struct bboard *b)
     if (b == NULL)
 	return 0;
 
-    if (*b -> bb_passwd == 0)
+    if (*b->bb_passwd == 0)
 	return 1;
 
-    if (strcmp (b -> bb_passwd,
-		crypt (getpass ("Password: "), b -> bb_passwd)) == 0)
+    if (strcmp (b->bb_passwd,
+		crypt (getpass ("Password: "), b->bb_passwd)) == 0)
 	return 1;
 
     fprintf (stderr, "Sorry\n");
@@ -537,53 +534,53 @@ getbbcpy (struct bboard *bp)
     if (b == NULL)
 	return NULL;
 
-    b -> bb_name = getcpy (bp -> bb_name);
-    b -> bb_file = getcpy (bp -> bb_file);
-    b -> bb_archive = getcpy (bp -> bb_archive);
-    b -> bb_info = getcpy (bp -> bb_info);
-    b -> bb_map = getcpy (bp -> bb_map);
-    b -> bb_passwd = getcpy (bp -> bb_passwd);
-    b -> bb_flags = bp -> bb_flags;
-    b -> bb_count = bp -> bb_count;
-    b -> bb_maxima = bp -> bb_maxima;
-    b -> bb_date = getcpy (bp -> bb_date);
-    b -> bb_addr = getcpy (bp -> bb_addr);
-    b -> bb_request = getcpy (bp -> bb_request);
-    b -> bb_relay = getcpy (bp -> bb_relay);
+    b->bb_name = getcpy (bp->bb_name);
+    b->bb_file = getcpy (bp->bb_file);
+    b->bb_archive = getcpy (bp->bb_archive);
+    b->bb_info = getcpy (bp->bb_info);
+    b->bb_map = getcpy (bp->bb_map);
+    b->bb_passwd = getcpy (bp->bb_passwd);
+    b->bb_flags = bp->bb_flags;
+    b->bb_count = bp->bb_count;
+    b->bb_maxima = bp->bb_maxima;
+    b->bb_date = getcpy (bp->bb_date);
+    b->bb_addr = getcpy (bp->bb_addr);
+    b->bb_request = getcpy (bp->bb_request);
+    b->bb_relay = getcpy (bp->bb_relay);
 
-    for (p = bp -> bb_aka; *p; p++)
+    for (p = bp->bb_aka; *p; p++)
 	continue;
-    b -> bb_aka =
-	q = (char **) calloc ((unsigned) (p - bp -> bb_aka + 1), sizeof *q);
+    b->bb_aka =
+	q = (char **) calloc ((unsigned) (p - bp->bb_aka + 1), sizeof *q);
     if (q == NULL)
 	return NULL;
-    for (p = bp -> bb_aka; *p; *q++ = getcpy (*p++))
+    for (p = bp->bb_aka; *p; *q++ = getcpy (*p++))
 	continue;
     *q = NULL;
 
-    for (p = bp -> bb_leader; *p; p++)
+    for (p = bp->bb_leader; *p; p++)
 	continue;
-    b -> bb_leader =
-	q = (char **) calloc ((unsigned) (p - bp -> bb_leader + 1), sizeof *q);
+    b->bb_leader =
+	q = (char **) calloc ((unsigned) (p - bp->bb_leader + 1), sizeof *q);
     if (q == NULL)
 	return NULL;
-    for (p = bp -> bb_leader; *p; *q++ = getcpy (*p++))
+    for (p = bp->bb_leader; *p; *q++ = getcpy (*p++))
 	continue;
     *q = NULL;
 
-    for (p = bp -> bb_dist; *p; p++)
+    for (p = bp->bb_dist; *p; p++)
 	continue;
-    b -> bb_dist = 
-	q = (char **) calloc ((unsigned) (p - bp -> bb_dist + 1), sizeof *q);
+    b->bb_dist = 
+	q = (char **) calloc ((unsigned) (p - bp->bb_dist + 1), sizeof *q);
     if (q == NULL)
 	return NULL;
-    for (p = bp -> bb_dist; *p; *q++ = getcpy (*p++))
+    for (p = bp->bb_dist; *p; *q++ = getcpy (*p++))
 	continue;
     *q = NULL;
 
-    b -> bb_next = bp -> bb_next;
-    b -> bb_link = bp -> bb_link;
-    b -> bb_chain = bp -> bb_chain;
+    b->bb_next = bp->bb_next;
+    b->bb_link = bp->bb_link;
+    b->bb_chain = bp->bb_chain;
 
     return b;
 }
@@ -596,7 +593,7 @@ getbbdist (struct bboard  *bb, int (*action)())
     register char **dp;
 
     BBErrors[0] = 0;
-    for (dp = bb -> bb_dist; *dp; dp++)
+    for (dp = bb->bb_dist; *dp; dp++)
 	if (result = getbbitem (bb, *dp, action))
 	    return result;
 
@@ -630,10 +627,10 @@ getbbitem (struct bboard *bb, char *item, int (*action)())
 		    break;
 
 		case 0: 
-		    if ((cp = strrchr(bb -> bb_file, '/')) == NULL || *++cp == 0)
-			strcpy (prf, ""), cp = bb -> bb_file;
+		    if ((cp = strrchr(bb->bb_file, '/')) == NULL || *++cp == 0)
+			strcpy (prf, ""), cp = bb->bb_file;
 		    else
-			sprintf (prf, "%.*s", cp - bb -> bb_file, bb -> bb_file);
+			sprintf (prf, "%.*s", cp - bb->bb_file, bb->bb_file);
 		    if ((dp = strchr(cp, '.')) == NULL)
 			dp = cp + strlen (cp);
 		    sprintf (file, "%s.%.*s%s", prf, dp - cp, cp, DSTFILE);
@@ -668,7 +665,7 @@ getbbitem (struct bboard *bb, char *item, int (*action)())
 		*--hp = '@';
 	    }
 	    else {
-		sprintf (mbox, "%s%s", DISTADR, bb -> bb_name);
+		sprintf (mbox, "%s%s", DISTADR, bb->bb_name);
 		strcpy (host, item);
 	    }
 	    if (result = (*action) (mbox, host))
@@ -677,17 +674,17 @@ getbbitem (struct bboard *bb, char *item, int (*action)())
     }
 }
 
-/* VARARGS1 */
 
-static int  bblose (fmt, a, b, c)
-char   *fmt,
-       *a,
-       *b,
-       *c;
+static int
+bblose (char *fmt, ...)
 {
-    if (BBErrors[0] == 0)
-	sprintf (BBErrors, fmt, a, b, c);
+    va_list ap;
 
+    va_start(ap, fmt);
+    if (BBErrors[0] == 0)
+	vsprintf (BBErrors, fmt, ap);
+
+    va_end(ap);
     return NOTOK;
 }
 
@@ -695,7 +692,7 @@ char   *fmt,
 void
 make_lower (char *s1, char *s2)
 {
-    if (s1 == NULL || s2 == NULL)
+    if (!s1 || !s2)
 	return;
 
     for (; *s2; s2++)
