@@ -42,15 +42,15 @@
 
 
 struct adrx {
-    char   *text;
-    char   *pers;
-    char   *mbox;
-    char   *host;
-    char   *path;
-    char   *grp;
-    int     ingrp;
-    char   *note;
-    char   *err;
+    char *text;
+    char *pers;
+    char *mbox;
+    char *host;
+    char *path;
+    char *grp;
+    int ingrp;
+    char *note;
+    char *err;
 };
 
 
@@ -69,6 +69,14 @@ struct adrx {
 #define	MFDLM	8		/* Bad delimiter in MMDF file	 */
 
 
-int     isfrom (), lequal (), mfgets ();
-char   *legal_person ();
-struct adrx *seekadrx (), *getadrx (), *uucpadrx ();
+/*
+ * prototypes
+ */
+int isfrom(char *);
+int lequal (char *, char *);
+int mfgets (FILE *, char **);
+char *legal_person (char *);
+struct adrx *seekadrx (char *);
+struct adrx *getadrx (char *);
+struct adrx *uucpadrx (char *);
+
