@@ -1,18 +1,15 @@
 
 /*
  * mts.c -- definitions for the mail transport system
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif /* lint */
-
-#define nmhetcdir(file) NMHETCDIR#file
-
 #include "../../h/nmh.h"
 
-#undef	NETWORK
+#define nmhetcdir(file) NMHETCDIR#file
 
+#undef NETWORK
 #if defined(BSD41A) || defined(BSD42) || defined(SOCKETS)
 # define NETWORK
 #endif
@@ -22,7 +19,7 @@ static char ident[] = "$Id$";
 #include "mts.h"
 
 #ifdef NETWORK
-# if defined(BSD42) || defined(SOCKETS)
+# ifdef SOCKETS
 #  include <netdb.h>
 # endif
 #else	/* NETWORK */
@@ -38,119 +35,121 @@ static char ident[] = "$Id$";
 #define	NOTOK	(-1)
 #define	OK	0
 
-#define	NULLCP	((char *) 0)
-
 extern int errno;
 
-static char *tailor_value ();
-
-#ifdef SYS5
-struct passwd *getpwuid ();
-#endif
+/*
+ * static prototypes
+ */
+static char *tailor_value (char *);
 
 /*
-   *mmdfldir and *uucpldir are the maildrop directories.  If maildrops
-   are kept in the user's home directory, then these should be empty
-   strings.  In this case, the appropriate ...lfil array should contain
-   the name of the file in the user's home directory.  Usually, this is
-   something like ".mail".
+ * *mmdfldir and *uucpldir are the maildrop directories.  If maildrops
+ * are kept in the user's home directory, then these should be empty
+ * strings.  In this case, the appropriate ...lfil array should contain
+ * the name of the file in the user's home directory.  Usually, this is
+ * something like ".mail".
  */
 
-static char *mtstailor = nmhetcdir(/mtstailor);
+/*
+ * nmh mail transport interface customization file
+ */
+static char *mtsconf = nmhetcdir(/mts.conf);
+
+static char *localname = "";
+static char *localdomain = "";
+static char *systemname = "";
 
-static char    *localname = "";
-static char    *localdomain = "";
-static char    *systemname = "";
 #ifdef	MF
-static char    *UUCPchan = "";
+static char *UUCPchan = "";
 #endif /* MF */
-char    *mmdfldir = MAILSPOOL;
-char    *mmdflfil = "";
-char    *uucpldir = "/usr/spool/mail";
-char    *uucplfil = "";
 
+char *mmdfldir = MAILSPOOL;
+char *mmdflfil = "";
+char *uucpldir = "/usr/spool/mail";
+char *uucplfil = "";
 
-char    *mmdlm1 = "\001\001\001\001\n";
-char    *mmdlm2 = "\001\001\001\001\n";
+char *mmdlm1 = "\001\001\001\001\n";
+char *mmdlm2 = "\001\001\001\001\n";
 
-
-static int  MMailids = 0;
+static int MMailids = 0;
 static char *mmailid = "0";
 
-
 #ifdef MF
 char *umincproc = nmhetcdir(/uminc);
-#else /* MF */
+#else
 char *umincproc = NULL;
-#endif /* MF */
+#endif
 
-
-int	lockstyle = LOK_UNIX;
+int lockstyle = LOK_UNIX;
 static char *lkstyle = "0";
-char   *lockldir = "";
+char *lockldir = "";
 
-/* MTS specific variables */
+/*
+ * MTS specific variables
+ */
 
-#ifdef	MHMTS
-char   *Mailqdir = "/usr/spool/netmail";
-char   *TMailqdir = "/usr/tmp";
-int     Syscpy = 1;
+#ifdef MHMTS
+char *Mailqdir = "/usr/spool/netmail";
+char *TMailqdir = "/usr/tmp";
+int Syscpy = 1;
 static char *syscpy = "1";
-char   *Overseer = "root";
-char   *Mailer = "root";
-char   *Fromtmp = "/tmp/rml.f.XXXXXX";
-char   *Msgtmp = "/tmp/rml.m.XXXXXX";
-char   *Errtmp = "/tmp/rml.e.XXXXXX";
-int     Tmpmode = 0600;
+char *Overseer = "root";
+char *Mailer = "root";
+char *Fromtmp = "/tmp/rml.f.XXXXXX";
+char *Msgtmp = "/tmp/rml.m.XXXXXX";
+char *Errtmp = "/tmp/rml.e.XXXXXX";
+int Tmpmode = 0600;
 static char *tmpmode = "0600";
-char   *Okhosts = nmhetcdir(/Rmail.OkHosts);
-char   *Okdests = nmhetcdir(/Rmail.OkDests);
+char *Okhosts = nmhetcdir(/Rmail.OkHosts);
+char *Okdests = nmhetcdir(/Rmail.OkDests);
 #endif /* MHMTS */
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
 #endif /* MMDFMTS */
 
-#ifdef	SENDMTS
-char   *hostable = nmhetcdir(/hosts);
-char   *sendmail = SENDMAILPATH;
+#ifdef SENDMTS
+char *hostable = nmhetcdir(/hosts);
+char *sendmail = SENDMAILPATH;
 #endif /* SENDMTS */
 
+/*
+ * SMTP/POP stuff
+ */
+char *clientname = "";
+char *servers = "localhost \01localnet";
+char *pophost = "";
 
-/* SMTP/POP stuff */
-
-char   *clientname = "";
-char   *servers = "localhost \01localnet";
-char   *pophost = "";
+/*
+ * BBoards-specific variables
+ */
+char *bb_domain = "";
 
 
-/* BBoards-specific variables */
-
-char   *bb_domain = "";
-
-
-/* POP BBoards-specific variables */
-
+/*
+ * POP BBoards-specific variables
+ */
 #ifdef	BPOP
-char    *popbbhost = "";
-char    *popbbuser = "";
-char    *popbblist = nmhetcdir(/hosts.popbb);
+char *popbbhost = "";
+char *popbbuser = "";
+char *popbblist = nmhetcdir(/hosts.popbb);
 #endif /* BPOP */
 
-
-/* MailDelivery */
-
+/*
+ * MailDelivery
+ */
 char *maildelivery = nmhetcdir(/maildelivery);
 
 
-/* Aliasing Facility (doesn't belong here) */
-
-int	Everyone = NOTOK;
+/*
+ * Aliasing Facility (doesn't belong here)
+ */
+int Everyone = NOTOK;
 static char *everyone = "-1";
-char   *NoShell = "";
+char *NoShell = "";
 
 /*
- *  Customize the MTS settings for MH by adjusting the file
- *  mtstailor in the mh etc directory.
+ * Customize the MTS settings for nmh by adjusting the file
+ * mts.conf in the nmh etc directory.
  */
 
 static  struct bind {
@@ -219,12 +218,12 @@ static  struct bind {
     NULL
 };
 
+
 /*
  * I'd like to use m_getfld() here, but not all programs
  * loading mts.o may be MH-style programs...
  */
 
-
 void
 mts_init (char *name)
 {
@@ -234,7 +233,7 @@ mts_init (char *name)
     register FILE *fp;
     static int inited = 0;
 
-    if (inited++ || (fp = fopen (mtstailor, "r")) == NULL)
+    if (inited++ || (fp = fopen (mtsconf, "r")) == NULL)
 	return;
 
     while (fgets (buffer, sizeof buffer, fp)) {
@@ -249,11 +248,11 @@ mts_init (char *name)
 	while (isspace (*bp))
 	    *bp++ = 0;
 
-	for (b = binds; b -> keyword; b++)
-	    if (strcmp (buffer, b -> keyword) == 0)
+	for (b = binds; b->keyword; b++)
+	    if (strcmp (buffer, b->keyword) == 0)
 		break;
-	if (b -> keyword && (cp = tailor_value (bp)))
-	    *b -> value = cp;
+	if (b->keyword && (cp = tailor_value (bp)))
+	    *b->value = cp;
     }
 
     fclose (fp);
@@ -357,7 +356,7 @@ LocalName (void)
     sethostent (1);
 #endif
     if (hp = gethostbyname (buffer))
-	strcpy (buffer, hp -> h_name);
+	strcpy (buffer, hp->h_name);
 #endif /* BSD42 or SOCKETS */
 #else /* not NETWORK */
 #ifndef	SYS5
@@ -442,7 +441,7 @@ getusr (void)
 {
     register char *cp, *np;
 #ifdef KPOP
-    int uid;
+    uid_t uid;
 #endif /* KPOP */
     register struct passwd *pw;
 
@@ -451,30 +450,30 @@ getusr (void)
 
 #ifndef KPOP
     if ((pw = getpwuid (getuid ())) == NULL
-	    || pw -> pw_name == NULL
-	    || *pw -> pw_name == NULL) {
+	    || pw->pw_name == NULL
+	    || *pw->pw_name == NULL) {
 #else /* KPOP */
     uid = getuid ();
     if (uid == geteuid () && (cp = getenv ("USER")) != NULL
 	&& (pw = getpwnam (cp)) != NULL)
       strcpy (username, cp);
     else if ((pw = getpwuid (uid)) == NULL
-	     || pw -> pw_name == NULL
-	     || *pw -> pw_name == '\0') {
+	     || pw->pw_name == NULL
+	     || *pw->pw_name == '\0') {
 #endif /* KPOP */
 	strcpy (username, "unknown");
 	sprintf (fullname, "The Unknown User-ID (%d)", getuid ());
 	return username;
     }
 
-    np = pw -> pw_gecos;
+    np = pw->pw_gecos;
 #ifndef	GCOS_HACK
     for (cp = fullname; *np && *np != (MMailids ? '<' : ','); *cp++ = *np++)
 	continue;
 #else
     for (cp = fullname; *np && *np != (MMailids ? '<' : ','); )
 	if (*np == '&')	{	/* blech! */
-	    strcpy(cp, pw -> pw_name);
+	    strcpy(cp, pw->pw_name);
 	    *cp = toupper(*cp);
 	    while (*cp)
 		cp++;
@@ -492,7 +491,7 @@ getusr (void)
 	*cp = '\0';
     }
     if (MMailids == 0 || *np == '\0')
-	strcpy (username, pw -> pw_name);
+	strcpy (username, pw->pw_name);
 
     if ((cp = getenv ("SIGNATURE")) && *cp)
 	strcpy (fullname, cp);
@@ -515,64 +514,3 @@ getfullname (void)
     return fullname;
 }
 
-/* COMMENTED OUT */
-
-#if 0
-/* version of dup2 for systems without it */
-
-#include <fcntl.h>
-
-int
-dup2 (int d1, int d2)
-{
-    int d;
-
-    if (d1 == d2)
-	return OK;
-
-    close (d2);
-    if ((d = fcntl (d1, F_DUPFD, d2)) == NOTOK)
-	return NOTOK;
-    if (d == d2)
-	return OK;
-
-    errno = 0;
-    return NOTOK;
-}
-
-#endif
-
-#if 0
-/* version of dup2 for systems without it */
-/* (recursive version)                    */
-
-int
-dup2 (int d1, int d2)
-{
-    if (d1 == d2)
-	return OK;
-
-    close (d2);
-    return dup2aux (d1, d2);
-}
-
-
-static int
-dup2aux (int d1, int d2)
-{
-    int d, i, eindex;
-
-    if ((d = dup (d1)) == NOTOK)
-	return NOTOK;
-    if (d == d2)
-	return OK;
-
-    i = dup2aux (d1, d2);
-    eindex = errno;
-    close (d);
-    errno = eindex;
-    return i;
-}
-
-#endif
-
