@@ -1,12 +1,10 @@
 
 /*
  * dtime.c -- routines to do ``ARPA-style'' time structures
+ *
+ * $Id$
  */
 
-#ifndef	lint
-static char ident[] = "$Id$";
-#endif	/* lint */
-
 #include "../../h/nmh.h"
 
 #include "tws.h"
@@ -22,15 +20,15 @@ static char ident[] = "$Id$";
 # include <sys/timeb.h>
 #endif	/* !defined(SYS5) && !defined(ZONEINFO) */
 
-#ifdef _AIX
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
 #else
-# ifdef	BSD42
-#  include <sys/time.h>
-# else	/* BSD42 */
+# ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
+# else
 #  include <time.h>
-# endif	/* BSD42 */
+# endif
 #endif
 
 #ifdef SYS5
@@ -46,7 +44,6 @@ extern char *tzname[];
 #define	dysize(y)	\
 	(((y) % 4) ? 365 : (((y) % 100) ? 366 : (((y) % 400) ? 365 : 366)))
 
-
 char *tw_moty[] = {
     "Jan", "Feb", "Mar", "Apr", "May", "Jun",
     "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", NULL
@@ -131,9 +128,9 @@ dctime (struct tws *tw)
 	return NULL;
 
     sprintf (buffer, "%.3s %.3s %02d %02d:%02d:%02d %.4d\n",
-	    tw_dotw[tw -> tw_wday], tw_moty[tw -> tw_mon], tw -> tw_mday,
-	    tw -> tw_hour, tw -> tw_min, tw -> tw_sec,
-	    tw -> tw_year >= 100 ? tw -> tw_year : CENTURY + tw -> tw_year);
+	    tw_dotw[tw->tw_wday], tw_moty[tw->tw_mon], tw->tw_mday,
+	    tw->tw_hour, tw->tw_min, tw->tw_sec,
+	    tw->tw_year >= 100 ? tw->tw_year : CENTURY + tw->tw_year);
 
     return buffer;
 }
@@ -165,15 +162,15 @@ dlocaltime (long *clock)
     tw.tw_flags = TW_NULL;
 
     tm = localtime (clock);
-    tw.tw_sec = tm -> tm_sec;
-    tw.tw_min = tm -> tm_min;
-    tw.tw_hour = tm -> tm_hour;
-    tw.tw_mday = tm -> tm_mday;
-    tw.tw_mon = tm -> tm_mon;
-    tw.tw_year = tm -> tm_year + CENTURY;
-    tw.tw_wday = tm -> tm_wday;
-    tw.tw_yday = tm -> tm_yday;
-    if (tm -> tm_isdst)
+    tw.tw_sec  = tm->tm_sec;
+    tw.tw_min  = tm->tm_min;
+    tw.tw_hour = tm->tm_hour;
+    tw.tw_mday = tm->tm_mday;
+    tw.tw_mon  = tm->tm_mon;
+    tw.tw_year = tm->tm_year + CENTURY;
+    tw.tw_wday = tm->tm_wday;
+    tw.tw_yday = tm->tm_yday;
+    if (tm->tm_isdst)
 	tw.tw_flags |= TW_DST;
 
 #ifdef SYS5
@@ -209,15 +206,15 @@ dgmtime (long *clock)
     tw.tw_flags = TW_NULL;
 
     tm = gmtime (clock);
-    tw.tw_sec = tm -> tm_sec;
-    tw.tw_min = tm -> tm_min;
-    tw.tw_hour = tm -> tm_hour;
-    tw.tw_mday = tm -> tm_mday;
-    tw.tw_mon = tm -> tm_mon;
-    tw.tw_year = tm -> tm_year + CENTURY;
-    tw.tw_wday = tm -> tm_wday;
-    tw.tw_yday = tm -> tm_yday;
-    if (tm -> tm_isdst)
+    tw.tw_sec  = tm->tm_sec;
+    tw.tw_min  = tm->tm_min;
+    tw.tw_hour = tm->tm_hour;
+    tw.tw_mday = tm->tm_mday;
+    tw.tw_mon  = tm->tm_mon;
+    tw.tw_year = tm->tm_year + CENTURY;
+    tw.tw_wday = tm->tm_wday;
+    tw.tw_yday = tm->tm_yday;
+    if (tm->tm_isdst)
 	tw.tw_flags |= TW_DST;
     tw.tw_zone = 0;
     tw.tw_flags &= ~TW_SDAY, tw.tw_flags |= TW_SEXP;
@@ -241,19 +238,19 @@ dasctime (struct tws *tw, int flags)
     if ((tw->tw_flags & TW_SZONE) == TW_SZNIL)
 	    result[0] = '\0';
     else
-	    sprintf(result, " %s", dtimezone(tw -> tw_zone, tw->tw_flags | flags));
+	    sprintf(result, " %s", dtimezone(tw->tw_zone, tw->tw_flags | flags));
     sprintf(buffer, "%02d %s %0*d %02d:%02d:%02d%s",
 	    tw->tw_mday, tw_moty[tw->tw_mon],
-	    tw -> tw_year < 100 ? 2 : 4, tw -> tw_year,
+	    tw->tw_year < 100 ? 2 : 4, tw->tw_year,
 	    tw->tw_hour, tw->tw_min, tw->tw_sec, result);
 
-    if ((tw -> tw_flags & TW_SDAY) == TW_SEXP)
-	sprintf (result, "%s, %s", tw_dotw[tw -> tw_wday], buffer);
+    if ((tw->tw_flags & TW_SDAY) == TW_SEXP)
+	sprintf (result, "%s, %s", tw_dotw[tw->tw_wday], buffer);
     else
-	if ((tw -> tw_flags & TW_SDAY) == TW_SNIL)
+	if ((tw->tw_flags & TW_SDAY) == TW_SNIL)
 	    strcpy (result, buffer);
 	else
-	    sprintf (result, "%s (%s)", buffer, tw_dotw[tw -> tw_wday]);
+	    sprintf (result, "%s (%s)", buffer, tw_dotw[tw->tw_wday]);
 
     return result;
 }
@@ -282,9 +279,9 @@ dtimezone (int offset, int flags)
 	return ((flags & TW_DST) ? tzname[1] : tzname[0]);
     }
 #else
-	for (z = zones; z -> std; z++)
-	    if (z -> shift == hours)
-		return (z -> dst && (flags & TW_DST) ? z -> dst : z -> std);
+	for (z = zones; z->std; z++)
+	    if (z->shift == hours)
+		return (z->dst && (flags & TW_DST) ? z->dst : z->std);
 #endif
 
 #if	defined(DSTXXX)
@@ -300,17 +297,17 @@ void
 twscopy (struct tws *tb, struct tws *tw)
 {
 #ifdef	notdef
-    tb -> tw_sec = tw -> tw_sec;
-    tb -> tw_min = tw -> tw_min;
-    tb -> tw_hour = tw -> tw_hour;
-    tb -> tw_mday = tw -> tw_mday;
-    tb -> tw_mon = tw -> tw_mon;
-    tb -> tw_year = tw -> tw_year;
-    tb -> tw_wday = tw -> tw_wday;
-    tb -> tw_yday = tw -> tw_yday;
-    tb -> tw_zone = tw -> tw_zone;
-    tb -> tw_clock = tw -> tw_clock;
-    tb -> tw_flags = tw -> tw_flags;
+    tb->tw_sec   = tw->tw_sec;
+    tb->tw_min   = tw->tw_min;
+    tb->tw_hour  = tw->tw_hour;
+    tb->tw_mday  = tw->tw_mday;
+    tb->tw_mon   = tw->tw_mon;
+    tb->tw_year  = tw->tw_year;
+    tb->tw_wday  = tw->tw_wday;
+    tb->tw_yday  = tw->tw_yday;
+    tb->tw_zone  = tw->tw_zone;
+    tb->tw_clock = tw->tw_clock;
+    tb->tw_flags = tw->tw_flags;
 #else	/* not notdef */
     *tb = *tw;
 #endif	/* not notdef */
@@ -327,7 +324,7 @@ twsort (struct tws *tw1, struct tws *tw2)
     if (tw2->tw_clock == 0L)
 	twclock (tw2);
 
-    return ((c1 = tw1 -> tw_clock) > (c2 = tw2 -> tw_clock) ? 1
+    return ((c1 = tw1->tw_clock) > (c2 = tw2->tw_clock) ? 1
 	    : c1 == c2 ? 0 : -1);
 }
 
@@ -349,16 +346,16 @@ twclock (struct tws *tw)
     int i, sec, min, hour, mday, mon, year;
     register long result;
 
-    if (tw -> tw_clock != 0L)
-	return tw -> tw_clock;
+    if (tw->tw_clock != 0L)
+	return tw->tw_clock;
 
-    if ((sec = tw -> tw_sec) < 0 || sec > 59
-	    || (min = tw -> tw_min) < 0 || min > 59
-	    || (hour = tw -> tw_hour) < 0 || hour > 23
-	    || (mday = tw -> tw_mday) < 1 || mday > 31
-	    || (mon = tw -> tw_mon + 1) < 1 || mon > 12)
-	return (tw -> tw_clock = -1L);
-    year = tw -> tw_year;
+    if ((sec = tw->tw_sec) < 0 || sec > 59
+	    || (min = tw->tw_min) < 0 || min > 59
+	    || (hour = tw->tw_hour) < 0 || hour > 23
+	    || (mday = tw->tw_mday) < 1 || mday > 31
+	    || (mon = tw->tw_mon + 1) < 1 || mon > 12)
+	return (tw->tw_clock = -1L);
+    year = tw->tw_year;
 
     result = 0L;
     if (year < 100)
@@ -373,17 +370,17 @@ twclock (struct tws *tw)
     result = 24 * result + hour;
     result = 60 * result + min;
     result = 60 * result + sec;
-    result -= 60 * tw -> tw_zone;
-    if (tw -> tw_flags & TW_DST)
+    result -= 60 * tw->tw_zone;
+    if (tw->tw_flags & TW_DST)
 	result -= 60 * 60;
 
-    return (tw -> tw_clock = result);
+    return (tw->tw_clock = result);
 }
 
 
 /*
  *    Simple calculation of day of the week.  Algorithm used is Zeller's
- *    congruence.  Currently, we assume if tw -> tw_year < 100
+ *    congruence.  Currently, we assume if tw->tw_year < 100
  *    then the century is CENTURY.
  */
 
